filecategorygen

package
v1.31.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Generator

type Generator struct {
	SchemaPath string
	OutputPath string
	Package    string
}

Generator emits the schema-to-file-category lookup used by file persistence.

func New

func New(schemaPath, outputPath string) *Generator

New creates a new file category generator.

func (*Generator) Generate

func (g *Generator) Generate(flags ...string) error

Generate reads schema annotations and writes the generated lookup file.

func (*Generator) Hook

func (g *Generator) Hook() gen.Hook

Hook allows the generator to run in the post-generation hook pipeline.

Jump to