Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Asset) predicate.Asset
- func AssetTypeEQ(v enums.AssetType) predicate.Asset
- func AssetTypeIn(vs ...enums.AssetType) predicate.Asset
- func AssetTypeNEQ(v enums.AssetType) predicate.Asset
- func AssetTypeNotIn(vs ...enums.AssetType) predicate.Asset
- func AssetTypeValidator(at enums.AssetType) error
- func CategoriesIsNil() predicate.Asset
- func CategoriesNotNil() predicate.Asset
- func Cpe(v string) predicate.Asset
- func CpeContains(v string) predicate.Asset
- func CpeContainsFold(v string) predicate.Asset
- func CpeEQ(v string) predicate.Asset
- func CpeEqualFold(v string) predicate.Asset
- func CpeGT(v string) predicate.Asset
- func CpeGTE(v string) predicate.Asset
- func CpeHasPrefix(v string) predicate.Asset
- func CpeHasSuffix(v string) predicate.Asset
- func CpeIn(vs ...string) predicate.Asset
- func CpeIsNil() predicate.Asset
- func CpeLT(v string) predicate.Asset
- func CpeLTE(v string) predicate.Asset
- func CpeNEQ(v string) predicate.Asset
- func CpeNotIn(vs ...string) predicate.Asset
- func CpeNotNil() predicate.Asset
- func CreatedAt(v time.Time) predicate.Asset
- func CreatedAtEQ(v time.Time) predicate.Asset
- func CreatedAtGT(v time.Time) predicate.Asset
- func CreatedAtGTE(v time.Time) predicate.Asset
- func CreatedAtIn(vs ...time.Time) predicate.Asset
- func CreatedAtIsNil() predicate.Asset
- func CreatedAtLT(v time.Time) predicate.Asset
- func CreatedAtLTE(v time.Time) predicate.Asset
- func CreatedAtNEQ(v time.Time) predicate.Asset
- func CreatedAtNotIn(vs ...time.Time) predicate.Asset
- func CreatedAtNotNil() predicate.Asset
- func CreatedBy(v string) predicate.Asset
- func CreatedByContains(v string) predicate.Asset
- func CreatedByContainsFold(v string) predicate.Asset
- func CreatedByEQ(v string) predicate.Asset
- func CreatedByEqualFold(v string) predicate.Asset
- func CreatedByGT(v string) predicate.Asset
- func CreatedByGTE(v string) predicate.Asset
- func CreatedByHasPrefix(v string) predicate.Asset
- func CreatedByHasSuffix(v string) predicate.Asset
- func CreatedByIn(vs ...string) predicate.Asset
- func CreatedByIsNil() predicate.Asset
- func CreatedByLT(v string) predicate.Asset
- func CreatedByLTE(v string) predicate.Asset
- func CreatedByNEQ(v string) predicate.Asset
- func CreatedByNotIn(vs ...string) predicate.Asset
- func CreatedByNotNil() predicate.Asset
- func DeletedAt(v time.Time) predicate.Asset
- func DeletedAtEQ(v time.Time) predicate.Asset
- func DeletedAtGT(v time.Time) predicate.Asset
- func DeletedAtGTE(v time.Time) predicate.Asset
- func DeletedAtIn(vs ...time.Time) predicate.Asset
- func DeletedAtIsNil() predicate.Asset
- func DeletedAtLT(v time.Time) predicate.Asset
- func DeletedAtLTE(v time.Time) predicate.Asset
- func DeletedAtNEQ(v time.Time) predicate.Asset
- func DeletedAtNotIn(vs ...time.Time) predicate.Asset
- func DeletedAtNotNil() predicate.Asset
- func DeletedBy(v string) predicate.Asset
- func DeletedByContains(v string) predicate.Asset
- func DeletedByContainsFold(v string) predicate.Asset
- func DeletedByEQ(v string) predicate.Asset
- func DeletedByEqualFold(v string) predicate.Asset
- func DeletedByGT(v string) predicate.Asset
- func DeletedByGTE(v string) predicate.Asset
- func DeletedByHasPrefix(v string) predicate.Asset
- func DeletedByHasSuffix(v string) predicate.Asset
- func DeletedByIn(vs ...string) predicate.Asset
- func DeletedByIsNil() predicate.Asset
- func DeletedByLT(v string) predicate.Asset
- func DeletedByLTE(v string) predicate.Asset
- func DeletedByNEQ(v string) predicate.Asset
- func DeletedByNotIn(vs ...string) predicate.Asset
- func DeletedByNotNil() predicate.Asset
- func Description(v string) predicate.Asset
- func DescriptionContains(v string) predicate.Asset
- func DescriptionContainsFold(v string) predicate.Asset
- func DescriptionEQ(v string) predicate.Asset
- func DescriptionEqualFold(v string) predicate.Asset
- func DescriptionGT(v string) predicate.Asset
- func DescriptionGTE(v string) predicate.Asset
- func DescriptionHasPrefix(v string) predicate.Asset
- func DescriptionHasSuffix(v string) predicate.Asset
- func DescriptionIn(vs ...string) predicate.Asset
- func DescriptionIsNil() predicate.Asset
- func DescriptionLT(v string) predicate.Asset
- func DescriptionLTE(v string) predicate.Asset
- func DescriptionNEQ(v string) predicate.Asset
- func DescriptionNotIn(vs ...string) predicate.Asset
- func DescriptionNotNil() predicate.Asset
- func HasBlockedGroups() predicate.Asset
- func HasBlockedGroupsWith(preds ...predicate.Group) predicate.Asset
- func HasControls() predicate.Asset
- func HasControlsWith(preds ...predicate.Control) predicate.Asset
- func HasEditors() predicate.Asset
- func HasEditorsWith(preds ...predicate.Group) predicate.Asset
- func HasEntities() predicate.Asset
- func HasEntitiesWith(preds ...predicate.Entity) predicate.Asset
- func HasOwner() predicate.Asset
- func HasOwnerWith(preds ...predicate.Organization) predicate.Asset
- func HasScans() predicate.Asset
- func HasScansWith(preds ...predicate.Scan) predicate.Asset
- func HasViewers() predicate.Asset
- func HasViewersWith(preds ...predicate.Group) predicate.Asset
- func ID(id string) predicate.Asset
- func IDContainsFold(id string) predicate.Asset
- func IDEQ(id string) predicate.Asset
- func IDEqualFold(id string) predicate.Asset
- func IDGT(id string) predicate.Asset
- func IDGTE(id string) predicate.Asset
- func IDIn(ids ...string) predicate.Asset
- func IDLT(id string) predicate.Asset
- func IDLTE(id string) predicate.Asset
- func IDNEQ(id string) predicate.Asset
- func IDNotIn(ids ...string) predicate.Asset
- func Identifier(v string) predicate.Asset
- func IdentifierContains(v string) predicate.Asset
- func IdentifierContainsFold(v string) predicate.Asset
- func IdentifierEQ(v string) predicate.Asset
- func IdentifierEqualFold(v string) predicate.Asset
- func IdentifierGT(v string) predicate.Asset
- func IdentifierGTE(v string) predicate.Asset
- func IdentifierHasPrefix(v string) predicate.Asset
- func IdentifierHasSuffix(v string) predicate.Asset
- func IdentifierIn(vs ...string) predicate.Asset
- func IdentifierIsNil() predicate.Asset
- func IdentifierLT(v string) predicate.Asset
- func IdentifierLTE(v string) predicate.Asset
- func IdentifierNEQ(v string) predicate.Asset
- func IdentifierNotIn(vs ...string) predicate.Asset
- func IdentifierNotNil() predicate.Asset
- func InternalNotes(v string) predicate.Asset
- func InternalNotesContains(v string) predicate.Asset
- func InternalNotesContainsFold(v string) predicate.Asset
- func InternalNotesEQ(v string) predicate.Asset
- func InternalNotesEqualFold(v string) predicate.Asset
- func InternalNotesGT(v string) predicate.Asset
- func InternalNotesGTE(v string) predicate.Asset
- func InternalNotesHasPrefix(v string) predicate.Asset
- func InternalNotesHasSuffix(v string) predicate.Asset
- func InternalNotesIn(vs ...string) predicate.Asset
- func InternalNotesIsNil() predicate.Asset
- func InternalNotesLT(v string) predicate.Asset
- func InternalNotesLTE(v string) predicate.Asset
- func InternalNotesNEQ(v string) predicate.Asset
- func InternalNotesNotIn(vs ...string) predicate.Asset
- func InternalNotesNotNil() predicate.Asset
- func Name(v string) predicate.Asset
- func NameContains(v string) predicate.Asset
- func NameContainsFold(v string) predicate.Asset
- func NameEQ(v string) predicate.Asset
- func NameEqualFold(v string) predicate.Asset
- func NameGT(v string) predicate.Asset
- func NameGTE(v string) predicate.Asset
- func NameHasPrefix(v string) predicate.Asset
- func NameHasSuffix(v string) predicate.Asset
- func NameIn(vs ...string) predicate.Asset
- func NameLT(v string) predicate.Asset
- func NameLTE(v string) predicate.Asset
- func NameNEQ(v string) predicate.Asset
- func NameNotIn(vs ...string) predicate.Asset
- func Not(p predicate.Asset) predicate.Asset
- func Or(predicates ...predicate.Asset) predicate.Asset
- func OwnerID(v string) predicate.Asset
- func OwnerIDContains(v string) predicate.Asset
- func OwnerIDContainsFold(v string) predicate.Asset
- func OwnerIDEQ(v string) predicate.Asset
- func OwnerIDEqualFold(v string) predicate.Asset
- func OwnerIDGT(v string) predicate.Asset
- func OwnerIDGTE(v string) predicate.Asset
- func OwnerIDHasPrefix(v string) predicate.Asset
- func OwnerIDHasSuffix(v string) predicate.Asset
- func OwnerIDIn(vs ...string) predicate.Asset
- func OwnerIDIsNil() predicate.Asset
- func OwnerIDLT(v string) predicate.Asset
- func OwnerIDLTE(v string) predicate.Asset
- func OwnerIDNEQ(v string) predicate.Asset
- func OwnerIDNotIn(vs ...string) predicate.Asset
- func OwnerIDNotNil() predicate.Asset
- func SystemInternalID(v string) predicate.Asset
- func SystemInternalIDContains(v string) predicate.Asset
- func SystemInternalIDContainsFold(v string) predicate.Asset
- func SystemInternalIDEQ(v string) predicate.Asset
- func SystemInternalIDEqualFold(v string) predicate.Asset
- func SystemInternalIDGT(v string) predicate.Asset
- func SystemInternalIDGTE(v string) predicate.Asset
- func SystemInternalIDHasPrefix(v string) predicate.Asset
- func SystemInternalIDHasSuffix(v string) predicate.Asset
- func SystemInternalIDIn(vs ...string) predicate.Asset
- func SystemInternalIDIsNil() predicate.Asset
- func SystemInternalIDLT(v string) predicate.Asset
- func SystemInternalIDLTE(v string) predicate.Asset
- func SystemInternalIDNEQ(v string) predicate.Asset
- func SystemInternalIDNotIn(vs ...string) predicate.Asset
- func SystemInternalIDNotNil() predicate.Asset
- func SystemOwned(v bool) predicate.Asset
- func SystemOwnedEQ(v bool) predicate.Asset
- func SystemOwnedIsNil() predicate.Asset
- func SystemOwnedNEQ(v bool) predicate.Asset
- func SystemOwnedNotNil() predicate.Asset
- func TagsIsNil() predicate.Asset
- func TagsNotNil() predicate.Asset
- func UpdatedAt(v time.Time) predicate.Asset
- func UpdatedAtEQ(v time.Time) predicate.Asset
- func UpdatedAtGT(v time.Time) predicate.Asset
- func UpdatedAtGTE(v time.Time) predicate.Asset
- func UpdatedAtIn(vs ...time.Time) predicate.Asset
- func UpdatedAtIsNil() predicate.Asset
- func UpdatedAtLT(v time.Time) predicate.Asset
- func UpdatedAtLTE(v time.Time) predicate.Asset
- func UpdatedAtNEQ(v time.Time) predicate.Asset
- func UpdatedAtNotIn(vs ...time.Time) predicate.Asset
- func UpdatedAtNotNil() predicate.Asset
- func UpdatedBy(v string) predicate.Asset
- func UpdatedByContains(v string) predicate.Asset
- func UpdatedByContainsFold(v string) predicate.Asset
- func UpdatedByEQ(v string) predicate.Asset
- func UpdatedByEqualFold(v string) predicate.Asset
- func UpdatedByGT(v string) predicate.Asset
- func UpdatedByGTE(v string) predicate.Asset
- func UpdatedByHasPrefix(v string) predicate.Asset
- func UpdatedByHasSuffix(v string) predicate.Asset
- func UpdatedByIn(vs ...string) predicate.Asset
- func UpdatedByIsNil() predicate.Asset
- func UpdatedByLT(v string) predicate.Asset
- func UpdatedByLTE(v string) predicate.Asset
- func UpdatedByNEQ(v string) predicate.Asset
- func UpdatedByNotIn(vs ...string) predicate.Asset
- func UpdatedByNotNil() predicate.Asset
- func ValidColumn(column string) bool
- func Website(v string) predicate.Asset
- func WebsiteContains(v string) predicate.Asset
- func WebsiteContainsFold(v string) predicate.Asset
- func WebsiteEQ(v string) predicate.Asset
- func WebsiteEqualFold(v string) predicate.Asset
- func WebsiteGT(v string) predicate.Asset
- func WebsiteGTE(v string) predicate.Asset
- func WebsiteHasPrefix(v string) predicate.Asset
- func WebsiteHasSuffix(v string) predicate.Asset
- func WebsiteIn(vs ...string) predicate.Asset
- func WebsiteIsNil() predicate.Asset
- func WebsiteLT(v string) predicate.Asset
- func WebsiteLTE(v string) predicate.Asset
- func WebsiteNEQ(v string) predicate.Asset
- func WebsiteNotIn(vs ...string) predicate.Asset
- func WebsiteNotNil() predicate.Asset
- type OrderOption
- func ByAssetType(opts ...sql.OrderTermOption) OrderOption
- func ByBlockedGroups(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByBlockedGroupsCount(opts ...sql.OrderTermOption) OrderOption
- func ByControls(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByControlsCount(opts ...sql.OrderTermOption) OrderOption
- func ByCpe(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByEditors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEditorsCount(opts ...sql.OrderTermOption) OrderOption
- func ByEntities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEntitiesCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIdentifier(opts ...sql.OrderTermOption) OrderOption
- func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByScans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByScansCount(opts ...sql.OrderTermOption) OrderOption
- func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption
- func BySystemOwned(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByViewers(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByViewersCount(opts ...sql.OrderTermOption) OrderOption
- func ByWebsite(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the asset type in the database. Label = "asset" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldSystemOwned holds the string denoting the system_owned field in the database. FieldSystemOwned = "system_owned" // FieldInternalNotes holds the string denoting the internal_notes field in the database. FieldInternalNotes = "internal_notes" // FieldSystemInternalID holds the string denoting the system_internal_id field in the database. FieldSystemInternalID = "system_internal_id" // FieldAssetType holds the string denoting the asset_type field in the database. FieldAssetType = "asset_type" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldIdentifier holds the string denoting the identifier field in the database. FieldIdentifier = "identifier" // FieldWebsite holds the string denoting the website field in the database. FieldWebsite = "website" // FieldCpe holds the string denoting the cpe field in the database. FieldCpe = "cpe" // FieldCategories holds the string denoting the categories field in the database. FieldCategories = "categories" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // EdgeBlockedGroups holds the string denoting the blocked_groups edge name in mutations. EdgeBlockedGroups = "blocked_groups" // EdgeEditors holds the string denoting the editors edge name in mutations. EdgeEditors = "editors" // EdgeViewers holds the string denoting the viewers edge name in mutations. EdgeViewers = "viewers" // EdgeScans holds the string denoting the scans edge name in mutations. EdgeScans = "scans" // EdgeEntities holds the string denoting the entities edge name in mutations. EdgeEntities = "entities" // EdgeControls holds the string denoting the controls edge name in mutations. EdgeControls = "controls" // Table holds the table name of the asset in the database. Table = "assets" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "assets" // OwnerInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OwnerInverseTable = "organizations" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "owner_id" // BlockedGroupsTable is the table that holds the blocked_groups relation/edge. BlockedGroupsTable = "groups" // BlockedGroupsInverseTable is the table name for the Group entity. // It exists in this package in order to avoid circular dependency with the "group" package. BlockedGroupsInverseTable = "groups" // BlockedGroupsColumn is the table column denoting the blocked_groups relation/edge. BlockedGroupsColumn = "asset_blocked_groups" // EditorsTable is the table that holds the editors relation/edge. EditorsTable = "groups" // EditorsInverseTable is the table name for the Group entity. // It exists in this package in order to avoid circular dependency with the "group" package. EditorsInverseTable = "groups" // EditorsColumn is the table column denoting the editors relation/edge. EditorsColumn = "asset_editors" // ViewersTable is the table that holds the viewers relation/edge. ViewersTable = "groups" // ViewersInverseTable is the table name for the Group entity. // It exists in this package in order to avoid circular dependency with the "group" package. ViewersInverseTable = "groups" // ViewersColumn is the table column denoting the viewers relation/edge. ViewersColumn = "asset_viewers" // ScansTable is the table that holds the scans relation/edge. The primary key declared below. ScansTable = "scan_assets" // ScansInverseTable is the table name for the Scan entity. // It exists in this package in order to avoid circular dependency with the "scan" package. ScansInverseTable = "scans" // EntitiesTable is the table that holds the entities relation/edge. The primary key declared below. EntitiesTable = "entity_assets" // EntitiesInverseTable is the table name for the Entity entity. // It exists in this package in order to avoid circular dependency with the "entity" package. EntitiesInverseTable = "entities" // ControlsTable is the table that holds the controls relation/edge. The primary key declared below. ControlsTable = "control_assets" // ControlsInverseTable is the table name for the Control entity. // It exists in this package in order to avoid circular dependency with the "control" package. ControlsInverseTable = "controls" )
const DefaultAssetType enums.AssetType = "TECHNOLOGY"
Variables ¶
var ( // ScansPrimaryKey and ScansColumn2 are the table columns denoting the // primary key for the scans relation (M2M). ScansPrimaryKey = []string{"scan_id", "asset_id"} // EntitiesPrimaryKey and EntitiesColumn2 are the table columns denoting the // primary key for the entities relation (M2M). EntitiesPrimaryKey = []string{"entity_id", "asset_id"} // ControlsPrimaryKey and ControlsColumn2 are the table columns denoting the // primary key for the controls relation (M2M). ControlsPrimaryKey = []string{"control_id", "asset_id"} )
var ( Hooks [10]ent.Hook Interceptors [3]ent.Interceptor Policy ent.Policy // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultTags holds the default value on creation for the "tags" field. DefaultTags []string // DefaultSystemOwned holds the default value on creation for the "system_owned" field. DefaultSystemOwned bool // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldTags, FieldOwnerID, FieldSystemOwned, FieldInternalNotes, FieldSystemInternalID, FieldAssetType, FieldName, FieldDescription, FieldIdentifier, FieldWebsite, FieldCpe, FieldCategories, }
Columns holds all SQL columns for asset fields.
var ForeignKeys = []string{
"finding_assets",
"remediation_assets",
"review_assets",
"risk_assets",
"vulnerability_assets",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "assets" table and are not defined as standalone fields in the schema.
Functions ¶
func AssetTypeEQ ¶
AssetTypeEQ applies the EQ predicate on the "asset_type" field.
func AssetTypeIn ¶
AssetTypeIn applies the In predicate on the "asset_type" field.
func AssetTypeNEQ ¶
AssetTypeNEQ applies the NEQ predicate on the "asset_type" field.
func AssetTypeNotIn ¶
AssetTypeNotIn applies the NotIn predicate on the "asset_type" field.
func AssetTypeValidator ¶
AssetTypeValidator is a validator for the "asset_type" field enum values. It is called by the builders before save.
func CategoriesIsNil ¶
CategoriesIsNil applies the IsNil predicate on the "categories" field.
func CategoriesNotNil ¶
CategoriesNotNil applies the NotNil predicate on the "categories" field.
func CpeContains ¶
CpeContains applies the Contains predicate on the "cpe" field.
func CpeContainsFold ¶
CpeContainsFold applies the ContainsFold predicate on the "cpe" field.
func CpeEqualFold ¶
CpeEqualFold applies the EqualFold predicate on the "cpe" field.
func CpeHasPrefix ¶
CpeHasPrefix applies the HasPrefix predicate on the "cpe" field.
func CpeHasSuffix ¶
CpeHasSuffix applies the HasSuffix predicate on the "cpe" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
DescriptionNotNil applies the NotNil predicate on the "description" field.
func HasBlockedGroups ¶
HasBlockedGroups applies the HasEdge predicate on the "blocked_groups" edge.
func HasBlockedGroupsWith ¶
HasBlockedGroupsWith applies the HasEdge predicate on the "blocked_groups" edge with a given conditions (other predicates).
func HasControls ¶
HasControls applies the HasEdge predicate on the "controls" edge.
func HasControlsWith ¶
HasControlsWith applies the HasEdge predicate on the "controls" edge with a given conditions (other predicates).
func HasEditors ¶
HasEditors applies the HasEdge predicate on the "editors" edge.
func HasEditorsWith ¶
HasEditorsWith applies the HasEdge predicate on the "editors" edge with a given conditions (other predicates).
func HasEntities ¶
HasEntities applies the HasEdge predicate on the "entities" edge.
func HasEntitiesWith ¶
HasEntitiesWith applies the HasEdge predicate on the "entities" edge with a given conditions (other predicates).
func HasOwnerWith ¶
func HasOwnerWith(preds ...predicate.Organization) predicate.Asset
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func HasScansWith ¶
HasScansWith applies the HasEdge predicate on the "scans" edge with a given conditions (other predicates).
func HasViewers ¶
HasViewers applies the HasEdge predicate on the "viewers" edge.
func HasViewersWith ¶
HasViewersWith applies the HasEdge predicate on the "viewers" edge with a given conditions (other predicates).
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func Identifier ¶
Identifier applies equality check predicate on the "identifier" field. It's identical to IdentifierEQ.
func IdentifierContains ¶
IdentifierContains applies the Contains predicate on the "identifier" field.
func IdentifierContainsFold ¶
IdentifierContainsFold applies the ContainsFold predicate on the "identifier" field.
func IdentifierEQ ¶
IdentifierEQ applies the EQ predicate on the "identifier" field.
func IdentifierEqualFold ¶
IdentifierEqualFold applies the EqualFold predicate on the "identifier" field.
func IdentifierGT ¶
IdentifierGT applies the GT predicate on the "identifier" field.
func IdentifierGTE ¶
IdentifierGTE applies the GTE predicate on the "identifier" field.
func IdentifierHasPrefix ¶
IdentifierHasPrefix applies the HasPrefix predicate on the "identifier" field.
func IdentifierHasSuffix ¶
IdentifierHasSuffix applies the HasSuffix predicate on the "identifier" field.
func IdentifierIn ¶
IdentifierIn applies the In predicate on the "identifier" field.
func IdentifierIsNil ¶
IdentifierIsNil applies the IsNil predicate on the "identifier" field.
func IdentifierLT ¶
IdentifierLT applies the LT predicate on the "identifier" field.
func IdentifierLTE ¶
IdentifierLTE applies the LTE predicate on the "identifier" field.
func IdentifierNEQ ¶
IdentifierNEQ applies the NEQ predicate on the "identifier" field.
func IdentifierNotIn ¶
IdentifierNotIn applies the NotIn predicate on the "identifier" field.
func IdentifierNotNil ¶
IdentifierNotNil applies the NotNil predicate on the "identifier" field.
func InternalNotes ¶ added in v0.34.0
InternalNotes applies equality check predicate on the "internal_notes" field. It's identical to InternalNotesEQ.
func InternalNotesContains ¶ added in v0.34.0
InternalNotesContains applies the Contains predicate on the "internal_notes" field.
func InternalNotesContainsFold ¶ added in v0.34.0
InternalNotesContainsFold applies the ContainsFold predicate on the "internal_notes" field.
func InternalNotesEQ ¶ added in v0.34.0
InternalNotesEQ applies the EQ predicate on the "internal_notes" field.
func InternalNotesEqualFold ¶ added in v0.34.0
InternalNotesEqualFold applies the EqualFold predicate on the "internal_notes" field.
func InternalNotesGT ¶ added in v0.34.0
InternalNotesGT applies the GT predicate on the "internal_notes" field.
func InternalNotesGTE ¶ added in v0.34.0
InternalNotesGTE applies the GTE predicate on the "internal_notes" field.
func InternalNotesHasPrefix ¶ added in v0.34.0
InternalNotesHasPrefix applies the HasPrefix predicate on the "internal_notes" field.
func InternalNotesHasSuffix ¶ added in v0.34.0
InternalNotesHasSuffix applies the HasSuffix predicate on the "internal_notes" field.
func InternalNotesIn ¶ added in v0.34.0
InternalNotesIn applies the In predicate on the "internal_notes" field.
func InternalNotesIsNil ¶ added in v0.34.0
InternalNotesIsNil applies the IsNil predicate on the "internal_notes" field.
func InternalNotesLT ¶ added in v0.34.0
InternalNotesLT applies the LT predicate on the "internal_notes" field.
func InternalNotesLTE ¶ added in v0.34.0
InternalNotesLTE applies the LTE predicate on the "internal_notes" field.
func InternalNotesNEQ ¶ added in v0.34.0
InternalNotesNEQ applies the NEQ predicate on the "internal_notes" field.
func InternalNotesNotIn ¶ added in v0.34.0
InternalNotesNotIn applies the NotIn predicate on the "internal_notes" field.
func InternalNotesNotNil ¶ added in v0.34.0
InternalNotesNotNil applies the NotNil predicate on the "internal_notes" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func OwnerID ¶
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDContains ¶
OwnerIDContains applies the Contains predicate on the "owner_id" field.
func OwnerIDContainsFold ¶
OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.
func OwnerIDEqualFold ¶
OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.
func OwnerIDGTE ¶
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDHasPrefix ¶
OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.
func OwnerIDHasSuffix ¶
OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.
func OwnerIDIsNil ¶
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLTE ¶
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func SystemInternalID ¶ added in v0.34.0
SystemInternalID applies equality check predicate on the "system_internal_id" field. It's identical to SystemInternalIDEQ.
func SystemInternalIDContains ¶ added in v0.34.0
SystemInternalIDContains applies the Contains predicate on the "system_internal_id" field.
func SystemInternalIDContainsFold ¶ added in v0.34.0
SystemInternalIDContainsFold applies the ContainsFold predicate on the "system_internal_id" field.
func SystemInternalIDEQ ¶ added in v0.34.0
SystemInternalIDEQ applies the EQ predicate on the "system_internal_id" field.
func SystemInternalIDEqualFold ¶ added in v0.34.0
SystemInternalIDEqualFold applies the EqualFold predicate on the "system_internal_id" field.
func SystemInternalIDGT ¶ added in v0.34.0
SystemInternalIDGT applies the GT predicate on the "system_internal_id" field.
func SystemInternalIDGTE ¶ added in v0.34.0
SystemInternalIDGTE applies the GTE predicate on the "system_internal_id" field.
func SystemInternalIDHasPrefix ¶ added in v0.34.0
SystemInternalIDHasPrefix applies the HasPrefix predicate on the "system_internal_id" field.
func SystemInternalIDHasSuffix ¶ added in v0.34.0
SystemInternalIDHasSuffix applies the HasSuffix predicate on the "system_internal_id" field.
func SystemInternalIDIn ¶ added in v0.34.0
SystemInternalIDIn applies the In predicate on the "system_internal_id" field.
func SystemInternalIDIsNil ¶ added in v0.34.0
SystemInternalIDIsNil applies the IsNil predicate on the "system_internal_id" field.
func SystemInternalIDLT ¶ added in v0.34.0
SystemInternalIDLT applies the LT predicate on the "system_internal_id" field.
func SystemInternalIDLTE ¶ added in v0.34.0
SystemInternalIDLTE applies the LTE predicate on the "system_internal_id" field.
func SystemInternalIDNEQ ¶ added in v0.34.0
SystemInternalIDNEQ applies the NEQ predicate on the "system_internal_id" field.
func SystemInternalIDNotIn ¶ added in v0.34.0
SystemInternalIDNotIn applies the NotIn predicate on the "system_internal_id" field.
func SystemInternalIDNotNil ¶ added in v0.34.0
SystemInternalIDNotNil applies the NotNil predicate on the "system_internal_id" field.
func SystemOwned ¶ added in v0.34.0
SystemOwned applies equality check predicate on the "system_owned" field. It's identical to SystemOwnedEQ.
func SystemOwnedEQ ¶ added in v0.34.0
SystemOwnedEQ applies the EQ predicate on the "system_owned" field.
func SystemOwnedIsNil ¶ added in v0.34.0
SystemOwnedIsNil applies the IsNil predicate on the "system_owned" field.
func SystemOwnedNEQ ¶ added in v0.34.0
SystemOwnedNEQ applies the NEQ predicate on the "system_owned" field.
func SystemOwnedNotNil ¶ added in v0.34.0
SystemOwnedNotNil applies the NotNil predicate on the "system_owned" field.
func TagsNotNil ¶
TagsNotNil applies the NotNil predicate on the "tags" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Website ¶
Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.
func WebsiteContains ¶
WebsiteContains applies the Contains predicate on the "website" field.
func WebsiteContainsFold ¶
WebsiteContainsFold applies the ContainsFold predicate on the "website" field.
func WebsiteEqualFold ¶
WebsiteEqualFold applies the EqualFold predicate on the "website" field.
func WebsiteGTE ¶
WebsiteGTE applies the GTE predicate on the "website" field.
func WebsiteHasPrefix ¶
WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.
func WebsiteHasSuffix ¶
WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.
func WebsiteIsNil ¶
WebsiteIsNil applies the IsNil predicate on the "website" field.
func WebsiteLTE ¶
WebsiteLTE applies the LTE predicate on the "website" field.
func WebsiteNEQ ¶
WebsiteNEQ applies the NEQ predicate on the "website" field.
func WebsiteNotIn ¶
WebsiteNotIn applies the NotIn predicate on the "website" field.
func WebsiteNotNil ¶
WebsiteNotNil applies the NotNil predicate on the "website" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Asset queries.
func ByAssetType ¶
func ByAssetType(opts ...sql.OrderTermOption) OrderOption
ByAssetType orders the results by the asset_type field.
func ByBlockedGroups ¶
func ByBlockedGroups(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByBlockedGroups orders the results by blocked_groups terms.
func ByBlockedGroupsCount ¶
func ByBlockedGroupsCount(opts ...sql.OrderTermOption) OrderOption
ByBlockedGroupsCount orders the results by blocked_groups count.
func ByControls ¶
func ByControls(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByControls orders the results by controls terms.
func ByControlsCount ¶
func ByControlsCount(opts ...sql.OrderTermOption) OrderOption
ByControlsCount orders the results by controls count.
func ByCpe ¶
func ByCpe(opts ...sql.OrderTermOption) OrderOption
ByCpe orders the results by the cpe field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByEditors ¶
func ByEditors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEditors orders the results by editors terms.
func ByEditorsCount ¶
func ByEditorsCount(opts ...sql.OrderTermOption) OrderOption
ByEditorsCount orders the results by editors count.
func ByEntities ¶
func ByEntities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEntities orders the results by entities terms.
func ByEntitiesCount ¶
func ByEntitiesCount(opts ...sql.OrderTermOption) OrderOption
ByEntitiesCount orders the results by entities count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIdentifier ¶
func ByIdentifier(opts ...sql.OrderTermOption) OrderOption
ByIdentifier orders the results by the identifier field.
func ByInternalNotes ¶ added in v0.34.0
func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption
ByInternalNotes orders the results by the internal_notes field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOwnerField ¶
func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
ByOwnerField orders the results by owner field.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByScans ¶
func ByScans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByScans orders the results by scans terms.
func ByScansCount ¶
func ByScansCount(opts ...sql.OrderTermOption) OrderOption
ByScansCount orders the results by scans count.
func BySystemInternalID ¶ added in v0.34.0
func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption
BySystemInternalID orders the results by the system_internal_id field.
func BySystemOwned ¶ added in v0.34.0
func BySystemOwned(opts ...sql.OrderTermOption) OrderOption
BySystemOwned orders the results by the system_owned field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.
func ByViewers ¶
func ByViewers(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByViewers orders the results by viewers terms.
func ByViewersCount ¶
func ByViewersCount(opts ...sql.OrderTermOption) OrderOption
ByViewersCount orders the results by viewers count.
func ByWebsite ¶
func ByWebsite(opts ...sql.OrderTermOption) OrderOption
ByWebsite orders the results by the website field.