assethistory

package
v0.45.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 13, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the assethistory type in the database.
	Label = "asset_history"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldHistoryTime holds the string denoting the history_time field in the database.
	FieldHistoryTime = "history_time"
	// FieldRef holds the string denoting the ref field in the database.
	FieldRef = "ref"
	// FieldOperation holds the string denoting the operation field in the database.
	FieldOperation = "operation"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldSystemOwned holds the string denoting the system_owned field in the database.
	FieldSystemOwned = "system_owned"
	// FieldInternalNotes holds the string denoting the internal_notes field in the database.
	FieldInternalNotes = "internal_notes"
	// FieldSystemInternalID holds the string denoting the system_internal_id field in the database.
	FieldSystemInternalID = "system_internal_id"
	// FieldAssetType holds the string denoting the asset_type field in the database.
	FieldAssetType = "asset_type"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldIdentifier holds the string denoting the identifier field in the database.
	FieldIdentifier = "identifier"
	// FieldWebsite holds the string denoting the website field in the database.
	FieldWebsite = "website"
	// FieldCpe holds the string denoting the cpe field in the database.
	FieldCpe = "cpe"
	// FieldCategories holds the string denoting the categories field in the database.
	FieldCategories = "categories"
	// Table holds the table name of the assethistory in the database.
	Table = "asset_history"
)
const DefaultAssetType enums.AssetType = "TECHNOLOGY"

Variables

var (
	Hooks        [1]ent.Hook
	Interceptors [1]ent.Interceptor
	Policy       ent.Policy
	// DefaultHistoryTime holds the default value on creation for the "history_time" field.
	DefaultHistoryTime func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// DefaultSystemOwned holds the default value on creation for the "system_owned" field.
	DefaultSystemOwned bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for assethistory fields.

Functions

func And

func And(predicates ...predicate.AssetHistory) predicate.AssetHistory

And groups predicates with the AND operator between them.

func AssetTypeEQ

func AssetTypeEQ(v enums.AssetType) predicate.AssetHistory

AssetTypeEQ applies the EQ predicate on the "asset_type" field.

func AssetTypeIn

func AssetTypeIn(vs ...enums.AssetType) predicate.AssetHistory

AssetTypeIn applies the In predicate on the "asset_type" field.

func AssetTypeNEQ

func AssetTypeNEQ(v enums.AssetType) predicate.AssetHistory

AssetTypeNEQ applies the NEQ predicate on the "asset_type" field.

func AssetTypeNotIn

func AssetTypeNotIn(vs ...enums.AssetType) predicate.AssetHistory

AssetTypeNotIn applies the NotIn predicate on the "asset_type" field.

func AssetTypeValidator

func AssetTypeValidator(at enums.AssetType) error

AssetTypeValidator is a validator for the "asset_type" field enum values. It is called by the builders before save.

func CategoriesIsNil

func CategoriesIsNil() predicate.AssetHistory

CategoriesIsNil applies the IsNil predicate on the "categories" field.

func CategoriesNotNil

func CategoriesNotNil() predicate.AssetHistory

CategoriesNotNil applies the NotNil predicate on the "categories" field.

func Cpe

Cpe applies equality check predicate on the "cpe" field. It's identical to CpeEQ.

func CpeContains

func CpeContains(v string) predicate.AssetHistory

CpeContains applies the Contains predicate on the "cpe" field.

func CpeContainsFold

func CpeContainsFold(v string) predicate.AssetHistory

CpeContainsFold applies the ContainsFold predicate on the "cpe" field.

func CpeEQ

func CpeEQ(v string) predicate.AssetHistory

CpeEQ applies the EQ predicate on the "cpe" field.

func CpeEqualFold

func CpeEqualFold(v string) predicate.AssetHistory

CpeEqualFold applies the EqualFold predicate on the "cpe" field.

func CpeGT

func CpeGT(v string) predicate.AssetHistory

CpeGT applies the GT predicate on the "cpe" field.

func CpeGTE

func CpeGTE(v string) predicate.AssetHistory

CpeGTE applies the GTE predicate on the "cpe" field.

func CpeHasPrefix

func CpeHasPrefix(v string) predicate.AssetHistory

CpeHasPrefix applies the HasPrefix predicate on the "cpe" field.

func CpeHasSuffix

func CpeHasSuffix(v string) predicate.AssetHistory

CpeHasSuffix applies the HasSuffix predicate on the "cpe" field.

func CpeIn

func CpeIn(vs ...string) predicate.AssetHistory

CpeIn applies the In predicate on the "cpe" field.

func CpeIsNil

func CpeIsNil() predicate.AssetHistory

CpeIsNil applies the IsNil predicate on the "cpe" field.

func CpeLT

func CpeLT(v string) predicate.AssetHistory

CpeLT applies the LT predicate on the "cpe" field.

func CpeLTE

func CpeLTE(v string) predicate.AssetHistory

CpeLTE applies the LTE predicate on the "cpe" field.

func CpeNEQ

func CpeNEQ(v string) predicate.AssetHistory

CpeNEQ applies the NEQ predicate on the "cpe" field.

func CpeNotIn

func CpeNotIn(vs ...string) predicate.AssetHistory

CpeNotIn applies the NotIn predicate on the "cpe" field.

func CpeNotNil

func CpeNotNil() predicate.AssetHistory

CpeNotNil applies the NotNil predicate on the "cpe" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.AssetHistory

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.AssetHistory

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.AssetHistory

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.AssetHistory

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.AssetHistory

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.AssetHistory

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.AssetHistory

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.AssetHistory

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.AssetHistory

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.AssetHistory

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.AssetHistory

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.AssetHistory

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.AssetHistory

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.AssetHistory

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.AssetHistory

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.AssetHistory

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.AssetHistory

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.AssetHistory

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.AssetHistory

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.AssetHistory

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.AssetHistory

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.AssetHistory

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.AssetHistory

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.AssetHistory

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.AssetHistory

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.AssetHistory

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.AssetHistory

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.AssetHistory

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.AssetHistory

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.AssetHistory

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.AssetHistory

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.AssetHistory

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.AssetHistory

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.AssetHistory

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.AssetHistory

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.AssetHistory

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.AssetHistory

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.AssetHistory

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.AssetHistory

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.AssetHistory

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.AssetHistory

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.AssetHistory

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.AssetHistory

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.AssetHistory

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.AssetHistory

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.AssetHistory

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.AssetHistory

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.AssetHistory

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.AssetHistory

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.AssetHistory

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.AssetHistory

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.AssetHistory

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.AssetHistory

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.AssetHistory

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func Description

func Description(v string) predicate.AssetHistory

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.AssetHistory

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.AssetHistory

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.AssetHistory

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.AssetHistory

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.AssetHistory

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.AssetHistory

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.AssetHistory

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.AssetHistory

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.AssetHistory

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.AssetHistory

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.AssetHistory

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.AssetHistory

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.AssetHistory

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.AssetHistory

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.AssetHistory

DescriptionNotNil applies the NotNil predicate on the "description" field.

func HistoryTime

func HistoryTime(v time.Time) predicate.AssetHistory

HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.

func HistoryTimeEQ

func HistoryTimeEQ(v time.Time) predicate.AssetHistory

HistoryTimeEQ applies the EQ predicate on the "history_time" field.

func HistoryTimeGT

func HistoryTimeGT(v time.Time) predicate.AssetHistory

HistoryTimeGT applies the GT predicate on the "history_time" field.

func HistoryTimeGTE

func HistoryTimeGTE(v time.Time) predicate.AssetHistory

HistoryTimeGTE applies the GTE predicate on the "history_time" field.

func HistoryTimeIn

func HistoryTimeIn(vs ...time.Time) predicate.AssetHistory

HistoryTimeIn applies the In predicate on the "history_time" field.

func HistoryTimeLT

func HistoryTimeLT(v time.Time) predicate.AssetHistory

HistoryTimeLT applies the LT predicate on the "history_time" field.

func HistoryTimeLTE

func HistoryTimeLTE(v time.Time) predicate.AssetHistory

HistoryTimeLTE applies the LTE predicate on the "history_time" field.

func HistoryTimeNEQ

func HistoryTimeNEQ(v time.Time) predicate.AssetHistory

HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.

func HistoryTimeNotIn

func HistoryTimeNotIn(vs ...time.Time) predicate.AssetHistory

HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.AssetHistory

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.AssetHistory

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.AssetHistory

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.AssetHistory

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.AssetHistory

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.AssetHistory

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.AssetHistory

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.AssetHistory

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.AssetHistory

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.AssetHistory

IDNotIn applies the NotIn predicate on the ID field.

func Identifier

func Identifier(v string) predicate.AssetHistory

Identifier applies equality check predicate on the "identifier" field. It's identical to IdentifierEQ.

func IdentifierContains

func IdentifierContains(v string) predicate.AssetHistory

IdentifierContains applies the Contains predicate on the "identifier" field.

func IdentifierContainsFold

func IdentifierContainsFold(v string) predicate.AssetHistory

IdentifierContainsFold applies the ContainsFold predicate on the "identifier" field.

func IdentifierEQ

func IdentifierEQ(v string) predicate.AssetHistory

IdentifierEQ applies the EQ predicate on the "identifier" field.

func IdentifierEqualFold

func IdentifierEqualFold(v string) predicate.AssetHistory

IdentifierEqualFold applies the EqualFold predicate on the "identifier" field.

func IdentifierGT

func IdentifierGT(v string) predicate.AssetHistory

IdentifierGT applies the GT predicate on the "identifier" field.

func IdentifierGTE

func IdentifierGTE(v string) predicate.AssetHistory

IdentifierGTE applies the GTE predicate on the "identifier" field.

func IdentifierHasPrefix

func IdentifierHasPrefix(v string) predicate.AssetHistory

IdentifierHasPrefix applies the HasPrefix predicate on the "identifier" field.

func IdentifierHasSuffix

func IdentifierHasSuffix(v string) predicate.AssetHistory

IdentifierHasSuffix applies the HasSuffix predicate on the "identifier" field.

func IdentifierIn

func IdentifierIn(vs ...string) predicate.AssetHistory

IdentifierIn applies the In predicate on the "identifier" field.

func IdentifierIsNil

func IdentifierIsNil() predicate.AssetHistory

IdentifierIsNil applies the IsNil predicate on the "identifier" field.

func IdentifierLT

func IdentifierLT(v string) predicate.AssetHistory

IdentifierLT applies the LT predicate on the "identifier" field.

func IdentifierLTE

func IdentifierLTE(v string) predicate.AssetHistory

IdentifierLTE applies the LTE predicate on the "identifier" field.

func IdentifierNEQ

func IdentifierNEQ(v string) predicate.AssetHistory

IdentifierNEQ applies the NEQ predicate on the "identifier" field.

func IdentifierNotIn

func IdentifierNotIn(vs ...string) predicate.AssetHistory

IdentifierNotIn applies the NotIn predicate on the "identifier" field.

func IdentifierNotNil

func IdentifierNotNil() predicate.AssetHistory

IdentifierNotNil applies the NotNil predicate on the "identifier" field.

func InternalNotes added in v0.34.0

func InternalNotes(v string) predicate.AssetHistory

InternalNotes applies equality check predicate on the "internal_notes" field. It's identical to InternalNotesEQ.

func InternalNotesContains added in v0.34.0

func InternalNotesContains(v string) predicate.AssetHistory

InternalNotesContains applies the Contains predicate on the "internal_notes" field.

func InternalNotesContainsFold added in v0.34.0

func InternalNotesContainsFold(v string) predicate.AssetHistory

InternalNotesContainsFold applies the ContainsFold predicate on the "internal_notes" field.

func InternalNotesEQ added in v0.34.0

func InternalNotesEQ(v string) predicate.AssetHistory

InternalNotesEQ applies the EQ predicate on the "internal_notes" field.

func InternalNotesEqualFold added in v0.34.0

func InternalNotesEqualFold(v string) predicate.AssetHistory

InternalNotesEqualFold applies the EqualFold predicate on the "internal_notes" field.

func InternalNotesGT added in v0.34.0

func InternalNotesGT(v string) predicate.AssetHistory

InternalNotesGT applies the GT predicate on the "internal_notes" field.

func InternalNotesGTE added in v0.34.0

func InternalNotesGTE(v string) predicate.AssetHistory

InternalNotesGTE applies the GTE predicate on the "internal_notes" field.

func InternalNotesHasPrefix added in v0.34.0

func InternalNotesHasPrefix(v string) predicate.AssetHistory

InternalNotesHasPrefix applies the HasPrefix predicate on the "internal_notes" field.

func InternalNotesHasSuffix added in v0.34.0

func InternalNotesHasSuffix(v string) predicate.AssetHistory

InternalNotesHasSuffix applies the HasSuffix predicate on the "internal_notes" field.

func InternalNotesIn added in v0.34.0

func InternalNotesIn(vs ...string) predicate.AssetHistory

InternalNotesIn applies the In predicate on the "internal_notes" field.

func InternalNotesIsNil added in v0.34.0

func InternalNotesIsNil() predicate.AssetHistory

InternalNotesIsNil applies the IsNil predicate on the "internal_notes" field.

func InternalNotesLT added in v0.34.0

func InternalNotesLT(v string) predicate.AssetHistory

InternalNotesLT applies the LT predicate on the "internal_notes" field.

func InternalNotesLTE added in v0.34.0

func InternalNotesLTE(v string) predicate.AssetHistory

InternalNotesLTE applies the LTE predicate on the "internal_notes" field.

func InternalNotesNEQ added in v0.34.0

func InternalNotesNEQ(v string) predicate.AssetHistory

InternalNotesNEQ applies the NEQ predicate on the "internal_notes" field.

func InternalNotesNotIn added in v0.34.0

func InternalNotesNotIn(vs ...string) predicate.AssetHistory

InternalNotesNotIn applies the NotIn predicate on the "internal_notes" field.

func InternalNotesNotNil added in v0.34.0

func InternalNotesNotNil() predicate.AssetHistory

InternalNotesNotNil applies the NotNil predicate on the "internal_notes" field.

func Name

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.AssetHistory

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.AssetHistory

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.AssetHistory

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.AssetHistory

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.AssetHistory

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.AssetHistory

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.AssetHistory

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.AssetHistory

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.AssetHistory

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.AssetHistory

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.AssetHistory

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.AssetHistory

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.AssetHistory

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func OperationEQ

func OperationEQ(v history.OpType) predicate.AssetHistory

OperationEQ applies the EQ predicate on the "operation" field.

func OperationIn

func OperationIn(vs ...history.OpType) predicate.AssetHistory

OperationIn applies the In predicate on the "operation" field.

func OperationNEQ

func OperationNEQ(v history.OpType) predicate.AssetHistory

OperationNEQ applies the NEQ predicate on the "operation" field.

func OperationNotIn

func OperationNotIn(vs ...history.OpType) predicate.AssetHistory

OperationNotIn applies the NotIn predicate on the "operation" field.

func OperationValidator

func OperationValidator(o history.OpType) error

OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.

func Or

func Or(predicates ...predicate.AssetHistory) predicate.AssetHistory

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.AssetHistory

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.AssetHistory

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.AssetHistory

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.AssetHistory

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.AssetHistory

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.AssetHistory

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.AssetHistory

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.AssetHistory

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.AssetHistory

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.AssetHistory

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.AssetHistory

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.AssetHistory

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.AssetHistory

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.AssetHistory

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.AssetHistory

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.AssetHistory

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func Ref

Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.

func RefContains

func RefContains(v string) predicate.AssetHistory

RefContains applies the Contains predicate on the "ref" field.

func RefContainsFold

func RefContainsFold(v string) predicate.AssetHistory

RefContainsFold applies the ContainsFold predicate on the "ref" field.

func RefEQ

func RefEQ(v string) predicate.AssetHistory

RefEQ applies the EQ predicate on the "ref" field.

func RefEqualFold

func RefEqualFold(v string) predicate.AssetHistory

RefEqualFold applies the EqualFold predicate on the "ref" field.

func RefGT

func RefGT(v string) predicate.AssetHistory

RefGT applies the GT predicate on the "ref" field.

func RefGTE

func RefGTE(v string) predicate.AssetHistory

RefGTE applies the GTE predicate on the "ref" field.

func RefHasPrefix

func RefHasPrefix(v string) predicate.AssetHistory

RefHasPrefix applies the HasPrefix predicate on the "ref" field.

func RefHasSuffix

func RefHasSuffix(v string) predicate.AssetHistory

RefHasSuffix applies the HasSuffix predicate on the "ref" field.

func RefIn

func RefIn(vs ...string) predicate.AssetHistory

RefIn applies the In predicate on the "ref" field.

func RefIsNil

func RefIsNil() predicate.AssetHistory

RefIsNil applies the IsNil predicate on the "ref" field.

func RefLT

func RefLT(v string) predicate.AssetHistory

RefLT applies the LT predicate on the "ref" field.

func RefLTE

func RefLTE(v string) predicate.AssetHistory

RefLTE applies the LTE predicate on the "ref" field.

func RefNEQ

func RefNEQ(v string) predicate.AssetHistory

RefNEQ applies the NEQ predicate on the "ref" field.

func RefNotIn

func RefNotIn(vs ...string) predicate.AssetHistory

RefNotIn applies the NotIn predicate on the "ref" field.

func RefNotNil

func RefNotNil() predicate.AssetHistory

RefNotNil applies the NotNil predicate on the "ref" field.

func SystemInternalID added in v0.34.0

func SystemInternalID(v string) predicate.AssetHistory

SystemInternalID applies equality check predicate on the "system_internal_id" field. It's identical to SystemInternalIDEQ.

func SystemInternalIDContains added in v0.34.0

func SystemInternalIDContains(v string) predicate.AssetHistory

SystemInternalIDContains applies the Contains predicate on the "system_internal_id" field.

func SystemInternalIDContainsFold added in v0.34.0

func SystemInternalIDContainsFold(v string) predicate.AssetHistory

SystemInternalIDContainsFold applies the ContainsFold predicate on the "system_internal_id" field.

func SystemInternalIDEQ added in v0.34.0

func SystemInternalIDEQ(v string) predicate.AssetHistory

SystemInternalIDEQ applies the EQ predicate on the "system_internal_id" field.

func SystemInternalIDEqualFold added in v0.34.0

func SystemInternalIDEqualFold(v string) predicate.AssetHistory

SystemInternalIDEqualFold applies the EqualFold predicate on the "system_internal_id" field.

func SystemInternalIDGT added in v0.34.0

func SystemInternalIDGT(v string) predicate.AssetHistory

SystemInternalIDGT applies the GT predicate on the "system_internal_id" field.

func SystemInternalIDGTE added in v0.34.0

func SystemInternalIDGTE(v string) predicate.AssetHistory

SystemInternalIDGTE applies the GTE predicate on the "system_internal_id" field.

func SystemInternalIDHasPrefix added in v0.34.0

func SystemInternalIDHasPrefix(v string) predicate.AssetHistory

SystemInternalIDHasPrefix applies the HasPrefix predicate on the "system_internal_id" field.

func SystemInternalIDHasSuffix added in v0.34.0

func SystemInternalIDHasSuffix(v string) predicate.AssetHistory

SystemInternalIDHasSuffix applies the HasSuffix predicate on the "system_internal_id" field.

func SystemInternalIDIn added in v0.34.0

func SystemInternalIDIn(vs ...string) predicate.AssetHistory

SystemInternalIDIn applies the In predicate on the "system_internal_id" field.

func SystemInternalIDIsNil added in v0.34.0

func SystemInternalIDIsNil() predicate.AssetHistory

SystemInternalIDIsNil applies the IsNil predicate on the "system_internal_id" field.

func SystemInternalIDLT added in v0.34.0

func SystemInternalIDLT(v string) predicate.AssetHistory

SystemInternalIDLT applies the LT predicate on the "system_internal_id" field.

func SystemInternalIDLTE added in v0.34.0

func SystemInternalIDLTE(v string) predicate.AssetHistory

SystemInternalIDLTE applies the LTE predicate on the "system_internal_id" field.

func SystemInternalIDNEQ added in v0.34.0

func SystemInternalIDNEQ(v string) predicate.AssetHistory

SystemInternalIDNEQ applies the NEQ predicate on the "system_internal_id" field.

func SystemInternalIDNotIn added in v0.34.0

func SystemInternalIDNotIn(vs ...string) predicate.AssetHistory

SystemInternalIDNotIn applies the NotIn predicate on the "system_internal_id" field.

func SystemInternalIDNotNil added in v0.34.0

func SystemInternalIDNotNil() predicate.AssetHistory

SystemInternalIDNotNil applies the NotNil predicate on the "system_internal_id" field.

func SystemOwned added in v0.34.0

func SystemOwned(v bool) predicate.AssetHistory

SystemOwned applies equality check predicate on the "system_owned" field. It's identical to SystemOwnedEQ.

func SystemOwnedEQ added in v0.34.0

func SystemOwnedEQ(v bool) predicate.AssetHistory

SystemOwnedEQ applies the EQ predicate on the "system_owned" field.

func SystemOwnedIsNil added in v0.34.0

func SystemOwnedIsNil() predicate.AssetHistory

SystemOwnedIsNil applies the IsNil predicate on the "system_owned" field.

func SystemOwnedNEQ added in v0.34.0

func SystemOwnedNEQ(v bool) predicate.AssetHistory

SystemOwnedNEQ applies the NEQ predicate on the "system_owned" field.

func SystemOwnedNotNil added in v0.34.0

func SystemOwnedNotNil() predicate.AssetHistory

SystemOwnedNotNil applies the NotNil predicate on the "system_owned" field.

func TagsIsNil

func TagsIsNil() predicate.AssetHistory

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.AssetHistory

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.AssetHistory

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.AssetHistory

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.AssetHistory

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.AssetHistory

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.AssetHistory

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.AssetHistory

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.AssetHistory

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.AssetHistory

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.AssetHistory

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.AssetHistory

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.AssetHistory

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.AssetHistory

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.AssetHistory

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.AssetHistory

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.AssetHistory

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.AssetHistory

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.AssetHistory

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.AssetHistory

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.AssetHistory

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.AssetHistory

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.AssetHistory

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.AssetHistory

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.AssetHistory

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.AssetHistory

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.AssetHistory

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.AssetHistory

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.AssetHistory

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Website

func Website(v string) predicate.AssetHistory

Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.

func WebsiteContains

func WebsiteContains(v string) predicate.AssetHistory

WebsiteContains applies the Contains predicate on the "website" field.

func WebsiteContainsFold

func WebsiteContainsFold(v string) predicate.AssetHistory

WebsiteContainsFold applies the ContainsFold predicate on the "website" field.

func WebsiteEQ

func WebsiteEQ(v string) predicate.AssetHistory

WebsiteEQ applies the EQ predicate on the "website" field.

func WebsiteEqualFold

func WebsiteEqualFold(v string) predicate.AssetHistory

WebsiteEqualFold applies the EqualFold predicate on the "website" field.

func WebsiteGT

func WebsiteGT(v string) predicate.AssetHistory

WebsiteGT applies the GT predicate on the "website" field.

func WebsiteGTE

func WebsiteGTE(v string) predicate.AssetHistory

WebsiteGTE applies the GTE predicate on the "website" field.

func WebsiteHasPrefix

func WebsiteHasPrefix(v string) predicate.AssetHistory

WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.

func WebsiteHasSuffix

func WebsiteHasSuffix(v string) predicate.AssetHistory

WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.

func WebsiteIn

func WebsiteIn(vs ...string) predicate.AssetHistory

WebsiteIn applies the In predicate on the "website" field.

func WebsiteIsNil

func WebsiteIsNil() predicate.AssetHistory

WebsiteIsNil applies the IsNil predicate on the "website" field.

func WebsiteLT

func WebsiteLT(v string) predicate.AssetHistory

WebsiteLT applies the LT predicate on the "website" field.

func WebsiteLTE

func WebsiteLTE(v string) predicate.AssetHistory

WebsiteLTE applies the LTE predicate on the "website" field.

func WebsiteNEQ

func WebsiteNEQ(v string) predicate.AssetHistory

WebsiteNEQ applies the NEQ predicate on the "website" field.

func WebsiteNotIn

func WebsiteNotIn(vs ...string) predicate.AssetHistory

WebsiteNotIn applies the NotIn predicate on the "website" field.

func WebsiteNotNil

func WebsiteNotNil() predicate.AssetHistory

WebsiteNotNil applies the NotNil predicate on the "website" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the AssetHistory queries.

func ByAssetType

func ByAssetType(opts ...sql.OrderTermOption) OrderOption

ByAssetType orders the results by the asset_type field.

func ByCpe

func ByCpe(opts ...sql.OrderTermOption) OrderOption

ByCpe orders the results by the cpe field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByHistoryTime

func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption

ByHistoryTime orders the results by the history_time field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIdentifier

func ByIdentifier(opts ...sql.OrderTermOption) OrderOption

ByIdentifier orders the results by the identifier field.

func ByInternalNotes added in v0.34.0

func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption

ByInternalNotes orders the results by the internal_notes field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByOperation

func ByOperation(opts ...sql.OrderTermOption) OrderOption

ByOperation orders the results by the operation field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByRef

func ByRef(opts ...sql.OrderTermOption) OrderOption

ByRef orders the results by the ref field.

func BySystemInternalID added in v0.34.0

func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption

BySystemInternalID orders the results by the system_internal_id field.

func BySystemOwned added in v0.34.0

func BySystemOwned(opts ...sql.OrderTermOption) OrderOption

BySystemOwned orders the results by the system_owned field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

func ByWebsite

func ByWebsite(opts ...sql.OrderTermOption) OrderOption

ByWebsite orders the results by the website field.

Jump to