campaigntarget

package
v1.23.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the campaigntarget type in the database.
	Label = "campaign_target"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldWorkflowEligibleMarker holds the string denoting the workflow_eligible_marker field in the database.
	FieldWorkflowEligibleMarker = "workflow_eligible_marker"
	// FieldCampaignID holds the string denoting the campaign_id field in the database.
	FieldCampaignID = "campaign_id"
	// FieldContactID holds the string denoting the contact_id field in the database.
	FieldContactID = "contact_id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldGroupID holds the string denoting the group_id field in the database.
	FieldGroupID = "group_id"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldFullName holds the string denoting the full_name field in the database.
	FieldFullName = "full_name"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldSentAt holds the string denoting the sent_at field in the database.
	FieldSentAt = "sent_at"
	// FieldCompletedAt holds the string denoting the completed_at field in the database.
	FieldCompletedAt = "completed_at"
	// FieldMetadata holds the string denoting the metadata field in the database.
	FieldMetadata = "metadata"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// EdgeCampaign holds the string denoting the campaign edge name in mutations.
	EdgeCampaign = "campaign"
	// EdgeContact holds the string denoting the contact edge name in mutations.
	EdgeContact = "contact"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeGroup holds the string denoting the group edge name in mutations.
	EdgeGroup = "group"
	// EdgeWorkflowObjectRefs holds the string denoting the workflow_object_refs edge name in mutations.
	EdgeWorkflowObjectRefs = "workflow_object_refs"
	// Table holds the table name of the campaigntarget in the database.
	Table = "campaign_targets"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "campaign_targets"
	// OwnerInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OwnerInverseTable = "organizations"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
	// CampaignTable is the table that holds the campaign relation/edge.
	CampaignTable = "campaign_targets"
	// CampaignInverseTable is the table name for the Campaign entity.
	// It exists in this package in order to avoid circular dependency with the "campaign" package.
	CampaignInverseTable = "campaigns"
	// CampaignColumn is the table column denoting the campaign relation/edge.
	CampaignColumn = "campaign_id"
	// ContactTable is the table that holds the contact relation/edge.
	ContactTable = "campaign_targets"
	// ContactInverseTable is the table name for the Contact entity.
	// It exists in this package in order to avoid circular dependency with the "contact" package.
	ContactInverseTable = "contacts"
	// ContactColumn is the table column denoting the contact relation/edge.
	ContactColumn = "contact_id"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "campaign_targets"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
	// GroupTable is the table that holds the group relation/edge.
	GroupTable = "campaign_targets"
	// GroupInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	GroupInverseTable = "groups"
	// GroupColumn is the table column denoting the group relation/edge.
	GroupColumn = "group_id"
	// WorkflowObjectRefsTable is the table that holds the workflow_object_refs relation/edge.
	WorkflowObjectRefsTable = "workflow_object_refs"
	// WorkflowObjectRefsInverseTable is the table name for the WorkflowObjectRef entity.
	// It exists in this package in order to avoid circular dependency with the "workflowobjectref" package.
	WorkflowObjectRefsInverseTable = "workflow_object_refs"
	// WorkflowObjectRefsColumn is the table column denoting the workflow_object_refs relation/edge.
	WorkflowObjectRefsColumn = "campaign_target_id"
)
const DefaultStatus enums.AssessmentResponseStatus = "NOT_STARTED"

Variables

var (
	Hooks        [7]ent.Hook
	Interceptors [3]ent.Interceptor
	Policy       ent.Policy
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save.
	OwnerIDValidator func(string) error
	// DefaultWorkflowEligibleMarker holds the default value on creation for the "workflow_eligible_marker" field.
	DefaultWorkflowEligibleMarker bool
	// CampaignIDValidator is a validator for the "campaign_id" field. It is called by the builders before save.
	CampaignIDValidator func(string) error
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for campaigntarget fields.

Functions

func And

And groups predicates with the AND operator between them.

func CampaignID

func CampaignID(v string) predicate.CampaignTarget

CampaignID applies equality check predicate on the "campaign_id" field. It's identical to CampaignIDEQ.

func CampaignIDContains

func CampaignIDContains(v string) predicate.CampaignTarget

CampaignIDContains applies the Contains predicate on the "campaign_id" field.

func CampaignIDContainsFold

func CampaignIDContainsFold(v string) predicate.CampaignTarget

CampaignIDContainsFold applies the ContainsFold predicate on the "campaign_id" field.

func CampaignIDEQ

func CampaignIDEQ(v string) predicate.CampaignTarget

CampaignIDEQ applies the EQ predicate on the "campaign_id" field.

func CampaignIDEqualFold

func CampaignIDEqualFold(v string) predicate.CampaignTarget

CampaignIDEqualFold applies the EqualFold predicate on the "campaign_id" field.

func CampaignIDGT

func CampaignIDGT(v string) predicate.CampaignTarget

CampaignIDGT applies the GT predicate on the "campaign_id" field.

func CampaignIDGTE

func CampaignIDGTE(v string) predicate.CampaignTarget

CampaignIDGTE applies the GTE predicate on the "campaign_id" field.

func CampaignIDHasPrefix

func CampaignIDHasPrefix(v string) predicate.CampaignTarget

CampaignIDHasPrefix applies the HasPrefix predicate on the "campaign_id" field.

func CampaignIDHasSuffix

func CampaignIDHasSuffix(v string) predicate.CampaignTarget

CampaignIDHasSuffix applies the HasSuffix predicate on the "campaign_id" field.

func CampaignIDIn

func CampaignIDIn(vs ...string) predicate.CampaignTarget

CampaignIDIn applies the In predicate on the "campaign_id" field.

func CampaignIDLT

func CampaignIDLT(v string) predicate.CampaignTarget

CampaignIDLT applies the LT predicate on the "campaign_id" field.

func CampaignIDLTE

func CampaignIDLTE(v string) predicate.CampaignTarget

CampaignIDLTE applies the LTE predicate on the "campaign_id" field.

func CampaignIDNEQ

func CampaignIDNEQ(v string) predicate.CampaignTarget

CampaignIDNEQ applies the NEQ predicate on the "campaign_id" field.

func CampaignIDNotIn

func CampaignIDNotIn(vs ...string) predicate.CampaignTarget

CampaignIDNotIn applies the NotIn predicate on the "campaign_id" field.

func CompletedAt

func CompletedAt(v models.DateTime) predicate.CampaignTarget

CompletedAt applies equality check predicate on the "completed_at" field. It's identical to CompletedAtEQ.

func CompletedAtEQ

func CompletedAtEQ(v models.DateTime) predicate.CampaignTarget

CompletedAtEQ applies the EQ predicate on the "completed_at" field.

func CompletedAtGT

func CompletedAtGT(v models.DateTime) predicate.CampaignTarget

CompletedAtGT applies the GT predicate on the "completed_at" field.

func CompletedAtGTE

func CompletedAtGTE(v models.DateTime) predicate.CampaignTarget

CompletedAtGTE applies the GTE predicate on the "completed_at" field.

func CompletedAtIn

func CompletedAtIn(vs ...models.DateTime) predicate.CampaignTarget

CompletedAtIn applies the In predicate on the "completed_at" field.

func CompletedAtIsNil

func CompletedAtIsNil() predicate.CampaignTarget

CompletedAtIsNil applies the IsNil predicate on the "completed_at" field.

func CompletedAtLT

func CompletedAtLT(v models.DateTime) predicate.CampaignTarget

CompletedAtLT applies the LT predicate on the "completed_at" field.

func CompletedAtLTE

func CompletedAtLTE(v models.DateTime) predicate.CampaignTarget

CompletedAtLTE applies the LTE predicate on the "completed_at" field.

func CompletedAtNEQ

func CompletedAtNEQ(v models.DateTime) predicate.CampaignTarget

CompletedAtNEQ applies the NEQ predicate on the "completed_at" field.

func CompletedAtNotIn

func CompletedAtNotIn(vs ...models.DateTime) predicate.CampaignTarget

CompletedAtNotIn applies the NotIn predicate on the "completed_at" field.

func CompletedAtNotNil

func CompletedAtNotNil() predicate.CampaignTarget

CompletedAtNotNil applies the NotNil predicate on the "completed_at" field.

func ContactID

func ContactID(v string) predicate.CampaignTarget

ContactID applies equality check predicate on the "contact_id" field. It's identical to ContactIDEQ.

func ContactIDContains

func ContactIDContains(v string) predicate.CampaignTarget

ContactIDContains applies the Contains predicate on the "contact_id" field.

func ContactIDContainsFold

func ContactIDContainsFold(v string) predicate.CampaignTarget

ContactIDContainsFold applies the ContainsFold predicate on the "contact_id" field.

func ContactIDEQ

func ContactIDEQ(v string) predicate.CampaignTarget

ContactIDEQ applies the EQ predicate on the "contact_id" field.

func ContactIDEqualFold

func ContactIDEqualFold(v string) predicate.CampaignTarget

ContactIDEqualFold applies the EqualFold predicate on the "contact_id" field.

func ContactIDGT

func ContactIDGT(v string) predicate.CampaignTarget

ContactIDGT applies the GT predicate on the "contact_id" field.

func ContactIDGTE

func ContactIDGTE(v string) predicate.CampaignTarget

ContactIDGTE applies the GTE predicate on the "contact_id" field.

func ContactIDHasPrefix

func ContactIDHasPrefix(v string) predicate.CampaignTarget

ContactIDHasPrefix applies the HasPrefix predicate on the "contact_id" field.

func ContactIDHasSuffix

func ContactIDHasSuffix(v string) predicate.CampaignTarget

ContactIDHasSuffix applies the HasSuffix predicate on the "contact_id" field.

func ContactIDIn

func ContactIDIn(vs ...string) predicate.CampaignTarget

ContactIDIn applies the In predicate on the "contact_id" field.

func ContactIDIsNil

func ContactIDIsNil() predicate.CampaignTarget

ContactIDIsNil applies the IsNil predicate on the "contact_id" field.

func ContactIDLT

func ContactIDLT(v string) predicate.CampaignTarget

ContactIDLT applies the LT predicate on the "contact_id" field.

func ContactIDLTE

func ContactIDLTE(v string) predicate.CampaignTarget

ContactIDLTE applies the LTE predicate on the "contact_id" field.

func ContactIDNEQ

func ContactIDNEQ(v string) predicate.CampaignTarget

ContactIDNEQ applies the NEQ predicate on the "contact_id" field.

func ContactIDNotIn

func ContactIDNotIn(vs ...string) predicate.CampaignTarget

ContactIDNotIn applies the NotIn predicate on the "contact_id" field.

func ContactIDNotNil

func ContactIDNotNil() predicate.CampaignTarget

ContactIDNotNil applies the NotNil predicate on the "contact_id" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.CampaignTarget

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.CampaignTarget

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.CampaignTarget

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.CampaignTarget

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.CampaignTarget

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.CampaignTarget

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.CampaignTarget

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.CampaignTarget

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.CampaignTarget

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.CampaignTarget

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.CampaignTarget

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.CampaignTarget

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.CampaignTarget

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.CampaignTarget

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.CampaignTarget

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.CampaignTarget

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.CampaignTarget

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.CampaignTarget

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.CampaignTarget

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.CampaignTarget

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.CampaignTarget

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.CampaignTarget

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.CampaignTarget

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.CampaignTarget

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.CampaignTarget

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.CampaignTarget

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.CampaignTarget

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.CampaignTarget

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.CampaignTarget

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.CampaignTarget

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.CampaignTarget

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.CampaignTarget

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.CampaignTarget

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.CampaignTarget

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.CampaignTarget

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.CampaignTarget

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.CampaignTarget

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.CampaignTarget

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.CampaignTarget

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.CampaignTarget

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.CampaignTarget

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.CampaignTarget

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.CampaignTarget

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.CampaignTarget

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.CampaignTarget

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.CampaignTarget

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.CampaignTarget

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.CampaignTarget

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.CampaignTarget

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.CampaignTarget

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.CampaignTarget

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.CampaignTarget

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.CampaignTarget

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.CampaignTarget

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func Email

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.CampaignTarget

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.CampaignTarget

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.CampaignTarget

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.CampaignTarget

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.CampaignTarget

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.CampaignTarget

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.CampaignTarget

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.CampaignTarget

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.CampaignTarget

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.CampaignTarget

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.CampaignTarget

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.CampaignTarget

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.CampaignTarget

EmailNotIn applies the NotIn predicate on the "email" field.

func FullName

func FullName(v string) predicate.CampaignTarget

FullName applies equality check predicate on the "full_name" field. It's identical to FullNameEQ.

func FullNameContains

func FullNameContains(v string) predicate.CampaignTarget

FullNameContains applies the Contains predicate on the "full_name" field.

func FullNameContainsFold

func FullNameContainsFold(v string) predicate.CampaignTarget

FullNameContainsFold applies the ContainsFold predicate on the "full_name" field.

func FullNameEQ

func FullNameEQ(v string) predicate.CampaignTarget

FullNameEQ applies the EQ predicate on the "full_name" field.

func FullNameEqualFold

func FullNameEqualFold(v string) predicate.CampaignTarget

FullNameEqualFold applies the EqualFold predicate on the "full_name" field.

func FullNameGT

func FullNameGT(v string) predicate.CampaignTarget

FullNameGT applies the GT predicate on the "full_name" field.

func FullNameGTE

func FullNameGTE(v string) predicate.CampaignTarget

FullNameGTE applies the GTE predicate on the "full_name" field.

func FullNameHasPrefix

func FullNameHasPrefix(v string) predicate.CampaignTarget

FullNameHasPrefix applies the HasPrefix predicate on the "full_name" field.

func FullNameHasSuffix

func FullNameHasSuffix(v string) predicate.CampaignTarget

FullNameHasSuffix applies the HasSuffix predicate on the "full_name" field.

func FullNameIn

func FullNameIn(vs ...string) predicate.CampaignTarget

FullNameIn applies the In predicate on the "full_name" field.

func FullNameIsNil

func FullNameIsNil() predicate.CampaignTarget

FullNameIsNil applies the IsNil predicate on the "full_name" field.

func FullNameLT

func FullNameLT(v string) predicate.CampaignTarget

FullNameLT applies the LT predicate on the "full_name" field.

func FullNameLTE

func FullNameLTE(v string) predicate.CampaignTarget

FullNameLTE applies the LTE predicate on the "full_name" field.

func FullNameNEQ

func FullNameNEQ(v string) predicate.CampaignTarget

FullNameNEQ applies the NEQ predicate on the "full_name" field.

func FullNameNotIn

func FullNameNotIn(vs ...string) predicate.CampaignTarget

FullNameNotIn applies the NotIn predicate on the "full_name" field.

func FullNameNotNil

func FullNameNotNil() predicate.CampaignTarget

FullNameNotNil applies the NotNil predicate on the "full_name" field.

func GroupID

func GroupID(v string) predicate.CampaignTarget

GroupID applies equality check predicate on the "group_id" field. It's identical to GroupIDEQ.

func GroupIDContains

func GroupIDContains(v string) predicate.CampaignTarget

GroupIDContains applies the Contains predicate on the "group_id" field.

func GroupIDContainsFold

func GroupIDContainsFold(v string) predicate.CampaignTarget

GroupIDContainsFold applies the ContainsFold predicate on the "group_id" field.

func GroupIDEQ

func GroupIDEQ(v string) predicate.CampaignTarget

GroupIDEQ applies the EQ predicate on the "group_id" field.

func GroupIDEqualFold

func GroupIDEqualFold(v string) predicate.CampaignTarget

GroupIDEqualFold applies the EqualFold predicate on the "group_id" field.

func GroupIDGT

func GroupIDGT(v string) predicate.CampaignTarget

GroupIDGT applies the GT predicate on the "group_id" field.

func GroupIDGTE

func GroupIDGTE(v string) predicate.CampaignTarget

GroupIDGTE applies the GTE predicate on the "group_id" field.

func GroupIDHasPrefix

func GroupIDHasPrefix(v string) predicate.CampaignTarget

GroupIDHasPrefix applies the HasPrefix predicate on the "group_id" field.

func GroupIDHasSuffix

func GroupIDHasSuffix(v string) predicate.CampaignTarget

GroupIDHasSuffix applies the HasSuffix predicate on the "group_id" field.

func GroupIDIn

func GroupIDIn(vs ...string) predicate.CampaignTarget

GroupIDIn applies the In predicate on the "group_id" field.

func GroupIDIsNil

func GroupIDIsNil() predicate.CampaignTarget

GroupIDIsNil applies the IsNil predicate on the "group_id" field.

func GroupIDLT

func GroupIDLT(v string) predicate.CampaignTarget

GroupIDLT applies the LT predicate on the "group_id" field.

func GroupIDLTE

func GroupIDLTE(v string) predicate.CampaignTarget

GroupIDLTE applies the LTE predicate on the "group_id" field.

func GroupIDNEQ

func GroupIDNEQ(v string) predicate.CampaignTarget

GroupIDNEQ applies the NEQ predicate on the "group_id" field.

func GroupIDNotIn

func GroupIDNotIn(vs ...string) predicate.CampaignTarget

GroupIDNotIn applies the NotIn predicate on the "group_id" field.

func GroupIDNotNil

func GroupIDNotNil() predicate.CampaignTarget

GroupIDNotNil applies the NotNil predicate on the "group_id" field.

func HasCampaign

func HasCampaign() predicate.CampaignTarget

HasCampaign applies the HasEdge predicate on the "campaign" edge.

func HasCampaignWith

func HasCampaignWith(preds ...predicate.Campaign) predicate.CampaignTarget

HasCampaignWith applies the HasEdge predicate on the "campaign" edge with a given conditions (other predicates).

func HasContact

func HasContact() predicate.CampaignTarget

HasContact applies the HasEdge predicate on the "contact" edge.

func HasContactWith

func HasContactWith(preds ...predicate.Contact) predicate.CampaignTarget

HasContactWith applies the HasEdge predicate on the "contact" edge with a given conditions (other predicates).

func HasGroup

func HasGroup() predicate.CampaignTarget

HasGroup applies the HasEdge predicate on the "group" edge.

func HasGroupWith

func HasGroupWith(preds ...predicate.Group) predicate.CampaignTarget

HasGroupWith applies the HasEdge predicate on the "group" edge with a given conditions (other predicates).

func HasOwner

func HasOwner() predicate.CampaignTarget

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Organization) predicate.CampaignTarget

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.CampaignTarget

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.CampaignTarget

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func HasWorkflowObjectRefs

func HasWorkflowObjectRefs() predicate.CampaignTarget

HasWorkflowObjectRefs applies the HasEdge predicate on the "workflow_object_refs" edge.

func HasWorkflowObjectRefsWith

func HasWorkflowObjectRefsWith(preds ...predicate.WorkflowObjectRef) predicate.CampaignTarget

HasWorkflowObjectRefsWith applies the HasEdge predicate on the "workflow_object_refs" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.CampaignTarget

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.CampaignTarget

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.CampaignTarget

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.CampaignTarget

IDNotIn applies the NotIn predicate on the ID field.

func MetadataIsNil

func MetadataIsNil() predicate.CampaignTarget

MetadataIsNil applies the IsNil predicate on the "metadata" field.

func MetadataNotNil

func MetadataNotNil() predicate.CampaignTarget

MetadataNotNil applies the NotNil predicate on the "metadata" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.CampaignTarget

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.CampaignTarget

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.CampaignTarget

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.CampaignTarget

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.CampaignTarget

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.CampaignTarget

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.CampaignTarget

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.CampaignTarget

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.CampaignTarget

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.CampaignTarget

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.CampaignTarget

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.CampaignTarget

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.CampaignTarget

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.CampaignTarget

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.CampaignTarget

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.CampaignTarget

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func SentAt

SentAt applies equality check predicate on the "sent_at" field. It's identical to SentAtEQ.

func SentAtEQ

SentAtEQ applies the EQ predicate on the "sent_at" field.

func SentAtGT

SentAtGT applies the GT predicate on the "sent_at" field.

func SentAtGTE

SentAtGTE applies the GTE predicate on the "sent_at" field.

func SentAtIn

func SentAtIn(vs ...models.DateTime) predicate.CampaignTarget

SentAtIn applies the In predicate on the "sent_at" field.

func SentAtIsNil

func SentAtIsNil() predicate.CampaignTarget

SentAtIsNil applies the IsNil predicate on the "sent_at" field.

func SentAtLT

SentAtLT applies the LT predicate on the "sent_at" field.

func SentAtLTE

SentAtLTE applies the LTE predicate on the "sent_at" field.

func SentAtNEQ

SentAtNEQ applies the NEQ predicate on the "sent_at" field.

func SentAtNotIn

func SentAtNotIn(vs ...models.DateTime) predicate.CampaignTarget

SentAtNotIn applies the NotIn predicate on the "sent_at" field.

func SentAtNotNil

func SentAtNotNil() predicate.CampaignTarget

SentAtNotNil applies the NotNil predicate on the "sent_at" field.

func StatusEQ

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s enums.AssessmentResponseStatus) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.CampaignTarget

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.CampaignTarget

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.CampaignTarget

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.CampaignTarget

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.CampaignTarget

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.CampaignTarget

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.CampaignTarget

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.CampaignTarget

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.CampaignTarget

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.CampaignTarget

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.CampaignTarget

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.CampaignTarget

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.CampaignTarget

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.CampaignTarget

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.CampaignTarget

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.CampaignTarget

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.CampaignTarget

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.CampaignTarget

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.CampaignTarget

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.CampaignTarget

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.CampaignTarget

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.CampaignTarget

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.CampaignTarget

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.CampaignTarget

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.CampaignTarget

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.CampaignTarget

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.CampaignTarget

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func UserID

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDContains

func UserIDContains(v string) predicate.CampaignTarget

UserIDContains applies the Contains predicate on the "user_id" field.

func UserIDContainsFold

func UserIDContainsFold(v string) predicate.CampaignTarget

UserIDContainsFold applies the ContainsFold predicate on the "user_id" field.

func UserIDEQ

func UserIDEQ(v string) predicate.CampaignTarget

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDEqualFold

func UserIDEqualFold(v string) predicate.CampaignTarget

UserIDEqualFold applies the EqualFold predicate on the "user_id" field.

func UserIDGT

func UserIDGT(v string) predicate.CampaignTarget

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

func UserIDGTE(v string) predicate.CampaignTarget

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDHasPrefix

func UserIDHasPrefix(v string) predicate.CampaignTarget

UserIDHasPrefix applies the HasPrefix predicate on the "user_id" field.

func UserIDHasSuffix

func UserIDHasSuffix(v string) predicate.CampaignTarget

UserIDHasSuffix applies the HasSuffix predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...string) predicate.CampaignTarget

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.CampaignTarget

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDLT

func UserIDLT(v string) predicate.CampaignTarget

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

func UserIDLTE(v string) predicate.CampaignTarget

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v string) predicate.CampaignTarget

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...string) predicate.CampaignTarget

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.CampaignTarget

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WorkflowEligibleMarker

func WorkflowEligibleMarker(v bool) predicate.CampaignTarget

WorkflowEligibleMarker applies equality check predicate on the "workflow_eligible_marker" field. It's identical to WorkflowEligibleMarkerEQ.

func WorkflowEligibleMarkerEQ

func WorkflowEligibleMarkerEQ(v bool) predicate.CampaignTarget

WorkflowEligibleMarkerEQ applies the EQ predicate on the "workflow_eligible_marker" field.

func WorkflowEligibleMarkerIsNil

func WorkflowEligibleMarkerIsNil() predicate.CampaignTarget

WorkflowEligibleMarkerIsNil applies the IsNil predicate on the "workflow_eligible_marker" field.

func WorkflowEligibleMarkerNEQ

func WorkflowEligibleMarkerNEQ(v bool) predicate.CampaignTarget

WorkflowEligibleMarkerNEQ applies the NEQ predicate on the "workflow_eligible_marker" field.

func WorkflowEligibleMarkerNotNil

func WorkflowEligibleMarkerNotNil() predicate.CampaignTarget

WorkflowEligibleMarkerNotNil applies the NotNil predicate on the "workflow_eligible_marker" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the CampaignTarget queries.

func ByCampaignField

func ByCampaignField(field string, opts ...sql.OrderTermOption) OrderOption

ByCampaignField orders the results by campaign field.

func ByCampaignID

func ByCampaignID(opts ...sql.OrderTermOption) OrderOption

ByCampaignID orders the results by the campaign_id field.

func ByCompletedAt

func ByCompletedAt(opts ...sql.OrderTermOption) OrderOption

ByCompletedAt orders the results by the completed_at field.

func ByContactField

func ByContactField(field string, opts ...sql.OrderTermOption) OrderOption

ByContactField orders the results by contact field.

func ByContactID

func ByContactID(opts ...sql.OrderTermOption) OrderOption

ByContactID orders the results by the contact_id field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByFullName

func ByFullName(opts ...sql.OrderTermOption) OrderOption

ByFullName orders the results by the full_name field.

func ByGroupField

func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption

ByGroupField orders the results by group field.

func ByGroupID

func ByGroupID(opts ...sql.OrderTermOption) OrderOption

ByGroupID orders the results by the group_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func BySentAt

func BySentAt(opts ...sql.OrderTermOption) OrderOption

BySentAt orders the results by the sent_at field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

func ByWorkflowEligibleMarker

func ByWorkflowEligibleMarker(opts ...sql.OrderTermOption) OrderOption

ByWorkflowEligibleMarker orders the results by the workflow_eligible_marker field.

func ByWorkflowObjectRefs

func ByWorkflowObjectRefs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByWorkflowObjectRefs orders the results by workflow_object_refs terms.

func ByWorkflowObjectRefsCount

func ByWorkflowObjectRefsCount(opts ...sql.OrderTermOption) OrderOption

ByWorkflowObjectRefsCount orders the results by workflow_object_refs count.

Jump to