controlhistory

package
v0.8.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the controlhistory type in the database.
	Label = "control_history"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldHistoryTime holds the string denoting the history_time field in the database.
	FieldHistoryTime = "history_time"
	// FieldRef holds the string denoting the ref field in the database.
	FieldRef = "ref"
	// FieldOperation holds the string denoting the operation field in the database.
	FieldOperation = "operation"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldDisplayID holds the string denoting the display_id field in the database.
	FieldDisplayID = "display_id"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldSource holds the string denoting the source field in the database.
	FieldSource = "source"
	// FieldControlType holds the string denoting the control_type field in the database.
	FieldControlType = "control_type"
	// FieldCategory holds the string denoting the category field in the database.
	FieldCategory = "category"
	// FieldCategoryID holds the string denoting the category_id field in the database.
	FieldCategoryID = "category_id"
	// FieldSubcategory holds the string denoting the subcategory field in the database.
	FieldSubcategory = "subcategory"
	// FieldMappedCategories holds the string denoting the mapped_categories field in the database.
	FieldMappedCategories = "mapped_categories"
	// FieldAssessmentObjectives holds the string denoting the assessment_objectives field in the database.
	FieldAssessmentObjectives = "assessment_objectives"
	// FieldAssessmentMethods holds the string denoting the assessment_methods field in the database.
	FieldAssessmentMethods = "assessment_methods"
	// FieldControlQuestions holds the string denoting the control_questions field in the database.
	FieldControlQuestions = "control_questions"
	// FieldImplementationGuidance holds the string denoting the implementation_guidance field in the database.
	FieldImplementationGuidance = "implementation_guidance"
	// FieldExampleEvidence holds the string denoting the example_evidence field in the database.
	FieldExampleEvidence = "example_evidence"
	// FieldReferences holds the string denoting the references field in the database.
	FieldReferences = "references"
	// FieldRefCode holds the string denoting the ref_code field in the database.
	FieldRefCode = "ref_code"
	// FieldStandardID holds the string denoting the standard_id field in the database.
	FieldStandardID = "standard_id"
	// Table holds the table name of the controlhistory in the database.
	Table = "control_history"
)
const DefaultControlType enums.ControlType = "PREVENTATIVE"
const DefaultSource enums.ControlSource = "USER_DEFINED"

Variables

var (
	Interceptors [1]ent.Interceptor
	// DefaultHistoryTime holds the default value on creation for the "history_time" field.
	DefaultHistoryTime func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for controlhistory fields.

Functions

func And

And groups predicates with the AND operator between them.

func AssessmentMethodsIsNil added in v0.7.3

func AssessmentMethodsIsNil() predicate.ControlHistory

AssessmentMethodsIsNil applies the IsNil predicate on the "assessment_methods" field.

func AssessmentMethodsNotNil added in v0.7.3

func AssessmentMethodsNotNil() predicate.ControlHistory

AssessmentMethodsNotNil applies the NotNil predicate on the "assessment_methods" field.

func AssessmentObjectivesIsNil added in v0.7.3

func AssessmentObjectivesIsNil() predicate.ControlHistory

AssessmentObjectivesIsNil applies the IsNil predicate on the "assessment_objectives" field.

func AssessmentObjectivesNotNil added in v0.7.3

func AssessmentObjectivesNotNil() predicate.ControlHistory

AssessmentObjectivesNotNil applies the NotNil predicate on the "assessment_objectives" field.

func Category added in v0.7.3

func Category(v string) predicate.ControlHistory

Category applies equality check predicate on the "category" field. It's identical to CategoryEQ.

func CategoryContains added in v0.7.3

func CategoryContains(v string) predicate.ControlHistory

CategoryContains applies the Contains predicate on the "category" field.

func CategoryContainsFold added in v0.7.3

func CategoryContainsFold(v string) predicate.ControlHistory

CategoryContainsFold applies the ContainsFold predicate on the "category" field.

func CategoryEQ added in v0.7.3

func CategoryEQ(v string) predicate.ControlHistory

CategoryEQ applies the EQ predicate on the "category" field.

func CategoryEqualFold added in v0.7.3

func CategoryEqualFold(v string) predicate.ControlHistory

CategoryEqualFold applies the EqualFold predicate on the "category" field.

func CategoryGT added in v0.7.3

func CategoryGT(v string) predicate.ControlHistory

CategoryGT applies the GT predicate on the "category" field.

func CategoryGTE added in v0.7.3

func CategoryGTE(v string) predicate.ControlHistory

CategoryGTE applies the GTE predicate on the "category" field.

func CategoryHasPrefix added in v0.7.3

func CategoryHasPrefix(v string) predicate.ControlHistory

CategoryHasPrefix applies the HasPrefix predicate on the "category" field.

func CategoryHasSuffix added in v0.7.3

func CategoryHasSuffix(v string) predicate.ControlHistory

CategoryHasSuffix applies the HasSuffix predicate on the "category" field.

func CategoryID added in v0.7.3

func CategoryID(v string) predicate.ControlHistory

CategoryID applies equality check predicate on the "category_id" field. It's identical to CategoryIDEQ.

func CategoryIDContains added in v0.7.3

func CategoryIDContains(v string) predicate.ControlHistory

CategoryIDContains applies the Contains predicate on the "category_id" field.

func CategoryIDContainsFold added in v0.7.3

func CategoryIDContainsFold(v string) predicate.ControlHistory

CategoryIDContainsFold applies the ContainsFold predicate on the "category_id" field.

func CategoryIDEQ added in v0.7.3

func CategoryIDEQ(v string) predicate.ControlHistory

CategoryIDEQ applies the EQ predicate on the "category_id" field.

func CategoryIDEqualFold added in v0.7.3

func CategoryIDEqualFold(v string) predicate.ControlHistory

CategoryIDEqualFold applies the EqualFold predicate on the "category_id" field.

func CategoryIDGT added in v0.7.3

func CategoryIDGT(v string) predicate.ControlHistory

CategoryIDGT applies the GT predicate on the "category_id" field.

func CategoryIDGTE added in v0.7.3

func CategoryIDGTE(v string) predicate.ControlHistory

CategoryIDGTE applies the GTE predicate on the "category_id" field.

func CategoryIDHasPrefix added in v0.7.3

func CategoryIDHasPrefix(v string) predicate.ControlHistory

CategoryIDHasPrefix applies the HasPrefix predicate on the "category_id" field.

func CategoryIDHasSuffix added in v0.7.3

func CategoryIDHasSuffix(v string) predicate.ControlHistory

CategoryIDHasSuffix applies the HasSuffix predicate on the "category_id" field.

func CategoryIDIn added in v0.7.3

func CategoryIDIn(vs ...string) predicate.ControlHistory

CategoryIDIn applies the In predicate on the "category_id" field.

func CategoryIDIsNil added in v0.7.3

func CategoryIDIsNil() predicate.ControlHistory

CategoryIDIsNil applies the IsNil predicate on the "category_id" field.

func CategoryIDLT added in v0.7.3

func CategoryIDLT(v string) predicate.ControlHistory

CategoryIDLT applies the LT predicate on the "category_id" field.

func CategoryIDLTE added in v0.7.3

func CategoryIDLTE(v string) predicate.ControlHistory

CategoryIDLTE applies the LTE predicate on the "category_id" field.

func CategoryIDNEQ added in v0.7.3

func CategoryIDNEQ(v string) predicate.ControlHistory

CategoryIDNEQ applies the NEQ predicate on the "category_id" field.

func CategoryIDNotIn added in v0.7.3

func CategoryIDNotIn(vs ...string) predicate.ControlHistory

CategoryIDNotIn applies the NotIn predicate on the "category_id" field.

func CategoryIDNotNil added in v0.7.3

func CategoryIDNotNil() predicate.ControlHistory

CategoryIDNotNil applies the NotNil predicate on the "category_id" field.

func CategoryIn added in v0.7.3

func CategoryIn(vs ...string) predicate.ControlHistory

CategoryIn applies the In predicate on the "category" field.

func CategoryIsNil added in v0.7.3

func CategoryIsNil() predicate.ControlHistory

CategoryIsNil applies the IsNil predicate on the "category" field.

func CategoryLT added in v0.7.3

func CategoryLT(v string) predicate.ControlHistory

CategoryLT applies the LT predicate on the "category" field.

func CategoryLTE added in v0.7.3

func CategoryLTE(v string) predicate.ControlHistory

CategoryLTE applies the LTE predicate on the "category" field.

func CategoryNEQ added in v0.7.3

func CategoryNEQ(v string) predicate.ControlHistory

CategoryNEQ applies the NEQ predicate on the "category" field.

func CategoryNotIn added in v0.7.3

func CategoryNotIn(vs ...string) predicate.ControlHistory

CategoryNotIn applies the NotIn predicate on the "category" field.

func CategoryNotNil added in v0.7.3

func CategoryNotNil() predicate.ControlHistory

CategoryNotNil applies the NotNil predicate on the "category" field.

func ControlQuestionsIsNil added in v0.7.3

func ControlQuestionsIsNil() predicate.ControlHistory

ControlQuestionsIsNil applies the IsNil predicate on the "control_questions" field.

func ControlQuestionsNotNil added in v0.7.3

func ControlQuestionsNotNil() predicate.ControlHistory

ControlQuestionsNotNil applies the NotNil predicate on the "control_questions" field.

func ControlTypeEQ

func ControlTypeEQ(v enums.ControlType) predicate.ControlHistory

ControlTypeEQ applies the EQ predicate on the "control_type" field.

func ControlTypeIn

func ControlTypeIn(vs ...enums.ControlType) predicate.ControlHistory

ControlTypeIn applies the In predicate on the "control_type" field.

func ControlTypeIsNil

func ControlTypeIsNil() predicate.ControlHistory

ControlTypeIsNil applies the IsNil predicate on the "control_type" field.

func ControlTypeNEQ

func ControlTypeNEQ(v enums.ControlType) predicate.ControlHistory

ControlTypeNEQ applies the NEQ predicate on the "control_type" field.

func ControlTypeNotIn

func ControlTypeNotIn(vs ...enums.ControlType) predicate.ControlHistory

ControlTypeNotIn applies the NotIn predicate on the "control_type" field.

func ControlTypeNotNil

func ControlTypeNotNil() predicate.ControlHistory

ControlTypeNotNil applies the NotNil predicate on the "control_type" field.

func ControlTypeValidator added in v0.7.3

func ControlTypeValidator(ct enums.ControlType) error

ControlTypeValidator is a validator for the "control_type" field enum values. It is called by the builders before save.

func CreatedAt

func CreatedAt(v time.Time) predicate.ControlHistory

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.ControlHistory

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.ControlHistory

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.ControlHistory

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.ControlHistory

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.ControlHistory

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.ControlHistory

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.ControlHistory

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.ControlHistory

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.ControlHistory

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.ControlHistory

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.ControlHistory

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.ControlHistory

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.ControlHistory

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.ControlHistory

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.ControlHistory

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.ControlHistory

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.ControlHistory

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.ControlHistory

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.ControlHistory

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.ControlHistory

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.ControlHistory

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.ControlHistory

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.ControlHistory

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.ControlHistory

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.ControlHistory

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.ControlHistory

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.ControlHistory

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.ControlHistory

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.ControlHistory

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.ControlHistory

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.ControlHistory

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.ControlHistory

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.ControlHistory

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.ControlHistory

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.ControlHistory

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.ControlHistory

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.ControlHistory

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.ControlHistory

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.ControlHistory

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.ControlHistory

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.ControlHistory

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.ControlHistory

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.ControlHistory

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.ControlHistory

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.ControlHistory

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.ControlHistory

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.ControlHistory

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.ControlHistory

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.ControlHistory

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.ControlHistory

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.ControlHistory

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.ControlHistory

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.ControlHistory

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func Description

func Description(v string) predicate.ControlHistory

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.ControlHistory

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.ControlHistory

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.ControlHistory

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.ControlHistory

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.ControlHistory

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.ControlHistory

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.ControlHistory

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.ControlHistory

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.ControlHistory

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.ControlHistory

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.ControlHistory

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.ControlHistory

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.ControlHistory

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.ControlHistory

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.ControlHistory

DescriptionNotNil applies the NotNil predicate on the "description" field.

func DisplayID added in v0.6.11

func DisplayID(v string) predicate.ControlHistory

DisplayID applies equality check predicate on the "display_id" field. It's identical to DisplayIDEQ.

func DisplayIDContains added in v0.6.11

func DisplayIDContains(v string) predicate.ControlHistory

DisplayIDContains applies the Contains predicate on the "display_id" field.

func DisplayIDContainsFold added in v0.6.11

func DisplayIDContainsFold(v string) predicate.ControlHistory

DisplayIDContainsFold applies the ContainsFold predicate on the "display_id" field.

func DisplayIDEQ added in v0.6.11

func DisplayIDEQ(v string) predicate.ControlHistory

DisplayIDEQ applies the EQ predicate on the "display_id" field.

func DisplayIDEqualFold added in v0.6.11

func DisplayIDEqualFold(v string) predicate.ControlHistory

DisplayIDEqualFold applies the EqualFold predicate on the "display_id" field.

func DisplayIDGT added in v0.6.11

func DisplayIDGT(v string) predicate.ControlHistory

DisplayIDGT applies the GT predicate on the "display_id" field.

func DisplayIDGTE added in v0.6.11

func DisplayIDGTE(v string) predicate.ControlHistory

DisplayIDGTE applies the GTE predicate on the "display_id" field.

func DisplayIDHasPrefix added in v0.6.11

func DisplayIDHasPrefix(v string) predicate.ControlHistory

DisplayIDHasPrefix applies the HasPrefix predicate on the "display_id" field.

func DisplayIDHasSuffix added in v0.6.11

func DisplayIDHasSuffix(v string) predicate.ControlHistory

DisplayIDHasSuffix applies the HasSuffix predicate on the "display_id" field.

func DisplayIDIn added in v0.6.11

func DisplayIDIn(vs ...string) predicate.ControlHistory

DisplayIDIn applies the In predicate on the "display_id" field.

func DisplayIDLT added in v0.6.11

func DisplayIDLT(v string) predicate.ControlHistory

DisplayIDLT applies the LT predicate on the "display_id" field.

func DisplayIDLTE added in v0.6.11

func DisplayIDLTE(v string) predicate.ControlHistory

DisplayIDLTE applies the LTE predicate on the "display_id" field.

func DisplayIDNEQ added in v0.6.11

func DisplayIDNEQ(v string) predicate.ControlHistory

DisplayIDNEQ applies the NEQ predicate on the "display_id" field.

func DisplayIDNotIn added in v0.6.11

func DisplayIDNotIn(vs ...string) predicate.ControlHistory

DisplayIDNotIn applies the NotIn predicate on the "display_id" field.

func ExampleEvidenceIsNil added in v0.6.19

func ExampleEvidenceIsNil() predicate.ControlHistory

ExampleEvidenceIsNil applies the IsNil predicate on the "example_evidence" field.

func ExampleEvidenceNotNil added in v0.6.19

func ExampleEvidenceNotNil() predicate.ControlHistory

ExampleEvidenceNotNil applies the NotNil predicate on the "example_evidence" field.

func HistoryTime

func HistoryTime(v time.Time) predicate.ControlHistory

HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.

func HistoryTimeEQ

func HistoryTimeEQ(v time.Time) predicate.ControlHistory

HistoryTimeEQ applies the EQ predicate on the "history_time" field.

func HistoryTimeGT

func HistoryTimeGT(v time.Time) predicate.ControlHistory

HistoryTimeGT applies the GT predicate on the "history_time" field.

func HistoryTimeGTE

func HistoryTimeGTE(v time.Time) predicate.ControlHistory

HistoryTimeGTE applies the GTE predicate on the "history_time" field.

func HistoryTimeIn

func HistoryTimeIn(vs ...time.Time) predicate.ControlHistory

HistoryTimeIn applies the In predicate on the "history_time" field.

func HistoryTimeLT

func HistoryTimeLT(v time.Time) predicate.ControlHistory

HistoryTimeLT applies the LT predicate on the "history_time" field.

func HistoryTimeLTE

func HistoryTimeLTE(v time.Time) predicate.ControlHistory

HistoryTimeLTE applies the LTE predicate on the "history_time" field.

func HistoryTimeNEQ

func HistoryTimeNEQ(v time.Time) predicate.ControlHistory

HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.

func HistoryTimeNotIn

func HistoryTimeNotIn(vs ...time.Time) predicate.ControlHistory

HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.ControlHistory

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.ControlHistory

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.ControlHistory

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.ControlHistory

IDNotIn applies the NotIn predicate on the ID field.

func ImplementationGuidanceIsNil added in v0.7.3

func ImplementationGuidanceIsNil() predicate.ControlHistory

ImplementationGuidanceIsNil applies the IsNil predicate on the "implementation_guidance" field.

func ImplementationGuidanceNotNil added in v0.7.3

func ImplementationGuidanceNotNil() predicate.ControlHistory

ImplementationGuidanceNotNil applies the NotNil predicate on the "implementation_guidance" field.

func MappedCategoriesIsNil added in v0.7.3

func MappedCategoriesIsNil() predicate.ControlHistory

MappedCategoriesIsNil applies the IsNil predicate on the "mapped_categories" field.

func MappedCategoriesNotNil added in v0.7.3

func MappedCategoriesNotNil() predicate.ControlHistory

MappedCategoriesNotNil applies the NotNil predicate on the "mapped_categories" field.

func Not

Not applies the not operator on the given predicate.

func OperationEQ

func OperationEQ(v history.OpType) predicate.ControlHistory

OperationEQ applies the EQ predicate on the "operation" field.

func OperationIn

func OperationIn(vs ...history.OpType) predicate.ControlHistory

OperationIn applies the In predicate on the "operation" field.

func OperationNEQ

func OperationNEQ(v history.OpType) predicate.ControlHistory

OperationNEQ applies the NEQ predicate on the "operation" field.

func OperationNotIn

func OperationNotIn(vs ...history.OpType) predicate.ControlHistory

OperationNotIn applies the NotIn predicate on the "operation" field.

func OperationValidator

func OperationValidator(o history.OpType) error

OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.

func Or

Or groups predicates with the OR operator between them.

func OwnerID added in v0.5.0

func OwnerID(v string) predicate.ControlHistory

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains added in v0.5.0

func OwnerIDContains(v string) predicate.ControlHistory

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold added in v0.5.0

func OwnerIDContainsFold(v string) predicate.ControlHistory

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ added in v0.5.0

func OwnerIDEQ(v string) predicate.ControlHistory

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold added in v0.5.0

func OwnerIDEqualFold(v string) predicate.ControlHistory

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT added in v0.5.0

func OwnerIDGT(v string) predicate.ControlHistory

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE added in v0.5.0

func OwnerIDGTE(v string) predicate.ControlHistory

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix added in v0.5.0

func OwnerIDHasPrefix(v string) predicate.ControlHistory

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix added in v0.5.0

func OwnerIDHasSuffix(v string) predicate.ControlHistory

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn added in v0.5.0

func OwnerIDIn(vs ...string) predicate.ControlHistory

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil added in v0.7.1

func OwnerIDIsNil() predicate.ControlHistory

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT added in v0.5.0

func OwnerIDLT(v string) predicate.ControlHistory

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE added in v0.5.0

func OwnerIDLTE(v string) predicate.ControlHistory

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ added in v0.5.0

func OwnerIDNEQ(v string) predicate.ControlHistory

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn added in v0.5.0

func OwnerIDNotIn(vs ...string) predicate.ControlHistory

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil added in v0.7.1

func OwnerIDNotNil() predicate.ControlHistory

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func Ref

Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.

func RefCode added in v0.7.3

func RefCode(v string) predicate.ControlHistory

RefCode applies equality check predicate on the "ref_code" field. It's identical to RefCodeEQ.

func RefCodeContains added in v0.7.3

func RefCodeContains(v string) predicate.ControlHistory

RefCodeContains applies the Contains predicate on the "ref_code" field.

func RefCodeContainsFold added in v0.7.3

func RefCodeContainsFold(v string) predicate.ControlHistory

RefCodeContainsFold applies the ContainsFold predicate on the "ref_code" field.

func RefCodeEQ added in v0.7.3

func RefCodeEQ(v string) predicate.ControlHistory

RefCodeEQ applies the EQ predicate on the "ref_code" field.

func RefCodeEqualFold added in v0.7.3

func RefCodeEqualFold(v string) predicate.ControlHistory

RefCodeEqualFold applies the EqualFold predicate on the "ref_code" field.

func RefCodeGT added in v0.7.3

func RefCodeGT(v string) predicate.ControlHistory

RefCodeGT applies the GT predicate on the "ref_code" field.

func RefCodeGTE added in v0.7.3

func RefCodeGTE(v string) predicate.ControlHistory

RefCodeGTE applies the GTE predicate on the "ref_code" field.

func RefCodeHasPrefix added in v0.7.3

func RefCodeHasPrefix(v string) predicate.ControlHistory

RefCodeHasPrefix applies the HasPrefix predicate on the "ref_code" field.

func RefCodeHasSuffix added in v0.7.3

func RefCodeHasSuffix(v string) predicate.ControlHistory

RefCodeHasSuffix applies the HasSuffix predicate on the "ref_code" field.

func RefCodeIn added in v0.7.3

func RefCodeIn(vs ...string) predicate.ControlHistory

RefCodeIn applies the In predicate on the "ref_code" field.

func RefCodeLT added in v0.7.3

func RefCodeLT(v string) predicate.ControlHistory

RefCodeLT applies the LT predicate on the "ref_code" field.

func RefCodeLTE added in v0.7.3

func RefCodeLTE(v string) predicate.ControlHistory

RefCodeLTE applies the LTE predicate on the "ref_code" field.

func RefCodeNEQ added in v0.7.3

func RefCodeNEQ(v string) predicate.ControlHistory

RefCodeNEQ applies the NEQ predicate on the "ref_code" field.

func RefCodeNotIn added in v0.7.3

func RefCodeNotIn(vs ...string) predicate.ControlHistory

RefCodeNotIn applies the NotIn predicate on the "ref_code" field.

func RefContains

func RefContains(v string) predicate.ControlHistory

RefContains applies the Contains predicate on the "ref" field.

func RefContainsFold

func RefContainsFold(v string) predicate.ControlHistory

RefContainsFold applies the ContainsFold predicate on the "ref" field.

func RefEQ

RefEQ applies the EQ predicate on the "ref" field.

func RefEqualFold

func RefEqualFold(v string) predicate.ControlHistory

RefEqualFold applies the EqualFold predicate on the "ref" field.

func RefGT

RefGT applies the GT predicate on the "ref" field.

func RefGTE

RefGTE applies the GTE predicate on the "ref" field.

func RefHasPrefix

func RefHasPrefix(v string) predicate.ControlHistory

RefHasPrefix applies the HasPrefix predicate on the "ref" field.

func RefHasSuffix

func RefHasSuffix(v string) predicate.ControlHistory

RefHasSuffix applies the HasSuffix predicate on the "ref" field.

func RefIn

func RefIn(vs ...string) predicate.ControlHistory

RefIn applies the In predicate on the "ref" field.

func RefIsNil

func RefIsNil() predicate.ControlHistory

RefIsNil applies the IsNil predicate on the "ref" field.

func RefLT

RefLT applies the LT predicate on the "ref" field.

func RefLTE

RefLTE applies the LTE predicate on the "ref" field.

func RefNEQ

RefNEQ applies the NEQ predicate on the "ref" field.

func RefNotIn

func RefNotIn(vs ...string) predicate.ControlHistory

RefNotIn applies the NotIn predicate on the "ref" field.

func RefNotNil

func RefNotNil() predicate.ControlHistory

RefNotNil applies the NotNil predicate on the "ref" field.

func ReferencesIsNil added in v0.7.3

func ReferencesIsNil() predicate.ControlHistory

ReferencesIsNil applies the IsNil predicate on the "references" field.

func ReferencesNotNil added in v0.7.3

func ReferencesNotNil() predicate.ControlHistory

ReferencesNotNil applies the NotNil predicate on the "references" field.

func SourceEQ

SourceEQ applies the EQ predicate on the "source" field.

func SourceIn

SourceIn applies the In predicate on the "source" field.

func SourceIsNil

func SourceIsNil() predicate.ControlHistory

SourceIsNil applies the IsNil predicate on the "source" field.

func SourceNEQ

SourceNEQ applies the NEQ predicate on the "source" field.

func SourceNotIn

func SourceNotIn(vs ...enums.ControlSource) predicate.ControlHistory

SourceNotIn applies the NotIn predicate on the "source" field.

func SourceNotNil

func SourceNotNil() predicate.ControlHistory

SourceNotNil applies the NotNil predicate on the "source" field.

func SourceValidator added in v0.7.3

func SourceValidator(s enums.ControlSource) error

SourceValidator is a validator for the "source" field enum values. It is called by the builders before save.

func StandardID added in v0.7.3

func StandardID(v string) predicate.ControlHistory

StandardID applies equality check predicate on the "standard_id" field. It's identical to StandardIDEQ.

func StandardIDContains added in v0.7.3

func StandardIDContains(v string) predicate.ControlHistory

StandardIDContains applies the Contains predicate on the "standard_id" field.

func StandardIDContainsFold added in v0.7.3

func StandardIDContainsFold(v string) predicate.ControlHistory

StandardIDContainsFold applies the ContainsFold predicate on the "standard_id" field.

func StandardIDEQ added in v0.7.3

func StandardIDEQ(v string) predicate.ControlHistory

StandardIDEQ applies the EQ predicate on the "standard_id" field.

func StandardIDEqualFold added in v0.7.3

func StandardIDEqualFold(v string) predicate.ControlHistory

StandardIDEqualFold applies the EqualFold predicate on the "standard_id" field.

func StandardIDGT added in v0.7.3

func StandardIDGT(v string) predicate.ControlHistory

StandardIDGT applies the GT predicate on the "standard_id" field.

func StandardIDGTE added in v0.7.3

func StandardIDGTE(v string) predicate.ControlHistory

StandardIDGTE applies the GTE predicate on the "standard_id" field.

func StandardIDHasPrefix added in v0.7.3

func StandardIDHasPrefix(v string) predicate.ControlHistory

StandardIDHasPrefix applies the HasPrefix predicate on the "standard_id" field.

func StandardIDHasSuffix added in v0.7.3

func StandardIDHasSuffix(v string) predicate.ControlHistory

StandardIDHasSuffix applies the HasSuffix predicate on the "standard_id" field.

func StandardIDIn added in v0.7.3

func StandardIDIn(vs ...string) predicate.ControlHistory

StandardIDIn applies the In predicate on the "standard_id" field.

func StandardIDIsNil added in v0.7.3

func StandardIDIsNil() predicate.ControlHistory

StandardIDIsNil applies the IsNil predicate on the "standard_id" field.

func StandardIDLT added in v0.7.3

func StandardIDLT(v string) predicate.ControlHistory

StandardIDLT applies the LT predicate on the "standard_id" field.

func StandardIDLTE added in v0.7.3

func StandardIDLTE(v string) predicate.ControlHistory

StandardIDLTE applies the LTE predicate on the "standard_id" field.

func StandardIDNEQ added in v0.7.3

func StandardIDNEQ(v string) predicate.ControlHistory

StandardIDNEQ applies the NEQ predicate on the "standard_id" field.

func StandardIDNotIn added in v0.7.3

func StandardIDNotIn(vs ...string) predicate.ControlHistory

StandardIDNotIn applies the NotIn predicate on the "standard_id" field.

func StandardIDNotNil added in v0.7.3

func StandardIDNotNil() predicate.ControlHistory

StandardIDNotNil applies the NotNil predicate on the "standard_id" field.

func Status

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.ControlHistory

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.ControlHistory

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.ControlHistory

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.ControlHistory

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.ControlHistory

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.ControlHistory

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.ControlHistory

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.ControlHistory

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.ControlHistory

StatusIn applies the In predicate on the "status" field.

func StatusIsNil

func StatusIsNil() predicate.ControlHistory

StatusIsNil applies the IsNil predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.ControlHistory

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.ControlHistory

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.ControlHistory

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.ControlHistory

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusNotNil

func StatusNotNil() predicate.ControlHistory

StatusNotNil applies the NotNil predicate on the "status" field.

func Subcategory added in v0.7.3

func Subcategory(v string) predicate.ControlHistory

Subcategory applies equality check predicate on the "subcategory" field. It's identical to SubcategoryEQ.

func SubcategoryContains added in v0.7.3

func SubcategoryContains(v string) predicate.ControlHistory

SubcategoryContains applies the Contains predicate on the "subcategory" field.

func SubcategoryContainsFold added in v0.7.3

func SubcategoryContainsFold(v string) predicate.ControlHistory

SubcategoryContainsFold applies the ContainsFold predicate on the "subcategory" field.

func SubcategoryEQ added in v0.7.3

func SubcategoryEQ(v string) predicate.ControlHistory

SubcategoryEQ applies the EQ predicate on the "subcategory" field.

func SubcategoryEqualFold added in v0.7.3

func SubcategoryEqualFold(v string) predicate.ControlHistory

SubcategoryEqualFold applies the EqualFold predicate on the "subcategory" field.

func SubcategoryGT added in v0.7.3

func SubcategoryGT(v string) predicate.ControlHistory

SubcategoryGT applies the GT predicate on the "subcategory" field.

func SubcategoryGTE added in v0.7.3

func SubcategoryGTE(v string) predicate.ControlHistory

SubcategoryGTE applies the GTE predicate on the "subcategory" field.

func SubcategoryHasPrefix added in v0.7.3

func SubcategoryHasPrefix(v string) predicate.ControlHistory

SubcategoryHasPrefix applies the HasPrefix predicate on the "subcategory" field.

func SubcategoryHasSuffix added in v0.7.3

func SubcategoryHasSuffix(v string) predicate.ControlHistory

SubcategoryHasSuffix applies the HasSuffix predicate on the "subcategory" field.

func SubcategoryIn added in v0.7.3

func SubcategoryIn(vs ...string) predicate.ControlHistory

SubcategoryIn applies the In predicate on the "subcategory" field.

func SubcategoryIsNil added in v0.7.3

func SubcategoryIsNil() predicate.ControlHistory

SubcategoryIsNil applies the IsNil predicate on the "subcategory" field.

func SubcategoryLT added in v0.7.3

func SubcategoryLT(v string) predicate.ControlHistory

SubcategoryLT applies the LT predicate on the "subcategory" field.

func SubcategoryLTE added in v0.7.3

func SubcategoryLTE(v string) predicate.ControlHistory

SubcategoryLTE applies the LTE predicate on the "subcategory" field.

func SubcategoryNEQ added in v0.7.3

func SubcategoryNEQ(v string) predicate.ControlHistory

SubcategoryNEQ applies the NEQ predicate on the "subcategory" field.

func SubcategoryNotIn added in v0.7.3

func SubcategoryNotIn(vs ...string) predicate.ControlHistory

SubcategoryNotIn applies the NotIn predicate on the "subcategory" field.

func SubcategoryNotNil added in v0.7.3

func SubcategoryNotNil() predicate.ControlHistory

SubcategoryNotNil applies the NotNil predicate on the "subcategory" field.

func TagsIsNil

func TagsIsNil() predicate.ControlHistory

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.ControlHistory

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.ControlHistory

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.ControlHistory

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.ControlHistory

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.ControlHistory

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.ControlHistory

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.ControlHistory

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.ControlHistory

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.ControlHistory

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.ControlHistory

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.ControlHistory

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.ControlHistory

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.ControlHistory

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.ControlHistory

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.ControlHistory

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.ControlHistory

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.ControlHistory

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.ControlHistory

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.ControlHistory

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.ControlHistory

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.ControlHistory

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.ControlHistory

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.ControlHistory

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.ControlHistory

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.ControlHistory

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.ControlHistory

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.ControlHistory

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.ControlHistory

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ControlHistory queries.

func ByCategory added in v0.7.3

func ByCategory(opts ...sql.OrderTermOption) OrderOption

ByCategory orders the results by the category field.

func ByCategoryID added in v0.7.3

func ByCategoryID(opts ...sql.OrderTermOption) OrderOption

ByCategoryID orders the results by the category_id field.

func ByControlType

func ByControlType(opts ...sql.OrderTermOption) OrderOption

ByControlType orders the results by the control_type field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByDisplayID added in v0.6.11

func ByDisplayID(opts ...sql.OrderTermOption) OrderOption

ByDisplayID orders the results by the display_id field.

func ByHistoryTime

func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption

ByHistoryTime orders the results by the history_time field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOperation

func ByOperation(opts ...sql.OrderTermOption) OrderOption

ByOperation orders the results by the operation field.

func ByOwnerID added in v0.5.0

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByRef

func ByRef(opts ...sql.OrderTermOption) OrderOption

ByRef orders the results by the ref field.

func ByRefCode added in v0.7.3

func ByRefCode(opts ...sql.OrderTermOption) OrderOption

ByRefCode orders the results by the ref_code field.

func BySource

func BySource(opts ...sql.OrderTermOption) OrderOption

BySource orders the results by the source field.

func ByStandardID added in v0.7.3

func ByStandardID(opts ...sql.OrderTermOption) OrderOption

ByStandardID orders the results by the standard_id field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func BySubcategory added in v0.7.3

func BySubcategory(opts ...sql.OrderTermOption) OrderOption

BySubcategory orders the results by the subcategory field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to