controlimplementationhistory

package
v0.42.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the controlimplementationhistory type in the database.
	Label = "control_implementation_history"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldHistoryTime holds the string denoting the history_time field in the database.
	FieldHistoryTime = "history_time"
	// FieldRef holds the string denoting the ref field in the database.
	FieldRef = "ref"
	// FieldOperation holds the string denoting the operation field in the database.
	FieldOperation = "operation"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldSystemOwned holds the string denoting the system_owned field in the database.
	FieldSystemOwned = "system_owned"
	// FieldInternalNotes holds the string denoting the internal_notes field in the database.
	FieldInternalNotes = "internal_notes"
	// FieldSystemInternalID holds the string denoting the system_internal_id field in the database.
	FieldSystemInternalID = "system_internal_id"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldImplementationDate holds the string denoting the implementation_date field in the database.
	FieldImplementationDate = "implementation_date"
	// FieldVerified holds the string denoting the verified field in the database.
	FieldVerified = "verified"
	// FieldVerificationDate holds the string denoting the verification_date field in the database.
	FieldVerificationDate = "verification_date"
	// FieldDetails holds the string denoting the details field in the database.
	FieldDetails = "details"
	// Table holds the table name of the controlimplementationhistory in the database.
	Table = "control_implementation_history"
)
const DefaultStatus enums.DocumentStatus = "DRAFT"

Variables

var (
	Hooks        [1]ent.Hook
	Interceptors [1]ent.Interceptor
	Policy       ent.Policy
	// DefaultHistoryTime holds the default value on creation for the "history_time" field.
	DefaultHistoryTime func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// DefaultSystemOwned holds the default value on creation for the "system_owned" field.
	DefaultSystemOwned bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for controlimplementationhistory fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.ControlImplementationHistory

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.ControlImplementationHistory

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.ControlImplementationHistory

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.ControlImplementationHistory

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.ControlImplementationHistory

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.ControlImplementationHistory

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.ControlImplementationHistory

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.ControlImplementationHistory

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.ControlImplementationHistory

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.ControlImplementationHistory

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.ControlImplementationHistory

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.ControlImplementationHistory

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.ControlImplementationHistory

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.ControlImplementationHistory

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.ControlImplementationHistory

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.ControlImplementationHistory

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.ControlImplementationHistory

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.ControlImplementationHistory

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.ControlImplementationHistory

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.ControlImplementationHistory

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.ControlImplementationHistory

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.ControlImplementationHistory

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func Details

Details applies equality check predicate on the "details" field. It's identical to DetailsEQ.

func DetailsContains

DetailsContains applies the Contains predicate on the "details" field.

func DetailsContainsFold

func DetailsContainsFold(v string) predicate.ControlImplementationHistory

DetailsContainsFold applies the ContainsFold predicate on the "details" field.

func DetailsEQ

DetailsEQ applies the EQ predicate on the "details" field.

func DetailsEqualFold

func DetailsEqualFold(v string) predicate.ControlImplementationHistory

DetailsEqualFold applies the EqualFold predicate on the "details" field.

func DetailsGT

DetailsGT applies the GT predicate on the "details" field.

func DetailsGTE

DetailsGTE applies the GTE predicate on the "details" field.

func DetailsHasPrefix

func DetailsHasPrefix(v string) predicate.ControlImplementationHistory

DetailsHasPrefix applies the HasPrefix predicate on the "details" field.

func DetailsHasSuffix

func DetailsHasSuffix(v string) predicate.ControlImplementationHistory

DetailsHasSuffix applies the HasSuffix predicate on the "details" field.

func DetailsIn

DetailsIn applies the In predicate on the "details" field.

func DetailsIsNil

DetailsIsNil applies the IsNil predicate on the "details" field.

func DetailsLT

DetailsLT applies the LT predicate on the "details" field.

func DetailsLTE

DetailsLTE applies the LTE predicate on the "details" field.

func DetailsNEQ

DetailsNEQ applies the NEQ predicate on the "details" field.

func DetailsNotIn

func DetailsNotIn(vs ...string) predicate.ControlImplementationHistory

DetailsNotIn applies the NotIn predicate on the "details" field.

func DetailsNotNil

DetailsNotNil applies the NotNil predicate on the "details" field.

func HistoryTime

HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.

func HistoryTimeEQ

HistoryTimeEQ applies the EQ predicate on the "history_time" field.

func HistoryTimeGT

HistoryTimeGT applies the GT predicate on the "history_time" field.

func HistoryTimeGTE

HistoryTimeGTE applies the GTE predicate on the "history_time" field.

func HistoryTimeIn

func HistoryTimeIn(vs ...time.Time) predicate.ControlImplementationHistory

HistoryTimeIn applies the In predicate on the "history_time" field.

func HistoryTimeLT

HistoryTimeLT applies the LT predicate on the "history_time" field.

func HistoryTimeLTE

HistoryTimeLTE applies the LTE predicate on the "history_time" field.

func HistoryTimeNEQ

HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.

func HistoryTimeNotIn

func HistoryTimeNotIn(vs ...time.Time) predicate.ControlImplementationHistory

HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

IDNotIn applies the NotIn predicate on the ID field.

func ImplementationDate

func ImplementationDate(v time.Time) predicate.ControlImplementationHistory

ImplementationDate applies equality check predicate on the "implementation_date" field. It's identical to ImplementationDateEQ.

func ImplementationDateEQ

func ImplementationDateEQ(v time.Time) predicate.ControlImplementationHistory

ImplementationDateEQ applies the EQ predicate on the "implementation_date" field.

func ImplementationDateGT

func ImplementationDateGT(v time.Time) predicate.ControlImplementationHistory

ImplementationDateGT applies the GT predicate on the "implementation_date" field.

func ImplementationDateGTE

func ImplementationDateGTE(v time.Time) predicate.ControlImplementationHistory

ImplementationDateGTE applies the GTE predicate on the "implementation_date" field.

func ImplementationDateIn

func ImplementationDateIn(vs ...time.Time) predicate.ControlImplementationHistory

ImplementationDateIn applies the In predicate on the "implementation_date" field.

func ImplementationDateIsNil

func ImplementationDateIsNil() predicate.ControlImplementationHistory

ImplementationDateIsNil applies the IsNil predicate on the "implementation_date" field.

func ImplementationDateLT

func ImplementationDateLT(v time.Time) predicate.ControlImplementationHistory

ImplementationDateLT applies the LT predicate on the "implementation_date" field.

func ImplementationDateLTE

func ImplementationDateLTE(v time.Time) predicate.ControlImplementationHistory

ImplementationDateLTE applies the LTE predicate on the "implementation_date" field.

func ImplementationDateNEQ

func ImplementationDateNEQ(v time.Time) predicate.ControlImplementationHistory

ImplementationDateNEQ applies the NEQ predicate on the "implementation_date" field.

func ImplementationDateNotIn

func ImplementationDateNotIn(vs ...time.Time) predicate.ControlImplementationHistory

ImplementationDateNotIn applies the NotIn predicate on the "implementation_date" field.

func ImplementationDateNotNil

func ImplementationDateNotNil() predicate.ControlImplementationHistory

ImplementationDateNotNil applies the NotNil predicate on the "implementation_date" field.

func InternalNotes added in v0.34.0

InternalNotes applies equality check predicate on the "internal_notes" field. It's identical to InternalNotesEQ.

func InternalNotesContains added in v0.34.0

func InternalNotesContains(v string) predicate.ControlImplementationHistory

InternalNotesContains applies the Contains predicate on the "internal_notes" field.

func InternalNotesContainsFold added in v0.34.0

func InternalNotesContainsFold(v string) predicate.ControlImplementationHistory

InternalNotesContainsFold applies the ContainsFold predicate on the "internal_notes" field.

func InternalNotesEQ added in v0.34.0

InternalNotesEQ applies the EQ predicate on the "internal_notes" field.

func InternalNotesEqualFold added in v0.34.0

func InternalNotesEqualFold(v string) predicate.ControlImplementationHistory

InternalNotesEqualFold applies the EqualFold predicate on the "internal_notes" field.

func InternalNotesGT added in v0.34.0

InternalNotesGT applies the GT predicate on the "internal_notes" field.

func InternalNotesGTE added in v0.34.0

func InternalNotesGTE(v string) predicate.ControlImplementationHistory

InternalNotesGTE applies the GTE predicate on the "internal_notes" field.

func InternalNotesHasPrefix added in v0.34.0

func InternalNotesHasPrefix(v string) predicate.ControlImplementationHistory

InternalNotesHasPrefix applies the HasPrefix predicate on the "internal_notes" field.

func InternalNotesHasSuffix added in v0.34.0

func InternalNotesHasSuffix(v string) predicate.ControlImplementationHistory

InternalNotesHasSuffix applies the HasSuffix predicate on the "internal_notes" field.

func InternalNotesIn added in v0.34.0

func InternalNotesIn(vs ...string) predicate.ControlImplementationHistory

InternalNotesIn applies the In predicate on the "internal_notes" field.

func InternalNotesIsNil added in v0.34.0

func InternalNotesIsNil() predicate.ControlImplementationHistory

InternalNotesIsNil applies the IsNil predicate on the "internal_notes" field.

func InternalNotesLT added in v0.34.0

InternalNotesLT applies the LT predicate on the "internal_notes" field.

func InternalNotesLTE added in v0.34.0

func InternalNotesLTE(v string) predicate.ControlImplementationHistory

InternalNotesLTE applies the LTE predicate on the "internal_notes" field.

func InternalNotesNEQ added in v0.34.0

func InternalNotesNEQ(v string) predicate.ControlImplementationHistory

InternalNotesNEQ applies the NEQ predicate on the "internal_notes" field.

func InternalNotesNotIn added in v0.34.0

func InternalNotesNotIn(vs ...string) predicate.ControlImplementationHistory

InternalNotesNotIn applies the NotIn predicate on the "internal_notes" field.

func InternalNotesNotNil added in v0.34.0

func InternalNotesNotNil() predicate.ControlImplementationHistory

InternalNotesNotNil applies the NotNil predicate on the "internal_notes" field.

func Not

Not applies the not operator on the given predicate.

func OperationEQ

OperationEQ applies the EQ predicate on the "operation" field.

func OperationIn

OperationIn applies the In predicate on the "operation" field.

func OperationNEQ

OperationNEQ applies the NEQ predicate on the "operation" field.

func OperationNotIn

OperationNotIn applies the NotIn predicate on the "operation" field.

func OperationValidator

func OperationValidator(o history.OpType) error

OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.

func Or

Or groups predicates with the OR operator between them.

func OwnerID added in v0.8.9

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains added in v0.8.9

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold added in v0.8.9

func OwnerIDContainsFold(v string) predicate.ControlImplementationHistory

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ added in v0.8.9

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold added in v0.8.9

func OwnerIDEqualFold(v string) predicate.ControlImplementationHistory

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT added in v0.8.9

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE added in v0.8.9

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix added in v0.8.9

func OwnerIDHasPrefix(v string) predicate.ControlImplementationHistory

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix added in v0.8.9

func OwnerIDHasSuffix(v string) predicate.ControlImplementationHistory

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn added in v0.8.9

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil added in v0.8.9

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT added in v0.8.9

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE added in v0.8.9

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ added in v0.8.9

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn added in v0.8.9

func OwnerIDNotIn(vs ...string) predicate.ControlImplementationHistory

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil added in v0.8.9

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func Ref

Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.

func RefContains

RefContains applies the Contains predicate on the "ref" field.

func RefContainsFold

RefContainsFold applies the ContainsFold predicate on the "ref" field.

func RefEQ

RefEQ applies the EQ predicate on the "ref" field.

func RefEqualFold

RefEqualFold applies the EqualFold predicate on the "ref" field.

func RefGT

RefGT applies the GT predicate on the "ref" field.

func RefGTE

RefGTE applies the GTE predicate on the "ref" field.

func RefHasPrefix

RefHasPrefix applies the HasPrefix predicate on the "ref" field.

func RefHasSuffix

RefHasSuffix applies the HasSuffix predicate on the "ref" field.

func RefIn

RefIn applies the In predicate on the "ref" field.

func RefIsNil

RefIsNil applies the IsNil predicate on the "ref" field.

func RefLT

RefLT applies the LT predicate on the "ref" field.

func RefLTE

RefLTE applies the LTE predicate on the "ref" field.

func RefNEQ

RefNEQ applies the NEQ predicate on the "ref" field.

func RefNotIn

RefNotIn applies the NotIn predicate on the "ref" field.

func RefNotNil

RefNotNil applies the NotNil predicate on the "ref" field.

func StatusEQ

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

StatusIn applies the In predicate on the "status" field.

func StatusIsNil

StatusIsNil applies the IsNil predicate on the "status" field.

func StatusNEQ

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusNotNil

StatusNotNil applies the NotNil predicate on the "status" field.

func StatusValidator added in v0.7.5

func StatusValidator(s enums.DocumentStatus) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func SystemInternalID added in v0.34.0

func SystemInternalID(v string) predicate.ControlImplementationHistory

SystemInternalID applies equality check predicate on the "system_internal_id" field. It's identical to SystemInternalIDEQ.

func SystemInternalIDContains added in v0.34.0

func SystemInternalIDContains(v string) predicate.ControlImplementationHistory

SystemInternalIDContains applies the Contains predicate on the "system_internal_id" field.

func SystemInternalIDContainsFold added in v0.34.0

func SystemInternalIDContainsFold(v string) predicate.ControlImplementationHistory

SystemInternalIDContainsFold applies the ContainsFold predicate on the "system_internal_id" field.

func SystemInternalIDEQ added in v0.34.0

func SystemInternalIDEQ(v string) predicate.ControlImplementationHistory

SystemInternalIDEQ applies the EQ predicate on the "system_internal_id" field.

func SystemInternalIDEqualFold added in v0.34.0

func SystemInternalIDEqualFold(v string) predicate.ControlImplementationHistory

SystemInternalIDEqualFold applies the EqualFold predicate on the "system_internal_id" field.

func SystemInternalIDGT added in v0.34.0

func SystemInternalIDGT(v string) predicate.ControlImplementationHistory

SystemInternalIDGT applies the GT predicate on the "system_internal_id" field.

func SystemInternalIDGTE added in v0.34.0

func SystemInternalIDGTE(v string) predicate.ControlImplementationHistory

SystemInternalIDGTE applies the GTE predicate on the "system_internal_id" field.

func SystemInternalIDHasPrefix added in v0.34.0

func SystemInternalIDHasPrefix(v string) predicate.ControlImplementationHistory

SystemInternalIDHasPrefix applies the HasPrefix predicate on the "system_internal_id" field.

func SystemInternalIDHasSuffix added in v0.34.0

func SystemInternalIDHasSuffix(v string) predicate.ControlImplementationHistory

SystemInternalIDHasSuffix applies the HasSuffix predicate on the "system_internal_id" field.

func SystemInternalIDIn added in v0.34.0

func SystemInternalIDIn(vs ...string) predicate.ControlImplementationHistory

SystemInternalIDIn applies the In predicate on the "system_internal_id" field.

func SystemInternalIDIsNil added in v0.34.0

func SystemInternalIDIsNil() predicate.ControlImplementationHistory

SystemInternalIDIsNil applies the IsNil predicate on the "system_internal_id" field.

func SystemInternalIDLT added in v0.34.0

func SystemInternalIDLT(v string) predicate.ControlImplementationHistory

SystemInternalIDLT applies the LT predicate on the "system_internal_id" field.

func SystemInternalIDLTE added in v0.34.0

func SystemInternalIDLTE(v string) predicate.ControlImplementationHistory

SystemInternalIDLTE applies the LTE predicate on the "system_internal_id" field.

func SystemInternalIDNEQ added in v0.34.0

func SystemInternalIDNEQ(v string) predicate.ControlImplementationHistory

SystemInternalIDNEQ applies the NEQ predicate on the "system_internal_id" field.

func SystemInternalIDNotIn added in v0.34.0

func SystemInternalIDNotIn(vs ...string) predicate.ControlImplementationHistory

SystemInternalIDNotIn applies the NotIn predicate on the "system_internal_id" field.

func SystemInternalIDNotNil added in v0.34.0

func SystemInternalIDNotNil() predicate.ControlImplementationHistory

SystemInternalIDNotNil applies the NotNil predicate on the "system_internal_id" field.

func SystemOwned added in v0.34.0

SystemOwned applies equality check predicate on the "system_owned" field. It's identical to SystemOwnedEQ.

func SystemOwnedEQ added in v0.34.0

SystemOwnedEQ applies the EQ predicate on the "system_owned" field.

func SystemOwnedIsNil added in v0.34.0

func SystemOwnedIsNil() predicate.ControlImplementationHistory

SystemOwnedIsNil applies the IsNil predicate on the "system_owned" field.

func SystemOwnedNEQ added in v0.34.0

SystemOwnedNEQ applies the NEQ predicate on the "system_owned" field.

func SystemOwnedNotNil added in v0.34.0

func SystemOwnedNotNil() predicate.ControlImplementationHistory

SystemOwnedNotNil applies the NotNil predicate on the "system_owned" field.

func TagsIsNil

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.ControlImplementationHistory

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.ControlImplementationHistory

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.ControlImplementationHistory

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.ControlImplementationHistory

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.ControlImplementationHistory

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.ControlImplementationHistory

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.ControlImplementationHistory

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.ControlImplementationHistory

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.ControlImplementationHistory

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.ControlImplementationHistory

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.ControlImplementationHistory

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func VerificationDate

func VerificationDate(v time.Time) predicate.ControlImplementationHistory

VerificationDate applies equality check predicate on the "verification_date" field. It's identical to VerificationDateEQ.

func VerificationDateEQ

func VerificationDateEQ(v time.Time) predicate.ControlImplementationHistory

VerificationDateEQ applies the EQ predicate on the "verification_date" field.

func VerificationDateGT

func VerificationDateGT(v time.Time) predicate.ControlImplementationHistory

VerificationDateGT applies the GT predicate on the "verification_date" field.

func VerificationDateGTE

func VerificationDateGTE(v time.Time) predicate.ControlImplementationHistory

VerificationDateGTE applies the GTE predicate on the "verification_date" field.

func VerificationDateIn

func VerificationDateIn(vs ...time.Time) predicate.ControlImplementationHistory

VerificationDateIn applies the In predicate on the "verification_date" field.

func VerificationDateIsNil

func VerificationDateIsNil() predicate.ControlImplementationHistory

VerificationDateIsNil applies the IsNil predicate on the "verification_date" field.

func VerificationDateLT

func VerificationDateLT(v time.Time) predicate.ControlImplementationHistory

VerificationDateLT applies the LT predicate on the "verification_date" field.

func VerificationDateLTE

func VerificationDateLTE(v time.Time) predicate.ControlImplementationHistory

VerificationDateLTE applies the LTE predicate on the "verification_date" field.

func VerificationDateNEQ

func VerificationDateNEQ(v time.Time) predicate.ControlImplementationHistory

VerificationDateNEQ applies the NEQ predicate on the "verification_date" field.

func VerificationDateNotIn

func VerificationDateNotIn(vs ...time.Time) predicate.ControlImplementationHistory

VerificationDateNotIn applies the NotIn predicate on the "verification_date" field.

func VerificationDateNotNil

func VerificationDateNotNil() predicate.ControlImplementationHistory

VerificationDateNotNil applies the NotNil predicate on the "verification_date" field.

func Verified

Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.

func VerifiedEQ

VerifiedEQ applies the EQ predicate on the "verified" field.

func VerifiedIsNil

VerifiedIsNil applies the IsNil predicate on the "verified" field.

func VerifiedNEQ

VerifiedNEQ applies the NEQ predicate on the "verified" field.

func VerifiedNotNil

func VerifiedNotNil() predicate.ControlImplementationHistory

VerifiedNotNil applies the NotNil predicate on the "verified" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ControlImplementationHistory queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByDetails

func ByDetails(opts ...sql.OrderTermOption) OrderOption

ByDetails orders the results by the details field.

func ByHistoryTime

func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption

ByHistoryTime orders the results by the history_time field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByImplementationDate

func ByImplementationDate(opts ...sql.OrderTermOption) OrderOption

ByImplementationDate orders the results by the implementation_date field.

func ByInternalNotes added in v0.34.0

func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption

ByInternalNotes orders the results by the internal_notes field.

func ByOperation

func ByOperation(opts ...sql.OrderTermOption) OrderOption

ByOperation orders the results by the operation field.

func ByOwnerID added in v0.8.9

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByRef

func ByRef(opts ...sql.OrderTermOption) OrderOption

ByRef orders the results by the ref field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func BySystemInternalID added in v0.34.0

func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption

BySystemInternalID orders the results by the system_internal_id field.

func BySystemOwned added in v0.34.0

func BySystemOwned(opts ...sql.OrderTermOption) OrderOption

BySystemOwned orders the results by the system_owned field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

func ByVerificationDate

func ByVerificationDate(opts ...sql.OrderTermOption) OrderOption

ByVerificationDate orders the results by the verification_date field.

func ByVerified

func ByVerified(opts ...sql.OrderTermOption) OrderOption

ByVerified orders the results by the verified field.

Jump to