Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.CustomDomain) predicate.CustomDomain
- func CnameRecord(v string) predicate.CustomDomain
- func CnameRecordContains(v string) predicate.CustomDomain
- func CnameRecordContainsFold(v string) predicate.CustomDomain
- func CnameRecordEQ(v string) predicate.CustomDomain
- func CnameRecordEqualFold(v string) predicate.CustomDomain
- func CnameRecordGT(v string) predicate.CustomDomain
- func CnameRecordGTE(v string) predicate.CustomDomain
- func CnameRecordHasPrefix(v string) predicate.CustomDomain
- func CnameRecordHasSuffix(v string) predicate.CustomDomain
- func CnameRecordIn(vs ...string) predicate.CustomDomain
- func CnameRecordLT(v string) predicate.CustomDomain
- func CnameRecordLTE(v string) predicate.CustomDomain
- func CnameRecordNEQ(v string) predicate.CustomDomain
- func CnameRecordNotIn(vs ...string) predicate.CustomDomain
- func CreatedAt(v time.Time) predicate.CustomDomain
- func CreatedAtEQ(v time.Time) predicate.CustomDomain
- func CreatedAtGT(v time.Time) predicate.CustomDomain
- func CreatedAtGTE(v time.Time) predicate.CustomDomain
- func CreatedAtIn(vs ...time.Time) predicate.CustomDomain
- func CreatedAtIsNil() predicate.CustomDomain
- func CreatedAtLT(v time.Time) predicate.CustomDomain
- func CreatedAtLTE(v time.Time) predicate.CustomDomain
- func CreatedAtNEQ(v time.Time) predicate.CustomDomain
- func CreatedAtNotIn(vs ...time.Time) predicate.CustomDomain
- func CreatedAtNotNil() predicate.CustomDomain
- func CreatedBy(v string) predicate.CustomDomain
- func CreatedByContains(v string) predicate.CustomDomain
- func CreatedByContainsFold(v string) predicate.CustomDomain
- func CreatedByEQ(v string) predicate.CustomDomain
- func CreatedByEqualFold(v string) predicate.CustomDomain
- func CreatedByGT(v string) predicate.CustomDomain
- func CreatedByGTE(v string) predicate.CustomDomain
- func CreatedByHasPrefix(v string) predicate.CustomDomain
- func CreatedByHasSuffix(v string) predicate.CustomDomain
- func CreatedByIn(vs ...string) predicate.CustomDomain
- func CreatedByIsNil() predicate.CustomDomain
- func CreatedByLT(v string) predicate.CustomDomain
- func CreatedByLTE(v string) predicate.CustomDomain
- func CreatedByNEQ(v string) predicate.CustomDomain
- func CreatedByNotIn(vs ...string) predicate.CustomDomain
- func CreatedByNotNil() predicate.CustomDomain
- func DeletedAt(v time.Time) predicate.CustomDomain
- func DeletedAtEQ(v time.Time) predicate.CustomDomain
- func DeletedAtGT(v time.Time) predicate.CustomDomain
- func DeletedAtGTE(v time.Time) predicate.CustomDomain
- func DeletedAtIn(vs ...time.Time) predicate.CustomDomain
- func DeletedAtIsNil() predicate.CustomDomain
- func DeletedAtLT(v time.Time) predicate.CustomDomain
- func DeletedAtLTE(v time.Time) predicate.CustomDomain
- func DeletedAtNEQ(v time.Time) predicate.CustomDomain
- func DeletedAtNotIn(vs ...time.Time) predicate.CustomDomain
- func DeletedAtNotNil() predicate.CustomDomain
- func DeletedBy(v string) predicate.CustomDomain
- func DeletedByContains(v string) predicate.CustomDomain
- func DeletedByContainsFold(v string) predicate.CustomDomain
- func DeletedByEQ(v string) predicate.CustomDomain
- func DeletedByEqualFold(v string) predicate.CustomDomain
- func DeletedByGT(v string) predicate.CustomDomain
- func DeletedByGTE(v string) predicate.CustomDomain
- func DeletedByHasPrefix(v string) predicate.CustomDomain
- func DeletedByHasSuffix(v string) predicate.CustomDomain
- func DeletedByIn(vs ...string) predicate.CustomDomain
- func DeletedByIsNil() predicate.CustomDomain
- func DeletedByLT(v string) predicate.CustomDomain
- func DeletedByLTE(v string) predicate.CustomDomain
- func DeletedByNEQ(v string) predicate.CustomDomain
- func DeletedByNotIn(vs ...string) predicate.CustomDomain
- func DeletedByNotNil() predicate.CustomDomain
- func HasMappableDomain() predicate.CustomDomain
- func HasMappableDomainWith(preds ...predicate.MappableDomain) predicate.CustomDomain
- func HasOwner() predicate.CustomDomain
- func HasOwnerWith(preds ...predicate.Organization) predicate.CustomDomain
- func ID(id string) predicate.CustomDomain
- func IDContainsFold(id string) predicate.CustomDomain
- func IDEQ(id string) predicate.CustomDomain
- func IDEqualFold(id string) predicate.CustomDomain
- func IDGT(id string) predicate.CustomDomain
- func IDGTE(id string) predicate.CustomDomain
- func IDIn(ids ...string) predicate.CustomDomain
- func IDLT(id string) predicate.CustomDomain
- func IDLTE(id string) predicate.CustomDomain
- func IDNEQ(id string) predicate.CustomDomain
- func IDNotIn(ids ...string) predicate.CustomDomain
- func MappableDomainID(v string) predicate.CustomDomain
- func MappableDomainIDContains(v string) predicate.CustomDomain
- func MappableDomainIDContainsFold(v string) predicate.CustomDomain
- func MappableDomainIDEQ(v string) predicate.CustomDomain
- func MappableDomainIDEqualFold(v string) predicate.CustomDomain
- func MappableDomainIDGT(v string) predicate.CustomDomain
- func MappableDomainIDGTE(v string) predicate.CustomDomain
- func MappableDomainIDHasPrefix(v string) predicate.CustomDomain
- func MappableDomainIDHasSuffix(v string) predicate.CustomDomain
- func MappableDomainIDIn(vs ...string) predicate.CustomDomain
- func MappableDomainIDLT(v string) predicate.CustomDomain
- func MappableDomainIDLTE(v string) predicate.CustomDomain
- func MappableDomainIDNEQ(v string) predicate.CustomDomain
- func MappableDomainIDNotIn(vs ...string) predicate.CustomDomain
- func Not(p predicate.CustomDomain) predicate.CustomDomain
- func Or(predicates ...predicate.CustomDomain) predicate.CustomDomain
- func OwnerID(v string) predicate.CustomDomain
- func OwnerIDContains(v string) predicate.CustomDomain
- func OwnerIDContainsFold(v string) predicate.CustomDomain
- func OwnerIDEQ(v string) predicate.CustomDomain
- func OwnerIDEqualFold(v string) predicate.CustomDomain
- func OwnerIDGT(v string) predicate.CustomDomain
- func OwnerIDGTE(v string) predicate.CustomDomain
- func OwnerIDHasPrefix(v string) predicate.CustomDomain
- func OwnerIDHasSuffix(v string) predicate.CustomDomain
- func OwnerIDIn(vs ...string) predicate.CustomDomain
- func OwnerIDIsNil() predicate.CustomDomain
- func OwnerIDLT(v string) predicate.CustomDomain
- func OwnerIDLTE(v string) predicate.CustomDomain
- func OwnerIDNEQ(v string) predicate.CustomDomain
- func OwnerIDNotIn(vs ...string) predicate.CustomDomain
- func OwnerIDNotNil() predicate.CustomDomain
- func TagsIsNil() predicate.CustomDomain
- func TagsNotNil() predicate.CustomDomain
- func UpdatedAt(v time.Time) predicate.CustomDomain
- func UpdatedAtEQ(v time.Time) predicate.CustomDomain
- func UpdatedAtGT(v time.Time) predicate.CustomDomain
- func UpdatedAtGTE(v time.Time) predicate.CustomDomain
- func UpdatedAtIn(vs ...time.Time) predicate.CustomDomain
- func UpdatedAtIsNil() predicate.CustomDomain
- func UpdatedAtLT(v time.Time) predicate.CustomDomain
- func UpdatedAtLTE(v time.Time) predicate.CustomDomain
- func UpdatedAtNEQ(v time.Time) predicate.CustomDomain
- func UpdatedAtNotIn(vs ...time.Time) predicate.CustomDomain
- func UpdatedAtNotNil() predicate.CustomDomain
- func UpdatedBy(v string) predicate.CustomDomain
- func UpdatedByContains(v string) predicate.CustomDomain
- func UpdatedByContainsFold(v string) predicate.CustomDomain
- func UpdatedByEQ(v string) predicate.CustomDomain
- func UpdatedByEqualFold(v string) predicate.CustomDomain
- func UpdatedByGT(v string) predicate.CustomDomain
- func UpdatedByGTE(v string) predicate.CustomDomain
- func UpdatedByHasPrefix(v string) predicate.CustomDomain
- func UpdatedByHasSuffix(v string) predicate.CustomDomain
- func UpdatedByIn(vs ...string) predicate.CustomDomain
- func UpdatedByIsNil() predicate.CustomDomain
- func UpdatedByLT(v string) predicate.CustomDomain
- func UpdatedByLTE(v string) predicate.CustomDomain
- func UpdatedByNEQ(v string) predicate.CustomDomain
- func UpdatedByNotIn(vs ...string) predicate.CustomDomain
- func UpdatedByNotNil() predicate.CustomDomain
- func ValidColumn(column string) bool
- type OrderOption
- func ByCnameRecord(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMappableDomainField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByMappableDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the customdomain type in the database. Label = "custom_domain" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldCnameRecord holds the string denoting the cname_record field in the database. FieldCnameRecord = "cname_record" // FieldMappableDomainID holds the string denoting the mappable_domain_id field in the database. FieldMappableDomainID = "mappable_domain_id" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // EdgeMappableDomain holds the string denoting the mappable_domain edge name in mutations. EdgeMappableDomain = "mappable_domain" // Table holds the table name of the customdomain in the database. Table = "custom_domains" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "custom_domains" // OwnerInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OwnerInverseTable = "organizations" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "owner_id" // MappableDomainTable is the table that holds the mappable_domain relation/edge. MappableDomainTable = "custom_domains" // MappableDomainInverseTable is the table name for the MappableDomain entity. // It exists in this package in order to avoid circular dependency with the "mappabledomain" package. MappableDomainInverseTable = "mappable_domains" // MappableDomainColumn is the table column denoting the mappable_domain relation/edge. MappableDomainColumn = "mappable_domain_id" )
Variables ¶
var ( Hooks [5]ent.Hook Interceptors [2]ent.Interceptor Policy ent.Policy // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultTags holds the default value on creation for the "tags" field. DefaultTags []string // OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save. OwnerIDValidator func(string) error // CnameRecordValidator is a validator for the "cname_record" field. It is called by the builders before save. CnameRecordValidator func(string) error // MappableDomainIDValidator is a validator for the "mappable_domain_id" field. It is called by the builders before save. MappableDomainIDValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldTags, FieldOwnerID, FieldCnameRecord, FieldMappableDomainID, }
Columns holds all SQL columns for customdomain fields.
var ForeignKeys = []string{
"mappable_domain_custom_domains",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "custom_domains" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.CustomDomain) predicate.CustomDomain
And groups predicates with the AND operator between them.
func CnameRecord ¶
func CnameRecord(v string) predicate.CustomDomain
CnameRecord applies equality check predicate on the "cname_record" field. It's identical to CnameRecordEQ.
func CnameRecordContains ¶
func CnameRecordContains(v string) predicate.CustomDomain
CnameRecordContains applies the Contains predicate on the "cname_record" field.
func CnameRecordContainsFold ¶
func CnameRecordContainsFold(v string) predicate.CustomDomain
CnameRecordContainsFold applies the ContainsFold predicate on the "cname_record" field.
func CnameRecordEQ ¶
func CnameRecordEQ(v string) predicate.CustomDomain
CnameRecordEQ applies the EQ predicate on the "cname_record" field.
func CnameRecordEqualFold ¶
func CnameRecordEqualFold(v string) predicate.CustomDomain
CnameRecordEqualFold applies the EqualFold predicate on the "cname_record" field.
func CnameRecordGT ¶
func CnameRecordGT(v string) predicate.CustomDomain
CnameRecordGT applies the GT predicate on the "cname_record" field.
func CnameRecordGTE ¶
func CnameRecordGTE(v string) predicate.CustomDomain
CnameRecordGTE applies the GTE predicate on the "cname_record" field.
func CnameRecordHasPrefix ¶
func CnameRecordHasPrefix(v string) predicate.CustomDomain
CnameRecordHasPrefix applies the HasPrefix predicate on the "cname_record" field.
func CnameRecordHasSuffix ¶
func CnameRecordHasSuffix(v string) predicate.CustomDomain
CnameRecordHasSuffix applies the HasSuffix predicate on the "cname_record" field.
func CnameRecordIn ¶
func CnameRecordIn(vs ...string) predicate.CustomDomain
CnameRecordIn applies the In predicate on the "cname_record" field.
func CnameRecordLT ¶
func CnameRecordLT(v string) predicate.CustomDomain
CnameRecordLT applies the LT predicate on the "cname_record" field.
func CnameRecordLTE ¶
func CnameRecordLTE(v string) predicate.CustomDomain
CnameRecordLTE applies the LTE predicate on the "cname_record" field.
func CnameRecordNEQ ¶
func CnameRecordNEQ(v string) predicate.CustomDomain
CnameRecordNEQ applies the NEQ predicate on the "cname_record" field.
func CnameRecordNotIn ¶
func CnameRecordNotIn(vs ...string) predicate.CustomDomain
CnameRecordNotIn applies the NotIn predicate on the "cname_record" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.CustomDomain
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.CustomDomain
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.CustomDomain
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.CustomDomain
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.CustomDomain
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.CustomDomain
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.CustomDomain
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.CustomDomain
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.CustomDomain
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.CustomDomain
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.CustomDomain
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
func CreatedBy(v string) predicate.CustomDomain
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
func CreatedByContains(v string) predicate.CustomDomain
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
func CreatedByContainsFold(v string) predicate.CustomDomain
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
func CreatedByEQ(v string) predicate.CustomDomain
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
func CreatedByEqualFold(v string) predicate.CustomDomain
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
func CreatedByGT(v string) predicate.CustomDomain
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
func CreatedByGTE(v string) predicate.CustomDomain
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
func CreatedByHasPrefix(v string) predicate.CustomDomain
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
func CreatedByHasSuffix(v string) predicate.CustomDomain
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
func CreatedByIn(vs ...string) predicate.CustomDomain
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
func CreatedByIsNil() predicate.CustomDomain
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
func CreatedByLT(v string) predicate.CustomDomain
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
func CreatedByLTE(v string) predicate.CustomDomain
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
func CreatedByNEQ(v string) predicate.CustomDomain
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
func CreatedByNotIn(vs ...string) predicate.CustomDomain
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
func CreatedByNotNil() predicate.CustomDomain
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.CustomDomain
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.CustomDomain
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.CustomDomain
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.CustomDomain
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.CustomDomain
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.CustomDomain
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.CustomDomain
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.CustomDomain
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.CustomDomain
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.CustomDomain
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.CustomDomain
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
func DeletedBy(v string) predicate.CustomDomain
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
func DeletedByContains(v string) predicate.CustomDomain
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
func DeletedByContainsFold(v string) predicate.CustomDomain
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
func DeletedByEQ(v string) predicate.CustomDomain
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
func DeletedByEqualFold(v string) predicate.CustomDomain
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
func DeletedByGT(v string) predicate.CustomDomain
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
func DeletedByGTE(v string) predicate.CustomDomain
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
func DeletedByHasPrefix(v string) predicate.CustomDomain
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
func DeletedByHasSuffix(v string) predicate.CustomDomain
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
func DeletedByIn(vs ...string) predicate.CustomDomain
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
func DeletedByIsNil() predicate.CustomDomain
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
func DeletedByLT(v string) predicate.CustomDomain
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
func DeletedByLTE(v string) predicate.CustomDomain
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
func DeletedByNEQ(v string) predicate.CustomDomain
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
func DeletedByNotIn(vs ...string) predicate.CustomDomain
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
func DeletedByNotNil() predicate.CustomDomain
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func HasMappableDomain ¶
func HasMappableDomain() predicate.CustomDomain
HasMappableDomain applies the HasEdge predicate on the "mappable_domain" edge.
func HasMappableDomainWith ¶
func HasMappableDomainWith(preds ...predicate.MappableDomain) predicate.CustomDomain
HasMappableDomainWith applies the HasEdge predicate on the "mappable_domain" edge with a given conditions (other predicates).
func HasOwner ¶
func HasOwner() predicate.CustomDomain
HasOwner applies the HasEdge predicate on the "owner" edge.
func HasOwnerWith ¶
func HasOwnerWith(preds ...predicate.Organization) predicate.CustomDomain
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func IDContainsFold ¶
func IDContainsFold(id string) predicate.CustomDomain
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEQ ¶
func IDEQ(id string) predicate.CustomDomain
IDEQ applies the EQ predicate on the ID field.
func IDEqualFold ¶
func IDEqualFold(id string) predicate.CustomDomain
IDEqualFold applies the EqualFold predicate on the ID field.
func IDGT ¶
func IDGT(id string) predicate.CustomDomain
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id string) predicate.CustomDomain
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...string) predicate.CustomDomain
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id string) predicate.CustomDomain
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id string) predicate.CustomDomain
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id string) predicate.CustomDomain
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...string) predicate.CustomDomain
IDNotIn applies the NotIn predicate on the ID field.
func MappableDomainID ¶
func MappableDomainID(v string) predicate.CustomDomain
MappableDomainID applies equality check predicate on the "mappable_domain_id" field. It's identical to MappableDomainIDEQ.
func MappableDomainIDContains ¶
func MappableDomainIDContains(v string) predicate.CustomDomain
MappableDomainIDContains applies the Contains predicate on the "mappable_domain_id" field.
func MappableDomainIDContainsFold ¶
func MappableDomainIDContainsFold(v string) predicate.CustomDomain
MappableDomainIDContainsFold applies the ContainsFold predicate on the "mappable_domain_id" field.
func MappableDomainIDEQ ¶
func MappableDomainIDEQ(v string) predicate.CustomDomain
MappableDomainIDEQ applies the EQ predicate on the "mappable_domain_id" field.
func MappableDomainIDEqualFold ¶
func MappableDomainIDEqualFold(v string) predicate.CustomDomain
MappableDomainIDEqualFold applies the EqualFold predicate on the "mappable_domain_id" field.
func MappableDomainIDGT ¶
func MappableDomainIDGT(v string) predicate.CustomDomain
MappableDomainIDGT applies the GT predicate on the "mappable_domain_id" field.
func MappableDomainIDGTE ¶
func MappableDomainIDGTE(v string) predicate.CustomDomain
MappableDomainIDGTE applies the GTE predicate on the "mappable_domain_id" field.
func MappableDomainIDHasPrefix ¶
func MappableDomainIDHasPrefix(v string) predicate.CustomDomain
MappableDomainIDHasPrefix applies the HasPrefix predicate on the "mappable_domain_id" field.
func MappableDomainIDHasSuffix ¶
func MappableDomainIDHasSuffix(v string) predicate.CustomDomain
MappableDomainIDHasSuffix applies the HasSuffix predicate on the "mappable_domain_id" field.
func MappableDomainIDIn ¶
func MappableDomainIDIn(vs ...string) predicate.CustomDomain
MappableDomainIDIn applies the In predicate on the "mappable_domain_id" field.
func MappableDomainIDLT ¶
func MappableDomainIDLT(v string) predicate.CustomDomain
MappableDomainIDLT applies the LT predicate on the "mappable_domain_id" field.
func MappableDomainIDLTE ¶
func MappableDomainIDLTE(v string) predicate.CustomDomain
MappableDomainIDLTE applies the LTE predicate on the "mappable_domain_id" field.
func MappableDomainIDNEQ ¶
func MappableDomainIDNEQ(v string) predicate.CustomDomain
MappableDomainIDNEQ applies the NEQ predicate on the "mappable_domain_id" field.
func MappableDomainIDNotIn ¶
func MappableDomainIDNotIn(vs ...string) predicate.CustomDomain
MappableDomainIDNotIn applies the NotIn predicate on the "mappable_domain_id" field.
func Not ¶
func Not(p predicate.CustomDomain) predicate.CustomDomain
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.CustomDomain) predicate.CustomDomain
Or groups predicates with the OR operator between them.
func OwnerID ¶
func OwnerID(v string) predicate.CustomDomain
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDContains ¶
func OwnerIDContains(v string) predicate.CustomDomain
OwnerIDContains applies the Contains predicate on the "owner_id" field.
func OwnerIDContainsFold ¶
func OwnerIDContainsFold(v string) predicate.CustomDomain
OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.
func OwnerIDEQ ¶
func OwnerIDEQ(v string) predicate.CustomDomain
OwnerIDEQ applies the EQ predicate on the "owner_id" field.
func OwnerIDEqualFold ¶
func OwnerIDEqualFold(v string) predicate.CustomDomain
OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.
func OwnerIDGT ¶
func OwnerIDGT(v string) predicate.CustomDomain
OwnerIDGT applies the GT predicate on the "owner_id" field.
func OwnerIDGTE ¶
func OwnerIDGTE(v string) predicate.CustomDomain
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDHasPrefix ¶
func OwnerIDHasPrefix(v string) predicate.CustomDomain
OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.
func OwnerIDHasSuffix ¶
func OwnerIDHasSuffix(v string) predicate.CustomDomain
OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.
func OwnerIDIn ¶
func OwnerIDIn(vs ...string) predicate.CustomDomain
OwnerIDIn applies the In predicate on the "owner_id" field.
func OwnerIDIsNil ¶
func OwnerIDIsNil() predicate.CustomDomain
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLT ¶
func OwnerIDLT(v string) predicate.CustomDomain
OwnerIDLT applies the LT predicate on the "owner_id" field.
func OwnerIDLTE ¶
func OwnerIDLTE(v string) predicate.CustomDomain
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
func OwnerIDNEQ(v string) predicate.CustomDomain
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
func OwnerIDNotIn(vs ...string) predicate.CustomDomain
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
func OwnerIDNotNil() predicate.CustomDomain
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func TagsIsNil ¶
func TagsIsNil() predicate.CustomDomain
TagsIsNil applies the IsNil predicate on the "tags" field.
func TagsNotNil ¶
func TagsNotNil() predicate.CustomDomain
TagsNotNil applies the NotNil predicate on the "tags" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.CustomDomain
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.CustomDomain
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.CustomDomain
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.CustomDomain
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.CustomDomain
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.CustomDomain
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.CustomDomain
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.CustomDomain
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.CustomDomain
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.CustomDomain
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.CustomDomain
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
func UpdatedBy(v string) predicate.CustomDomain
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
func UpdatedByContains(v string) predicate.CustomDomain
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
func UpdatedByContainsFold(v string) predicate.CustomDomain
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
func UpdatedByEQ(v string) predicate.CustomDomain
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
func UpdatedByEqualFold(v string) predicate.CustomDomain
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
func UpdatedByGT(v string) predicate.CustomDomain
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
func UpdatedByGTE(v string) predicate.CustomDomain
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
func UpdatedByHasPrefix(v string) predicate.CustomDomain
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
func UpdatedByHasSuffix(v string) predicate.CustomDomain
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
func UpdatedByIn(vs ...string) predicate.CustomDomain
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
func UpdatedByIsNil() predicate.CustomDomain
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
func UpdatedByLT(v string) predicate.CustomDomain
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
func UpdatedByLTE(v string) predicate.CustomDomain
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
func UpdatedByNEQ(v string) predicate.CustomDomain
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
func UpdatedByNotIn(vs ...string) predicate.CustomDomain
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
func UpdatedByNotNil() predicate.CustomDomain
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the CustomDomain queries.
func ByCnameRecord ¶
func ByCnameRecord(opts ...sql.OrderTermOption) OrderOption
ByCnameRecord orders the results by the cname_record field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMappableDomainField ¶
func ByMappableDomainField(field string, opts ...sql.OrderTermOption) OrderOption
ByMappableDomainField orders the results by mappable_domain field.
func ByMappableDomainID ¶
func ByMappableDomainID(opts ...sql.OrderTermOption) OrderOption
ByMappableDomainID orders the results by the mappable_domain_id field.
func ByOwnerField ¶
func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
ByOwnerField orders the results by owner field.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.