jobresult

package
v0.19.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the jobresult type in the database.
	Label = "job_result"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldScheduledJobID holds the string denoting the scheduled_job_id field in the database.
	FieldScheduledJobID = "scheduled_job_id"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldExitCode holds the string denoting the exit_code field in the database.
	FieldExitCode = "exit_code"
	// FieldFinishedAt holds the string denoting the finished_at field in the database.
	FieldFinishedAt = "finished_at"
	// FieldStartedAt holds the string denoting the started_at field in the database.
	FieldStartedAt = "started_at"
	// FieldFileID holds the string denoting the file_id field in the database.
	FieldFileID = "file_id"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// EdgeScheduledJob holds the string denoting the scheduled_job edge name in mutations.
	EdgeScheduledJob = "scheduled_job"
	// EdgeFile holds the string denoting the file edge name in mutations.
	EdgeFile = "file"
	// Table holds the table name of the jobresult in the database.
	Table = "job_results"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "job_results"
	// OwnerInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OwnerInverseTable = "organizations"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
	// ScheduledJobTable is the table that holds the scheduled_job relation/edge.
	ScheduledJobTable = "job_results"
	// ScheduledJobInverseTable is the table name for the ControlScheduledJob entity.
	// It exists in this package in order to avoid circular dependency with the "controlscheduledjob" package.
	ScheduledJobInverseTable = "control_scheduled_jobs"
	// ScheduledJobColumn is the table column denoting the scheduled_job relation/edge.
	ScheduledJobColumn = "scheduled_job_id"
	// FileTable is the table that holds the file relation/edge.
	FileTable = "job_results"
	// FileInverseTable is the table name for the File entity.
	// It exists in this package in order to avoid circular dependency with the "file" package.
	FileInverseTable = "files"
	// FileColumn is the table column denoting the file relation/edge.
	FileColumn = "file_id"
)

Variables

var (
	Hooks        [4]ent.Hook
	Interceptors [2]ent.Interceptor
	Policy       ent.Policy
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save.
	OwnerIDValidator func(string) error
	// ExitCodeValidator is a validator for the "exit_code" field. It is called by the builders before save.
	ExitCodeValidator func(int) error
	// DefaultFinishedAt holds the default value on creation for the "finished_at" field.
	DefaultFinishedAt func() time.Time
	// DefaultStartedAt holds the default value on creation for the "started_at" field.
	DefaultStartedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for jobresult fields.

Functions

func And

func And(predicates ...predicate.JobResult) predicate.JobResult

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.JobResult

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.JobResult

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.JobResult

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.JobResult

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.JobResult

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.JobResult

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.JobResult

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.JobResult

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.JobResult

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.JobResult

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.JobResult

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.JobResult

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.JobResult

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.JobResult

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.JobResult

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.JobResult

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.JobResult

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.JobResult

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.JobResult

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.JobResult

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.JobResult

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.JobResult

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.JobResult

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.JobResult

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.JobResult

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.JobResult

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.JobResult

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.JobResult

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.JobResult

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.JobResult

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.JobResult

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.JobResult

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.JobResult

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.JobResult

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.JobResult

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.JobResult

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.JobResult

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.JobResult

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.JobResult

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.JobResult

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.JobResult

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.JobResult

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.JobResult

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.JobResult

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.JobResult

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.JobResult

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.JobResult

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.JobResult

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.JobResult

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.JobResult

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.JobResult

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.JobResult

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.JobResult

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.JobResult

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func ExitCode

func ExitCode(v int) predicate.JobResult

ExitCode applies equality check predicate on the "exit_code" field. It's identical to ExitCodeEQ.

func ExitCodeEQ

func ExitCodeEQ(v int) predicate.JobResult

ExitCodeEQ applies the EQ predicate on the "exit_code" field.

func ExitCodeGT

func ExitCodeGT(v int) predicate.JobResult

ExitCodeGT applies the GT predicate on the "exit_code" field.

func ExitCodeGTE

func ExitCodeGTE(v int) predicate.JobResult

ExitCodeGTE applies the GTE predicate on the "exit_code" field.

func ExitCodeIn

func ExitCodeIn(vs ...int) predicate.JobResult

ExitCodeIn applies the In predicate on the "exit_code" field.

func ExitCodeLT

func ExitCodeLT(v int) predicate.JobResult

ExitCodeLT applies the LT predicate on the "exit_code" field.

func ExitCodeLTE

func ExitCodeLTE(v int) predicate.JobResult

ExitCodeLTE applies the LTE predicate on the "exit_code" field.

func ExitCodeNEQ

func ExitCodeNEQ(v int) predicate.JobResult

ExitCodeNEQ applies the NEQ predicate on the "exit_code" field.

func ExitCodeNotIn

func ExitCodeNotIn(vs ...int) predicate.JobResult

ExitCodeNotIn applies the NotIn predicate on the "exit_code" field.

func FileID

func FileID(v string) predicate.JobResult

FileID applies equality check predicate on the "file_id" field. It's identical to FileIDEQ.

func FileIDContains

func FileIDContains(v string) predicate.JobResult

FileIDContains applies the Contains predicate on the "file_id" field.

func FileIDContainsFold

func FileIDContainsFold(v string) predicate.JobResult

FileIDContainsFold applies the ContainsFold predicate on the "file_id" field.

func FileIDEQ

func FileIDEQ(v string) predicate.JobResult

FileIDEQ applies the EQ predicate on the "file_id" field.

func FileIDEqualFold

func FileIDEqualFold(v string) predicate.JobResult

FileIDEqualFold applies the EqualFold predicate on the "file_id" field.

func FileIDGT

func FileIDGT(v string) predicate.JobResult

FileIDGT applies the GT predicate on the "file_id" field.

func FileIDGTE

func FileIDGTE(v string) predicate.JobResult

FileIDGTE applies the GTE predicate on the "file_id" field.

func FileIDHasPrefix

func FileIDHasPrefix(v string) predicate.JobResult

FileIDHasPrefix applies the HasPrefix predicate on the "file_id" field.

func FileIDHasSuffix

func FileIDHasSuffix(v string) predicate.JobResult

FileIDHasSuffix applies the HasSuffix predicate on the "file_id" field.

func FileIDIn

func FileIDIn(vs ...string) predicate.JobResult

FileIDIn applies the In predicate on the "file_id" field.

func FileIDLT

func FileIDLT(v string) predicate.JobResult

FileIDLT applies the LT predicate on the "file_id" field.

func FileIDLTE

func FileIDLTE(v string) predicate.JobResult

FileIDLTE applies the LTE predicate on the "file_id" field.

func FileIDNEQ

func FileIDNEQ(v string) predicate.JobResult

FileIDNEQ applies the NEQ predicate on the "file_id" field.

func FileIDNotIn

func FileIDNotIn(vs ...string) predicate.JobResult

FileIDNotIn applies the NotIn predicate on the "file_id" field.

func FinishedAt

func FinishedAt(v time.Time) predicate.JobResult

FinishedAt applies equality check predicate on the "finished_at" field. It's identical to FinishedAtEQ.

func FinishedAtEQ

func FinishedAtEQ(v time.Time) predicate.JobResult

FinishedAtEQ applies the EQ predicate on the "finished_at" field.

func FinishedAtGT

func FinishedAtGT(v time.Time) predicate.JobResult

FinishedAtGT applies the GT predicate on the "finished_at" field.

func FinishedAtGTE

func FinishedAtGTE(v time.Time) predicate.JobResult

FinishedAtGTE applies the GTE predicate on the "finished_at" field.

func FinishedAtIn

func FinishedAtIn(vs ...time.Time) predicate.JobResult

FinishedAtIn applies the In predicate on the "finished_at" field.

func FinishedAtLT

func FinishedAtLT(v time.Time) predicate.JobResult

FinishedAtLT applies the LT predicate on the "finished_at" field.

func FinishedAtLTE

func FinishedAtLTE(v time.Time) predicate.JobResult

FinishedAtLTE applies the LTE predicate on the "finished_at" field.

func FinishedAtNEQ

func FinishedAtNEQ(v time.Time) predicate.JobResult

FinishedAtNEQ applies the NEQ predicate on the "finished_at" field.

func FinishedAtNotIn

func FinishedAtNotIn(vs ...time.Time) predicate.JobResult

FinishedAtNotIn applies the NotIn predicate on the "finished_at" field.

func HasFile

func HasFile() predicate.JobResult

HasFile applies the HasEdge predicate on the "file" edge.

func HasFileWith

func HasFileWith(preds ...predicate.File) predicate.JobResult

HasFileWith applies the HasEdge predicate on the "file" edge with a given conditions (other predicates).

func HasOwner

func HasOwner() predicate.JobResult

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Organization) predicate.JobResult

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func HasScheduledJob

func HasScheduledJob() predicate.JobResult

HasScheduledJob applies the HasEdge predicate on the "scheduled_job" edge.

func HasScheduledJobWith

func HasScheduledJobWith(preds ...predicate.ControlScheduledJob) predicate.JobResult

HasScheduledJobWith applies the HasEdge predicate on the "scheduled_job" edge with a given conditions (other predicates).

func ID

func ID(id string) predicate.JobResult

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.JobResult

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.JobResult

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.JobResult

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.JobResult

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.JobResult

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.JobResult

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.JobResult

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.JobResult

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.JobResult

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.JobResult

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.JobResult) predicate.JobResult

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.JobResult

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.JobResult

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.JobResult

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.JobResult

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.JobResult

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.JobResult

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.JobResult

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.JobResult

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.JobResult

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.JobResult

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.JobResult

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.JobResult

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.JobResult

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.JobResult

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.JobResult

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.JobResult

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func ScheduledJobID

func ScheduledJobID(v string) predicate.JobResult

ScheduledJobID applies equality check predicate on the "scheduled_job_id" field. It's identical to ScheduledJobIDEQ.

func ScheduledJobIDContains

func ScheduledJobIDContains(v string) predicate.JobResult

ScheduledJobIDContains applies the Contains predicate on the "scheduled_job_id" field.

func ScheduledJobIDContainsFold

func ScheduledJobIDContainsFold(v string) predicate.JobResult

ScheduledJobIDContainsFold applies the ContainsFold predicate on the "scheduled_job_id" field.

func ScheduledJobIDEQ

func ScheduledJobIDEQ(v string) predicate.JobResult

ScheduledJobIDEQ applies the EQ predicate on the "scheduled_job_id" field.

func ScheduledJobIDEqualFold

func ScheduledJobIDEqualFold(v string) predicate.JobResult

ScheduledJobIDEqualFold applies the EqualFold predicate on the "scheduled_job_id" field.

func ScheduledJobIDGT

func ScheduledJobIDGT(v string) predicate.JobResult

ScheduledJobIDGT applies the GT predicate on the "scheduled_job_id" field.

func ScheduledJobIDGTE

func ScheduledJobIDGTE(v string) predicate.JobResult

ScheduledJobIDGTE applies the GTE predicate on the "scheduled_job_id" field.

func ScheduledJobIDHasPrefix

func ScheduledJobIDHasPrefix(v string) predicate.JobResult

ScheduledJobIDHasPrefix applies the HasPrefix predicate on the "scheduled_job_id" field.

func ScheduledJobIDHasSuffix

func ScheduledJobIDHasSuffix(v string) predicate.JobResult

ScheduledJobIDHasSuffix applies the HasSuffix predicate on the "scheduled_job_id" field.

func ScheduledJobIDIn

func ScheduledJobIDIn(vs ...string) predicate.JobResult

ScheduledJobIDIn applies the In predicate on the "scheduled_job_id" field.

func ScheduledJobIDLT

func ScheduledJobIDLT(v string) predicate.JobResult

ScheduledJobIDLT applies the LT predicate on the "scheduled_job_id" field.

func ScheduledJobIDLTE

func ScheduledJobIDLTE(v string) predicate.JobResult

ScheduledJobIDLTE applies the LTE predicate on the "scheduled_job_id" field.

func ScheduledJobIDNEQ

func ScheduledJobIDNEQ(v string) predicate.JobResult

ScheduledJobIDNEQ applies the NEQ predicate on the "scheduled_job_id" field.

func ScheduledJobIDNotIn

func ScheduledJobIDNotIn(vs ...string) predicate.JobResult

ScheduledJobIDNotIn applies the NotIn predicate on the "scheduled_job_id" field.

func StartedAt

func StartedAt(v time.Time) predicate.JobResult

StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.

func StartedAtEQ

func StartedAtEQ(v time.Time) predicate.JobResult

StartedAtEQ applies the EQ predicate on the "started_at" field.

func StartedAtGT

func StartedAtGT(v time.Time) predicate.JobResult

StartedAtGT applies the GT predicate on the "started_at" field.

func StartedAtGTE

func StartedAtGTE(v time.Time) predicate.JobResult

StartedAtGTE applies the GTE predicate on the "started_at" field.

func StartedAtIn

func StartedAtIn(vs ...time.Time) predicate.JobResult

StartedAtIn applies the In predicate on the "started_at" field.

func StartedAtLT

func StartedAtLT(v time.Time) predicate.JobResult

StartedAtLT applies the LT predicate on the "started_at" field.

func StartedAtLTE

func StartedAtLTE(v time.Time) predicate.JobResult

StartedAtLTE applies the LTE predicate on the "started_at" field.

func StartedAtNEQ

func StartedAtNEQ(v time.Time) predicate.JobResult

StartedAtNEQ applies the NEQ predicate on the "started_at" field.

func StartedAtNotIn

func StartedAtNotIn(vs ...time.Time) predicate.JobResult

StartedAtNotIn applies the NotIn predicate on the "started_at" field.

func StatusEQ

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...enums.JobExecutionStatus) predicate.JobResult

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s enums.JobExecutionStatus) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.JobResult

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.JobResult

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.JobResult

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.JobResult

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.JobResult

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.JobResult

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.JobResult

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.JobResult

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.JobResult

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.JobResult

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.JobResult

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.JobResult

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.JobResult

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.JobResult

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.JobResult

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.JobResult

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.JobResult

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.JobResult

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.JobResult

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.JobResult

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.JobResult

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.JobResult

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.JobResult

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.JobResult

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.JobResult

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.JobResult

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.JobResult

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the JobResult queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByExitCode

func ByExitCode(opts ...sql.OrderTermOption) OrderOption

ByExitCode orders the results by the exit_code field.

func ByFileField

func ByFileField(field string, opts ...sql.OrderTermOption) OrderOption

ByFileField orders the results by file field.

func ByFileID

func ByFileID(opts ...sql.OrderTermOption) OrderOption

ByFileID orders the results by the file_id field.

func ByFinishedAt

func ByFinishedAt(opts ...sql.OrderTermOption) OrderOption

ByFinishedAt orders the results by the finished_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByScheduledJobField

func ByScheduledJobField(field string, opts ...sql.OrderTermOption) OrderOption

ByScheduledJobField orders the results by scheduled_job field.

func ByScheduledJobID

func ByScheduledJobID(opts ...sql.OrderTermOption) OrderOption

ByScheduledJobID orders the results by the scheduled_job_id field.

func ByStartedAt

func ByStartedAt(opts ...sql.OrderTermOption) OrderOption

ByStartedAt orders the results by the started_at field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to