orgprice

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the orgprice type in the database.
	Label = "org_price"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldPrice holds the string denoting the price field in the database.
	FieldPrice = "price"
	// FieldStripePriceID holds the string denoting the stripe_price_id field in the database.
	FieldStripePriceID = "stripe_price_id"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldActive holds the string denoting the active field in the database.
	FieldActive = "active"
	// FieldProductID holds the string denoting the product_id field in the database.
	FieldProductID = "product_id"
	// FieldSubscriptionID holds the string denoting the subscription_id field in the database.
	FieldSubscriptionID = "subscription_id"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// EdgeOrgProducts holds the string denoting the org_products edge name in mutations.
	EdgeOrgProducts = "org_products"
	// EdgeOrgModules holds the string denoting the org_modules edge name in mutations.
	EdgeOrgModules = "org_modules"
	// EdgeOrgSubscription holds the string denoting the org_subscription edge name in mutations.
	EdgeOrgSubscription = "org_subscription"
	// Table holds the table name of the orgprice in the database.
	Table = "org_prices"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "org_prices"
	// OwnerInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OwnerInverseTable = "organizations"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
	// OrgProductsTable is the table that holds the org_products relation/edge. The primary key declared below.
	OrgProductsTable = "org_product_org_prices"
	// OrgProductsInverseTable is the table name for the OrgProduct entity.
	// It exists in this package in order to avoid circular dependency with the "orgproduct" package.
	OrgProductsInverseTable = "org_products"
	// OrgModulesTable is the table that holds the org_modules relation/edge. The primary key declared below.
	OrgModulesTable = "org_module_org_prices"
	// OrgModulesInverseTable is the table name for the OrgModule entity.
	// It exists in this package in order to avoid circular dependency with the "orgmodule" package.
	OrgModulesInverseTable = "org_modules"
	// OrgSubscriptionTable is the table that holds the org_subscription relation/edge.
	OrgSubscriptionTable = "org_prices"
	// OrgSubscriptionInverseTable is the table name for the OrgSubscription entity.
	// It exists in this package in order to avoid circular dependency with the "orgsubscription" package.
	OrgSubscriptionInverseTable = "org_subscriptions"
	// OrgSubscriptionColumn is the table column denoting the org_subscription relation/edge.
	OrgSubscriptionColumn = "subscription_id"
)

Variables

var (
	// OrgProductsPrimaryKey and OrgProductsColumn2 are the table columns denoting the
	// primary key for the org_products relation (M2M).
	OrgProductsPrimaryKey = []string{"org_product_id", "org_price_id"}
	// OrgModulesPrimaryKey and OrgModulesColumn2 are the table columns denoting the
	// primary key for the org_modules relation (M2M).
	OrgModulesPrimaryKey = []string{"org_module_id", "org_price_id"}
)
var (
	Hooks        [4]ent.Hook
	Interceptors [2]ent.Interceptor
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save.
	OwnerIDValidator func(string) error
	// DefaultActive holds the default value on creation for the "active" field.
	DefaultActive bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for orgprice fields.

Functions

func Active

func Active(v bool) predicate.OrgPrice

Active applies equality check predicate on the "active" field. It's identical to ActiveEQ.

func ActiveEQ

func ActiveEQ(v bool) predicate.OrgPrice

ActiveEQ applies the EQ predicate on the "active" field.

func ActiveNEQ

func ActiveNEQ(v bool) predicate.OrgPrice

ActiveNEQ applies the NEQ predicate on the "active" field.

func And

func And(predicates ...predicate.OrgPrice) predicate.OrgPrice

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.OrgPrice

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.OrgPrice

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.OrgPrice

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.OrgPrice

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.OrgPrice

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.OrgPrice

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.OrgPrice

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.OrgPrice

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.OrgPrice

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.OrgPrice

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.OrgPrice

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.OrgPrice

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.OrgPrice

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.OrgPrice

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.OrgPrice

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.OrgPrice

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.OrgPrice

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.OrgPrice

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.OrgPrice

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.OrgPrice

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.OrgPrice

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.OrgPrice

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.OrgPrice

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.OrgPrice

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.OrgPrice

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.OrgPrice

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.OrgPrice

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.OrgPrice

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.OrgPrice

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.OrgPrice

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.OrgPrice

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.OrgPrice

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.OrgPrice

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.OrgPrice

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.OrgPrice

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.OrgPrice

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.OrgPrice

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.OrgPrice

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.OrgPrice

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.OrgPrice

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.OrgPrice

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.OrgPrice

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.OrgPrice

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.OrgPrice

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.OrgPrice

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.OrgPrice

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.OrgPrice

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.OrgPrice

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.OrgPrice

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.OrgPrice

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.OrgPrice

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.OrgPrice

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.OrgPrice

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.OrgPrice

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func HasOrgModules added in v0.19.0

func HasOrgModules() predicate.OrgPrice

HasOrgModules applies the HasEdge predicate on the "org_modules" edge.

func HasOrgModulesWith added in v0.19.0

func HasOrgModulesWith(preds ...predicate.OrgModule) predicate.OrgPrice

HasOrgModulesWith applies the HasEdge predicate on the "org_modules" edge with a given conditions (other predicates).

func HasOrgProducts added in v0.19.0

func HasOrgProducts() predicate.OrgPrice

HasOrgProducts applies the HasEdge predicate on the "org_products" edge.

func HasOrgProductsWith added in v0.19.0

func HasOrgProductsWith(preds ...predicate.OrgProduct) predicate.OrgPrice

HasOrgProductsWith applies the HasEdge predicate on the "org_products" edge with a given conditions (other predicates).

func HasOrgSubscription added in v0.19.0

func HasOrgSubscription() predicate.OrgPrice

HasOrgSubscription applies the HasEdge predicate on the "org_subscription" edge.

func HasOrgSubscriptionWith added in v0.19.0

func HasOrgSubscriptionWith(preds ...predicate.OrgSubscription) predicate.OrgPrice

HasOrgSubscriptionWith applies the HasEdge predicate on the "org_subscription" edge with a given conditions (other predicates).

func HasOwner

func HasOwner() predicate.OrgPrice

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Organization) predicate.OrgPrice

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func ID

func ID(id string) predicate.OrgPrice

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.OrgPrice

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.OrgPrice

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.OrgPrice

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.OrgPrice

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.OrgPrice

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.OrgPrice

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.OrgPrice

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.OrgPrice

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.OrgPrice

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.OrgPrice

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.OrgPrice) predicate.OrgPrice

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.OrgPrice

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.OrgPrice

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.OrgPrice

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.OrgPrice

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.OrgPrice

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.OrgPrice

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.OrgPrice

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.OrgPrice

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.OrgPrice

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.OrgPrice

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.OrgPrice

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.OrgPrice

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.OrgPrice

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.OrgPrice

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.OrgPrice

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.OrgPrice

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func PriceIsNil

func PriceIsNil() predicate.OrgPrice

PriceIsNil applies the IsNil predicate on the "price" field.

func PriceNotNil

func PriceNotNil() predicate.OrgPrice

PriceNotNil applies the NotNil predicate on the "price" field.

func ProductID

func ProductID(v string) predicate.OrgPrice

ProductID applies equality check predicate on the "product_id" field. It's identical to ProductIDEQ.

func ProductIDContains

func ProductIDContains(v string) predicate.OrgPrice

ProductIDContains applies the Contains predicate on the "product_id" field.

func ProductIDContainsFold

func ProductIDContainsFold(v string) predicate.OrgPrice

ProductIDContainsFold applies the ContainsFold predicate on the "product_id" field.

func ProductIDEQ

func ProductIDEQ(v string) predicate.OrgPrice

ProductIDEQ applies the EQ predicate on the "product_id" field.

func ProductIDEqualFold

func ProductIDEqualFold(v string) predicate.OrgPrice

ProductIDEqualFold applies the EqualFold predicate on the "product_id" field.

func ProductIDGT

func ProductIDGT(v string) predicate.OrgPrice

ProductIDGT applies the GT predicate on the "product_id" field.

func ProductIDGTE

func ProductIDGTE(v string) predicate.OrgPrice

ProductIDGTE applies the GTE predicate on the "product_id" field.

func ProductIDHasPrefix

func ProductIDHasPrefix(v string) predicate.OrgPrice

ProductIDHasPrefix applies the HasPrefix predicate on the "product_id" field.

func ProductIDHasSuffix

func ProductIDHasSuffix(v string) predicate.OrgPrice

ProductIDHasSuffix applies the HasSuffix predicate on the "product_id" field.

func ProductIDIn

func ProductIDIn(vs ...string) predicate.OrgPrice

ProductIDIn applies the In predicate on the "product_id" field.

func ProductIDIsNil

func ProductIDIsNil() predicate.OrgPrice

ProductIDIsNil applies the IsNil predicate on the "product_id" field.

func ProductIDLT

func ProductIDLT(v string) predicate.OrgPrice

ProductIDLT applies the LT predicate on the "product_id" field.

func ProductIDLTE

func ProductIDLTE(v string) predicate.OrgPrice

ProductIDLTE applies the LTE predicate on the "product_id" field.

func ProductIDNEQ

func ProductIDNEQ(v string) predicate.OrgPrice

ProductIDNEQ applies the NEQ predicate on the "product_id" field.

func ProductIDNotIn

func ProductIDNotIn(vs ...string) predicate.OrgPrice

ProductIDNotIn applies the NotIn predicate on the "product_id" field.

func ProductIDNotNil

func ProductIDNotNil() predicate.OrgPrice

ProductIDNotNil applies the NotNil predicate on the "product_id" field.

func Status

func Status(v string) predicate.OrgPrice

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.OrgPrice

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.OrgPrice

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.OrgPrice

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.OrgPrice

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.OrgPrice

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.OrgPrice

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.OrgPrice

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.OrgPrice

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.OrgPrice

StatusIn applies the In predicate on the "status" field.

func StatusIsNil

func StatusIsNil() predicate.OrgPrice

StatusIsNil applies the IsNil predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.OrgPrice

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.OrgPrice

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.OrgPrice

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.OrgPrice

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusNotNil

func StatusNotNil() predicate.OrgPrice

StatusNotNil applies the NotNil predicate on the "status" field.

func StripePriceID

func StripePriceID(v string) predicate.OrgPrice

StripePriceID applies equality check predicate on the "stripe_price_id" field. It's identical to StripePriceIDEQ.

func StripePriceIDContains

func StripePriceIDContains(v string) predicate.OrgPrice

StripePriceIDContains applies the Contains predicate on the "stripe_price_id" field.

func StripePriceIDContainsFold

func StripePriceIDContainsFold(v string) predicate.OrgPrice

StripePriceIDContainsFold applies the ContainsFold predicate on the "stripe_price_id" field.

func StripePriceIDEQ

func StripePriceIDEQ(v string) predicate.OrgPrice

StripePriceIDEQ applies the EQ predicate on the "stripe_price_id" field.

func StripePriceIDEqualFold

func StripePriceIDEqualFold(v string) predicate.OrgPrice

StripePriceIDEqualFold applies the EqualFold predicate on the "stripe_price_id" field.

func StripePriceIDGT

func StripePriceIDGT(v string) predicate.OrgPrice

StripePriceIDGT applies the GT predicate on the "stripe_price_id" field.

func StripePriceIDGTE

func StripePriceIDGTE(v string) predicate.OrgPrice

StripePriceIDGTE applies the GTE predicate on the "stripe_price_id" field.

func StripePriceIDHasPrefix

func StripePriceIDHasPrefix(v string) predicate.OrgPrice

StripePriceIDHasPrefix applies the HasPrefix predicate on the "stripe_price_id" field.

func StripePriceIDHasSuffix

func StripePriceIDHasSuffix(v string) predicate.OrgPrice

StripePriceIDHasSuffix applies the HasSuffix predicate on the "stripe_price_id" field.

func StripePriceIDIn

func StripePriceIDIn(vs ...string) predicate.OrgPrice

StripePriceIDIn applies the In predicate on the "stripe_price_id" field.

func StripePriceIDIsNil

func StripePriceIDIsNil() predicate.OrgPrice

StripePriceIDIsNil applies the IsNil predicate on the "stripe_price_id" field.

func StripePriceIDLT

func StripePriceIDLT(v string) predicate.OrgPrice

StripePriceIDLT applies the LT predicate on the "stripe_price_id" field.

func StripePriceIDLTE

func StripePriceIDLTE(v string) predicate.OrgPrice

StripePriceIDLTE applies the LTE predicate on the "stripe_price_id" field.

func StripePriceIDNEQ

func StripePriceIDNEQ(v string) predicate.OrgPrice

StripePriceIDNEQ applies the NEQ predicate on the "stripe_price_id" field.

func StripePriceIDNotIn

func StripePriceIDNotIn(vs ...string) predicate.OrgPrice

StripePriceIDNotIn applies the NotIn predicate on the "stripe_price_id" field.

func StripePriceIDNotNil

func StripePriceIDNotNil() predicate.OrgPrice

StripePriceIDNotNil applies the NotNil predicate on the "stripe_price_id" field.

func SubscriptionID added in v0.19.0

func SubscriptionID(v string) predicate.OrgPrice

SubscriptionID applies equality check predicate on the "subscription_id" field. It's identical to SubscriptionIDEQ.

func SubscriptionIDContains added in v0.19.0

func SubscriptionIDContains(v string) predicate.OrgPrice

SubscriptionIDContains applies the Contains predicate on the "subscription_id" field.

func SubscriptionIDContainsFold added in v0.19.0

func SubscriptionIDContainsFold(v string) predicate.OrgPrice

SubscriptionIDContainsFold applies the ContainsFold predicate on the "subscription_id" field.

func SubscriptionIDEQ added in v0.19.0

func SubscriptionIDEQ(v string) predicate.OrgPrice

SubscriptionIDEQ applies the EQ predicate on the "subscription_id" field.

func SubscriptionIDEqualFold added in v0.19.0

func SubscriptionIDEqualFold(v string) predicate.OrgPrice

SubscriptionIDEqualFold applies the EqualFold predicate on the "subscription_id" field.

func SubscriptionIDGT added in v0.19.0

func SubscriptionIDGT(v string) predicate.OrgPrice

SubscriptionIDGT applies the GT predicate on the "subscription_id" field.

func SubscriptionIDGTE added in v0.19.0

func SubscriptionIDGTE(v string) predicate.OrgPrice

SubscriptionIDGTE applies the GTE predicate on the "subscription_id" field.

func SubscriptionIDHasPrefix added in v0.19.0

func SubscriptionIDHasPrefix(v string) predicate.OrgPrice

SubscriptionIDHasPrefix applies the HasPrefix predicate on the "subscription_id" field.

func SubscriptionIDHasSuffix added in v0.19.0

func SubscriptionIDHasSuffix(v string) predicate.OrgPrice

SubscriptionIDHasSuffix applies the HasSuffix predicate on the "subscription_id" field.

func SubscriptionIDIn added in v0.19.0

func SubscriptionIDIn(vs ...string) predicate.OrgPrice

SubscriptionIDIn applies the In predicate on the "subscription_id" field.

func SubscriptionIDIsNil added in v0.19.0

func SubscriptionIDIsNil() predicate.OrgPrice

SubscriptionIDIsNil applies the IsNil predicate on the "subscription_id" field.

func SubscriptionIDLT added in v0.19.0

func SubscriptionIDLT(v string) predicate.OrgPrice

SubscriptionIDLT applies the LT predicate on the "subscription_id" field.

func SubscriptionIDLTE added in v0.19.0

func SubscriptionIDLTE(v string) predicate.OrgPrice

SubscriptionIDLTE applies the LTE predicate on the "subscription_id" field.

func SubscriptionIDNEQ added in v0.19.0

func SubscriptionIDNEQ(v string) predicate.OrgPrice

SubscriptionIDNEQ applies the NEQ predicate on the "subscription_id" field.

func SubscriptionIDNotIn added in v0.19.0

func SubscriptionIDNotIn(vs ...string) predicate.OrgPrice

SubscriptionIDNotIn applies the NotIn predicate on the "subscription_id" field.

func SubscriptionIDNotNil added in v0.19.0

func SubscriptionIDNotNil() predicate.OrgPrice

SubscriptionIDNotNil applies the NotNil predicate on the "subscription_id" field.

func TagsIsNil

func TagsIsNil() predicate.OrgPrice

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.OrgPrice

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.OrgPrice

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.OrgPrice

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.OrgPrice

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.OrgPrice

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.OrgPrice

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.OrgPrice

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.OrgPrice

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.OrgPrice

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.OrgPrice

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.OrgPrice

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.OrgPrice

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.OrgPrice

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.OrgPrice

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.OrgPrice

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.OrgPrice

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.OrgPrice

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.OrgPrice

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.OrgPrice

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.OrgPrice

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.OrgPrice

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.OrgPrice

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.OrgPrice

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.OrgPrice

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.OrgPrice

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.OrgPrice

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.OrgPrice

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.OrgPrice

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the OrgPrice queries.

func ByActive

func ByActive(opts ...sql.OrderTermOption) OrderOption

ByActive orders the results by the active field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOrgModules added in v0.19.0

func ByOrgModules(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByOrgModules orders the results by org_modules terms.

func ByOrgModulesCount added in v0.19.0

func ByOrgModulesCount(opts ...sql.OrderTermOption) OrderOption

ByOrgModulesCount orders the results by org_modules count.

func ByOrgProducts added in v0.19.0

func ByOrgProducts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByOrgProducts orders the results by org_products terms.

func ByOrgProductsCount added in v0.19.0

func ByOrgProductsCount(opts ...sql.OrderTermOption) OrderOption

ByOrgProductsCount orders the results by org_products count.

func ByOrgSubscriptionField added in v0.19.0

func ByOrgSubscriptionField(field string, opts ...sql.OrderTermOption) OrderOption

ByOrgSubscriptionField orders the results by org_subscription field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByProductID

func ByProductID(opts ...sql.OrderTermOption) OrderOption

ByProductID orders the results by the product_id field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByStripePriceID

func ByStripePriceID(opts ...sql.OrderTermOption) OrderOption

ByStripePriceID orders the results by the stripe_price_id field.

func BySubscriptionID added in v0.19.0

func BySubscriptionID(opts ...sql.OrderTermOption) OrderOption

BySubscriptionID orders the results by the subscription_id field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to