Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.TemplateHistory) predicate.TemplateHistory
- func CreatedAt(v time.Time) predicate.TemplateHistory
- func CreatedAtEQ(v time.Time) predicate.TemplateHistory
- func CreatedAtGT(v time.Time) predicate.TemplateHistory
- func CreatedAtGTE(v time.Time) predicate.TemplateHistory
- func CreatedAtIn(vs ...time.Time) predicate.TemplateHistory
- func CreatedAtIsNil() predicate.TemplateHistory
- func CreatedAtLT(v time.Time) predicate.TemplateHistory
- func CreatedAtLTE(v time.Time) predicate.TemplateHistory
- func CreatedAtNEQ(v time.Time) predicate.TemplateHistory
- func CreatedAtNotIn(vs ...time.Time) predicate.TemplateHistory
- func CreatedAtNotNil() predicate.TemplateHistory
- func CreatedBy(v string) predicate.TemplateHistory
- func CreatedByContains(v string) predicate.TemplateHistory
- func CreatedByContainsFold(v string) predicate.TemplateHistory
- func CreatedByEQ(v string) predicate.TemplateHistory
- func CreatedByEqualFold(v string) predicate.TemplateHistory
- func CreatedByGT(v string) predicate.TemplateHistory
- func CreatedByGTE(v string) predicate.TemplateHistory
- func CreatedByHasPrefix(v string) predicate.TemplateHistory
- func CreatedByHasSuffix(v string) predicate.TemplateHistory
- func CreatedByIn(vs ...string) predicate.TemplateHistory
- func CreatedByIsNil() predicate.TemplateHistory
- func CreatedByLT(v string) predicate.TemplateHistory
- func CreatedByLTE(v string) predicate.TemplateHistory
- func CreatedByNEQ(v string) predicate.TemplateHistory
- func CreatedByNotIn(vs ...string) predicate.TemplateHistory
- func CreatedByNotNil() predicate.TemplateHistory
- func DeletedAt(v time.Time) predicate.TemplateHistory
- func DeletedAtEQ(v time.Time) predicate.TemplateHistory
- func DeletedAtGT(v time.Time) predicate.TemplateHistory
- func DeletedAtGTE(v time.Time) predicate.TemplateHistory
- func DeletedAtIn(vs ...time.Time) predicate.TemplateHistory
- func DeletedAtIsNil() predicate.TemplateHistory
- func DeletedAtLT(v time.Time) predicate.TemplateHistory
- func DeletedAtLTE(v time.Time) predicate.TemplateHistory
- func DeletedAtNEQ(v time.Time) predicate.TemplateHistory
- func DeletedAtNotIn(vs ...time.Time) predicate.TemplateHistory
- func DeletedAtNotNil() predicate.TemplateHistory
- func DeletedBy(v string) predicate.TemplateHistory
- func DeletedByContains(v string) predicate.TemplateHistory
- func DeletedByContainsFold(v string) predicate.TemplateHistory
- func DeletedByEQ(v string) predicate.TemplateHistory
- func DeletedByEqualFold(v string) predicate.TemplateHistory
- func DeletedByGT(v string) predicate.TemplateHistory
- func DeletedByGTE(v string) predicate.TemplateHistory
- func DeletedByHasPrefix(v string) predicate.TemplateHistory
- func DeletedByHasSuffix(v string) predicate.TemplateHistory
- func DeletedByIn(vs ...string) predicate.TemplateHistory
- func DeletedByIsNil() predicate.TemplateHistory
- func DeletedByLT(v string) predicate.TemplateHistory
- func DeletedByLTE(v string) predicate.TemplateHistory
- func DeletedByNEQ(v string) predicate.TemplateHistory
- func DeletedByNotIn(vs ...string) predicate.TemplateHistory
- func DeletedByNotNil() predicate.TemplateHistory
- func Description(v string) predicate.TemplateHistory
- func DescriptionContains(v string) predicate.TemplateHistory
- func DescriptionContainsFold(v string) predicate.TemplateHistory
- func DescriptionEQ(v string) predicate.TemplateHistory
- func DescriptionEqualFold(v string) predicate.TemplateHistory
- func DescriptionGT(v string) predicate.TemplateHistory
- func DescriptionGTE(v string) predicate.TemplateHistory
- func DescriptionHasPrefix(v string) predicate.TemplateHistory
- func DescriptionHasSuffix(v string) predicate.TemplateHistory
- func DescriptionIn(vs ...string) predicate.TemplateHistory
- func DescriptionIsNil() predicate.TemplateHistory
- func DescriptionLT(v string) predicate.TemplateHistory
- func DescriptionLTE(v string) predicate.TemplateHistory
- func DescriptionNEQ(v string) predicate.TemplateHistory
- func DescriptionNotIn(vs ...string) predicate.TemplateHistory
- func DescriptionNotNil() predicate.TemplateHistory
- func HistoryTime(v time.Time) predicate.TemplateHistory
- func HistoryTimeEQ(v time.Time) predicate.TemplateHistory
- func HistoryTimeGT(v time.Time) predicate.TemplateHistory
- func HistoryTimeGTE(v time.Time) predicate.TemplateHistory
- func HistoryTimeIn(vs ...time.Time) predicate.TemplateHistory
- func HistoryTimeLT(v time.Time) predicate.TemplateHistory
- func HistoryTimeLTE(v time.Time) predicate.TemplateHistory
- func HistoryTimeNEQ(v time.Time) predicate.TemplateHistory
- func HistoryTimeNotIn(vs ...time.Time) predicate.TemplateHistory
- func ID(id string) predicate.TemplateHistory
- func IDContainsFold(id string) predicate.TemplateHistory
- func IDEQ(id string) predicate.TemplateHistory
- func IDEqualFold(id string) predicate.TemplateHistory
- func IDGT(id string) predicate.TemplateHistory
- func IDGTE(id string) predicate.TemplateHistory
- func IDIn(ids ...string) predicate.TemplateHistory
- func IDLT(id string) predicate.TemplateHistory
- func IDLTE(id string) predicate.TemplateHistory
- func IDNEQ(id string) predicate.TemplateHistory
- func IDNotIn(ids ...string) predicate.TemplateHistory
- func InternalNotes(v string) predicate.TemplateHistory
- func InternalNotesContains(v string) predicate.TemplateHistory
- func InternalNotesContainsFold(v string) predicate.TemplateHistory
- func InternalNotesEQ(v string) predicate.TemplateHistory
- func InternalNotesEqualFold(v string) predicate.TemplateHistory
- func InternalNotesGT(v string) predicate.TemplateHistory
- func InternalNotesGTE(v string) predicate.TemplateHistory
- func InternalNotesHasPrefix(v string) predicate.TemplateHistory
- func InternalNotesHasSuffix(v string) predicate.TemplateHistory
- func InternalNotesIn(vs ...string) predicate.TemplateHistory
- func InternalNotesIsNil() predicate.TemplateHistory
- func InternalNotesLT(v string) predicate.TemplateHistory
- func InternalNotesLTE(v string) predicate.TemplateHistory
- func InternalNotesNEQ(v string) predicate.TemplateHistory
- func InternalNotesNotIn(vs ...string) predicate.TemplateHistory
- func InternalNotesNotNil() predicate.TemplateHistory
- func KindEQ(v enums.TemplateKind) predicate.TemplateHistory
- func KindIn(vs ...enums.TemplateKind) predicate.TemplateHistory
- func KindIsNil() predicate.TemplateHistory
- func KindNEQ(v enums.TemplateKind) predicate.TemplateHistory
- func KindNotIn(vs ...enums.TemplateKind) predicate.TemplateHistory
- func KindNotNil() predicate.TemplateHistory
- func KindValidator(k enums.TemplateKind) error
- func Name(v string) predicate.TemplateHistory
- func NameContains(v string) predicate.TemplateHistory
- func NameContainsFold(v string) predicate.TemplateHistory
- func NameEQ(v string) predicate.TemplateHistory
- func NameEqualFold(v string) predicate.TemplateHistory
- func NameGT(v string) predicate.TemplateHistory
- func NameGTE(v string) predicate.TemplateHistory
- func NameHasPrefix(v string) predicate.TemplateHistory
- func NameHasSuffix(v string) predicate.TemplateHistory
- func NameIn(vs ...string) predicate.TemplateHistory
- func NameLT(v string) predicate.TemplateHistory
- func NameLTE(v string) predicate.TemplateHistory
- func NameNEQ(v string) predicate.TemplateHistory
- func NameNotIn(vs ...string) predicate.TemplateHistory
- func Not(p predicate.TemplateHistory) predicate.TemplateHistory
- func OperationEQ(v history.OpType) predicate.TemplateHistory
- func OperationIn(vs ...history.OpType) predicate.TemplateHistory
- func OperationNEQ(v history.OpType) predicate.TemplateHistory
- func OperationNotIn(vs ...history.OpType) predicate.TemplateHistory
- func OperationValidator(o history.OpType) error
- func Or(predicates ...predicate.TemplateHistory) predicate.TemplateHistory
- func OwnerID(v string) predicate.TemplateHistory
- func OwnerIDContains(v string) predicate.TemplateHistory
- func OwnerIDContainsFold(v string) predicate.TemplateHistory
- func OwnerIDEQ(v string) predicate.TemplateHistory
- func OwnerIDEqualFold(v string) predicate.TemplateHistory
- func OwnerIDGT(v string) predicate.TemplateHistory
- func OwnerIDGTE(v string) predicate.TemplateHistory
- func OwnerIDHasPrefix(v string) predicate.TemplateHistory
- func OwnerIDHasSuffix(v string) predicate.TemplateHistory
- func OwnerIDIn(vs ...string) predicate.TemplateHistory
- func OwnerIDIsNil() predicate.TemplateHistory
- func OwnerIDLT(v string) predicate.TemplateHistory
- func OwnerIDLTE(v string) predicate.TemplateHistory
- func OwnerIDNEQ(v string) predicate.TemplateHistory
- func OwnerIDNotIn(vs ...string) predicate.TemplateHistory
- func OwnerIDNotNil() predicate.TemplateHistory
- func Ref(v string) predicate.TemplateHistory
- func RefContains(v string) predicate.TemplateHistory
- func RefContainsFold(v string) predicate.TemplateHistory
- func RefEQ(v string) predicate.TemplateHistory
- func RefEqualFold(v string) predicate.TemplateHistory
- func RefGT(v string) predicate.TemplateHistory
- func RefGTE(v string) predicate.TemplateHistory
- func RefHasPrefix(v string) predicate.TemplateHistory
- func RefHasSuffix(v string) predicate.TemplateHistory
- func RefIn(vs ...string) predicate.TemplateHistory
- func RefIsNil() predicate.TemplateHistory
- func RefLT(v string) predicate.TemplateHistory
- func RefLTE(v string) predicate.TemplateHistory
- func RefNEQ(v string) predicate.TemplateHistory
- func RefNotIn(vs ...string) predicate.TemplateHistory
- func RefNotNil() predicate.TemplateHistory
- func SystemInternalID(v string) predicate.TemplateHistory
- func SystemInternalIDContains(v string) predicate.TemplateHistory
- func SystemInternalIDContainsFold(v string) predicate.TemplateHistory
- func SystemInternalIDEQ(v string) predicate.TemplateHistory
- func SystemInternalIDEqualFold(v string) predicate.TemplateHistory
- func SystemInternalIDGT(v string) predicate.TemplateHistory
- func SystemInternalIDGTE(v string) predicate.TemplateHistory
- func SystemInternalIDHasPrefix(v string) predicate.TemplateHistory
- func SystemInternalIDHasSuffix(v string) predicate.TemplateHistory
- func SystemInternalIDIn(vs ...string) predicate.TemplateHistory
- func SystemInternalIDIsNil() predicate.TemplateHistory
- func SystemInternalIDLT(v string) predicate.TemplateHistory
- func SystemInternalIDLTE(v string) predicate.TemplateHistory
- func SystemInternalIDNEQ(v string) predicate.TemplateHistory
- func SystemInternalIDNotIn(vs ...string) predicate.TemplateHistory
- func SystemInternalIDNotNil() predicate.TemplateHistory
- func SystemOwned(v bool) predicate.TemplateHistory
- func SystemOwnedEQ(v bool) predicate.TemplateHistory
- func SystemOwnedIsNil() predicate.TemplateHistory
- func SystemOwnedNEQ(v bool) predicate.TemplateHistory
- func SystemOwnedNotNil() predicate.TemplateHistory
- func TagsIsNil() predicate.TemplateHistory
- func TagsNotNil() predicate.TemplateHistory
- func TemplateTypeEQ(v enums.DocumentType) predicate.TemplateHistory
- func TemplateTypeIn(vs ...enums.DocumentType) predicate.TemplateHistory
- func TemplateTypeNEQ(v enums.DocumentType) predicate.TemplateHistory
- func TemplateTypeNotIn(vs ...enums.DocumentType) predicate.TemplateHistory
- func TemplateTypeValidator(tt enums.DocumentType) error
- func TrustCenterID(v string) predicate.TemplateHistory
- func TrustCenterIDContains(v string) predicate.TemplateHistory
- func TrustCenterIDContainsFold(v string) predicate.TemplateHistory
- func TrustCenterIDEQ(v string) predicate.TemplateHistory
- func TrustCenterIDEqualFold(v string) predicate.TemplateHistory
- func TrustCenterIDGT(v string) predicate.TemplateHistory
- func TrustCenterIDGTE(v string) predicate.TemplateHistory
- func TrustCenterIDHasPrefix(v string) predicate.TemplateHistory
- func TrustCenterIDHasSuffix(v string) predicate.TemplateHistory
- func TrustCenterIDIn(vs ...string) predicate.TemplateHistory
- func TrustCenterIDIsNil() predicate.TemplateHistory
- func TrustCenterIDLT(v string) predicate.TemplateHistory
- func TrustCenterIDLTE(v string) predicate.TemplateHistory
- func TrustCenterIDNEQ(v string) predicate.TemplateHistory
- func TrustCenterIDNotIn(vs ...string) predicate.TemplateHistory
- func TrustCenterIDNotNil() predicate.TemplateHistory
- func UischemaIsNil() predicate.TemplateHistory
- func UischemaNotNil() predicate.TemplateHistory
- func UpdatedAt(v time.Time) predicate.TemplateHistory
- func UpdatedAtEQ(v time.Time) predicate.TemplateHistory
- func UpdatedAtGT(v time.Time) predicate.TemplateHistory
- func UpdatedAtGTE(v time.Time) predicate.TemplateHistory
- func UpdatedAtIn(vs ...time.Time) predicate.TemplateHistory
- func UpdatedAtIsNil() predicate.TemplateHistory
- func UpdatedAtLT(v time.Time) predicate.TemplateHistory
- func UpdatedAtLTE(v time.Time) predicate.TemplateHistory
- func UpdatedAtNEQ(v time.Time) predicate.TemplateHistory
- func UpdatedAtNotIn(vs ...time.Time) predicate.TemplateHistory
- func UpdatedAtNotNil() predicate.TemplateHistory
- func UpdatedBy(v string) predicate.TemplateHistory
- func UpdatedByContains(v string) predicate.TemplateHistory
- func UpdatedByContainsFold(v string) predicate.TemplateHistory
- func UpdatedByEQ(v string) predicate.TemplateHistory
- func UpdatedByEqualFold(v string) predicate.TemplateHistory
- func UpdatedByGT(v string) predicate.TemplateHistory
- func UpdatedByGTE(v string) predicate.TemplateHistory
- func UpdatedByHasPrefix(v string) predicate.TemplateHistory
- func UpdatedByHasSuffix(v string) predicate.TemplateHistory
- func UpdatedByIn(vs ...string) predicate.TemplateHistory
- func UpdatedByIsNil() predicate.TemplateHistory
- func UpdatedByLT(v string) predicate.TemplateHistory
- func UpdatedByLTE(v string) predicate.TemplateHistory
- func UpdatedByNEQ(v string) predicate.TemplateHistory
- func UpdatedByNotIn(vs ...string) predicate.TemplateHistory
- func UpdatedByNotNil() predicate.TemplateHistory
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption
- func ByKind(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOperation(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByRef(opts ...sql.OrderTermOption) OrderOption
- func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption
- func BySystemOwned(opts ...sql.OrderTermOption) OrderOption
- func ByTemplateType(opts ...sql.OrderTermOption) OrderOption
- func ByTrustCenterID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the templatehistory type in the database. Label = "template_history" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldHistoryTime holds the string denoting the history_time field in the database. FieldHistoryTime = "history_time" // FieldRef holds the string denoting the ref field in the database. FieldRef = "ref" // FieldOperation holds the string denoting the operation field in the database. FieldOperation = "operation" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldSystemOwned holds the string denoting the system_owned field in the database. FieldSystemOwned = "system_owned" // FieldInternalNotes holds the string denoting the internal_notes field in the database. FieldInternalNotes = "internal_notes" // FieldSystemInternalID holds the string denoting the system_internal_id field in the database. FieldSystemInternalID = "system_internal_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldTemplateType holds the string denoting the template_type field in the database. FieldTemplateType = "template_type" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldKind holds the string denoting the kind field in the database. FieldKind = "kind" // FieldJsonconfig holds the string denoting the jsonconfig field in the database. FieldJsonconfig = "jsonconfig" // FieldUischema holds the string denoting the uischema field in the database. FieldUischema = "uischema" // FieldTrustCenterID holds the string denoting the trust_center_id field in the database. FieldTrustCenterID = "trust_center_id" // Table holds the table name of the templatehistory in the database. Table = "template_history" )
const DefaultKind enums.TemplateKind = "QUESTIONNAIRE"
const DefaultTemplateType enums.DocumentType = "DOCUMENT"
Variables ¶
var ( Hooks [1]ent.Hook Interceptors [1]ent.Interceptor Policy ent.Policy // DefaultHistoryTime holds the default value on creation for the "history_time" field. DefaultHistoryTime func() time.Time // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultTags holds the default value on creation for the "tags" field. DefaultTags []string // DefaultSystemOwned holds the default value on creation for the "system_owned" field. DefaultSystemOwned bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldHistoryTime, FieldRef, FieldOperation, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldTags, FieldOwnerID, FieldSystemOwned, FieldInternalNotes, FieldSystemInternalID, FieldName, FieldTemplateType, FieldDescription, FieldKind, FieldJsonconfig, FieldUischema, FieldTrustCenterID, }
Columns holds all SQL columns for templatehistory fields.
Functions ¶
func And ¶
func And(predicates ...predicate.TemplateHistory) predicate.TemplateHistory
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.TemplateHistory
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.TemplateHistory
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.TemplateHistory
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.TemplateHistory
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.TemplateHistory
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.TemplateHistory
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.TemplateHistory
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.TemplateHistory
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.TemplateHistory
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.TemplateHistory
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.TemplateHistory
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
func CreatedBy(v string) predicate.TemplateHistory
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
func CreatedByContains(v string) predicate.TemplateHistory
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
func CreatedByContainsFold(v string) predicate.TemplateHistory
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
func CreatedByEQ(v string) predicate.TemplateHistory
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
func CreatedByEqualFold(v string) predicate.TemplateHistory
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
func CreatedByGT(v string) predicate.TemplateHistory
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
func CreatedByGTE(v string) predicate.TemplateHistory
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
func CreatedByHasPrefix(v string) predicate.TemplateHistory
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
func CreatedByHasSuffix(v string) predicate.TemplateHistory
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
func CreatedByIn(vs ...string) predicate.TemplateHistory
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
func CreatedByIsNil() predicate.TemplateHistory
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
func CreatedByLT(v string) predicate.TemplateHistory
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
func CreatedByLTE(v string) predicate.TemplateHistory
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
func CreatedByNEQ(v string) predicate.TemplateHistory
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
func CreatedByNotIn(vs ...string) predicate.TemplateHistory
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
func CreatedByNotNil() predicate.TemplateHistory
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.TemplateHistory
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.TemplateHistory
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.TemplateHistory
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.TemplateHistory
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.TemplateHistory
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.TemplateHistory
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.TemplateHistory
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.TemplateHistory
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.TemplateHistory
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.TemplateHistory
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.TemplateHistory
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
func DeletedBy(v string) predicate.TemplateHistory
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
func DeletedByContains(v string) predicate.TemplateHistory
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
func DeletedByContainsFold(v string) predicate.TemplateHistory
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
func DeletedByEQ(v string) predicate.TemplateHistory
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
func DeletedByEqualFold(v string) predicate.TemplateHistory
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
func DeletedByGT(v string) predicate.TemplateHistory
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
func DeletedByGTE(v string) predicate.TemplateHistory
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
func DeletedByHasPrefix(v string) predicate.TemplateHistory
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
func DeletedByHasSuffix(v string) predicate.TemplateHistory
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
func DeletedByIn(vs ...string) predicate.TemplateHistory
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
func DeletedByIsNil() predicate.TemplateHistory
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
func DeletedByLT(v string) predicate.TemplateHistory
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
func DeletedByLTE(v string) predicate.TemplateHistory
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
func DeletedByNEQ(v string) predicate.TemplateHistory
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
func DeletedByNotIn(vs ...string) predicate.TemplateHistory
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
func DeletedByNotNil() predicate.TemplateHistory
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func Description ¶
func Description(v string) predicate.TemplateHistory
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
func DescriptionContains(v string) predicate.TemplateHistory
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
func DescriptionContainsFold(v string) predicate.TemplateHistory
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
func DescriptionEQ(v string) predicate.TemplateHistory
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
func DescriptionEqualFold(v string) predicate.TemplateHistory
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
func DescriptionGT(v string) predicate.TemplateHistory
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
func DescriptionGTE(v string) predicate.TemplateHistory
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
func DescriptionHasPrefix(v string) predicate.TemplateHistory
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
func DescriptionHasSuffix(v string) predicate.TemplateHistory
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
func DescriptionIn(vs ...string) predicate.TemplateHistory
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
func DescriptionIsNil() predicate.TemplateHistory
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
func DescriptionLT(v string) predicate.TemplateHistory
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
func DescriptionLTE(v string) predicate.TemplateHistory
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
func DescriptionNEQ(v string) predicate.TemplateHistory
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
func DescriptionNotIn(vs ...string) predicate.TemplateHistory
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
func DescriptionNotNil() predicate.TemplateHistory
DescriptionNotNil applies the NotNil predicate on the "description" field.
func HistoryTime ¶
func HistoryTime(v time.Time) predicate.TemplateHistory
HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.
func HistoryTimeEQ ¶
func HistoryTimeEQ(v time.Time) predicate.TemplateHistory
HistoryTimeEQ applies the EQ predicate on the "history_time" field.
func HistoryTimeGT ¶
func HistoryTimeGT(v time.Time) predicate.TemplateHistory
HistoryTimeGT applies the GT predicate on the "history_time" field.
func HistoryTimeGTE ¶
func HistoryTimeGTE(v time.Time) predicate.TemplateHistory
HistoryTimeGTE applies the GTE predicate on the "history_time" field.
func HistoryTimeIn ¶
func HistoryTimeIn(vs ...time.Time) predicate.TemplateHistory
HistoryTimeIn applies the In predicate on the "history_time" field.
func HistoryTimeLT ¶
func HistoryTimeLT(v time.Time) predicate.TemplateHistory
HistoryTimeLT applies the LT predicate on the "history_time" field.
func HistoryTimeLTE ¶
func HistoryTimeLTE(v time.Time) predicate.TemplateHistory
HistoryTimeLTE applies the LTE predicate on the "history_time" field.
func HistoryTimeNEQ ¶
func HistoryTimeNEQ(v time.Time) predicate.TemplateHistory
HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.
func HistoryTimeNotIn ¶
func HistoryTimeNotIn(vs ...time.Time) predicate.TemplateHistory
HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.
func IDContainsFold ¶
func IDContainsFold(id string) predicate.TemplateHistory
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEQ ¶
func IDEQ(id string) predicate.TemplateHistory
IDEQ applies the EQ predicate on the ID field.
func IDEqualFold ¶
func IDEqualFold(id string) predicate.TemplateHistory
IDEqualFold applies the EqualFold predicate on the ID field.
func IDGT ¶
func IDGT(id string) predicate.TemplateHistory
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id string) predicate.TemplateHistory
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...string) predicate.TemplateHistory
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id string) predicate.TemplateHistory
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id string) predicate.TemplateHistory
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id string) predicate.TemplateHistory
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...string) predicate.TemplateHistory
IDNotIn applies the NotIn predicate on the ID field.
func InternalNotes ¶ added in v0.34.0
func InternalNotes(v string) predicate.TemplateHistory
InternalNotes applies equality check predicate on the "internal_notes" field. It's identical to InternalNotesEQ.
func InternalNotesContains ¶ added in v0.34.0
func InternalNotesContains(v string) predicate.TemplateHistory
InternalNotesContains applies the Contains predicate on the "internal_notes" field.
func InternalNotesContainsFold ¶ added in v0.34.0
func InternalNotesContainsFold(v string) predicate.TemplateHistory
InternalNotesContainsFold applies the ContainsFold predicate on the "internal_notes" field.
func InternalNotesEQ ¶ added in v0.34.0
func InternalNotesEQ(v string) predicate.TemplateHistory
InternalNotesEQ applies the EQ predicate on the "internal_notes" field.
func InternalNotesEqualFold ¶ added in v0.34.0
func InternalNotesEqualFold(v string) predicate.TemplateHistory
InternalNotesEqualFold applies the EqualFold predicate on the "internal_notes" field.
func InternalNotesGT ¶ added in v0.34.0
func InternalNotesGT(v string) predicate.TemplateHistory
InternalNotesGT applies the GT predicate on the "internal_notes" field.
func InternalNotesGTE ¶ added in v0.34.0
func InternalNotesGTE(v string) predicate.TemplateHistory
InternalNotesGTE applies the GTE predicate on the "internal_notes" field.
func InternalNotesHasPrefix ¶ added in v0.34.0
func InternalNotesHasPrefix(v string) predicate.TemplateHistory
InternalNotesHasPrefix applies the HasPrefix predicate on the "internal_notes" field.
func InternalNotesHasSuffix ¶ added in v0.34.0
func InternalNotesHasSuffix(v string) predicate.TemplateHistory
InternalNotesHasSuffix applies the HasSuffix predicate on the "internal_notes" field.
func InternalNotesIn ¶ added in v0.34.0
func InternalNotesIn(vs ...string) predicate.TemplateHistory
InternalNotesIn applies the In predicate on the "internal_notes" field.
func InternalNotesIsNil ¶ added in v0.34.0
func InternalNotesIsNil() predicate.TemplateHistory
InternalNotesIsNil applies the IsNil predicate on the "internal_notes" field.
func InternalNotesLT ¶ added in v0.34.0
func InternalNotesLT(v string) predicate.TemplateHistory
InternalNotesLT applies the LT predicate on the "internal_notes" field.
func InternalNotesLTE ¶ added in v0.34.0
func InternalNotesLTE(v string) predicate.TemplateHistory
InternalNotesLTE applies the LTE predicate on the "internal_notes" field.
func InternalNotesNEQ ¶ added in v0.34.0
func InternalNotesNEQ(v string) predicate.TemplateHistory
InternalNotesNEQ applies the NEQ predicate on the "internal_notes" field.
func InternalNotesNotIn ¶ added in v0.34.0
func InternalNotesNotIn(vs ...string) predicate.TemplateHistory
InternalNotesNotIn applies the NotIn predicate on the "internal_notes" field.
func InternalNotesNotNil ¶ added in v0.34.0
func InternalNotesNotNil() predicate.TemplateHistory
InternalNotesNotNil applies the NotNil predicate on the "internal_notes" field.
func KindEQ ¶ added in v0.32.0
func KindEQ(v enums.TemplateKind) predicate.TemplateHistory
KindEQ applies the EQ predicate on the "kind" field.
func KindIn ¶ added in v0.32.0
func KindIn(vs ...enums.TemplateKind) predicate.TemplateHistory
KindIn applies the In predicate on the "kind" field.
func KindIsNil ¶ added in v0.32.0
func KindIsNil() predicate.TemplateHistory
KindIsNil applies the IsNil predicate on the "kind" field.
func KindNEQ ¶ added in v0.32.0
func KindNEQ(v enums.TemplateKind) predicate.TemplateHistory
KindNEQ applies the NEQ predicate on the "kind" field.
func KindNotIn ¶ added in v0.32.0
func KindNotIn(vs ...enums.TemplateKind) predicate.TemplateHistory
KindNotIn applies the NotIn predicate on the "kind" field.
func KindNotNil ¶ added in v0.32.0
func KindNotNil() predicate.TemplateHistory
KindNotNil applies the NotNil predicate on the "kind" field.
func KindValidator ¶ added in v0.32.0
func KindValidator(k enums.TemplateKind) error
KindValidator is a validator for the "kind" field enum values. It is called by the builders before save.
func Name ¶
func Name(v string) predicate.TemplateHistory
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.TemplateHistory
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.TemplateHistory
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.TemplateHistory
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.TemplateHistory
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.TemplateHistory
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.TemplateHistory
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.TemplateHistory
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.TemplateHistory
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.TemplateHistory
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.TemplateHistory
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.TemplateHistory
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.TemplateHistory
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.TemplateHistory
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.TemplateHistory) predicate.TemplateHistory
Not applies the not operator on the given predicate.
func OperationEQ ¶
func OperationEQ(v history.OpType) predicate.TemplateHistory
OperationEQ applies the EQ predicate on the "operation" field.
func OperationIn ¶
func OperationIn(vs ...history.OpType) predicate.TemplateHistory
OperationIn applies the In predicate on the "operation" field.
func OperationNEQ ¶
func OperationNEQ(v history.OpType) predicate.TemplateHistory
OperationNEQ applies the NEQ predicate on the "operation" field.
func OperationNotIn ¶
func OperationNotIn(vs ...history.OpType) predicate.TemplateHistory
OperationNotIn applies the NotIn predicate on the "operation" field.
func OperationValidator ¶
OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.
func Or ¶
func Or(predicates ...predicate.TemplateHistory) predicate.TemplateHistory
Or groups predicates with the OR operator between them.
func OwnerID ¶
func OwnerID(v string) predicate.TemplateHistory
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDContains ¶
func OwnerIDContains(v string) predicate.TemplateHistory
OwnerIDContains applies the Contains predicate on the "owner_id" field.
func OwnerIDContainsFold ¶
func OwnerIDContainsFold(v string) predicate.TemplateHistory
OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.
func OwnerIDEQ ¶
func OwnerIDEQ(v string) predicate.TemplateHistory
OwnerIDEQ applies the EQ predicate on the "owner_id" field.
func OwnerIDEqualFold ¶
func OwnerIDEqualFold(v string) predicate.TemplateHistory
OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.
func OwnerIDGT ¶
func OwnerIDGT(v string) predicate.TemplateHistory
OwnerIDGT applies the GT predicate on the "owner_id" field.
func OwnerIDGTE ¶
func OwnerIDGTE(v string) predicate.TemplateHistory
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDHasPrefix ¶
func OwnerIDHasPrefix(v string) predicate.TemplateHistory
OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.
func OwnerIDHasSuffix ¶
func OwnerIDHasSuffix(v string) predicate.TemplateHistory
OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.
func OwnerIDIn ¶
func OwnerIDIn(vs ...string) predicate.TemplateHistory
OwnerIDIn applies the In predicate on the "owner_id" field.
func OwnerIDIsNil ¶
func OwnerIDIsNil() predicate.TemplateHistory
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLT ¶
func OwnerIDLT(v string) predicate.TemplateHistory
OwnerIDLT applies the LT predicate on the "owner_id" field.
func OwnerIDLTE ¶
func OwnerIDLTE(v string) predicate.TemplateHistory
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
func OwnerIDNEQ(v string) predicate.TemplateHistory
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
func OwnerIDNotIn(vs ...string) predicate.TemplateHistory
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
func OwnerIDNotNil() predicate.TemplateHistory
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func Ref ¶
func Ref(v string) predicate.TemplateHistory
Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.
func RefContains ¶
func RefContains(v string) predicate.TemplateHistory
RefContains applies the Contains predicate on the "ref" field.
func RefContainsFold ¶
func RefContainsFold(v string) predicate.TemplateHistory
RefContainsFold applies the ContainsFold predicate on the "ref" field.
func RefEQ ¶
func RefEQ(v string) predicate.TemplateHistory
RefEQ applies the EQ predicate on the "ref" field.
func RefEqualFold ¶
func RefEqualFold(v string) predicate.TemplateHistory
RefEqualFold applies the EqualFold predicate on the "ref" field.
func RefGT ¶
func RefGT(v string) predicate.TemplateHistory
RefGT applies the GT predicate on the "ref" field.
func RefGTE ¶
func RefGTE(v string) predicate.TemplateHistory
RefGTE applies the GTE predicate on the "ref" field.
func RefHasPrefix ¶
func RefHasPrefix(v string) predicate.TemplateHistory
RefHasPrefix applies the HasPrefix predicate on the "ref" field.
func RefHasSuffix ¶
func RefHasSuffix(v string) predicate.TemplateHistory
RefHasSuffix applies the HasSuffix predicate on the "ref" field.
func RefIn ¶
func RefIn(vs ...string) predicate.TemplateHistory
RefIn applies the In predicate on the "ref" field.
func RefIsNil ¶
func RefIsNil() predicate.TemplateHistory
RefIsNil applies the IsNil predicate on the "ref" field.
func RefLT ¶
func RefLT(v string) predicate.TemplateHistory
RefLT applies the LT predicate on the "ref" field.
func RefLTE ¶
func RefLTE(v string) predicate.TemplateHistory
RefLTE applies the LTE predicate on the "ref" field.
func RefNEQ ¶
func RefNEQ(v string) predicate.TemplateHistory
RefNEQ applies the NEQ predicate on the "ref" field.
func RefNotIn ¶
func RefNotIn(vs ...string) predicate.TemplateHistory
RefNotIn applies the NotIn predicate on the "ref" field.
func RefNotNil ¶
func RefNotNil() predicate.TemplateHistory
RefNotNil applies the NotNil predicate on the "ref" field.
func SystemInternalID ¶ added in v0.34.0
func SystemInternalID(v string) predicate.TemplateHistory
SystemInternalID applies equality check predicate on the "system_internal_id" field. It's identical to SystemInternalIDEQ.
func SystemInternalIDContains ¶ added in v0.34.0
func SystemInternalIDContains(v string) predicate.TemplateHistory
SystemInternalIDContains applies the Contains predicate on the "system_internal_id" field.
func SystemInternalIDContainsFold ¶ added in v0.34.0
func SystemInternalIDContainsFold(v string) predicate.TemplateHistory
SystemInternalIDContainsFold applies the ContainsFold predicate on the "system_internal_id" field.
func SystemInternalIDEQ ¶ added in v0.34.0
func SystemInternalIDEQ(v string) predicate.TemplateHistory
SystemInternalIDEQ applies the EQ predicate on the "system_internal_id" field.
func SystemInternalIDEqualFold ¶ added in v0.34.0
func SystemInternalIDEqualFold(v string) predicate.TemplateHistory
SystemInternalIDEqualFold applies the EqualFold predicate on the "system_internal_id" field.
func SystemInternalIDGT ¶ added in v0.34.0
func SystemInternalIDGT(v string) predicate.TemplateHistory
SystemInternalIDGT applies the GT predicate on the "system_internal_id" field.
func SystemInternalIDGTE ¶ added in v0.34.0
func SystemInternalIDGTE(v string) predicate.TemplateHistory
SystemInternalIDGTE applies the GTE predicate on the "system_internal_id" field.
func SystemInternalIDHasPrefix ¶ added in v0.34.0
func SystemInternalIDHasPrefix(v string) predicate.TemplateHistory
SystemInternalIDHasPrefix applies the HasPrefix predicate on the "system_internal_id" field.
func SystemInternalIDHasSuffix ¶ added in v0.34.0
func SystemInternalIDHasSuffix(v string) predicate.TemplateHistory
SystemInternalIDHasSuffix applies the HasSuffix predicate on the "system_internal_id" field.
func SystemInternalIDIn ¶ added in v0.34.0
func SystemInternalIDIn(vs ...string) predicate.TemplateHistory
SystemInternalIDIn applies the In predicate on the "system_internal_id" field.
func SystemInternalIDIsNil ¶ added in v0.34.0
func SystemInternalIDIsNil() predicate.TemplateHistory
SystemInternalIDIsNil applies the IsNil predicate on the "system_internal_id" field.
func SystemInternalIDLT ¶ added in v0.34.0
func SystemInternalIDLT(v string) predicate.TemplateHistory
SystemInternalIDLT applies the LT predicate on the "system_internal_id" field.
func SystemInternalIDLTE ¶ added in v0.34.0
func SystemInternalIDLTE(v string) predicate.TemplateHistory
SystemInternalIDLTE applies the LTE predicate on the "system_internal_id" field.
func SystemInternalIDNEQ ¶ added in v0.34.0
func SystemInternalIDNEQ(v string) predicate.TemplateHistory
SystemInternalIDNEQ applies the NEQ predicate on the "system_internal_id" field.
func SystemInternalIDNotIn ¶ added in v0.34.0
func SystemInternalIDNotIn(vs ...string) predicate.TemplateHistory
SystemInternalIDNotIn applies the NotIn predicate on the "system_internal_id" field.
func SystemInternalIDNotNil ¶ added in v0.34.0
func SystemInternalIDNotNil() predicate.TemplateHistory
SystemInternalIDNotNil applies the NotNil predicate on the "system_internal_id" field.
func SystemOwned ¶ added in v0.34.0
func SystemOwned(v bool) predicate.TemplateHistory
SystemOwned applies equality check predicate on the "system_owned" field. It's identical to SystemOwnedEQ.
func SystemOwnedEQ ¶ added in v0.34.0
func SystemOwnedEQ(v bool) predicate.TemplateHistory
SystemOwnedEQ applies the EQ predicate on the "system_owned" field.
func SystemOwnedIsNil ¶ added in v0.34.0
func SystemOwnedIsNil() predicate.TemplateHistory
SystemOwnedIsNil applies the IsNil predicate on the "system_owned" field.
func SystemOwnedNEQ ¶ added in v0.34.0
func SystemOwnedNEQ(v bool) predicate.TemplateHistory
SystemOwnedNEQ applies the NEQ predicate on the "system_owned" field.
func SystemOwnedNotNil ¶ added in v0.34.0
func SystemOwnedNotNil() predicate.TemplateHistory
SystemOwnedNotNil applies the NotNil predicate on the "system_owned" field.
func TagsIsNil ¶
func TagsIsNil() predicate.TemplateHistory
TagsIsNil applies the IsNil predicate on the "tags" field.
func TagsNotNil ¶
func TagsNotNil() predicate.TemplateHistory
TagsNotNil applies the NotNil predicate on the "tags" field.
func TemplateTypeEQ ¶
func TemplateTypeEQ(v enums.DocumentType) predicate.TemplateHistory
TemplateTypeEQ applies the EQ predicate on the "template_type" field.
func TemplateTypeIn ¶
func TemplateTypeIn(vs ...enums.DocumentType) predicate.TemplateHistory
TemplateTypeIn applies the In predicate on the "template_type" field.
func TemplateTypeNEQ ¶
func TemplateTypeNEQ(v enums.DocumentType) predicate.TemplateHistory
TemplateTypeNEQ applies the NEQ predicate on the "template_type" field.
func TemplateTypeNotIn ¶
func TemplateTypeNotIn(vs ...enums.DocumentType) predicate.TemplateHistory
TemplateTypeNotIn applies the NotIn predicate on the "template_type" field.
func TemplateTypeValidator ¶
func TemplateTypeValidator(tt enums.DocumentType) error
TemplateTypeValidator is a validator for the "template_type" field enum values. It is called by the builders before save.
func TrustCenterID ¶ added in v0.34.1
func TrustCenterID(v string) predicate.TemplateHistory
TrustCenterID applies equality check predicate on the "trust_center_id" field. It's identical to TrustCenterIDEQ.
func TrustCenterIDContains ¶ added in v0.34.1
func TrustCenterIDContains(v string) predicate.TemplateHistory
TrustCenterIDContains applies the Contains predicate on the "trust_center_id" field.
func TrustCenterIDContainsFold ¶ added in v0.34.1
func TrustCenterIDContainsFold(v string) predicate.TemplateHistory
TrustCenterIDContainsFold applies the ContainsFold predicate on the "trust_center_id" field.
func TrustCenterIDEQ ¶ added in v0.34.1
func TrustCenterIDEQ(v string) predicate.TemplateHistory
TrustCenterIDEQ applies the EQ predicate on the "trust_center_id" field.
func TrustCenterIDEqualFold ¶ added in v0.34.1
func TrustCenterIDEqualFold(v string) predicate.TemplateHistory
TrustCenterIDEqualFold applies the EqualFold predicate on the "trust_center_id" field.
func TrustCenterIDGT ¶ added in v0.34.1
func TrustCenterIDGT(v string) predicate.TemplateHistory
TrustCenterIDGT applies the GT predicate on the "trust_center_id" field.
func TrustCenterIDGTE ¶ added in v0.34.1
func TrustCenterIDGTE(v string) predicate.TemplateHistory
TrustCenterIDGTE applies the GTE predicate on the "trust_center_id" field.
func TrustCenterIDHasPrefix ¶ added in v0.34.1
func TrustCenterIDHasPrefix(v string) predicate.TemplateHistory
TrustCenterIDHasPrefix applies the HasPrefix predicate on the "trust_center_id" field.
func TrustCenterIDHasSuffix ¶ added in v0.34.1
func TrustCenterIDHasSuffix(v string) predicate.TemplateHistory
TrustCenterIDHasSuffix applies the HasSuffix predicate on the "trust_center_id" field.
func TrustCenterIDIn ¶ added in v0.34.1
func TrustCenterIDIn(vs ...string) predicate.TemplateHistory
TrustCenterIDIn applies the In predicate on the "trust_center_id" field.
func TrustCenterIDIsNil ¶ added in v0.34.1
func TrustCenterIDIsNil() predicate.TemplateHistory
TrustCenterIDIsNil applies the IsNil predicate on the "trust_center_id" field.
func TrustCenterIDLT ¶ added in v0.34.1
func TrustCenterIDLT(v string) predicate.TemplateHistory
TrustCenterIDLT applies the LT predicate on the "trust_center_id" field.
func TrustCenterIDLTE ¶ added in v0.34.1
func TrustCenterIDLTE(v string) predicate.TemplateHistory
TrustCenterIDLTE applies the LTE predicate on the "trust_center_id" field.
func TrustCenterIDNEQ ¶ added in v0.34.1
func TrustCenterIDNEQ(v string) predicate.TemplateHistory
TrustCenterIDNEQ applies the NEQ predicate on the "trust_center_id" field.
func TrustCenterIDNotIn ¶ added in v0.34.1
func TrustCenterIDNotIn(vs ...string) predicate.TemplateHistory
TrustCenterIDNotIn applies the NotIn predicate on the "trust_center_id" field.
func TrustCenterIDNotNil ¶ added in v0.34.1
func TrustCenterIDNotNil() predicate.TemplateHistory
TrustCenterIDNotNil applies the NotNil predicate on the "trust_center_id" field.
func UischemaIsNil ¶
func UischemaIsNil() predicate.TemplateHistory
UischemaIsNil applies the IsNil predicate on the "uischema" field.
func UischemaNotNil ¶
func UischemaNotNil() predicate.TemplateHistory
UischemaNotNil applies the NotNil predicate on the "uischema" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.TemplateHistory
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.TemplateHistory
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.TemplateHistory
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.TemplateHistory
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.TemplateHistory
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.TemplateHistory
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.TemplateHistory
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.TemplateHistory
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.TemplateHistory
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.TemplateHistory
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.TemplateHistory
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
func UpdatedBy(v string) predicate.TemplateHistory
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
func UpdatedByContains(v string) predicate.TemplateHistory
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
func UpdatedByContainsFold(v string) predicate.TemplateHistory
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
func UpdatedByEQ(v string) predicate.TemplateHistory
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
func UpdatedByEqualFold(v string) predicate.TemplateHistory
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
func UpdatedByGT(v string) predicate.TemplateHistory
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
func UpdatedByGTE(v string) predicate.TemplateHistory
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
func UpdatedByHasPrefix(v string) predicate.TemplateHistory
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
func UpdatedByHasSuffix(v string) predicate.TemplateHistory
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
func UpdatedByIn(vs ...string) predicate.TemplateHistory
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
func UpdatedByIsNil() predicate.TemplateHistory
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
func UpdatedByLT(v string) predicate.TemplateHistory
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
func UpdatedByLTE(v string) predicate.TemplateHistory
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
func UpdatedByNEQ(v string) predicate.TemplateHistory
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
func UpdatedByNotIn(vs ...string) predicate.TemplateHistory
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
func UpdatedByNotNil() predicate.TemplateHistory
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the TemplateHistory queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByHistoryTime ¶
func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption
ByHistoryTime orders the results by the history_time field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByInternalNotes ¶ added in v0.34.0
func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption
ByInternalNotes orders the results by the internal_notes field.
func ByKind ¶ added in v0.32.0
func ByKind(opts ...sql.OrderTermOption) OrderOption
ByKind orders the results by the kind field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOperation ¶
func ByOperation(opts ...sql.OrderTermOption) OrderOption
ByOperation orders the results by the operation field.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByRef ¶
func ByRef(opts ...sql.OrderTermOption) OrderOption
ByRef orders the results by the ref field.
func BySystemInternalID ¶ added in v0.34.0
func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption
BySystemInternalID orders the results by the system_internal_id field.
func BySystemOwned ¶ added in v0.34.0
func BySystemOwned(opts ...sql.OrderTermOption) OrderOption
BySystemOwned orders the results by the system_owned field.
func ByTemplateType ¶
func ByTemplateType(opts ...sql.OrderTermOption) OrderOption
ByTemplateType orders the results by the template_type field.
func ByTrustCenterID ¶ added in v0.34.1
func ByTrustCenterID(opts ...sql.OrderTermOption) OrderOption
ByTrustCenterID orders the results by the trust_center_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.