trustcenter

package
v0.25.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the trustcenter type in the database.
	Label = "trust_center"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldSlug holds the string denoting the slug field in the database.
	FieldSlug = "slug"
	// FieldCustomDomainID holds the string denoting the custom_domain_id field in the database.
	FieldCustomDomainID = "custom_domain_id"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// EdgeCustomDomain holds the string denoting the custom_domain edge name in mutations.
	EdgeCustomDomain = "custom_domain"
	// EdgeSetting holds the string denoting the setting edge name in mutations.
	EdgeSetting = "setting"
	// EdgeTrustCenterSubprocessors holds the string denoting the trust_center_subprocessors edge name in mutations.
	EdgeTrustCenterSubprocessors = "trust_center_subprocessors"
	// Table holds the table name of the trustcenter in the database.
	Table = "trust_centers"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "trust_centers"
	// OwnerInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OwnerInverseTable = "organizations"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
	// CustomDomainTable is the table that holds the custom_domain relation/edge.
	CustomDomainTable = "trust_centers"
	// CustomDomainInverseTable is the table name for the CustomDomain entity.
	// It exists in this package in order to avoid circular dependency with the "customdomain" package.
	CustomDomainInverseTable = "custom_domains"
	// CustomDomainColumn is the table column denoting the custom_domain relation/edge.
	CustomDomainColumn = "custom_domain_id"
	// SettingTable is the table that holds the setting relation/edge.
	SettingTable = "trust_center_settings"
	// SettingInverseTable is the table name for the TrustCenterSetting entity.
	// It exists in this package in order to avoid circular dependency with the "trustcentersetting" package.
	SettingInverseTable = "trust_center_settings"
	// SettingColumn is the table column denoting the setting relation/edge.
	SettingColumn = "trust_center_id"
	// TrustCenterSubprocessorsTable is the table that holds the trust_center_subprocessors relation/edge.
	TrustCenterSubprocessorsTable = "trust_center_subprocessors"
	// TrustCenterSubprocessorsInverseTable is the table name for the TrustCenterSubprocessor entity.
	// It exists in this package in order to avoid circular dependency with the "trustcentersubprocessor" package.
	TrustCenterSubprocessorsInverseTable = "trust_center_subprocessors"
	// TrustCenterSubprocessorsColumn is the table column denoting the trust_center_subprocessors relation/edge.
	TrustCenterSubprocessorsColumn = "trust_center_id"
)

Variables

var (
	Hooks        [7]ent.Hook
	Interceptors [4]ent.Interceptor
	Policy       ent.Policy
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save.
	OwnerIDValidator func(string) error
	// SlugValidator is a validator for the "slug" field. It is called by the builders before save.
	SlugValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for trustcenter fields.

Functions

func And

func And(predicates ...predicate.TrustCenter) predicate.TrustCenter

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.TrustCenter

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.TrustCenter

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.TrustCenter

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.TrustCenter

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.TrustCenter

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.TrustCenter

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.TrustCenter

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.TrustCenter

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.TrustCenter

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.TrustCenter

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.TrustCenter

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.TrustCenter

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.TrustCenter

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.TrustCenter

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.TrustCenter

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.TrustCenter

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.TrustCenter

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.TrustCenter

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.TrustCenter

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.TrustCenter

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.TrustCenter

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.TrustCenter

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.TrustCenter

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.TrustCenter

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.TrustCenter

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.TrustCenter

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.TrustCenter

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func CustomDomainID

func CustomDomainID(v string) predicate.TrustCenter

CustomDomainID applies equality check predicate on the "custom_domain_id" field. It's identical to CustomDomainIDEQ.

func CustomDomainIDContains

func CustomDomainIDContains(v string) predicate.TrustCenter

CustomDomainIDContains applies the Contains predicate on the "custom_domain_id" field.

func CustomDomainIDContainsFold

func CustomDomainIDContainsFold(v string) predicate.TrustCenter

CustomDomainIDContainsFold applies the ContainsFold predicate on the "custom_domain_id" field.

func CustomDomainIDEQ

func CustomDomainIDEQ(v string) predicate.TrustCenter

CustomDomainIDEQ applies the EQ predicate on the "custom_domain_id" field.

func CustomDomainIDEqualFold

func CustomDomainIDEqualFold(v string) predicate.TrustCenter

CustomDomainIDEqualFold applies the EqualFold predicate on the "custom_domain_id" field.

func CustomDomainIDGT

func CustomDomainIDGT(v string) predicate.TrustCenter

CustomDomainIDGT applies the GT predicate on the "custom_domain_id" field.

func CustomDomainIDGTE

func CustomDomainIDGTE(v string) predicate.TrustCenter

CustomDomainIDGTE applies the GTE predicate on the "custom_domain_id" field.

func CustomDomainIDHasPrefix

func CustomDomainIDHasPrefix(v string) predicate.TrustCenter

CustomDomainIDHasPrefix applies the HasPrefix predicate on the "custom_domain_id" field.

func CustomDomainIDHasSuffix

func CustomDomainIDHasSuffix(v string) predicate.TrustCenter

CustomDomainIDHasSuffix applies the HasSuffix predicate on the "custom_domain_id" field.

func CustomDomainIDIn

func CustomDomainIDIn(vs ...string) predicate.TrustCenter

CustomDomainIDIn applies the In predicate on the "custom_domain_id" field.

func CustomDomainIDIsNil

func CustomDomainIDIsNil() predicate.TrustCenter

CustomDomainIDIsNil applies the IsNil predicate on the "custom_domain_id" field.

func CustomDomainIDLT

func CustomDomainIDLT(v string) predicate.TrustCenter

CustomDomainIDLT applies the LT predicate on the "custom_domain_id" field.

func CustomDomainIDLTE

func CustomDomainIDLTE(v string) predicate.TrustCenter

CustomDomainIDLTE applies the LTE predicate on the "custom_domain_id" field.

func CustomDomainIDNEQ

func CustomDomainIDNEQ(v string) predicate.TrustCenter

CustomDomainIDNEQ applies the NEQ predicate on the "custom_domain_id" field.

func CustomDomainIDNotIn

func CustomDomainIDNotIn(vs ...string) predicate.TrustCenter

CustomDomainIDNotIn applies the NotIn predicate on the "custom_domain_id" field.

func CustomDomainIDNotNil

func CustomDomainIDNotNil() predicate.TrustCenter

CustomDomainIDNotNil applies the NotNil predicate on the "custom_domain_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.TrustCenter

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.TrustCenter

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.TrustCenter

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.TrustCenter

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.TrustCenter

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.TrustCenter

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.TrustCenter

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.TrustCenter

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.TrustCenter

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.TrustCenter

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.TrustCenter

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.TrustCenter

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.TrustCenter

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.TrustCenter

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.TrustCenter

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.TrustCenter

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.TrustCenter

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.TrustCenter

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.TrustCenter

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.TrustCenter

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.TrustCenter

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.TrustCenter

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.TrustCenter

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.TrustCenter

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.TrustCenter

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.TrustCenter

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.TrustCenter

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func HasCustomDomain

func HasCustomDomain() predicate.TrustCenter

HasCustomDomain applies the HasEdge predicate on the "custom_domain" edge.

func HasCustomDomainWith

func HasCustomDomainWith(preds ...predicate.CustomDomain) predicate.TrustCenter

HasCustomDomainWith applies the HasEdge predicate on the "custom_domain" edge with a given conditions (other predicates).

func HasOwner

func HasOwner() predicate.TrustCenter

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Organization) predicate.TrustCenter

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func HasSetting

func HasSetting() predicate.TrustCenter

HasSetting applies the HasEdge predicate on the "setting" edge.

func HasSettingWith

func HasSettingWith(preds ...predicate.TrustCenterSetting) predicate.TrustCenter

HasSettingWith applies the HasEdge predicate on the "setting" edge with a given conditions (other predicates).

func HasTrustCenterSubprocessors added in v0.23.0

func HasTrustCenterSubprocessors() predicate.TrustCenter

HasTrustCenterSubprocessors applies the HasEdge predicate on the "trust_center_subprocessors" edge.

func HasTrustCenterSubprocessorsWith added in v0.23.0

func HasTrustCenterSubprocessorsWith(preds ...predicate.TrustCenterSubprocessor) predicate.TrustCenter

HasTrustCenterSubprocessorsWith applies the HasEdge predicate on the "trust_center_subprocessors" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.TrustCenter

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.TrustCenter

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.TrustCenter

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.TrustCenter

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.TrustCenter

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.TrustCenter

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.TrustCenter

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.TrustCenter

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.TrustCenter

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.TrustCenter

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.TrustCenter) predicate.TrustCenter

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.TrustCenter

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.TrustCenter

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.TrustCenter

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.TrustCenter

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.TrustCenter

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.TrustCenter

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.TrustCenter

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.TrustCenter

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.TrustCenter

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.TrustCenter

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.TrustCenter

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.TrustCenter

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.TrustCenter

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.TrustCenter

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.TrustCenter

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.TrustCenter

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func Slug

Slug applies equality check predicate on the "slug" field. It's identical to SlugEQ.

func SlugContains

func SlugContains(v string) predicate.TrustCenter

SlugContains applies the Contains predicate on the "slug" field.

func SlugContainsFold

func SlugContainsFold(v string) predicate.TrustCenter

SlugContainsFold applies the ContainsFold predicate on the "slug" field.

func SlugEQ

func SlugEQ(v string) predicate.TrustCenter

SlugEQ applies the EQ predicate on the "slug" field.

func SlugEqualFold

func SlugEqualFold(v string) predicate.TrustCenter

SlugEqualFold applies the EqualFold predicate on the "slug" field.

func SlugGT

func SlugGT(v string) predicate.TrustCenter

SlugGT applies the GT predicate on the "slug" field.

func SlugGTE

func SlugGTE(v string) predicate.TrustCenter

SlugGTE applies the GTE predicate on the "slug" field.

func SlugHasPrefix

func SlugHasPrefix(v string) predicate.TrustCenter

SlugHasPrefix applies the HasPrefix predicate on the "slug" field.

func SlugHasSuffix

func SlugHasSuffix(v string) predicate.TrustCenter

SlugHasSuffix applies the HasSuffix predicate on the "slug" field.

func SlugIn

func SlugIn(vs ...string) predicate.TrustCenter

SlugIn applies the In predicate on the "slug" field.

func SlugIsNil

func SlugIsNil() predicate.TrustCenter

SlugIsNil applies the IsNil predicate on the "slug" field.

func SlugLT

func SlugLT(v string) predicate.TrustCenter

SlugLT applies the LT predicate on the "slug" field.

func SlugLTE

func SlugLTE(v string) predicate.TrustCenter

SlugLTE applies the LTE predicate on the "slug" field.

func SlugNEQ

func SlugNEQ(v string) predicate.TrustCenter

SlugNEQ applies the NEQ predicate on the "slug" field.

func SlugNotIn

func SlugNotIn(vs ...string) predicate.TrustCenter

SlugNotIn applies the NotIn predicate on the "slug" field.

func SlugNotNil

func SlugNotNil() predicate.TrustCenter

SlugNotNil applies the NotNil predicate on the "slug" field.

func TagsIsNil

func TagsIsNil() predicate.TrustCenter

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.TrustCenter

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.TrustCenter

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.TrustCenter

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.TrustCenter

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.TrustCenter

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.TrustCenter

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.TrustCenter

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.TrustCenter

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.TrustCenter

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.TrustCenter

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.TrustCenter

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.TrustCenter

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.TrustCenter

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.TrustCenter

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.TrustCenter

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.TrustCenter

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.TrustCenter

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.TrustCenter

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.TrustCenter

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.TrustCenter

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.TrustCenter

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.TrustCenter

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.TrustCenter

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.TrustCenter

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.TrustCenter

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.TrustCenter

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.TrustCenter

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.TrustCenter

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TrustCenter queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByCustomDomainField

func ByCustomDomainField(field string, opts ...sql.OrderTermOption) OrderOption

ByCustomDomainField orders the results by custom_domain field.

func ByCustomDomainID

func ByCustomDomainID(opts ...sql.OrderTermOption) OrderOption

ByCustomDomainID orders the results by the custom_domain_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func BySettingField

func BySettingField(field string, opts ...sql.OrderTermOption) OrderOption

BySettingField orders the results by setting field.

func BySlug

func BySlug(opts ...sql.OrderTermOption) OrderOption

BySlug orders the results by the slug field.

func ByTrustCenterSubprocessors added in v0.23.0

func ByTrustCenterSubprocessors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByTrustCenterSubprocessors orders the results by trust_center_subprocessors terms.

func ByTrustCenterSubprocessorsCount added in v0.23.0

func ByTrustCenterSubprocessorsCount(opts ...sql.OrderTermOption) OrderOption

ByTrustCenterSubprocessorsCount orders the results by trust_center_subprocessors count.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to