workfloweventhistory

package
v0.47.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 24, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the workfloweventhistory type in the database.
	Label = "workflow_event_history"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldHistoryTime holds the string denoting the history_time field in the database.
	FieldHistoryTime = "history_time"
	// FieldRef holds the string denoting the ref field in the database.
	FieldRef = "ref"
	// FieldOperation holds the string denoting the operation field in the database.
	FieldOperation = "operation"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldDisplayID holds the string denoting the display_id field in the database.
	FieldDisplayID = "display_id"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldWorkflowInstanceID holds the string denoting the workflow_instance_id field in the database.
	FieldWorkflowInstanceID = "workflow_instance_id"
	// FieldEventType holds the string denoting the event_type field in the database.
	FieldEventType = "event_type"
	// FieldPayload holds the string denoting the payload field in the database.
	FieldPayload = "payload"
	// Table holds the table name of the workfloweventhistory in the database.
	Table = "workflow_event_history"
)

Variables

var (
	Hooks        [1]ent.Hook
	Interceptors [1]ent.Interceptor
	Policy       ent.Policy
	// DefaultHistoryTime holds the default value on creation for the "history_time" field.
	DefaultHistoryTime func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for workfloweventhistory fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.WorkflowEventHistory

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.WorkflowEventHistory

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.WorkflowEventHistory

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.WorkflowEventHistory

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.WorkflowEventHistory

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.WorkflowEventHistory

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.WorkflowEventHistory

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.WorkflowEventHistory

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.WorkflowEventHistory

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.WorkflowEventHistory

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.WorkflowEventHistory

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.WorkflowEventHistory

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.WorkflowEventHistory

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.WorkflowEventHistory

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.WorkflowEventHistory

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.WorkflowEventHistory

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.WorkflowEventHistory

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.WorkflowEventHistory

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.WorkflowEventHistory

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.WorkflowEventHistory

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.WorkflowEventHistory

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.WorkflowEventHistory

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.WorkflowEventHistory

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.WorkflowEventHistory

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.WorkflowEventHistory

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.WorkflowEventHistory

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.WorkflowEventHistory

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.WorkflowEventHistory

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.WorkflowEventHistory

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.WorkflowEventHistory

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.WorkflowEventHistory

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.WorkflowEventHistory

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.WorkflowEventHistory

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.WorkflowEventHistory

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.WorkflowEventHistory

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.WorkflowEventHistory

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.WorkflowEventHistory

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.WorkflowEventHistory

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.WorkflowEventHistory

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.WorkflowEventHistory

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.WorkflowEventHistory

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.WorkflowEventHistory

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.WorkflowEventHistory

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.WorkflowEventHistory

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.WorkflowEventHistory

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.WorkflowEventHistory

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.WorkflowEventHistory

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.WorkflowEventHistory

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.WorkflowEventHistory

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.WorkflowEventHistory

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func DisplayID

DisplayID applies equality check predicate on the "display_id" field. It's identical to DisplayIDEQ.

func DisplayIDContains

func DisplayIDContains(v string) predicate.WorkflowEventHistory

DisplayIDContains applies the Contains predicate on the "display_id" field.

func DisplayIDContainsFold

func DisplayIDContainsFold(v string) predicate.WorkflowEventHistory

DisplayIDContainsFold applies the ContainsFold predicate on the "display_id" field.

func DisplayIDEQ

func DisplayIDEQ(v string) predicate.WorkflowEventHistory

DisplayIDEQ applies the EQ predicate on the "display_id" field.

func DisplayIDEqualFold

func DisplayIDEqualFold(v string) predicate.WorkflowEventHistory

DisplayIDEqualFold applies the EqualFold predicate on the "display_id" field.

func DisplayIDGT

func DisplayIDGT(v string) predicate.WorkflowEventHistory

DisplayIDGT applies the GT predicate on the "display_id" field.

func DisplayIDGTE

func DisplayIDGTE(v string) predicate.WorkflowEventHistory

DisplayIDGTE applies the GTE predicate on the "display_id" field.

func DisplayIDHasPrefix

func DisplayIDHasPrefix(v string) predicate.WorkflowEventHistory

DisplayIDHasPrefix applies the HasPrefix predicate on the "display_id" field.

func DisplayIDHasSuffix

func DisplayIDHasSuffix(v string) predicate.WorkflowEventHistory

DisplayIDHasSuffix applies the HasSuffix predicate on the "display_id" field.

func DisplayIDIn

func DisplayIDIn(vs ...string) predicate.WorkflowEventHistory

DisplayIDIn applies the In predicate on the "display_id" field.

func DisplayIDLT

func DisplayIDLT(v string) predicate.WorkflowEventHistory

DisplayIDLT applies the LT predicate on the "display_id" field.

func DisplayIDLTE

func DisplayIDLTE(v string) predicate.WorkflowEventHistory

DisplayIDLTE applies the LTE predicate on the "display_id" field.

func DisplayIDNEQ

func DisplayIDNEQ(v string) predicate.WorkflowEventHistory

DisplayIDNEQ applies the NEQ predicate on the "display_id" field.

func DisplayIDNotIn

func DisplayIDNotIn(vs ...string) predicate.WorkflowEventHistory

DisplayIDNotIn applies the NotIn predicate on the "display_id" field.

func EventTypeEQ

EventTypeEQ applies the EQ predicate on the "event_type" field.

func EventTypeIn

EventTypeIn applies the In predicate on the "event_type" field.

func EventTypeNEQ

EventTypeNEQ applies the NEQ predicate on the "event_type" field.

func EventTypeNotIn

EventTypeNotIn applies the NotIn predicate on the "event_type" field.

func EventTypeValidator

func EventTypeValidator(et enums.WorkflowEventType) error

EventTypeValidator is a validator for the "event_type" field enum values. It is called by the builders before save.

func HistoryTime

func HistoryTime(v time.Time) predicate.WorkflowEventHistory

HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.

func HistoryTimeEQ

func HistoryTimeEQ(v time.Time) predicate.WorkflowEventHistory

HistoryTimeEQ applies the EQ predicate on the "history_time" field.

func HistoryTimeGT

func HistoryTimeGT(v time.Time) predicate.WorkflowEventHistory

HistoryTimeGT applies the GT predicate on the "history_time" field.

func HistoryTimeGTE

func HistoryTimeGTE(v time.Time) predicate.WorkflowEventHistory

HistoryTimeGTE applies the GTE predicate on the "history_time" field.

func HistoryTimeIn

func HistoryTimeIn(vs ...time.Time) predicate.WorkflowEventHistory

HistoryTimeIn applies the In predicate on the "history_time" field.

func HistoryTimeLT

func HistoryTimeLT(v time.Time) predicate.WorkflowEventHistory

HistoryTimeLT applies the LT predicate on the "history_time" field.

func HistoryTimeLTE

func HistoryTimeLTE(v time.Time) predicate.WorkflowEventHistory

HistoryTimeLTE applies the LTE predicate on the "history_time" field.

func HistoryTimeNEQ

func HistoryTimeNEQ(v time.Time) predicate.WorkflowEventHistory

HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.

func HistoryTimeNotIn

func HistoryTimeNotIn(vs ...time.Time) predicate.WorkflowEventHistory

HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.WorkflowEventHistory

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.WorkflowEventHistory

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.WorkflowEventHistory

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func OperationEQ

OperationEQ applies the EQ predicate on the "operation" field.

func OperationIn

func OperationIn(vs ...history.OpType) predicate.WorkflowEventHistory

OperationIn applies the In predicate on the "operation" field.

func OperationNEQ

OperationNEQ applies the NEQ predicate on the "operation" field.

func OperationNotIn

func OperationNotIn(vs ...history.OpType) predicate.WorkflowEventHistory

OperationNotIn applies the NotIn predicate on the "operation" field.

func OperationValidator

func OperationValidator(o history.OpType) error

OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.

func Or

Or groups predicates with the OR operator between them.

func OwnerID

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.WorkflowEventHistory

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.WorkflowEventHistory

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.WorkflowEventHistory

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.WorkflowEventHistory

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.WorkflowEventHistory

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.WorkflowEventHistory

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.WorkflowEventHistory

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.WorkflowEventHistory

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.WorkflowEventHistory

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func PayloadIsNil

func PayloadIsNil() predicate.WorkflowEventHistory

PayloadIsNil applies the IsNil predicate on the "payload" field.

func PayloadNotNil

func PayloadNotNil() predicate.WorkflowEventHistory

PayloadNotNil applies the NotNil predicate on the "payload" field.

func Ref

Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.

func RefContains

func RefContains(v string) predicate.WorkflowEventHistory

RefContains applies the Contains predicate on the "ref" field.

func RefContainsFold

func RefContainsFold(v string) predicate.WorkflowEventHistory

RefContainsFold applies the ContainsFold predicate on the "ref" field.

func RefEQ

RefEQ applies the EQ predicate on the "ref" field.

func RefEqualFold

func RefEqualFold(v string) predicate.WorkflowEventHistory

RefEqualFold applies the EqualFold predicate on the "ref" field.

func RefGT

RefGT applies the GT predicate on the "ref" field.

func RefGTE

RefGTE applies the GTE predicate on the "ref" field.

func RefHasPrefix

func RefHasPrefix(v string) predicate.WorkflowEventHistory

RefHasPrefix applies the HasPrefix predicate on the "ref" field.

func RefHasSuffix

func RefHasSuffix(v string) predicate.WorkflowEventHistory

RefHasSuffix applies the HasSuffix predicate on the "ref" field.

func RefIn

RefIn applies the In predicate on the "ref" field.

func RefIsNil

RefIsNil applies the IsNil predicate on the "ref" field.

func RefLT

RefLT applies the LT predicate on the "ref" field.

func RefLTE

RefLTE applies the LTE predicate on the "ref" field.

func RefNEQ

RefNEQ applies the NEQ predicate on the "ref" field.

func RefNotIn

func RefNotIn(vs ...string) predicate.WorkflowEventHistory

RefNotIn applies the NotIn predicate on the "ref" field.

func RefNotNil

func RefNotNil() predicate.WorkflowEventHistory

RefNotNil applies the NotNil predicate on the "ref" field.

func TagsIsNil

func TagsIsNil() predicate.WorkflowEventHistory

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.WorkflowEventHistory

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.WorkflowEventHistory

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.WorkflowEventHistory

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.WorkflowEventHistory

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.WorkflowEventHistory

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.WorkflowEventHistory

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.WorkflowEventHistory

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.WorkflowEventHistory

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.WorkflowEventHistory

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.WorkflowEventHistory

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.WorkflowEventHistory

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.WorkflowEventHistory

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.WorkflowEventHistory

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.WorkflowEventHistory

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.WorkflowEventHistory

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.WorkflowEventHistory

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.WorkflowEventHistory

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.WorkflowEventHistory

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.WorkflowEventHistory

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.WorkflowEventHistory

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.WorkflowEventHistory

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.WorkflowEventHistory

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.WorkflowEventHistory

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.WorkflowEventHistory

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.WorkflowEventHistory

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.WorkflowEventHistory

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WorkflowInstanceID

func WorkflowInstanceID(v string) predicate.WorkflowEventHistory

WorkflowInstanceID applies equality check predicate on the "workflow_instance_id" field. It's identical to WorkflowInstanceIDEQ.

func WorkflowInstanceIDContains

func WorkflowInstanceIDContains(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDContains applies the Contains predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDContainsFold

func WorkflowInstanceIDContainsFold(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDContainsFold applies the ContainsFold predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDEQ

func WorkflowInstanceIDEQ(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDEQ applies the EQ predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDEqualFold

func WorkflowInstanceIDEqualFold(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDEqualFold applies the EqualFold predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDGT

func WorkflowInstanceIDGT(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDGT applies the GT predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDGTE

func WorkflowInstanceIDGTE(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDGTE applies the GTE predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDHasPrefix

func WorkflowInstanceIDHasPrefix(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDHasPrefix applies the HasPrefix predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDHasSuffix

func WorkflowInstanceIDHasSuffix(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDHasSuffix applies the HasSuffix predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDIn

func WorkflowInstanceIDIn(vs ...string) predicate.WorkflowEventHistory

WorkflowInstanceIDIn applies the In predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDLT

func WorkflowInstanceIDLT(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDLT applies the LT predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDLTE

func WorkflowInstanceIDLTE(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDLTE applies the LTE predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDNEQ

func WorkflowInstanceIDNEQ(v string) predicate.WorkflowEventHistory

WorkflowInstanceIDNEQ applies the NEQ predicate on the "workflow_instance_id" field.

func WorkflowInstanceIDNotIn

func WorkflowInstanceIDNotIn(vs ...string) predicate.WorkflowEventHistory

WorkflowInstanceIDNotIn applies the NotIn predicate on the "workflow_instance_id" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the WorkflowEventHistory queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByDisplayID

func ByDisplayID(opts ...sql.OrderTermOption) OrderOption

ByDisplayID orders the results by the display_id field.

func ByEventType

func ByEventType(opts ...sql.OrderTermOption) OrderOption

ByEventType orders the results by the event_type field.

func ByHistoryTime

func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption

ByHistoryTime orders the results by the history_time field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOperation

func ByOperation(opts ...sql.OrderTermOption) OrderOption

ByOperation orders the results by the operation field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByRef

func ByRef(opts ...sql.OrderTermOption) OrderOption

ByRef orders the results by the ref field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

func ByWorkflowInstanceID

func ByWorkflowInstanceID(opts ...sql.OrderTermOption) OrderOption

ByWorkflowInstanceID orders the results by the workflow_instance_id field.

Jump to