schemautil

package
v1.22.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var EdgeAuthCheckName = "EDGE_AUTH_CHECK"

EdgeAuthCheckName is a name for the edge auth check

Functions

func TrustCenterScopePredicate added in v1.9.8

func TrustCenterScopePredicate() func(*sql.Selector)

TrustCenterScopePredicate returns a predicate that scopes trust center joins and filters out correctly using the trustcenter_id

Types

type EdgeAccessAnnotation

type EdgeAccessAnnotation struct {
	ObjectType        string
	RequiresEditCheck bool
}

func EdgeAuthCheck

func EdgeAuthCheck(objectType string) EdgeAccessAnnotation

func EdgeNoAuthCheck

func EdgeNoAuthCheck(objectType string) EdgeAccessAnnotation

func (EdgeAccessAnnotation) Name

func (a EdgeAccessAnnotation) Name() string

Name returns the name of the SchemaGenAnnotation

Jump to