mocks

package
v0.19.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockClient

type MockClient struct {
	mock.Mock
}

MockClient is an autogenerated mock type for the Client type

func NewMockClient

func NewMockClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockClient

NewMockClient creates a new instance of MockClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockClient) CustomHostnames

func (_mock *MockClient) CustomHostnames() cloudflare.CustomHostnamesService

CustomHostnames provides a mock function for the type MockClient

func (*MockClient) EXPECT

func (_m *MockClient) EXPECT() *MockClient_Expecter

type MockClient_CustomHostnames_Call

type MockClient_CustomHostnames_Call struct {
	*mock.Call
}

MockClient_CustomHostnames_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CustomHostnames'

func (*MockClient_CustomHostnames_Call) Return

func (*MockClient_CustomHostnames_Call) Run

func (*MockClient_CustomHostnames_Call) RunAndReturn

type MockClient_Expecter

type MockClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockClient_Expecter) CustomHostnames

CustomHostnames is a helper method to define mock.On call

type MockCustomHostnamesService

type MockCustomHostnamesService struct {
	mock.Mock
}

MockCustomHostnamesService is an autogenerated mock type for the CustomHostnamesService type

func NewMockCustomHostnamesService

func NewMockCustomHostnamesService(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCustomHostnamesService

NewMockCustomHostnamesService creates a new instance of MockCustomHostnamesService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCustomHostnamesService) Delete

Delete provides a mock function for the type MockCustomHostnamesService

func (*MockCustomHostnamesService) EXPECT

func (*MockCustomHostnamesService) Get

Get provides a mock function for the type MockCustomHostnamesService

func (*MockCustomHostnamesService) New

New provides a mock function for the type MockCustomHostnamesService

type MockCustomHostnamesService_Delete_Call

type MockCustomHostnamesService_Delete_Call struct {
	*mock.Call
}

MockCustomHostnamesService_Delete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Delete'

func (*MockCustomHostnamesService_Delete_Call) Return

func (*MockCustomHostnamesService_Delete_Call) Run

func (*MockCustomHostnamesService_Delete_Call) RunAndReturn

type MockCustomHostnamesService_Expecter

type MockCustomHostnamesService_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCustomHostnamesService_Expecter) Delete

func (_e *MockCustomHostnamesService_Expecter) Delete(context1 interface{}, s interface{}, customHostnameDeleteParams interface{}, vs ...interface{}) *MockCustomHostnamesService_Delete_Call

Delete is a helper method to define mock.On call

  • context1 context.Context
  • s string
  • customHostnameDeleteParams custom_hostnames.CustomHostnameDeleteParams
  • vs ...option.RequestOption

func (*MockCustomHostnamesService_Expecter) Get

func (_e *MockCustomHostnamesService_Expecter) Get(context1 interface{}, s interface{}, customHostnameGetParams interface{}, vs ...interface{}) *MockCustomHostnamesService_Get_Call

Get is a helper method to define mock.On call

  • context1 context.Context
  • s string
  • customHostnameGetParams custom_hostnames.CustomHostnameGetParams
  • vs ...option.RequestOption

func (*MockCustomHostnamesService_Expecter) New

func (_e *MockCustomHostnamesService_Expecter) New(context1 interface{}, customHostnameNewParams interface{}, vs ...interface{}) *MockCustomHostnamesService_New_Call

New is a helper method to define mock.On call

  • context1 context.Context
  • customHostnameNewParams custom_hostnames.CustomHostnameNewParams
  • vs ...option.RequestOption

type MockCustomHostnamesService_Get_Call

type MockCustomHostnamesService_Get_Call struct {
	*mock.Call
}

MockCustomHostnamesService_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'

func (*MockCustomHostnamesService_Get_Call) Return

func (*MockCustomHostnamesService_Get_Call) Run

func (*MockCustomHostnamesService_Get_Call) RunAndReturn

type MockCustomHostnamesService_New_Call

type MockCustomHostnamesService_New_Call struct {
	*mock.Call
}

MockCustomHostnamesService_New_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'New'

func (*MockCustomHostnamesService_New_Call) Return

func (*MockCustomHostnamesService_New_Call) Run

func (*MockCustomHostnamesService_New_Call) RunAndReturn

Jump to