asset

package
v0.37.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 2, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the asset type in the database.
	Label = "asset"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeletedBy holds the string denoting the deleted_by field in the database.
	FieldDeletedBy = "deleted_by"
	// FieldTags holds the string denoting the tags field in the database.
	FieldTags = "tags"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldSystemOwned holds the string denoting the system_owned field in the database.
	FieldSystemOwned = "system_owned"
	// FieldInternalNotes holds the string denoting the internal_notes field in the database.
	FieldInternalNotes = "internal_notes"
	// FieldSystemInternalID holds the string denoting the system_internal_id field in the database.
	FieldSystemInternalID = "system_internal_id"
	// FieldAssetType holds the string denoting the asset_type field in the database.
	FieldAssetType = "asset_type"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldIdentifier holds the string denoting the identifier field in the database.
	FieldIdentifier = "identifier"
	// FieldWebsite holds the string denoting the website field in the database.
	FieldWebsite = "website"
	// FieldCpe holds the string denoting the cpe field in the database.
	FieldCpe = "cpe"
	// FieldCategories holds the string denoting the categories field in the database.
	FieldCategories = "categories"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// EdgeBlockedGroups holds the string denoting the blocked_groups edge name in mutations.
	EdgeBlockedGroups = "blocked_groups"
	// EdgeEditors holds the string denoting the editors edge name in mutations.
	EdgeEditors = "editors"
	// EdgeViewers holds the string denoting the viewers edge name in mutations.
	EdgeViewers = "viewers"
	// EdgeScans holds the string denoting the scans edge name in mutations.
	EdgeScans = "scans"
	// EdgeEntities holds the string denoting the entities edge name in mutations.
	EdgeEntities = "entities"
	// EdgeControls holds the string denoting the controls edge name in mutations.
	EdgeControls = "controls"
	// Table holds the table name of the asset in the database.
	Table = "assets"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "assets"
	// OwnerInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OwnerInverseTable = "organizations"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
	// BlockedGroupsTable is the table that holds the blocked_groups relation/edge.
	BlockedGroupsTable = "groups"
	// BlockedGroupsInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	BlockedGroupsInverseTable = "groups"
	// BlockedGroupsColumn is the table column denoting the blocked_groups relation/edge.
	BlockedGroupsColumn = "asset_blocked_groups"
	// EditorsTable is the table that holds the editors relation/edge.
	EditorsTable = "groups"
	// EditorsInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	EditorsInverseTable = "groups"
	// EditorsColumn is the table column denoting the editors relation/edge.
	EditorsColumn = "asset_editors"
	// ViewersTable is the table that holds the viewers relation/edge.
	ViewersTable = "groups"
	// ViewersInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	ViewersInverseTable = "groups"
	// ViewersColumn is the table column denoting the viewers relation/edge.
	ViewersColumn = "asset_viewers"
	// ScansTable is the table that holds the scans relation/edge. The primary key declared below.
	ScansTable = "scan_assets"
	// ScansInverseTable is the table name for the Scan entity.
	// It exists in this package in order to avoid circular dependency with the "scan" package.
	ScansInverseTable = "scans"
	// EntitiesTable is the table that holds the entities relation/edge. The primary key declared below.
	EntitiesTable = "entity_assets"
	// EntitiesInverseTable is the table name for the Entity entity.
	// It exists in this package in order to avoid circular dependency with the "entity" package.
	EntitiesInverseTable = "entities"
	// ControlsTable is the table that holds the controls relation/edge. The primary key declared below.
	ControlsTable = "control_assets"
	// ControlsInverseTable is the table name for the Control entity.
	// It exists in this package in order to avoid circular dependency with the "control" package.
	ControlsInverseTable = "controls"
)
const DefaultAssetType enums.AssetType = "TECHNOLOGY"

Variables

var (
	// ScansPrimaryKey and ScansColumn2 are the table columns denoting the
	// primary key for the scans relation (M2M).
	ScansPrimaryKey = []string{"scan_id", "asset_id"}
	// EntitiesPrimaryKey and EntitiesColumn2 are the table columns denoting the
	// primary key for the entities relation (M2M).
	EntitiesPrimaryKey = []string{"entity_id", "asset_id"}
	// ControlsPrimaryKey and ControlsColumn2 are the table columns denoting the
	// primary key for the controls relation (M2M).
	ControlsPrimaryKey = []string{"control_id", "asset_id"}
)
var (
	Hooks        [9]ent.Hook
	Interceptors [3]ent.Interceptor
	Policy       ent.Policy
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultTags holds the default value on creation for the "tags" field.
	DefaultTags []string
	// DefaultSystemOwned holds the default value on creation for the "system_owned" field.
	DefaultSystemOwned bool
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/theopenlane/core/internal/ent/generated/runtime"

Columns holds all SQL columns for asset fields.

var ForeignKeys = []string{
	"risk_assets",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "assets" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Asset) predicate.Asset

And groups predicates with the AND operator between them.

func AssetTypeEQ

func AssetTypeEQ(v enums.AssetType) predicate.Asset

AssetTypeEQ applies the EQ predicate on the "asset_type" field.

func AssetTypeIn

func AssetTypeIn(vs ...enums.AssetType) predicate.Asset

AssetTypeIn applies the In predicate on the "asset_type" field.

func AssetTypeNEQ

func AssetTypeNEQ(v enums.AssetType) predicate.Asset

AssetTypeNEQ applies the NEQ predicate on the "asset_type" field.

func AssetTypeNotIn

func AssetTypeNotIn(vs ...enums.AssetType) predicate.Asset

AssetTypeNotIn applies the NotIn predicate on the "asset_type" field.

func AssetTypeValidator

func AssetTypeValidator(at enums.AssetType) error

AssetTypeValidator is a validator for the "asset_type" field enum values. It is called by the builders before save.

func CategoriesIsNil

func CategoriesIsNil() predicate.Asset

CategoriesIsNil applies the IsNil predicate on the "categories" field.

func CategoriesNotNil

func CategoriesNotNil() predicate.Asset

CategoriesNotNil applies the NotNil predicate on the "categories" field.

func Cpe

func Cpe(v string) predicate.Asset

Cpe applies equality check predicate on the "cpe" field. It's identical to CpeEQ.

func CpeContains

func CpeContains(v string) predicate.Asset

CpeContains applies the Contains predicate on the "cpe" field.

func CpeContainsFold

func CpeContainsFold(v string) predicate.Asset

CpeContainsFold applies the ContainsFold predicate on the "cpe" field.

func CpeEQ

func CpeEQ(v string) predicate.Asset

CpeEQ applies the EQ predicate on the "cpe" field.

func CpeEqualFold

func CpeEqualFold(v string) predicate.Asset

CpeEqualFold applies the EqualFold predicate on the "cpe" field.

func CpeGT

func CpeGT(v string) predicate.Asset

CpeGT applies the GT predicate on the "cpe" field.

func CpeGTE

func CpeGTE(v string) predicate.Asset

CpeGTE applies the GTE predicate on the "cpe" field.

func CpeHasPrefix

func CpeHasPrefix(v string) predicate.Asset

CpeHasPrefix applies the HasPrefix predicate on the "cpe" field.

func CpeHasSuffix

func CpeHasSuffix(v string) predicate.Asset

CpeHasSuffix applies the HasSuffix predicate on the "cpe" field.

func CpeIn

func CpeIn(vs ...string) predicate.Asset

CpeIn applies the In predicate on the "cpe" field.

func CpeIsNil

func CpeIsNil() predicate.Asset

CpeIsNil applies the IsNil predicate on the "cpe" field.

func CpeLT

func CpeLT(v string) predicate.Asset

CpeLT applies the LT predicate on the "cpe" field.

func CpeLTE

func CpeLTE(v string) predicate.Asset

CpeLTE applies the LTE predicate on the "cpe" field.

func CpeNEQ

func CpeNEQ(v string) predicate.Asset

CpeNEQ applies the NEQ predicate on the "cpe" field.

func CpeNotIn

func CpeNotIn(vs ...string) predicate.Asset

CpeNotIn applies the NotIn predicate on the "cpe" field.

func CpeNotNil

func CpeNotNil() predicate.Asset

CpeNotNil applies the NotNil predicate on the "cpe" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Asset

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Asset

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Asset

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Asset

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Asset

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.Asset

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Asset

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Asset

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Asset

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Asset

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.Asset

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v string) predicate.Asset

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByContains

func CreatedByContains(v string) predicate.Asset

CreatedByContains applies the Contains predicate on the "created_by" field.

func CreatedByContainsFold

func CreatedByContainsFold(v string) predicate.Asset

CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.

func CreatedByEQ

func CreatedByEQ(v string) predicate.Asset

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByEqualFold

func CreatedByEqualFold(v string) predicate.Asset

CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v string) predicate.Asset

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v string) predicate.Asset

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByHasPrefix

func CreatedByHasPrefix(v string) predicate.Asset

CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.

func CreatedByHasSuffix

func CreatedByHasSuffix(v string) predicate.Asset

CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...string) predicate.Asset

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.Asset

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v string) predicate.Asset

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v string) predicate.Asset

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v string) predicate.Asset

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...string) predicate.Asset

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.Asset

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Asset

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Asset

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Asset

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Asset

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Asset

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.Asset

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Asset

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Asset

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Asset

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Asset

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.Asset

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedBy

func DeletedBy(v string) predicate.Asset

DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.

func DeletedByContains

func DeletedByContains(v string) predicate.Asset

DeletedByContains applies the Contains predicate on the "deleted_by" field.

func DeletedByContainsFold

func DeletedByContainsFold(v string) predicate.Asset

DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.

func DeletedByEQ

func DeletedByEQ(v string) predicate.Asset

DeletedByEQ applies the EQ predicate on the "deleted_by" field.

func DeletedByEqualFold

func DeletedByEqualFold(v string) predicate.Asset

DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.

func DeletedByGT

func DeletedByGT(v string) predicate.Asset

DeletedByGT applies the GT predicate on the "deleted_by" field.

func DeletedByGTE

func DeletedByGTE(v string) predicate.Asset

DeletedByGTE applies the GTE predicate on the "deleted_by" field.

func DeletedByHasPrefix

func DeletedByHasPrefix(v string) predicate.Asset

DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.

func DeletedByHasSuffix

func DeletedByHasSuffix(v string) predicate.Asset

DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.

func DeletedByIn

func DeletedByIn(vs ...string) predicate.Asset

DeletedByIn applies the In predicate on the "deleted_by" field.

func DeletedByIsNil

func DeletedByIsNil() predicate.Asset

DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.

func DeletedByLT

func DeletedByLT(v string) predicate.Asset

DeletedByLT applies the LT predicate on the "deleted_by" field.

func DeletedByLTE

func DeletedByLTE(v string) predicate.Asset

DeletedByLTE applies the LTE predicate on the "deleted_by" field.

func DeletedByNEQ

func DeletedByNEQ(v string) predicate.Asset

DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.

func DeletedByNotIn

func DeletedByNotIn(vs ...string) predicate.Asset

DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.

func DeletedByNotNil

func DeletedByNotNil() predicate.Asset

DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.

func Description

func Description(v string) predicate.Asset

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Asset

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Asset

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Asset

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Asset

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Asset

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Asset

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Asset

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Asset

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Asset

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.Asset

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Asset

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Asset

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Asset

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Asset

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.Asset

DescriptionNotNil applies the NotNil predicate on the "description" field.

func HasBlockedGroups

func HasBlockedGroups() predicate.Asset

HasBlockedGroups applies the HasEdge predicate on the "blocked_groups" edge.

func HasBlockedGroupsWith

func HasBlockedGroupsWith(preds ...predicate.Group) predicate.Asset

HasBlockedGroupsWith applies the HasEdge predicate on the "blocked_groups" edge with a given conditions (other predicates).

func HasControls

func HasControls() predicate.Asset

HasControls applies the HasEdge predicate on the "controls" edge.

func HasControlsWith

func HasControlsWith(preds ...predicate.Control) predicate.Asset

HasControlsWith applies the HasEdge predicate on the "controls" edge with a given conditions (other predicates).

func HasEditors

func HasEditors() predicate.Asset

HasEditors applies the HasEdge predicate on the "editors" edge.

func HasEditorsWith

func HasEditorsWith(preds ...predicate.Group) predicate.Asset

HasEditorsWith applies the HasEdge predicate on the "editors" edge with a given conditions (other predicates).

func HasEntities

func HasEntities() predicate.Asset

HasEntities applies the HasEdge predicate on the "entities" edge.

func HasEntitiesWith

func HasEntitiesWith(preds ...predicate.Entity) predicate.Asset

HasEntitiesWith applies the HasEdge predicate on the "entities" edge with a given conditions (other predicates).

func HasOwner

func HasOwner() predicate.Asset

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Organization) predicate.Asset

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func HasScans

func HasScans() predicate.Asset

HasScans applies the HasEdge predicate on the "scans" edge.

func HasScansWith

func HasScansWith(preds ...predicate.Scan) predicate.Asset

HasScansWith applies the HasEdge predicate on the "scans" edge with a given conditions (other predicates).

func HasViewers

func HasViewers() predicate.Asset

HasViewers applies the HasEdge predicate on the "viewers" edge.

func HasViewersWith

func HasViewersWith(preds ...predicate.Group) predicate.Asset

HasViewersWith applies the HasEdge predicate on the "viewers" edge with a given conditions (other predicates).

func ID

func ID(id string) predicate.Asset

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.Asset

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.Asset

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.Asset

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Asset

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Asset

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Asset

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Asset

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Asset

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Asset

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Asset

IDNotIn applies the NotIn predicate on the ID field.

func Identifier

func Identifier(v string) predicate.Asset

Identifier applies equality check predicate on the "identifier" field. It's identical to IdentifierEQ.

func IdentifierContains

func IdentifierContains(v string) predicate.Asset

IdentifierContains applies the Contains predicate on the "identifier" field.

func IdentifierContainsFold

func IdentifierContainsFold(v string) predicate.Asset

IdentifierContainsFold applies the ContainsFold predicate on the "identifier" field.

func IdentifierEQ

func IdentifierEQ(v string) predicate.Asset

IdentifierEQ applies the EQ predicate on the "identifier" field.

func IdentifierEqualFold

func IdentifierEqualFold(v string) predicate.Asset

IdentifierEqualFold applies the EqualFold predicate on the "identifier" field.

func IdentifierGT

func IdentifierGT(v string) predicate.Asset

IdentifierGT applies the GT predicate on the "identifier" field.

func IdentifierGTE

func IdentifierGTE(v string) predicate.Asset

IdentifierGTE applies the GTE predicate on the "identifier" field.

func IdentifierHasPrefix

func IdentifierHasPrefix(v string) predicate.Asset

IdentifierHasPrefix applies the HasPrefix predicate on the "identifier" field.

func IdentifierHasSuffix

func IdentifierHasSuffix(v string) predicate.Asset

IdentifierHasSuffix applies the HasSuffix predicate on the "identifier" field.

func IdentifierIn

func IdentifierIn(vs ...string) predicate.Asset

IdentifierIn applies the In predicate on the "identifier" field.

func IdentifierIsNil

func IdentifierIsNil() predicate.Asset

IdentifierIsNil applies the IsNil predicate on the "identifier" field.

func IdentifierLT

func IdentifierLT(v string) predicate.Asset

IdentifierLT applies the LT predicate on the "identifier" field.

func IdentifierLTE

func IdentifierLTE(v string) predicate.Asset

IdentifierLTE applies the LTE predicate on the "identifier" field.

func IdentifierNEQ

func IdentifierNEQ(v string) predicate.Asset

IdentifierNEQ applies the NEQ predicate on the "identifier" field.

func IdentifierNotIn

func IdentifierNotIn(vs ...string) predicate.Asset

IdentifierNotIn applies the NotIn predicate on the "identifier" field.

func IdentifierNotNil

func IdentifierNotNil() predicate.Asset

IdentifierNotNil applies the NotNil predicate on the "identifier" field.

func InternalNotes added in v0.34.0

func InternalNotes(v string) predicate.Asset

InternalNotes applies equality check predicate on the "internal_notes" field. It's identical to InternalNotesEQ.

func InternalNotesContains added in v0.34.0

func InternalNotesContains(v string) predicate.Asset

InternalNotesContains applies the Contains predicate on the "internal_notes" field.

func InternalNotesContainsFold added in v0.34.0

func InternalNotesContainsFold(v string) predicate.Asset

InternalNotesContainsFold applies the ContainsFold predicate on the "internal_notes" field.

func InternalNotesEQ added in v0.34.0

func InternalNotesEQ(v string) predicate.Asset

InternalNotesEQ applies the EQ predicate on the "internal_notes" field.

func InternalNotesEqualFold added in v0.34.0

func InternalNotesEqualFold(v string) predicate.Asset

InternalNotesEqualFold applies the EqualFold predicate on the "internal_notes" field.

func InternalNotesGT added in v0.34.0

func InternalNotesGT(v string) predicate.Asset

InternalNotesGT applies the GT predicate on the "internal_notes" field.

func InternalNotesGTE added in v0.34.0

func InternalNotesGTE(v string) predicate.Asset

InternalNotesGTE applies the GTE predicate on the "internal_notes" field.

func InternalNotesHasPrefix added in v0.34.0

func InternalNotesHasPrefix(v string) predicate.Asset

InternalNotesHasPrefix applies the HasPrefix predicate on the "internal_notes" field.

func InternalNotesHasSuffix added in v0.34.0

func InternalNotesHasSuffix(v string) predicate.Asset

InternalNotesHasSuffix applies the HasSuffix predicate on the "internal_notes" field.

func InternalNotesIn added in v0.34.0

func InternalNotesIn(vs ...string) predicate.Asset

InternalNotesIn applies the In predicate on the "internal_notes" field.

func InternalNotesIsNil added in v0.34.0

func InternalNotesIsNil() predicate.Asset

InternalNotesIsNil applies the IsNil predicate on the "internal_notes" field.

func InternalNotesLT added in v0.34.0

func InternalNotesLT(v string) predicate.Asset

InternalNotesLT applies the LT predicate on the "internal_notes" field.

func InternalNotesLTE added in v0.34.0

func InternalNotesLTE(v string) predicate.Asset

InternalNotesLTE applies the LTE predicate on the "internal_notes" field.

func InternalNotesNEQ added in v0.34.0

func InternalNotesNEQ(v string) predicate.Asset

InternalNotesNEQ applies the NEQ predicate on the "internal_notes" field.

func InternalNotesNotIn added in v0.34.0

func InternalNotesNotIn(vs ...string) predicate.Asset

InternalNotesNotIn applies the NotIn predicate on the "internal_notes" field.

func InternalNotesNotNil added in v0.34.0

func InternalNotesNotNil() predicate.Asset

InternalNotesNotNil applies the NotNil predicate on the "internal_notes" field.

func Name

func Name(v string) predicate.Asset

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Asset

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Asset

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Asset

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Asset

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Asset

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Asset

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Asset

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Asset

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Asset

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Asset

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Asset

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Asset

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Asset

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Asset) predicate.Asset

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v string) predicate.Asset

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDContains

func OwnerIDContains(v string) predicate.Asset

OwnerIDContains applies the Contains predicate on the "owner_id" field.

func OwnerIDContainsFold

func OwnerIDContainsFold(v string) predicate.Asset

OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.

func OwnerIDEQ

func OwnerIDEQ(v string) predicate.Asset

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDEqualFold

func OwnerIDEqualFold(v string) predicate.Asset

OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v string) predicate.Asset

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v string) predicate.Asset

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDHasPrefix

func OwnerIDHasPrefix(v string) predicate.Asset

OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.

func OwnerIDHasSuffix

func OwnerIDHasSuffix(v string) predicate.Asset

OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...string) predicate.Asset

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.Asset

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v string) predicate.Asset

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v string) predicate.Asset

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v string) predicate.Asset

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...string) predicate.Asset

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.Asset

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func SystemInternalID added in v0.34.0

func SystemInternalID(v string) predicate.Asset

SystemInternalID applies equality check predicate on the "system_internal_id" field. It's identical to SystemInternalIDEQ.

func SystemInternalIDContains added in v0.34.0

func SystemInternalIDContains(v string) predicate.Asset

SystemInternalIDContains applies the Contains predicate on the "system_internal_id" field.

func SystemInternalIDContainsFold added in v0.34.0

func SystemInternalIDContainsFold(v string) predicate.Asset

SystemInternalIDContainsFold applies the ContainsFold predicate on the "system_internal_id" field.

func SystemInternalIDEQ added in v0.34.0

func SystemInternalIDEQ(v string) predicate.Asset

SystemInternalIDEQ applies the EQ predicate on the "system_internal_id" field.

func SystemInternalIDEqualFold added in v0.34.0

func SystemInternalIDEqualFold(v string) predicate.Asset

SystemInternalIDEqualFold applies the EqualFold predicate on the "system_internal_id" field.

func SystemInternalIDGT added in v0.34.0

func SystemInternalIDGT(v string) predicate.Asset

SystemInternalIDGT applies the GT predicate on the "system_internal_id" field.

func SystemInternalIDGTE added in v0.34.0

func SystemInternalIDGTE(v string) predicate.Asset

SystemInternalIDGTE applies the GTE predicate on the "system_internal_id" field.

func SystemInternalIDHasPrefix added in v0.34.0

func SystemInternalIDHasPrefix(v string) predicate.Asset

SystemInternalIDHasPrefix applies the HasPrefix predicate on the "system_internal_id" field.

func SystemInternalIDHasSuffix added in v0.34.0

func SystemInternalIDHasSuffix(v string) predicate.Asset

SystemInternalIDHasSuffix applies the HasSuffix predicate on the "system_internal_id" field.

func SystemInternalIDIn added in v0.34.0

func SystemInternalIDIn(vs ...string) predicate.Asset

SystemInternalIDIn applies the In predicate on the "system_internal_id" field.

func SystemInternalIDIsNil added in v0.34.0

func SystemInternalIDIsNil() predicate.Asset

SystemInternalIDIsNil applies the IsNil predicate on the "system_internal_id" field.

func SystemInternalIDLT added in v0.34.0

func SystemInternalIDLT(v string) predicate.Asset

SystemInternalIDLT applies the LT predicate on the "system_internal_id" field.

func SystemInternalIDLTE added in v0.34.0

func SystemInternalIDLTE(v string) predicate.Asset

SystemInternalIDLTE applies the LTE predicate on the "system_internal_id" field.

func SystemInternalIDNEQ added in v0.34.0

func SystemInternalIDNEQ(v string) predicate.Asset

SystemInternalIDNEQ applies the NEQ predicate on the "system_internal_id" field.

func SystemInternalIDNotIn added in v0.34.0

func SystemInternalIDNotIn(vs ...string) predicate.Asset

SystemInternalIDNotIn applies the NotIn predicate on the "system_internal_id" field.

func SystemInternalIDNotNil added in v0.34.0

func SystemInternalIDNotNil() predicate.Asset

SystemInternalIDNotNil applies the NotNil predicate on the "system_internal_id" field.

func SystemOwned added in v0.34.0

func SystemOwned(v bool) predicate.Asset

SystemOwned applies equality check predicate on the "system_owned" field. It's identical to SystemOwnedEQ.

func SystemOwnedEQ added in v0.34.0

func SystemOwnedEQ(v bool) predicate.Asset

SystemOwnedEQ applies the EQ predicate on the "system_owned" field.

func SystemOwnedIsNil added in v0.34.0

func SystemOwnedIsNil() predicate.Asset

SystemOwnedIsNil applies the IsNil predicate on the "system_owned" field.

func SystemOwnedNEQ added in v0.34.0

func SystemOwnedNEQ(v bool) predicate.Asset

SystemOwnedNEQ applies the NEQ predicate on the "system_owned" field.

func SystemOwnedNotNil added in v0.34.0

func SystemOwnedNotNil() predicate.Asset

SystemOwnedNotNil applies the NotNil predicate on the "system_owned" field.

func TagsIsNil

func TagsIsNil() predicate.Asset

TagsIsNil applies the IsNil predicate on the "tags" field.

func TagsNotNil

func TagsNotNil() predicate.Asset

TagsNotNil applies the NotNil predicate on the "tags" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Asset

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Asset

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Asset

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Asset

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Asset

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.Asset

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Asset

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Asset

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Asset

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Asset

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.Asset

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v string) predicate.Asset

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByContains

func UpdatedByContains(v string) predicate.Asset

UpdatedByContains applies the Contains predicate on the "updated_by" field.

func UpdatedByContainsFold

func UpdatedByContainsFold(v string) predicate.Asset

UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.

func UpdatedByEQ

func UpdatedByEQ(v string) predicate.Asset

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByEqualFold

func UpdatedByEqualFold(v string) predicate.Asset

UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v string) predicate.Asset

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v string) predicate.Asset

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByHasPrefix

func UpdatedByHasPrefix(v string) predicate.Asset

UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.

func UpdatedByHasSuffix

func UpdatedByHasSuffix(v string) predicate.Asset

UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...string) predicate.Asset

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.Asset

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v string) predicate.Asset

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v string) predicate.Asset

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v string) predicate.Asset

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...string) predicate.Asset

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.Asset

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Website

func Website(v string) predicate.Asset

Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.

func WebsiteContains

func WebsiteContains(v string) predicate.Asset

WebsiteContains applies the Contains predicate on the "website" field.

func WebsiteContainsFold

func WebsiteContainsFold(v string) predicate.Asset

WebsiteContainsFold applies the ContainsFold predicate on the "website" field.

func WebsiteEQ

func WebsiteEQ(v string) predicate.Asset

WebsiteEQ applies the EQ predicate on the "website" field.

func WebsiteEqualFold

func WebsiteEqualFold(v string) predicate.Asset

WebsiteEqualFold applies the EqualFold predicate on the "website" field.

func WebsiteGT

func WebsiteGT(v string) predicate.Asset

WebsiteGT applies the GT predicate on the "website" field.

func WebsiteGTE

func WebsiteGTE(v string) predicate.Asset

WebsiteGTE applies the GTE predicate on the "website" field.

func WebsiteHasPrefix

func WebsiteHasPrefix(v string) predicate.Asset

WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.

func WebsiteHasSuffix

func WebsiteHasSuffix(v string) predicate.Asset

WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.

func WebsiteIn

func WebsiteIn(vs ...string) predicate.Asset

WebsiteIn applies the In predicate on the "website" field.

func WebsiteIsNil

func WebsiteIsNil() predicate.Asset

WebsiteIsNil applies the IsNil predicate on the "website" field.

func WebsiteLT

func WebsiteLT(v string) predicate.Asset

WebsiteLT applies the LT predicate on the "website" field.

func WebsiteLTE

func WebsiteLTE(v string) predicate.Asset

WebsiteLTE applies the LTE predicate on the "website" field.

func WebsiteNEQ

func WebsiteNEQ(v string) predicate.Asset

WebsiteNEQ applies the NEQ predicate on the "website" field.

func WebsiteNotIn

func WebsiteNotIn(vs ...string) predicate.Asset

WebsiteNotIn applies the NotIn predicate on the "website" field.

func WebsiteNotNil

func WebsiteNotNil() predicate.Asset

WebsiteNotNil applies the NotNil predicate on the "website" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Asset queries.

func ByAssetType

func ByAssetType(opts ...sql.OrderTermOption) OrderOption

ByAssetType orders the results by the asset_type field.

func ByBlockedGroups

func ByBlockedGroups(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByBlockedGroups orders the results by blocked_groups terms.

func ByBlockedGroupsCount

func ByBlockedGroupsCount(opts ...sql.OrderTermOption) OrderOption

ByBlockedGroupsCount orders the results by blocked_groups count.

func ByControls

func ByControls(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByControls orders the results by controls terms.

func ByControlsCount

func ByControlsCount(opts ...sql.OrderTermOption) OrderOption

ByControlsCount orders the results by controls count.

func ByCpe

func ByCpe(opts ...sql.OrderTermOption) OrderOption

ByCpe orders the results by the cpe field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedBy

func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption

ByDeletedBy orders the results by the deleted_by field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByEditors

func ByEditors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEditors orders the results by editors terms.

func ByEditorsCount

func ByEditorsCount(opts ...sql.OrderTermOption) OrderOption

ByEditorsCount orders the results by editors count.

func ByEntities

func ByEntities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEntities orders the results by entities terms.

func ByEntitiesCount

func ByEntitiesCount(opts ...sql.OrderTermOption) OrderOption

ByEntitiesCount orders the results by entities count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIdentifier

func ByIdentifier(opts ...sql.OrderTermOption) OrderOption

ByIdentifier orders the results by the identifier field.

func ByInternalNotes added in v0.34.0

func ByInternalNotes(opts ...sql.OrderTermOption) OrderOption

ByInternalNotes orders the results by the internal_notes field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByScans

func ByScans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByScans orders the results by scans terms.

func ByScansCount

func ByScansCount(opts ...sql.OrderTermOption) OrderOption

ByScansCount orders the results by scans count.

func BySystemInternalID added in v0.34.0

func BySystemInternalID(opts ...sql.OrderTermOption) OrderOption

BySystemInternalID orders the results by the system_internal_id field.

func BySystemOwned added in v0.34.0

func BySystemOwned(opts ...sql.OrderTermOption) OrderOption

BySystemOwned orders the results by the system_owned field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

func ByViewers

func ByViewers(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByViewers orders the results by viewers terms.

func ByViewersCount

func ByViewersCount(opts ...sql.OrderTermOption) OrderOption

ByViewersCount orders the results by viewers count.

func ByWebsite

func ByWebsite(opts ...sql.OrderTermOption) OrderOption

ByWebsite orders the results by the website field.

Jump to