Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.FindingControlHistory) predicate.FindingControlHistory
- func ControlID(v string) predicate.FindingControlHistory
- func ControlIDContains(v string) predicate.FindingControlHistory
- func ControlIDContainsFold(v string) predicate.FindingControlHistory
- func ControlIDEQ(v string) predicate.FindingControlHistory
- func ControlIDEqualFold(v string) predicate.FindingControlHistory
- func ControlIDGT(v string) predicate.FindingControlHistory
- func ControlIDGTE(v string) predicate.FindingControlHistory
- func ControlIDHasPrefix(v string) predicate.FindingControlHistory
- func ControlIDHasSuffix(v string) predicate.FindingControlHistory
- func ControlIDIn(vs ...string) predicate.FindingControlHistory
- func ControlIDLT(v string) predicate.FindingControlHistory
- func ControlIDLTE(v string) predicate.FindingControlHistory
- func ControlIDNEQ(v string) predicate.FindingControlHistory
- func ControlIDNotIn(vs ...string) predicate.FindingControlHistory
- func CreatedAt(v time.Time) predicate.FindingControlHistory
- func CreatedAtEQ(v time.Time) predicate.FindingControlHistory
- func CreatedAtGT(v time.Time) predicate.FindingControlHistory
- func CreatedAtGTE(v time.Time) predicate.FindingControlHistory
- func CreatedAtIn(vs ...time.Time) predicate.FindingControlHistory
- func CreatedAtIsNil() predicate.FindingControlHistory
- func CreatedAtLT(v time.Time) predicate.FindingControlHistory
- func CreatedAtLTE(v time.Time) predicate.FindingControlHistory
- func CreatedAtNEQ(v time.Time) predicate.FindingControlHistory
- func CreatedAtNotIn(vs ...time.Time) predicate.FindingControlHistory
- func CreatedAtNotNil() predicate.FindingControlHistory
- func CreatedBy(v string) predicate.FindingControlHistory
- func CreatedByContains(v string) predicate.FindingControlHistory
- func CreatedByContainsFold(v string) predicate.FindingControlHistory
- func CreatedByEQ(v string) predicate.FindingControlHistory
- func CreatedByEqualFold(v string) predicate.FindingControlHistory
- func CreatedByGT(v string) predicate.FindingControlHistory
- func CreatedByGTE(v string) predicate.FindingControlHistory
- func CreatedByHasPrefix(v string) predicate.FindingControlHistory
- func CreatedByHasSuffix(v string) predicate.FindingControlHistory
- func CreatedByIn(vs ...string) predicate.FindingControlHistory
- func CreatedByIsNil() predicate.FindingControlHistory
- func CreatedByLT(v string) predicate.FindingControlHistory
- func CreatedByLTE(v string) predicate.FindingControlHistory
- func CreatedByNEQ(v string) predicate.FindingControlHistory
- func CreatedByNotIn(vs ...string) predicate.FindingControlHistory
- func CreatedByNotNil() predicate.FindingControlHistory
- func DiscoveredAt(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtEQ(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtGT(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtGTE(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtIn(vs ...models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtIsNil() predicate.FindingControlHistory
- func DiscoveredAtLT(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtLTE(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtNEQ(v models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtNotIn(vs ...models.DateTime) predicate.FindingControlHistory
- func DiscoveredAtNotNil() predicate.FindingControlHistory
- func ExternalControlID(v string) predicate.FindingControlHistory
- func ExternalControlIDContains(v string) predicate.FindingControlHistory
- func ExternalControlIDContainsFold(v string) predicate.FindingControlHistory
- func ExternalControlIDEQ(v string) predicate.FindingControlHistory
- func ExternalControlIDEqualFold(v string) predicate.FindingControlHistory
- func ExternalControlIDGT(v string) predicate.FindingControlHistory
- func ExternalControlIDGTE(v string) predicate.FindingControlHistory
- func ExternalControlIDHasPrefix(v string) predicate.FindingControlHistory
- func ExternalControlIDHasSuffix(v string) predicate.FindingControlHistory
- func ExternalControlIDIn(vs ...string) predicate.FindingControlHistory
- func ExternalControlIDIsNil() predicate.FindingControlHistory
- func ExternalControlIDLT(v string) predicate.FindingControlHistory
- func ExternalControlIDLTE(v string) predicate.FindingControlHistory
- func ExternalControlIDNEQ(v string) predicate.FindingControlHistory
- func ExternalControlIDNotIn(vs ...string) predicate.FindingControlHistory
- func ExternalControlIDNotNil() predicate.FindingControlHistory
- func ExternalStandard(v string) predicate.FindingControlHistory
- func ExternalStandardContains(v string) predicate.FindingControlHistory
- func ExternalStandardContainsFold(v string) predicate.FindingControlHistory
- func ExternalStandardEQ(v string) predicate.FindingControlHistory
- func ExternalStandardEqualFold(v string) predicate.FindingControlHistory
- func ExternalStandardGT(v string) predicate.FindingControlHistory
- func ExternalStandardGTE(v string) predicate.FindingControlHistory
- func ExternalStandardHasPrefix(v string) predicate.FindingControlHistory
- func ExternalStandardHasSuffix(v string) predicate.FindingControlHistory
- func ExternalStandardIn(vs ...string) predicate.FindingControlHistory
- func ExternalStandardIsNil() predicate.FindingControlHistory
- func ExternalStandardLT(v string) predicate.FindingControlHistory
- func ExternalStandardLTE(v string) predicate.FindingControlHistory
- func ExternalStandardNEQ(v string) predicate.FindingControlHistory
- func ExternalStandardNotIn(vs ...string) predicate.FindingControlHistory
- func ExternalStandardNotNil() predicate.FindingControlHistory
- func ExternalStandardVersion(v string) predicate.FindingControlHistory
- func ExternalStandardVersionContains(v string) predicate.FindingControlHistory
- func ExternalStandardVersionContainsFold(v string) predicate.FindingControlHistory
- func ExternalStandardVersionEQ(v string) predicate.FindingControlHistory
- func ExternalStandardVersionEqualFold(v string) predicate.FindingControlHistory
- func ExternalStandardVersionGT(v string) predicate.FindingControlHistory
- func ExternalStandardVersionGTE(v string) predicate.FindingControlHistory
- func ExternalStandardVersionHasPrefix(v string) predicate.FindingControlHistory
- func ExternalStandardVersionHasSuffix(v string) predicate.FindingControlHistory
- func ExternalStandardVersionIn(vs ...string) predicate.FindingControlHistory
- func ExternalStandardVersionIsNil() predicate.FindingControlHistory
- func ExternalStandardVersionLT(v string) predicate.FindingControlHistory
- func ExternalStandardVersionLTE(v string) predicate.FindingControlHistory
- func ExternalStandardVersionNEQ(v string) predicate.FindingControlHistory
- func ExternalStandardVersionNotIn(vs ...string) predicate.FindingControlHistory
- func ExternalStandardVersionNotNil() predicate.FindingControlHistory
- func FindingID(v string) predicate.FindingControlHistory
- func FindingIDContains(v string) predicate.FindingControlHistory
- func FindingIDContainsFold(v string) predicate.FindingControlHistory
- func FindingIDEQ(v string) predicate.FindingControlHistory
- func FindingIDEqualFold(v string) predicate.FindingControlHistory
- func FindingIDGT(v string) predicate.FindingControlHistory
- func FindingIDGTE(v string) predicate.FindingControlHistory
- func FindingIDHasPrefix(v string) predicate.FindingControlHistory
- func FindingIDHasSuffix(v string) predicate.FindingControlHistory
- func FindingIDIn(vs ...string) predicate.FindingControlHistory
- func FindingIDLT(v string) predicate.FindingControlHistory
- func FindingIDLTE(v string) predicate.FindingControlHistory
- func FindingIDNEQ(v string) predicate.FindingControlHistory
- func FindingIDNotIn(vs ...string) predicate.FindingControlHistory
- func HistoryTime(v time.Time) predicate.FindingControlHistory
- func HistoryTimeEQ(v time.Time) predicate.FindingControlHistory
- func HistoryTimeGT(v time.Time) predicate.FindingControlHistory
- func HistoryTimeGTE(v time.Time) predicate.FindingControlHistory
- func HistoryTimeIn(vs ...time.Time) predicate.FindingControlHistory
- func HistoryTimeLT(v time.Time) predicate.FindingControlHistory
- func HistoryTimeLTE(v time.Time) predicate.FindingControlHistory
- func HistoryTimeNEQ(v time.Time) predicate.FindingControlHistory
- func HistoryTimeNotIn(vs ...time.Time) predicate.FindingControlHistory
- func ID(id string) predicate.FindingControlHistory
- func IDContainsFold(id string) predicate.FindingControlHistory
- func IDEQ(id string) predicate.FindingControlHistory
- func IDEqualFold(id string) predicate.FindingControlHistory
- func IDGT(id string) predicate.FindingControlHistory
- func IDGTE(id string) predicate.FindingControlHistory
- func IDIn(ids ...string) predicate.FindingControlHistory
- func IDLT(id string) predicate.FindingControlHistory
- func IDLTE(id string) predicate.FindingControlHistory
- func IDNEQ(id string) predicate.FindingControlHistory
- func IDNotIn(ids ...string) predicate.FindingControlHistory
- func MetadataIsNil() predicate.FindingControlHistory
- func MetadataNotNil() predicate.FindingControlHistory
- func Not(p predicate.FindingControlHistory) predicate.FindingControlHistory
- func OperationEQ(v history.OpType) predicate.FindingControlHistory
- func OperationIn(vs ...history.OpType) predicate.FindingControlHistory
- func OperationNEQ(v history.OpType) predicate.FindingControlHistory
- func OperationNotIn(vs ...history.OpType) predicate.FindingControlHistory
- func OperationValidator(o history.OpType) error
- func Or(predicates ...predicate.FindingControlHistory) predicate.FindingControlHistory
- func Ref(v string) predicate.FindingControlHistory
- func RefContains(v string) predicate.FindingControlHistory
- func RefContainsFold(v string) predicate.FindingControlHistory
- func RefEQ(v string) predicate.FindingControlHistory
- func RefEqualFold(v string) predicate.FindingControlHistory
- func RefGT(v string) predicate.FindingControlHistory
- func RefGTE(v string) predicate.FindingControlHistory
- func RefHasPrefix(v string) predicate.FindingControlHistory
- func RefHasSuffix(v string) predicate.FindingControlHistory
- func RefIn(vs ...string) predicate.FindingControlHistory
- func RefIsNil() predicate.FindingControlHistory
- func RefLT(v string) predicate.FindingControlHistory
- func RefLTE(v string) predicate.FindingControlHistory
- func RefNEQ(v string) predicate.FindingControlHistory
- func RefNotIn(vs ...string) predicate.FindingControlHistory
- func RefNotNil() predicate.FindingControlHistory
- func Source(v string) predicate.FindingControlHistory
- func SourceContains(v string) predicate.FindingControlHistory
- func SourceContainsFold(v string) predicate.FindingControlHistory
- func SourceEQ(v string) predicate.FindingControlHistory
- func SourceEqualFold(v string) predicate.FindingControlHistory
- func SourceGT(v string) predicate.FindingControlHistory
- func SourceGTE(v string) predicate.FindingControlHistory
- func SourceHasPrefix(v string) predicate.FindingControlHistory
- func SourceHasSuffix(v string) predicate.FindingControlHistory
- func SourceIn(vs ...string) predicate.FindingControlHistory
- func SourceIsNil() predicate.FindingControlHistory
- func SourceLT(v string) predicate.FindingControlHistory
- func SourceLTE(v string) predicate.FindingControlHistory
- func SourceNEQ(v string) predicate.FindingControlHistory
- func SourceNotIn(vs ...string) predicate.FindingControlHistory
- func SourceNotNil() predicate.FindingControlHistory
- func StandardID(v string) predicate.FindingControlHistory
- func StandardIDContains(v string) predicate.FindingControlHistory
- func StandardIDContainsFold(v string) predicate.FindingControlHistory
- func StandardIDEQ(v string) predicate.FindingControlHistory
- func StandardIDEqualFold(v string) predicate.FindingControlHistory
- func StandardIDGT(v string) predicate.FindingControlHistory
- func StandardIDGTE(v string) predicate.FindingControlHistory
- func StandardIDHasPrefix(v string) predicate.FindingControlHistory
- func StandardIDHasSuffix(v string) predicate.FindingControlHistory
- func StandardIDIn(vs ...string) predicate.FindingControlHistory
- func StandardIDIsNil() predicate.FindingControlHistory
- func StandardIDLT(v string) predicate.FindingControlHistory
- func StandardIDLTE(v string) predicate.FindingControlHistory
- func StandardIDNEQ(v string) predicate.FindingControlHistory
- func StandardIDNotIn(vs ...string) predicate.FindingControlHistory
- func StandardIDNotNil() predicate.FindingControlHistory
- func UpdatedAt(v time.Time) predicate.FindingControlHistory
- func UpdatedAtEQ(v time.Time) predicate.FindingControlHistory
- func UpdatedAtGT(v time.Time) predicate.FindingControlHistory
- func UpdatedAtGTE(v time.Time) predicate.FindingControlHistory
- func UpdatedAtIn(vs ...time.Time) predicate.FindingControlHistory
- func UpdatedAtIsNil() predicate.FindingControlHistory
- func UpdatedAtLT(v time.Time) predicate.FindingControlHistory
- func UpdatedAtLTE(v time.Time) predicate.FindingControlHistory
- func UpdatedAtNEQ(v time.Time) predicate.FindingControlHistory
- func UpdatedAtNotIn(vs ...time.Time) predicate.FindingControlHistory
- func UpdatedAtNotNil() predicate.FindingControlHistory
- func UpdatedBy(v string) predicate.FindingControlHistory
- func UpdatedByContains(v string) predicate.FindingControlHistory
- func UpdatedByContainsFold(v string) predicate.FindingControlHistory
- func UpdatedByEQ(v string) predicate.FindingControlHistory
- func UpdatedByEqualFold(v string) predicate.FindingControlHistory
- func UpdatedByGT(v string) predicate.FindingControlHistory
- func UpdatedByGTE(v string) predicate.FindingControlHistory
- func UpdatedByHasPrefix(v string) predicate.FindingControlHistory
- func UpdatedByHasSuffix(v string) predicate.FindingControlHistory
- func UpdatedByIn(vs ...string) predicate.FindingControlHistory
- func UpdatedByIsNil() predicate.FindingControlHistory
- func UpdatedByLT(v string) predicate.FindingControlHistory
- func UpdatedByLTE(v string) predicate.FindingControlHistory
- func UpdatedByNEQ(v string) predicate.FindingControlHistory
- func UpdatedByNotIn(vs ...string) predicate.FindingControlHistory
- func UpdatedByNotNil() predicate.FindingControlHistory
- func ValidColumn(column string) bool
- type OrderOption
- func ByControlID(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDiscoveredAt(opts ...sql.OrderTermOption) OrderOption
- func ByExternalControlID(opts ...sql.OrderTermOption) OrderOption
- func ByExternalStandard(opts ...sql.OrderTermOption) OrderOption
- func ByExternalStandardVersion(opts ...sql.OrderTermOption) OrderOption
- func ByFindingID(opts ...sql.OrderTermOption) OrderOption
- func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByOperation(opts ...sql.OrderTermOption) OrderOption
- func ByRef(opts ...sql.OrderTermOption) OrderOption
- func BySource(opts ...sql.OrderTermOption) OrderOption
- func ByStandardID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the findingcontrolhistory type in the database. Label = "finding_control_history" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldHistoryTime holds the string denoting the history_time field in the database. FieldHistoryTime = "history_time" // FieldRef holds the string denoting the ref field in the database. FieldRef = "ref" // FieldOperation holds the string denoting the operation field in the database. FieldOperation = "operation" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldFindingID holds the string denoting the finding_id field in the database. FieldFindingID = "finding_id" // FieldControlID holds the string denoting the control_id field in the database. FieldControlID = "control_id" // FieldStandardID holds the string denoting the standard_id field in the database. FieldStandardID = "standard_id" // FieldExternalStandard holds the string denoting the external_standard field in the database. FieldExternalStandard = "external_standard" // FieldExternalStandardVersion holds the string denoting the external_standard_version field in the database. FieldExternalStandardVersion = "external_standard_version" // FieldExternalControlID holds the string denoting the external_control_id field in the database. FieldExternalControlID = "external_control_id" // FieldSource holds the string denoting the source field in the database. FieldSource = "source" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // FieldDiscoveredAt holds the string denoting the discovered_at field in the database. FieldDiscoveredAt = "discovered_at" // Table holds the table name of the findingcontrolhistory in the database. Table = "finding_control_history" )
Variables ¶
var ( Hooks [1]ent.Hook Interceptors [1]ent.Interceptor Policy ent.Policy // DefaultHistoryTime holds the default value on creation for the "history_time" field. DefaultHistoryTime func() time.Time // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldHistoryTime, FieldRef, FieldOperation, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldFindingID, FieldControlID, FieldStandardID, FieldExternalStandard, FieldExternalStandardVersion, FieldExternalControlID, FieldSource, FieldMetadata, FieldDiscoveredAt, }
Columns holds all SQL columns for findingcontrolhistory fields.
Functions ¶
func And ¶
func And(predicates ...predicate.FindingControlHistory) predicate.FindingControlHistory
And groups predicates with the AND operator between them.
func ControlID ¶
func ControlID(v string) predicate.FindingControlHistory
ControlID applies equality check predicate on the "control_id" field. It's identical to ControlIDEQ.
func ControlIDContains ¶
func ControlIDContains(v string) predicate.FindingControlHistory
ControlIDContains applies the Contains predicate on the "control_id" field.
func ControlIDContainsFold ¶
func ControlIDContainsFold(v string) predicate.FindingControlHistory
ControlIDContainsFold applies the ContainsFold predicate on the "control_id" field.
func ControlIDEQ ¶
func ControlIDEQ(v string) predicate.FindingControlHistory
ControlIDEQ applies the EQ predicate on the "control_id" field.
func ControlIDEqualFold ¶
func ControlIDEqualFold(v string) predicate.FindingControlHistory
ControlIDEqualFold applies the EqualFold predicate on the "control_id" field.
func ControlIDGT ¶
func ControlIDGT(v string) predicate.FindingControlHistory
ControlIDGT applies the GT predicate on the "control_id" field.
func ControlIDGTE ¶
func ControlIDGTE(v string) predicate.FindingControlHistory
ControlIDGTE applies the GTE predicate on the "control_id" field.
func ControlIDHasPrefix ¶
func ControlIDHasPrefix(v string) predicate.FindingControlHistory
ControlIDHasPrefix applies the HasPrefix predicate on the "control_id" field.
func ControlIDHasSuffix ¶
func ControlIDHasSuffix(v string) predicate.FindingControlHistory
ControlIDHasSuffix applies the HasSuffix predicate on the "control_id" field.
func ControlIDIn ¶
func ControlIDIn(vs ...string) predicate.FindingControlHistory
ControlIDIn applies the In predicate on the "control_id" field.
func ControlIDLT ¶
func ControlIDLT(v string) predicate.FindingControlHistory
ControlIDLT applies the LT predicate on the "control_id" field.
func ControlIDLTE ¶
func ControlIDLTE(v string) predicate.FindingControlHistory
ControlIDLTE applies the LTE predicate on the "control_id" field.
func ControlIDNEQ ¶
func ControlIDNEQ(v string) predicate.FindingControlHistory
ControlIDNEQ applies the NEQ predicate on the "control_id" field.
func ControlIDNotIn ¶
func ControlIDNotIn(vs ...string) predicate.FindingControlHistory
ControlIDNotIn applies the NotIn predicate on the "control_id" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.FindingControlHistory
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.FindingControlHistory
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.FindingControlHistory
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.FindingControlHistory
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.FindingControlHistory
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.FindingControlHistory
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.FindingControlHistory
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.FindingControlHistory
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.FindingControlHistory
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.FindingControlHistory
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.FindingControlHistory
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
func CreatedBy(v string) predicate.FindingControlHistory
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
func CreatedByContains(v string) predicate.FindingControlHistory
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
func CreatedByContainsFold(v string) predicate.FindingControlHistory
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
func CreatedByEQ(v string) predicate.FindingControlHistory
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
func CreatedByEqualFold(v string) predicate.FindingControlHistory
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
func CreatedByGT(v string) predicate.FindingControlHistory
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
func CreatedByGTE(v string) predicate.FindingControlHistory
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
func CreatedByHasPrefix(v string) predicate.FindingControlHistory
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
func CreatedByHasSuffix(v string) predicate.FindingControlHistory
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
func CreatedByIn(vs ...string) predicate.FindingControlHistory
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
func CreatedByIsNil() predicate.FindingControlHistory
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
func CreatedByLT(v string) predicate.FindingControlHistory
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
func CreatedByLTE(v string) predicate.FindingControlHistory
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
func CreatedByNEQ(v string) predicate.FindingControlHistory
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
func CreatedByNotIn(vs ...string) predicate.FindingControlHistory
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
func CreatedByNotNil() predicate.FindingControlHistory
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DiscoveredAt ¶
func DiscoveredAt(v models.DateTime) predicate.FindingControlHistory
DiscoveredAt applies equality check predicate on the "discovered_at" field. It's identical to DiscoveredAtEQ.
func DiscoveredAtEQ ¶
func DiscoveredAtEQ(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtEQ applies the EQ predicate on the "discovered_at" field.
func DiscoveredAtGT ¶
func DiscoveredAtGT(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtGT applies the GT predicate on the "discovered_at" field.
func DiscoveredAtGTE ¶
func DiscoveredAtGTE(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtGTE applies the GTE predicate on the "discovered_at" field.
func DiscoveredAtIn ¶
func DiscoveredAtIn(vs ...models.DateTime) predicate.FindingControlHistory
DiscoveredAtIn applies the In predicate on the "discovered_at" field.
func DiscoveredAtIsNil ¶
func DiscoveredAtIsNil() predicate.FindingControlHistory
DiscoveredAtIsNil applies the IsNil predicate on the "discovered_at" field.
func DiscoveredAtLT ¶
func DiscoveredAtLT(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtLT applies the LT predicate on the "discovered_at" field.
func DiscoveredAtLTE ¶
func DiscoveredAtLTE(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtLTE applies the LTE predicate on the "discovered_at" field.
func DiscoveredAtNEQ ¶
func DiscoveredAtNEQ(v models.DateTime) predicate.FindingControlHistory
DiscoveredAtNEQ applies the NEQ predicate on the "discovered_at" field.
func DiscoveredAtNotIn ¶
func DiscoveredAtNotIn(vs ...models.DateTime) predicate.FindingControlHistory
DiscoveredAtNotIn applies the NotIn predicate on the "discovered_at" field.
func DiscoveredAtNotNil ¶
func DiscoveredAtNotNil() predicate.FindingControlHistory
DiscoveredAtNotNil applies the NotNil predicate on the "discovered_at" field.
func ExternalControlID ¶
func ExternalControlID(v string) predicate.FindingControlHistory
ExternalControlID applies equality check predicate on the "external_control_id" field. It's identical to ExternalControlIDEQ.
func ExternalControlIDContains ¶
func ExternalControlIDContains(v string) predicate.FindingControlHistory
ExternalControlIDContains applies the Contains predicate on the "external_control_id" field.
func ExternalControlIDContainsFold ¶
func ExternalControlIDContainsFold(v string) predicate.FindingControlHistory
ExternalControlIDContainsFold applies the ContainsFold predicate on the "external_control_id" field.
func ExternalControlIDEQ ¶
func ExternalControlIDEQ(v string) predicate.FindingControlHistory
ExternalControlIDEQ applies the EQ predicate on the "external_control_id" field.
func ExternalControlIDEqualFold ¶
func ExternalControlIDEqualFold(v string) predicate.FindingControlHistory
ExternalControlIDEqualFold applies the EqualFold predicate on the "external_control_id" field.
func ExternalControlIDGT ¶
func ExternalControlIDGT(v string) predicate.FindingControlHistory
ExternalControlIDGT applies the GT predicate on the "external_control_id" field.
func ExternalControlIDGTE ¶
func ExternalControlIDGTE(v string) predicate.FindingControlHistory
ExternalControlIDGTE applies the GTE predicate on the "external_control_id" field.
func ExternalControlIDHasPrefix ¶
func ExternalControlIDHasPrefix(v string) predicate.FindingControlHistory
ExternalControlIDHasPrefix applies the HasPrefix predicate on the "external_control_id" field.
func ExternalControlIDHasSuffix ¶
func ExternalControlIDHasSuffix(v string) predicate.FindingControlHistory
ExternalControlIDHasSuffix applies the HasSuffix predicate on the "external_control_id" field.
func ExternalControlIDIn ¶
func ExternalControlIDIn(vs ...string) predicate.FindingControlHistory
ExternalControlIDIn applies the In predicate on the "external_control_id" field.
func ExternalControlIDIsNil ¶
func ExternalControlIDIsNil() predicate.FindingControlHistory
ExternalControlIDIsNil applies the IsNil predicate on the "external_control_id" field.
func ExternalControlIDLT ¶
func ExternalControlIDLT(v string) predicate.FindingControlHistory
ExternalControlIDLT applies the LT predicate on the "external_control_id" field.
func ExternalControlIDLTE ¶
func ExternalControlIDLTE(v string) predicate.FindingControlHistory
ExternalControlIDLTE applies the LTE predicate on the "external_control_id" field.
func ExternalControlIDNEQ ¶
func ExternalControlIDNEQ(v string) predicate.FindingControlHistory
ExternalControlIDNEQ applies the NEQ predicate on the "external_control_id" field.
func ExternalControlIDNotIn ¶
func ExternalControlIDNotIn(vs ...string) predicate.FindingControlHistory
ExternalControlIDNotIn applies the NotIn predicate on the "external_control_id" field.
func ExternalControlIDNotNil ¶
func ExternalControlIDNotNil() predicate.FindingControlHistory
ExternalControlIDNotNil applies the NotNil predicate on the "external_control_id" field.
func ExternalStandard ¶
func ExternalStandard(v string) predicate.FindingControlHistory
ExternalStandard applies equality check predicate on the "external_standard" field. It's identical to ExternalStandardEQ.
func ExternalStandardContains ¶
func ExternalStandardContains(v string) predicate.FindingControlHistory
ExternalStandardContains applies the Contains predicate on the "external_standard" field.
func ExternalStandardContainsFold ¶
func ExternalStandardContainsFold(v string) predicate.FindingControlHistory
ExternalStandardContainsFold applies the ContainsFold predicate on the "external_standard" field.
func ExternalStandardEQ ¶
func ExternalStandardEQ(v string) predicate.FindingControlHistory
ExternalStandardEQ applies the EQ predicate on the "external_standard" field.
func ExternalStandardEqualFold ¶
func ExternalStandardEqualFold(v string) predicate.FindingControlHistory
ExternalStandardEqualFold applies the EqualFold predicate on the "external_standard" field.
func ExternalStandardGT ¶
func ExternalStandardGT(v string) predicate.FindingControlHistory
ExternalStandardGT applies the GT predicate on the "external_standard" field.
func ExternalStandardGTE ¶
func ExternalStandardGTE(v string) predicate.FindingControlHistory
ExternalStandardGTE applies the GTE predicate on the "external_standard" field.
func ExternalStandardHasPrefix ¶
func ExternalStandardHasPrefix(v string) predicate.FindingControlHistory
ExternalStandardHasPrefix applies the HasPrefix predicate on the "external_standard" field.
func ExternalStandardHasSuffix ¶
func ExternalStandardHasSuffix(v string) predicate.FindingControlHistory
ExternalStandardHasSuffix applies the HasSuffix predicate on the "external_standard" field.
func ExternalStandardIn ¶
func ExternalStandardIn(vs ...string) predicate.FindingControlHistory
ExternalStandardIn applies the In predicate on the "external_standard" field.
func ExternalStandardIsNil ¶
func ExternalStandardIsNil() predicate.FindingControlHistory
ExternalStandardIsNil applies the IsNil predicate on the "external_standard" field.
func ExternalStandardLT ¶
func ExternalStandardLT(v string) predicate.FindingControlHistory
ExternalStandardLT applies the LT predicate on the "external_standard" field.
func ExternalStandardLTE ¶
func ExternalStandardLTE(v string) predicate.FindingControlHistory
ExternalStandardLTE applies the LTE predicate on the "external_standard" field.
func ExternalStandardNEQ ¶
func ExternalStandardNEQ(v string) predicate.FindingControlHistory
ExternalStandardNEQ applies the NEQ predicate on the "external_standard" field.
func ExternalStandardNotIn ¶
func ExternalStandardNotIn(vs ...string) predicate.FindingControlHistory
ExternalStandardNotIn applies the NotIn predicate on the "external_standard" field.
func ExternalStandardNotNil ¶
func ExternalStandardNotNil() predicate.FindingControlHistory
ExternalStandardNotNil applies the NotNil predicate on the "external_standard" field.
func ExternalStandardVersion ¶
func ExternalStandardVersion(v string) predicate.FindingControlHistory
ExternalStandardVersion applies equality check predicate on the "external_standard_version" field. It's identical to ExternalStandardVersionEQ.
func ExternalStandardVersionContains ¶
func ExternalStandardVersionContains(v string) predicate.FindingControlHistory
ExternalStandardVersionContains applies the Contains predicate on the "external_standard_version" field.
func ExternalStandardVersionContainsFold ¶
func ExternalStandardVersionContainsFold(v string) predicate.FindingControlHistory
ExternalStandardVersionContainsFold applies the ContainsFold predicate on the "external_standard_version" field.
func ExternalStandardVersionEQ ¶
func ExternalStandardVersionEQ(v string) predicate.FindingControlHistory
ExternalStandardVersionEQ applies the EQ predicate on the "external_standard_version" field.
func ExternalStandardVersionEqualFold ¶
func ExternalStandardVersionEqualFold(v string) predicate.FindingControlHistory
ExternalStandardVersionEqualFold applies the EqualFold predicate on the "external_standard_version" field.
func ExternalStandardVersionGT ¶
func ExternalStandardVersionGT(v string) predicate.FindingControlHistory
ExternalStandardVersionGT applies the GT predicate on the "external_standard_version" field.
func ExternalStandardVersionGTE ¶
func ExternalStandardVersionGTE(v string) predicate.FindingControlHistory
ExternalStandardVersionGTE applies the GTE predicate on the "external_standard_version" field.
func ExternalStandardVersionHasPrefix ¶
func ExternalStandardVersionHasPrefix(v string) predicate.FindingControlHistory
ExternalStandardVersionHasPrefix applies the HasPrefix predicate on the "external_standard_version" field.
func ExternalStandardVersionHasSuffix ¶
func ExternalStandardVersionHasSuffix(v string) predicate.FindingControlHistory
ExternalStandardVersionHasSuffix applies the HasSuffix predicate on the "external_standard_version" field.
func ExternalStandardVersionIn ¶
func ExternalStandardVersionIn(vs ...string) predicate.FindingControlHistory
ExternalStandardVersionIn applies the In predicate on the "external_standard_version" field.
func ExternalStandardVersionIsNil ¶
func ExternalStandardVersionIsNil() predicate.FindingControlHistory
ExternalStandardVersionIsNil applies the IsNil predicate on the "external_standard_version" field.
func ExternalStandardVersionLT ¶
func ExternalStandardVersionLT(v string) predicate.FindingControlHistory
ExternalStandardVersionLT applies the LT predicate on the "external_standard_version" field.
func ExternalStandardVersionLTE ¶
func ExternalStandardVersionLTE(v string) predicate.FindingControlHistory
ExternalStandardVersionLTE applies the LTE predicate on the "external_standard_version" field.
func ExternalStandardVersionNEQ ¶
func ExternalStandardVersionNEQ(v string) predicate.FindingControlHistory
ExternalStandardVersionNEQ applies the NEQ predicate on the "external_standard_version" field.
func ExternalStandardVersionNotIn ¶
func ExternalStandardVersionNotIn(vs ...string) predicate.FindingControlHistory
ExternalStandardVersionNotIn applies the NotIn predicate on the "external_standard_version" field.
func ExternalStandardVersionNotNil ¶
func ExternalStandardVersionNotNil() predicate.FindingControlHistory
ExternalStandardVersionNotNil applies the NotNil predicate on the "external_standard_version" field.
func FindingID ¶
func FindingID(v string) predicate.FindingControlHistory
FindingID applies equality check predicate on the "finding_id" field. It's identical to FindingIDEQ.
func FindingIDContains ¶
func FindingIDContains(v string) predicate.FindingControlHistory
FindingIDContains applies the Contains predicate on the "finding_id" field.
func FindingIDContainsFold ¶
func FindingIDContainsFold(v string) predicate.FindingControlHistory
FindingIDContainsFold applies the ContainsFold predicate on the "finding_id" field.
func FindingIDEQ ¶
func FindingIDEQ(v string) predicate.FindingControlHistory
FindingIDEQ applies the EQ predicate on the "finding_id" field.
func FindingIDEqualFold ¶
func FindingIDEqualFold(v string) predicate.FindingControlHistory
FindingIDEqualFold applies the EqualFold predicate on the "finding_id" field.
func FindingIDGT ¶
func FindingIDGT(v string) predicate.FindingControlHistory
FindingIDGT applies the GT predicate on the "finding_id" field.
func FindingIDGTE ¶
func FindingIDGTE(v string) predicate.FindingControlHistory
FindingIDGTE applies the GTE predicate on the "finding_id" field.
func FindingIDHasPrefix ¶
func FindingIDHasPrefix(v string) predicate.FindingControlHistory
FindingIDHasPrefix applies the HasPrefix predicate on the "finding_id" field.
func FindingIDHasSuffix ¶
func FindingIDHasSuffix(v string) predicate.FindingControlHistory
FindingIDHasSuffix applies the HasSuffix predicate on the "finding_id" field.
func FindingIDIn ¶
func FindingIDIn(vs ...string) predicate.FindingControlHistory
FindingIDIn applies the In predicate on the "finding_id" field.
func FindingIDLT ¶
func FindingIDLT(v string) predicate.FindingControlHistory
FindingIDLT applies the LT predicate on the "finding_id" field.
func FindingIDLTE ¶
func FindingIDLTE(v string) predicate.FindingControlHistory
FindingIDLTE applies the LTE predicate on the "finding_id" field.
func FindingIDNEQ ¶
func FindingIDNEQ(v string) predicate.FindingControlHistory
FindingIDNEQ applies the NEQ predicate on the "finding_id" field.
func FindingIDNotIn ¶
func FindingIDNotIn(vs ...string) predicate.FindingControlHistory
FindingIDNotIn applies the NotIn predicate on the "finding_id" field.
func HistoryTime ¶
func HistoryTime(v time.Time) predicate.FindingControlHistory
HistoryTime applies equality check predicate on the "history_time" field. It's identical to HistoryTimeEQ.
func HistoryTimeEQ ¶
func HistoryTimeEQ(v time.Time) predicate.FindingControlHistory
HistoryTimeEQ applies the EQ predicate on the "history_time" field.
func HistoryTimeGT ¶
func HistoryTimeGT(v time.Time) predicate.FindingControlHistory
HistoryTimeGT applies the GT predicate on the "history_time" field.
func HistoryTimeGTE ¶
func HistoryTimeGTE(v time.Time) predicate.FindingControlHistory
HistoryTimeGTE applies the GTE predicate on the "history_time" field.
func HistoryTimeIn ¶
func HistoryTimeIn(vs ...time.Time) predicate.FindingControlHistory
HistoryTimeIn applies the In predicate on the "history_time" field.
func HistoryTimeLT ¶
func HistoryTimeLT(v time.Time) predicate.FindingControlHistory
HistoryTimeLT applies the LT predicate on the "history_time" field.
func HistoryTimeLTE ¶
func HistoryTimeLTE(v time.Time) predicate.FindingControlHistory
HistoryTimeLTE applies the LTE predicate on the "history_time" field.
func HistoryTimeNEQ ¶
func HistoryTimeNEQ(v time.Time) predicate.FindingControlHistory
HistoryTimeNEQ applies the NEQ predicate on the "history_time" field.
func HistoryTimeNotIn ¶
func HistoryTimeNotIn(vs ...time.Time) predicate.FindingControlHistory
HistoryTimeNotIn applies the NotIn predicate on the "history_time" field.
func ID ¶
func ID(id string) predicate.FindingControlHistory
ID filters vertices based on their ID field.
func IDContainsFold ¶
func IDContainsFold(id string) predicate.FindingControlHistory
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEQ ¶
func IDEQ(id string) predicate.FindingControlHistory
IDEQ applies the EQ predicate on the ID field.
func IDEqualFold ¶
func IDEqualFold(id string) predicate.FindingControlHistory
IDEqualFold applies the EqualFold predicate on the ID field.
func IDGT ¶
func IDGT(id string) predicate.FindingControlHistory
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id string) predicate.FindingControlHistory
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...string) predicate.FindingControlHistory
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id string) predicate.FindingControlHistory
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id string) predicate.FindingControlHistory
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id string) predicate.FindingControlHistory
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...string) predicate.FindingControlHistory
IDNotIn applies the NotIn predicate on the ID field.
func MetadataIsNil ¶
func MetadataIsNil() predicate.FindingControlHistory
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
func MetadataNotNil() predicate.FindingControlHistory
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func Not ¶
func Not(p predicate.FindingControlHistory) predicate.FindingControlHistory
Not applies the not operator on the given predicate.
func OperationEQ ¶
func OperationEQ(v history.OpType) predicate.FindingControlHistory
OperationEQ applies the EQ predicate on the "operation" field.
func OperationIn ¶
func OperationIn(vs ...history.OpType) predicate.FindingControlHistory
OperationIn applies the In predicate on the "operation" field.
func OperationNEQ ¶
func OperationNEQ(v history.OpType) predicate.FindingControlHistory
OperationNEQ applies the NEQ predicate on the "operation" field.
func OperationNotIn ¶
func OperationNotIn(vs ...history.OpType) predicate.FindingControlHistory
OperationNotIn applies the NotIn predicate on the "operation" field.
func OperationValidator ¶
OperationValidator is a validator for the "operation" field enum values. It is called by the builders before save.
func Or ¶
func Or(predicates ...predicate.FindingControlHistory) predicate.FindingControlHistory
Or groups predicates with the OR operator between them.
func Ref ¶
func Ref(v string) predicate.FindingControlHistory
Ref applies equality check predicate on the "ref" field. It's identical to RefEQ.
func RefContains ¶
func RefContains(v string) predicate.FindingControlHistory
RefContains applies the Contains predicate on the "ref" field.
func RefContainsFold ¶
func RefContainsFold(v string) predicate.FindingControlHistory
RefContainsFold applies the ContainsFold predicate on the "ref" field.
func RefEQ ¶
func RefEQ(v string) predicate.FindingControlHistory
RefEQ applies the EQ predicate on the "ref" field.
func RefEqualFold ¶
func RefEqualFold(v string) predicate.FindingControlHistory
RefEqualFold applies the EqualFold predicate on the "ref" field.
func RefGT ¶
func RefGT(v string) predicate.FindingControlHistory
RefGT applies the GT predicate on the "ref" field.
func RefGTE ¶
func RefGTE(v string) predicate.FindingControlHistory
RefGTE applies the GTE predicate on the "ref" field.
func RefHasPrefix ¶
func RefHasPrefix(v string) predicate.FindingControlHistory
RefHasPrefix applies the HasPrefix predicate on the "ref" field.
func RefHasSuffix ¶
func RefHasSuffix(v string) predicate.FindingControlHistory
RefHasSuffix applies the HasSuffix predicate on the "ref" field.
func RefIn ¶
func RefIn(vs ...string) predicate.FindingControlHistory
RefIn applies the In predicate on the "ref" field.
func RefIsNil ¶
func RefIsNil() predicate.FindingControlHistory
RefIsNil applies the IsNil predicate on the "ref" field.
func RefLT ¶
func RefLT(v string) predicate.FindingControlHistory
RefLT applies the LT predicate on the "ref" field.
func RefLTE ¶
func RefLTE(v string) predicate.FindingControlHistory
RefLTE applies the LTE predicate on the "ref" field.
func RefNEQ ¶
func RefNEQ(v string) predicate.FindingControlHistory
RefNEQ applies the NEQ predicate on the "ref" field.
func RefNotIn ¶
func RefNotIn(vs ...string) predicate.FindingControlHistory
RefNotIn applies the NotIn predicate on the "ref" field.
func RefNotNil ¶
func RefNotNil() predicate.FindingControlHistory
RefNotNil applies the NotNil predicate on the "ref" field.
func Source ¶
func Source(v string) predicate.FindingControlHistory
Source applies equality check predicate on the "source" field. It's identical to SourceEQ.
func SourceContains ¶
func SourceContains(v string) predicate.FindingControlHistory
SourceContains applies the Contains predicate on the "source" field.
func SourceContainsFold ¶
func SourceContainsFold(v string) predicate.FindingControlHistory
SourceContainsFold applies the ContainsFold predicate on the "source" field.
func SourceEQ ¶
func SourceEQ(v string) predicate.FindingControlHistory
SourceEQ applies the EQ predicate on the "source" field.
func SourceEqualFold ¶
func SourceEqualFold(v string) predicate.FindingControlHistory
SourceEqualFold applies the EqualFold predicate on the "source" field.
func SourceGT ¶
func SourceGT(v string) predicate.FindingControlHistory
SourceGT applies the GT predicate on the "source" field.
func SourceGTE ¶
func SourceGTE(v string) predicate.FindingControlHistory
SourceGTE applies the GTE predicate on the "source" field.
func SourceHasPrefix ¶
func SourceHasPrefix(v string) predicate.FindingControlHistory
SourceHasPrefix applies the HasPrefix predicate on the "source" field.
func SourceHasSuffix ¶
func SourceHasSuffix(v string) predicate.FindingControlHistory
SourceHasSuffix applies the HasSuffix predicate on the "source" field.
func SourceIn ¶
func SourceIn(vs ...string) predicate.FindingControlHistory
SourceIn applies the In predicate on the "source" field.
func SourceIsNil ¶
func SourceIsNil() predicate.FindingControlHistory
SourceIsNil applies the IsNil predicate on the "source" field.
func SourceLT ¶
func SourceLT(v string) predicate.FindingControlHistory
SourceLT applies the LT predicate on the "source" field.
func SourceLTE ¶
func SourceLTE(v string) predicate.FindingControlHistory
SourceLTE applies the LTE predicate on the "source" field.
func SourceNEQ ¶
func SourceNEQ(v string) predicate.FindingControlHistory
SourceNEQ applies the NEQ predicate on the "source" field.
func SourceNotIn ¶
func SourceNotIn(vs ...string) predicate.FindingControlHistory
SourceNotIn applies the NotIn predicate on the "source" field.
func SourceNotNil ¶
func SourceNotNil() predicate.FindingControlHistory
SourceNotNil applies the NotNil predicate on the "source" field.
func StandardID ¶
func StandardID(v string) predicate.FindingControlHistory
StandardID applies equality check predicate on the "standard_id" field. It's identical to StandardIDEQ.
func StandardIDContains ¶
func StandardIDContains(v string) predicate.FindingControlHistory
StandardIDContains applies the Contains predicate on the "standard_id" field.
func StandardIDContainsFold ¶
func StandardIDContainsFold(v string) predicate.FindingControlHistory
StandardIDContainsFold applies the ContainsFold predicate on the "standard_id" field.
func StandardIDEQ ¶
func StandardIDEQ(v string) predicate.FindingControlHistory
StandardIDEQ applies the EQ predicate on the "standard_id" field.
func StandardIDEqualFold ¶
func StandardIDEqualFold(v string) predicate.FindingControlHistory
StandardIDEqualFold applies the EqualFold predicate on the "standard_id" field.
func StandardIDGT ¶
func StandardIDGT(v string) predicate.FindingControlHistory
StandardIDGT applies the GT predicate on the "standard_id" field.
func StandardIDGTE ¶
func StandardIDGTE(v string) predicate.FindingControlHistory
StandardIDGTE applies the GTE predicate on the "standard_id" field.
func StandardIDHasPrefix ¶
func StandardIDHasPrefix(v string) predicate.FindingControlHistory
StandardIDHasPrefix applies the HasPrefix predicate on the "standard_id" field.
func StandardIDHasSuffix ¶
func StandardIDHasSuffix(v string) predicate.FindingControlHistory
StandardIDHasSuffix applies the HasSuffix predicate on the "standard_id" field.
func StandardIDIn ¶
func StandardIDIn(vs ...string) predicate.FindingControlHistory
StandardIDIn applies the In predicate on the "standard_id" field.
func StandardIDIsNil ¶
func StandardIDIsNil() predicate.FindingControlHistory
StandardIDIsNil applies the IsNil predicate on the "standard_id" field.
func StandardIDLT ¶
func StandardIDLT(v string) predicate.FindingControlHistory
StandardIDLT applies the LT predicate on the "standard_id" field.
func StandardIDLTE ¶
func StandardIDLTE(v string) predicate.FindingControlHistory
StandardIDLTE applies the LTE predicate on the "standard_id" field.
func StandardIDNEQ ¶
func StandardIDNEQ(v string) predicate.FindingControlHistory
StandardIDNEQ applies the NEQ predicate on the "standard_id" field.
func StandardIDNotIn ¶
func StandardIDNotIn(vs ...string) predicate.FindingControlHistory
StandardIDNotIn applies the NotIn predicate on the "standard_id" field.
func StandardIDNotNil ¶
func StandardIDNotNil() predicate.FindingControlHistory
StandardIDNotNil applies the NotNil predicate on the "standard_id" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.FindingControlHistory
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.FindingControlHistory
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.FindingControlHistory
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.FindingControlHistory
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.FindingControlHistory
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.FindingControlHistory
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.FindingControlHistory
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.FindingControlHistory
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.FindingControlHistory
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.FindingControlHistory
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.FindingControlHistory
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
func UpdatedBy(v string) predicate.FindingControlHistory
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
func UpdatedByContains(v string) predicate.FindingControlHistory
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
func UpdatedByContainsFold(v string) predicate.FindingControlHistory
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
func UpdatedByEQ(v string) predicate.FindingControlHistory
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
func UpdatedByEqualFold(v string) predicate.FindingControlHistory
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
func UpdatedByGT(v string) predicate.FindingControlHistory
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
func UpdatedByGTE(v string) predicate.FindingControlHistory
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
func UpdatedByHasPrefix(v string) predicate.FindingControlHistory
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
func UpdatedByHasSuffix(v string) predicate.FindingControlHistory
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
func UpdatedByIn(vs ...string) predicate.FindingControlHistory
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
func UpdatedByIsNil() predicate.FindingControlHistory
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
func UpdatedByLT(v string) predicate.FindingControlHistory
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
func UpdatedByLTE(v string) predicate.FindingControlHistory
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
func UpdatedByNEQ(v string) predicate.FindingControlHistory
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
func UpdatedByNotIn(vs ...string) predicate.FindingControlHistory
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
func UpdatedByNotNil() predicate.FindingControlHistory
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the FindingControlHistory queries.
func ByControlID ¶
func ByControlID(opts ...sql.OrderTermOption) OrderOption
ByControlID orders the results by the control_id field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDiscoveredAt ¶
func ByDiscoveredAt(opts ...sql.OrderTermOption) OrderOption
ByDiscoveredAt orders the results by the discovered_at field.
func ByExternalControlID ¶
func ByExternalControlID(opts ...sql.OrderTermOption) OrderOption
ByExternalControlID orders the results by the external_control_id field.
func ByExternalStandard ¶
func ByExternalStandard(opts ...sql.OrderTermOption) OrderOption
ByExternalStandard orders the results by the external_standard field.
func ByExternalStandardVersion ¶
func ByExternalStandardVersion(opts ...sql.OrderTermOption) OrderOption
ByExternalStandardVersion orders the results by the external_standard_version field.
func ByFindingID ¶
func ByFindingID(opts ...sql.OrderTermOption) OrderOption
ByFindingID orders the results by the finding_id field.
func ByHistoryTime ¶
func ByHistoryTime(opts ...sql.OrderTermOption) OrderOption
ByHistoryTime orders the results by the history_time field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByOperation ¶
func ByOperation(opts ...sql.OrderTermOption) OrderOption
ByOperation orders the results by the operation field.
func ByRef ¶
func ByRef(opts ...sql.OrderTermOption) OrderOption
ByRef orders the results by the ref field.
func BySource ¶
func BySource(opts ...sql.OrderTermOption) OrderOption
BySource orders the results by the source field.
func ByStandardID ¶
func ByStandardID(opts ...sql.OrderTermOption) OrderOption
ByStandardID orders the results by the standard_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.