Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.JobResult) predicate.JobResult
- func CreatedAt(v time.Time) predicate.JobResult
- func CreatedAtEQ(v time.Time) predicate.JobResult
- func CreatedAtGT(v time.Time) predicate.JobResult
- func CreatedAtGTE(v time.Time) predicate.JobResult
- func CreatedAtIn(vs ...time.Time) predicate.JobResult
- func CreatedAtIsNil() predicate.JobResult
- func CreatedAtLT(v time.Time) predicate.JobResult
- func CreatedAtLTE(v time.Time) predicate.JobResult
- func CreatedAtNEQ(v time.Time) predicate.JobResult
- func CreatedAtNotIn(vs ...time.Time) predicate.JobResult
- func CreatedAtNotNil() predicate.JobResult
- func CreatedBy(v string) predicate.JobResult
- func CreatedByContains(v string) predicate.JobResult
- func CreatedByContainsFold(v string) predicate.JobResult
- func CreatedByEQ(v string) predicate.JobResult
- func CreatedByEqualFold(v string) predicate.JobResult
- func CreatedByGT(v string) predicate.JobResult
- func CreatedByGTE(v string) predicate.JobResult
- func CreatedByHasPrefix(v string) predicate.JobResult
- func CreatedByHasSuffix(v string) predicate.JobResult
- func CreatedByIn(vs ...string) predicate.JobResult
- func CreatedByIsNil() predicate.JobResult
- func CreatedByLT(v string) predicate.JobResult
- func CreatedByLTE(v string) predicate.JobResult
- func CreatedByNEQ(v string) predicate.JobResult
- func CreatedByNotIn(vs ...string) predicate.JobResult
- func CreatedByNotNil() predicate.JobResult
- func DeletedAt(v time.Time) predicate.JobResult
- func DeletedAtEQ(v time.Time) predicate.JobResult
- func DeletedAtGT(v time.Time) predicate.JobResult
- func DeletedAtGTE(v time.Time) predicate.JobResult
- func DeletedAtIn(vs ...time.Time) predicate.JobResult
- func DeletedAtIsNil() predicate.JobResult
- func DeletedAtLT(v time.Time) predicate.JobResult
- func DeletedAtLTE(v time.Time) predicate.JobResult
- func DeletedAtNEQ(v time.Time) predicate.JobResult
- func DeletedAtNotIn(vs ...time.Time) predicate.JobResult
- func DeletedAtNotNil() predicate.JobResult
- func DeletedBy(v string) predicate.JobResult
- func DeletedByContains(v string) predicate.JobResult
- func DeletedByContainsFold(v string) predicate.JobResult
- func DeletedByEQ(v string) predicate.JobResult
- func DeletedByEqualFold(v string) predicate.JobResult
- func DeletedByGT(v string) predicate.JobResult
- func DeletedByGTE(v string) predicate.JobResult
- func DeletedByHasPrefix(v string) predicate.JobResult
- func DeletedByHasSuffix(v string) predicate.JobResult
- func DeletedByIn(vs ...string) predicate.JobResult
- func DeletedByIsNil() predicate.JobResult
- func DeletedByLT(v string) predicate.JobResult
- func DeletedByLTE(v string) predicate.JobResult
- func DeletedByNEQ(v string) predicate.JobResult
- func DeletedByNotIn(vs ...string) predicate.JobResult
- func DeletedByNotNil() predicate.JobResult
- func ExitCode(v int) predicate.JobResult
- func ExitCodeEQ(v int) predicate.JobResult
- func ExitCodeGT(v int) predicate.JobResult
- func ExitCodeGTE(v int) predicate.JobResult
- func ExitCodeIn(vs ...int) predicate.JobResult
- func ExitCodeLT(v int) predicate.JobResult
- func ExitCodeLTE(v int) predicate.JobResult
- func ExitCodeNEQ(v int) predicate.JobResult
- func ExitCodeNotIn(vs ...int) predicate.JobResult
- func FileID(v string) predicate.JobResult
- func FileIDContains(v string) predicate.JobResult
- func FileIDContainsFold(v string) predicate.JobResult
- func FileIDEQ(v string) predicate.JobResult
- func FileIDEqualFold(v string) predicate.JobResult
- func FileIDGT(v string) predicate.JobResult
- func FileIDGTE(v string) predicate.JobResult
- func FileIDHasPrefix(v string) predicate.JobResult
- func FileIDHasSuffix(v string) predicate.JobResult
- func FileIDIn(vs ...string) predicate.JobResult
- func FileIDLT(v string) predicate.JobResult
- func FileIDLTE(v string) predicate.JobResult
- func FileIDNEQ(v string) predicate.JobResult
- func FileIDNotIn(vs ...string) predicate.JobResult
- func FinishedAt(v time.Time) predicate.JobResult
- func FinishedAtEQ(v time.Time) predicate.JobResult
- func FinishedAtGT(v time.Time) predicate.JobResult
- func FinishedAtGTE(v time.Time) predicate.JobResult
- func FinishedAtIn(vs ...time.Time) predicate.JobResult
- func FinishedAtLT(v time.Time) predicate.JobResult
- func FinishedAtLTE(v time.Time) predicate.JobResult
- func FinishedAtNEQ(v time.Time) predicate.JobResult
- func FinishedAtNotIn(vs ...time.Time) predicate.JobResult
- func HasFile() predicate.JobResult
- func HasFileWith(preds ...predicate.File) predicate.JobResult
- func HasOwner() predicate.JobResult
- func HasOwnerWith(preds ...predicate.Organization) predicate.JobResult
- func HasScheduledJob() predicate.JobResult
- func HasScheduledJobWith(preds ...predicate.ControlScheduledJob) predicate.JobResult
- func ID(id string) predicate.JobResult
- func IDContainsFold(id string) predicate.JobResult
- func IDEQ(id string) predicate.JobResult
- func IDEqualFold(id string) predicate.JobResult
- func IDGT(id string) predicate.JobResult
- func IDGTE(id string) predicate.JobResult
- func IDIn(ids ...string) predicate.JobResult
- func IDLT(id string) predicate.JobResult
- func IDLTE(id string) predicate.JobResult
- func IDNEQ(id string) predicate.JobResult
- func IDNotIn(ids ...string) predicate.JobResult
- func Not(p predicate.JobResult) predicate.JobResult
- func Or(predicates ...predicate.JobResult) predicate.JobResult
- func OwnerID(v string) predicate.JobResult
- func OwnerIDContains(v string) predicate.JobResult
- func OwnerIDContainsFold(v string) predicate.JobResult
- func OwnerIDEQ(v string) predicate.JobResult
- func OwnerIDEqualFold(v string) predicate.JobResult
- func OwnerIDGT(v string) predicate.JobResult
- func OwnerIDGTE(v string) predicate.JobResult
- func OwnerIDHasPrefix(v string) predicate.JobResult
- func OwnerIDHasSuffix(v string) predicate.JobResult
- func OwnerIDIn(vs ...string) predicate.JobResult
- func OwnerIDIsNil() predicate.JobResult
- func OwnerIDLT(v string) predicate.JobResult
- func OwnerIDLTE(v string) predicate.JobResult
- func OwnerIDNEQ(v string) predicate.JobResult
- func OwnerIDNotIn(vs ...string) predicate.JobResult
- func OwnerIDNotNil() predicate.JobResult
- func ScheduledJobID(v string) predicate.JobResult
- func ScheduledJobIDContains(v string) predicate.JobResult
- func ScheduledJobIDContainsFold(v string) predicate.JobResult
- func ScheduledJobIDEQ(v string) predicate.JobResult
- func ScheduledJobIDEqualFold(v string) predicate.JobResult
- func ScheduledJobIDGT(v string) predicate.JobResult
- func ScheduledJobIDGTE(v string) predicate.JobResult
- func ScheduledJobIDHasPrefix(v string) predicate.JobResult
- func ScheduledJobIDHasSuffix(v string) predicate.JobResult
- func ScheduledJobIDIn(vs ...string) predicate.JobResult
- func ScheduledJobIDLT(v string) predicate.JobResult
- func ScheduledJobIDLTE(v string) predicate.JobResult
- func ScheduledJobIDNEQ(v string) predicate.JobResult
- func ScheduledJobIDNotIn(vs ...string) predicate.JobResult
- func StartedAt(v time.Time) predicate.JobResult
- func StartedAtEQ(v time.Time) predicate.JobResult
- func StartedAtGT(v time.Time) predicate.JobResult
- func StartedAtGTE(v time.Time) predicate.JobResult
- func StartedAtIn(vs ...time.Time) predicate.JobResult
- func StartedAtLT(v time.Time) predicate.JobResult
- func StartedAtLTE(v time.Time) predicate.JobResult
- func StartedAtNEQ(v time.Time) predicate.JobResult
- func StartedAtNotIn(vs ...time.Time) predicate.JobResult
- func StatusEQ(v enums.JobExecutionStatus) predicate.JobResult
- func StatusIn(vs ...enums.JobExecutionStatus) predicate.JobResult
- func StatusNEQ(v enums.JobExecutionStatus) predicate.JobResult
- func StatusNotIn(vs ...enums.JobExecutionStatus) predicate.JobResult
- func StatusValidator(s enums.JobExecutionStatus) error
- func UpdatedAt(v time.Time) predicate.JobResult
- func UpdatedAtEQ(v time.Time) predicate.JobResult
- func UpdatedAtGT(v time.Time) predicate.JobResult
- func UpdatedAtGTE(v time.Time) predicate.JobResult
- func UpdatedAtIn(vs ...time.Time) predicate.JobResult
- func UpdatedAtIsNil() predicate.JobResult
- func UpdatedAtLT(v time.Time) predicate.JobResult
- func UpdatedAtLTE(v time.Time) predicate.JobResult
- func UpdatedAtNEQ(v time.Time) predicate.JobResult
- func UpdatedAtNotIn(vs ...time.Time) predicate.JobResult
- func UpdatedAtNotNil() predicate.JobResult
- func UpdatedBy(v string) predicate.JobResult
- func UpdatedByContains(v string) predicate.JobResult
- func UpdatedByContainsFold(v string) predicate.JobResult
- func UpdatedByEQ(v string) predicate.JobResult
- func UpdatedByEqualFold(v string) predicate.JobResult
- func UpdatedByGT(v string) predicate.JobResult
- func UpdatedByGTE(v string) predicate.JobResult
- func UpdatedByHasPrefix(v string) predicate.JobResult
- func UpdatedByHasSuffix(v string) predicate.JobResult
- func UpdatedByIn(vs ...string) predicate.JobResult
- func UpdatedByIsNil() predicate.JobResult
- func UpdatedByLT(v string) predicate.JobResult
- func UpdatedByLTE(v string) predicate.JobResult
- func UpdatedByNEQ(v string) predicate.JobResult
- func UpdatedByNotIn(vs ...string) predicate.JobResult
- func UpdatedByNotNil() predicate.JobResult
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByExitCode(opts ...sql.OrderTermOption) OrderOption
- func ByFileField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByFileID(opts ...sql.OrderTermOption) OrderOption
- func ByFinishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByScheduledJobField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByScheduledJobID(opts ...sql.OrderTermOption) OrderOption
- func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the jobresult type in the database. Label = "job_result" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldScheduledJobID holds the string denoting the scheduled_job_id field in the database. FieldScheduledJobID = "scheduled_job_id" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldExitCode holds the string denoting the exit_code field in the database. FieldExitCode = "exit_code" // FieldFinishedAt holds the string denoting the finished_at field in the database. FieldFinishedAt = "finished_at" // FieldStartedAt holds the string denoting the started_at field in the database. FieldStartedAt = "started_at" // FieldFileID holds the string denoting the file_id field in the database. FieldFileID = "file_id" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // EdgeScheduledJob holds the string denoting the scheduled_job edge name in mutations. EdgeScheduledJob = "scheduled_job" // EdgeFile holds the string denoting the file edge name in mutations. EdgeFile = "file" // Table holds the table name of the jobresult in the database. Table = "job_results" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "job_results" // OwnerInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OwnerInverseTable = "organizations" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "owner_id" // ScheduledJobTable is the table that holds the scheduled_job relation/edge. ScheduledJobTable = "job_results" // ScheduledJobInverseTable is the table name for the ControlScheduledJob entity. // It exists in this package in order to avoid circular dependency with the "controlscheduledjob" package. ScheduledJobInverseTable = "control_scheduled_jobs" // ScheduledJobColumn is the table column denoting the scheduled_job relation/edge. ScheduledJobColumn = "scheduled_job_id" // FileTable is the table that holds the file relation/edge. FileTable = "job_results" // FileInverseTable is the table name for the File entity. // It exists in this package in order to avoid circular dependency with the "file" package. FileInverseTable = "files" // FileColumn is the table column denoting the file relation/edge. FileColumn = "file_id" )
Variables ¶
var ( Hooks [4]ent.Hook Interceptors [2]ent.Interceptor Policy ent.Policy // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save. OwnerIDValidator func(string) error // ExitCodeValidator is a validator for the "exit_code" field. It is called by the builders before save. ExitCodeValidator func(int) error // DefaultFinishedAt holds the default value on creation for the "finished_at" field. DefaultFinishedAt func() time.Time // DefaultStartedAt holds the default value on creation for the "started_at" field. DefaultStartedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldOwnerID, FieldScheduledJobID, FieldStatus, FieldExitCode, FieldFinishedAt, FieldStartedAt, FieldFileID, }
Columns holds all SQL columns for jobresult fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func ExitCode ¶
ExitCode applies equality check predicate on the "exit_code" field. It's identical to ExitCodeEQ.
func ExitCodeEQ ¶
ExitCodeEQ applies the EQ predicate on the "exit_code" field.
func ExitCodeGT ¶
ExitCodeGT applies the GT predicate on the "exit_code" field.
func ExitCodeGTE ¶
ExitCodeGTE applies the GTE predicate on the "exit_code" field.
func ExitCodeIn ¶
ExitCodeIn applies the In predicate on the "exit_code" field.
func ExitCodeLT ¶
ExitCodeLT applies the LT predicate on the "exit_code" field.
func ExitCodeLTE ¶
ExitCodeLTE applies the LTE predicate on the "exit_code" field.
func ExitCodeNEQ ¶
ExitCodeNEQ applies the NEQ predicate on the "exit_code" field.
func ExitCodeNotIn ¶
ExitCodeNotIn applies the NotIn predicate on the "exit_code" field.
func FileID ¶
FileID applies equality check predicate on the "file_id" field. It's identical to FileIDEQ.
func FileIDContains ¶
FileIDContains applies the Contains predicate on the "file_id" field.
func FileIDContainsFold ¶
FileIDContainsFold applies the ContainsFold predicate on the "file_id" field.
func FileIDEqualFold ¶
FileIDEqualFold applies the EqualFold predicate on the "file_id" field.
func FileIDHasPrefix ¶
FileIDHasPrefix applies the HasPrefix predicate on the "file_id" field.
func FileIDHasSuffix ¶
FileIDHasSuffix applies the HasSuffix predicate on the "file_id" field.
func FileIDNotIn ¶
FileIDNotIn applies the NotIn predicate on the "file_id" field.
func FinishedAt ¶
FinishedAt applies equality check predicate on the "finished_at" field. It's identical to FinishedAtEQ.
func FinishedAtEQ ¶
FinishedAtEQ applies the EQ predicate on the "finished_at" field.
func FinishedAtGT ¶
FinishedAtGT applies the GT predicate on the "finished_at" field.
func FinishedAtGTE ¶
FinishedAtGTE applies the GTE predicate on the "finished_at" field.
func FinishedAtIn ¶
FinishedAtIn applies the In predicate on the "finished_at" field.
func FinishedAtLT ¶
FinishedAtLT applies the LT predicate on the "finished_at" field.
func FinishedAtLTE ¶
FinishedAtLTE applies the LTE predicate on the "finished_at" field.
func FinishedAtNEQ ¶
FinishedAtNEQ applies the NEQ predicate on the "finished_at" field.
func FinishedAtNotIn ¶
FinishedAtNotIn applies the NotIn predicate on the "finished_at" field.
func HasFileWith ¶
HasFileWith applies the HasEdge predicate on the "file" edge with a given conditions (other predicates).
func HasOwnerWith ¶
func HasOwnerWith(preds ...predicate.Organization) predicate.JobResult
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func HasScheduledJob ¶
HasScheduledJob applies the HasEdge predicate on the "scheduled_job" edge.
func HasScheduledJobWith ¶
func HasScheduledJobWith(preds ...predicate.ControlScheduledJob) predicate.JobResult
HasScheduledJobWith applies the HasEdge predicate on the "scheduled_job" edge with a given conditions (other predicates).
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func OwnerID ¶
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDContains ¶
OwnerIDContains applies the Contains predicate on the "owner_id" field.
func OwnerIDContainsFold ¶
OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.
func OwnerIDEqualFold ¶
OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.
func OwnerIDGTE ¶
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDHasPrefix ¶
OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.
func OwnerIDHasSuffix ¶
OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.
func OwnerIDIsNil ¶
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLTE ¶
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func ScheduledJobID ¶
ScheduledJobID applies equality check predicate on the "scheduled_job_id" field. It's identical to ScheduledJobIDEQ.
func ScheduledJobIDContains ¶
ScheduledJobIDContains applies the Contains predicate on the "scheduled_job_id" field.
func ScheduledJobIDContainsFold ¶
ScheduledJobIDContainsFold applies the ContainsFold predicate on the "scheduled_job_id" field.
func ScheduledJobIDEQ ¶
ScheduledJobIDEQ applies the EQ predicate on the "scheduled_job_id" field.
func ScheduledJobIDEqualFold ¶
ScheduledJobIDEqualFold applies the EqualFold predicate on the "scheduled_job_id" field.
func ScheduledJobIDGT ¶
ScheduledJobIDGT applies the GT predicate on the "scheduled_job_id" field.
func ScheduledJobIDGTE ¶
ScheduledJobIDGTE applies the GTE predicate on the "scheduled_job_id" field.
func ScheduledJobIDHasPrefix ¶
ScheduledJobIDHasPrefix applies the HasPrefix predicate on the "scheduled_job_id" field.
func ScheduledJobIDHasSuffix ¶
ScheduledJobIDHasSuffix applies the HasSuffix predicate on the "scheduled_job_id" field.
func ScheduledJobIDIn ¶
ScheduledJobIDIn applies the In predicate on the "scheduled_job_id" field.
func ScheduledJobIDLT ¶
ScheduledJobIDLT applies the LT predicate on the "scheduled_job_id" field.
func ScheduledJobIDLTE ¶
ScheduledJobIDLTE applies the LTE predicate on the "scheduled_job_id" field.
func ScheduledJobIDNEQ ¶
ScheduledJobIDNEQ applies the NEQ predicate on the "scheduled_job_id" field.
func ScheduledJobIDNotIn ¶
ScheduledJobIDNotIn applies the NotIn predicate on the "scheduled_job_id" field.
func StartedAt ¶
StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.
func StartedAtEQ ¶
StartedAtEQ applies the EQ predicate on the "started_at" field.
func StartedAtGT ¶
StartedAtGT applies the GT predicate on the "started_at" field.
func StartedAtGTE ¶
StartedAtGTE applies the GTE predicate on the "started_at" field.
func StartedAtIn ¶
StartedAtIn applies the In predicate on the "started_at" field.
func StartedAtLT ¶
StartedAtLT applies the LT predicate on the "started_at" field.
func StartedAtLTE ¶
StartedAtLTE applies the LTE predicate on the "started_at" field.
func StartedAtNEQ ¶
StartedAtNEQ applies the NEQ predicate on the "started_at" field.
func StartedAtNotIn ¶
StartedAtNotIn applies the NotIn predicate on the "started_at" field.
func StatusEQ ¶
func StatusEQ(v enums.JobExecutionStatus) predicate.JobResult
StatusEQ applies the EQ predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...enums.JobExecutionStatus) predicate.JobResult
StatusIn applies the In predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v enums.JobExecutionStatus) predicate.JobResult
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...enums.JobExecutionStatus) predicate.JobResult
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
func StatusValidator(s enums.JobExecutionStatus) error
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the JobResult queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByExitCode ¶
func ByExitCode(opts ...sql.OrderTermOption) OrderOption
ByExitCode orders the results by the exit_code field.
func ByFileField ¶
func ByFileField(field string, opts ...sql.OrderTermOption) OrderOption
ByFileField orders the results by file field.
func ByFileID ¶
func ByFileID(opts ...sql.OrderTermOption) OrderOption
ByFileID orders the results by the file_id field.
func ByFinishedAt ¶
func ByFinishedAt(opts ...sql.OrderTermOption) OrderOption
ByFinishedAt orders the results by the finished_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByOwnerField ¶
func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
ByOwnerField orders the results by owner field.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByScheduledJobField ¶
func ByScheduledJobField(field string, opts ...sql.OrderTermOption) OrderOption
ByScheduledJobField orders the results by scheduled_job field.
func ByScheduledJobID ¶
func ByScheduledJobID(opts ...sql.OrderTermOption) OrderOption
ByScheduledJobID orders the results by the scheduled_job_id field.
func ByStartedAt ¶
func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
ByStartedAt orders the results by the started_at field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.