Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.MappableDomain) predicate.MappableDomain
- func CreatedAt(v time.Time) predicate.MappableDomain
- func CreatedAtEQ(v time.Time) predicate.MappableDomain
- func CreatedAtGT(v time.Time) predicate.MappableDomain
- func CreatedAtGTE(v time.Time) predicate.MappableDomain
- func CreatedAtIn(vs ...time.Time) predicate.MappableDomain
- func CreatedAtIsNil() predicate.MappableDomain
- func CreatedAtLT(v time.Time) predicate.MappableDomain
- func CreatedAtLTE(v time.Time) predicate.MappableDomain
- func CreatedAtNEQ(v time.Time) predicate.MappableDomain
- func CreatedAtNotIn(vs ...time.Time) predicate.MappableDomain
- func CreatedAtNotNil() predicate.MappableDomain
- func CreatedBy(v string) predicate.MappableDomain
- func CreatedByContains(v string) predicate.MappableDomain
- func CreatedByContainsFold(v string) predicate.MappableDomain
- func CreatedByEQ(v string) predicate.MappableDomain
- func CreatedByEqualFold(v string) predicate.MappableDomain
- func CreatedByGT(v string) predicate.MappableDomain
- func CreatedByGTE(v string) predicate.MappableDomain
- func CreatedByHasPrefix(v string) predicate.MappableDomain
- func CreatedByHasSuffix(v string) predicate.MappableDomain
- func CreatedByIn(vs ...string) predicate.MappableDomain
- func CreatedByIsNil() predicate.MappableDomain
- func CreatedByLT(v string) predicate.MappableDomain
- func CreatedByLTE(v string) predicate.MappableDomain
- func CreatedByNEQ(v string) predicate.MappableDomain
- func CreatedByNotIn(vs ...string) predicate.MappableDomain
- func CreatedByNotNil() predicate.MappableDomain
- func DeletedAt(v time.Time) predicate.MappableDomain
- func DeletedAtEQ(v time.Time) predicate.MappableDomain
- func DeletedAtGT(v time.Time) predicate.MappableDomain
- func DeletedAtGTE(v time.Time) predicate.MappableDomain
- func DeletedAtIn(vs ...time.Time) predicate.MappableDomain
- func DeletedAtIsNil() predicate.MappableDomain
- func DeletedAtLT(v time.Time) predicate.MappableDomain
- func DeletedAtLTE(v time.Time) predicate.MappableDomain
- func DeletedAtNEQ(v time.Time) predicate.MappableDomain
- func DeletedAtNotIn(vs ...time.Time) predicate.MappableDomain
- func DeletedAtNotNil() predicate.MappableDomain
- func DeletedBy(v string) predicate.MappableDomain
- func DeletedByContains(v string) predicate.MappableDomain
- func DeletedByContainsFold(v string) predicate.MappableDomain
- func DeletedByEQ(v string) predicate.MappableDomain
- func DeletedByEqualFold(v string) predicate.MappableDomain
- func DeletedByGT(v string) predicate.MappableDomain
- func DeletedByGTE(v string) predicate.MappableDomain
- func DeletedByHasPrefix(v string) predicate.MappableDomain
- func DeletedByHasSuffix(v string) predicate.MappableDomain
- func DeletedByIn(vs ...string) predicate.MappableDomain
- func DeletedByIsNil() predicate.MappableDomain
- func DeletedByLT(v string) predicate.MappableDomain
- func DeletedByLTE(v string) predicate.MappableDomain
- func DeletedByNEQ(v string) predicate.MappableDomain
- func DeletedByNotIn(vs ...string) predicate.MappableDomain
- func DeletedByNotNil() predicate.MappableDomain
- func HasCustomDomains() predicate.MappableDomain
- func HasCustomDomainsWith(preds ...predicate.CustomDomain) predicate.MappableDomain
- func ID(id string) predicate.MappableDomain
- func IDContainsFold(id string) predicate.MappableDomain
- func IDEQ(id string) predicate.MappableDomain
- func IDEqualFold(id string) predicate.MappableDomain
- func IDGT(id string) predicate.MappableDomain
- func IDGTE(id string) predicate.MappableDomain
- func IDIn(ids ...string) predicate.MappableDomain
- func IDLT(id string) predicate.MappableDomain
- func IDLTE(id string) predicate.MappableDomain
- func IDNEQ(id string) predicate.MappableDomain
- func IDNotIn(ids ...string) predicate.MappableDomain
- func Name(v string) predicate.MappableDomain
- func NameContains(v string) predicate.MappableDomain
- func NameContainsFold(v string) predicate.MappableDomain
- func NameEQ(v string) predicate.MappableDomain
- func NameEqualFold(v string) predicate.MappableDomain
- func NameGT(v string) predicate.MappableDomain
- func NameGTE(v string) predicate.MappableDomain
- func NameHasPrefix(v string) predicate.MappableDomain
- func NameHasSuffix(v string) predicate.MappableDomain
- func NameIn(vs ...string) predicate.MappableDomain
- func NameLT(v string) predicate.MappableDomain
- func NameLTE(v string) predicate.MappableDomain
- func NameNEQ(v string) predicate.MappableDomain
- func NameNotIn(vs ...string) predicate.MappableDomain
- func Not(p predicate.MappableDomain) predicate.MappableDomain
- func Or(predicates ...predicate.MappableDomain) predicate.MappableDomain
- func TagsIsNil() predicate.MappableDomain
- func TagsNotNil() predicate.MappableDomain
- func UpdatedAt(v time.Time) predicate.MappableDomain
- func UpdatedAtEQ(v time.Time) predicate.MappableDomain
- func UpdatedAtGT(v time.Time) predicate.MappableDomain
- func UpdatedAtGTE(v time.Time) predicate.MappableDomain
- func UpdatedAtIn(vs ...time.Time) predicate.MappableDomain
- func UpdatedAtIsNil() predicate.MappableDomain
- func UpdatedAtLT(v time.Time) predicate.MappableDomain
- func UpdatedAtLTE(v time.Time) predicate.MappableDomain
- func UpdatedAtNEQ(v time.Time) predicate.MappableDomain
- func UpdatedAtNotIn(vs ...time.Time) predicate.MappableDomain
- func UpdatedAtNotNil() predicate.MappableDomain
- func UpdatedBy(v string) predicate.MappableDomain
- func UpdatedByContains(v string) predicate.MappableDomain
- func UpdatedByContainsFold(v string) predicate.MappableDomain
- func UpdatedByEQ(v string) predicate.MappableDomain
- func UpdatedByEqualFold(v string) predicate.MappableDomain
- func UpdatedByGT(v string) predicate.MappableDomain
- func UpdatedByGTE(v string) predicate.MappableDomain
- func UpdatedByHasPrefix(v string) predicate.MappableDomain
- func UpdatedByHasSuffix(v string) predicate.MappableDomain
- func UpdatedByIn(vs ...string) predicate.MappableDomain
- func UpdatedByIsNil() predicate.MappableDomain
- func UpdatedByLT(v string) predicate.MappableDomain
- func UpdatedByLTE(v string) predicate.MappableDomain
- func UpdatedByNEQ(v string) predicate.MappableDomain
- func UpdatedByNotIn(vs ...string) predicate.MappableDomain
- func UpdatedByNotNil() predicate.MappableDomain
- func ValidColumn(column string) bool
- func ZoneID(v string) predicate.MappableDomain
- func ZoneIDContains(v string) predicate.MappableDomain
- func ZoneIDContainsFold(v string) predicate.MappableDomain
- func ZoneIDEQ(v string) predicate.MappableDomain
- func ZoneIDEqualFold(v string) predicate.MappableDomain
- func ZoneIDGT(v string) predicate.MappableDomain
- func ZoneIDGTE(v string) predicate.MappableDomain
- func ZoneIDHasPrefix(v string) predicate.MappableDomain
- func ZoneIDHasSuffix(v string) predicate.MappableDomain
- func ZoneIDIn(vs ...string) predicate.MappableDomain
- func ZoneIDLT(v string) predicate.MappableDomain
- func ZoneIDLTE(v string) predicate.MappableDomain
- func ZoneIDNEQ(v string) predicate.MappableDomain
- func ZoneIDNotIn(vs ...string) predicate.MappableDomain
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByCustomDomains(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByCustomDomainsCount(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByZoneID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the mappabledomain type in the database. Label = "mappable_domain" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldZoneID holds the string denoting the zone_id field in the database. FieldZoneID = "zone_id" // EdgeCustomDomains holds the string denoting the custom_domains edge name in mutations. EdgeCustomDomains = "custom_domains" // Table holds the table name of the mappabledomain in the database. Table = "mappable_domains" // CustomDomainsTable is the table that holds the custom_domains relation/edge. CustomDomainsTable = "custom_domains" // CustomDomainsInverseTable is the table name for the CustomDomain entity. // It exists in this package in order to avoid circular dependency with the "customdomain" package. CustomDomainsInverseTable = "custom_domains" // CustomDomainsColumn is the table column denoting the custom_domains relation/edge. CustomDomainsColumn = "mappable_domain_custom_domains" )
Variables ¶
var ( Hooks [4]ent.Hook Interceptors [1]ent.Interceptor Policy ent.Policy // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultTags holds the default value on creation for the "tags" field. DefaultTags []string // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // ZoneIDValidator is a validator for the "zone_id" field. It is called by the builders before save. ZoneIDValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldTags, FieldName, FieldZoneID, }
Columns holds all SQL columns for mappabledomain fields.
Functions ¶
func And ¶
func And(predicates ...predicate.MappableDomain) predicate.MappableDomain
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.MappableDomain
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.MappableDomain
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.MappableDomain
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.MappableDomain
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.MappableDomain
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.MappableDomain
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.MappableDomain
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.MappableDomain
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.MappableDomain
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.MappableDomain
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.MappableDomain
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
func CreatedBy(v string) predicate.MappableDomain
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
func CreatedByContains(v string) predicate.MappableDomain
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
func CreatedByContainsFold(v string) predicate.MappableDomain
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
func CreatedByEQ(v string) predicate.MappableDomain
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
func CreatedByEqualFold(v string) predicate.MappableDomain
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
func CreatedByGT(v string) predicate.MappableDomain
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
func CreatedByGTE(v string) predicate.MappableDomain
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
func CreatedByHasPrefix(v string) predicate.MappableDomain
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
func CreatedByHasSuffix(v string) predicate.MappableDomain
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
func CreatedByIn(vs ...string) predicate.MappableDomain
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
func CreatedByIsNil() predicate.MappableDomain
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
func CreatedByLT(v string) predicate.MappableDomain
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
func CreatedByLTE(v string) predicate.MappableDomain
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
func CreatedByNEQ(v string) predicate.MappableDomain
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
func CreatedByNotIn(vs ...string) predicate.MappableDomain
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
func CreatedByNotNil() predicate.MappableDomain
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.MappableDomain
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.MappableDomain
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.MappableDomain
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.MappableDomain
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.MappableDomain
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.MappableDomain
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.MappableDomain
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.MappableDomain
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.MappableDomain
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.MappableDomain
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.MappableDomain
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
func DeletedBy(v string) predicate.MappableDomain
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
func DeletedByContains(v string) predicate.MappableDomain
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
func DeletedByContainsFold(v string) predicate.MappableDomain
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
func DeletedByEQ(v string) predicate.MappableDomain
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
func DeletedByEqualFold(v string) predicate.MappableDomain
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
func DeletedByGT(v string) predicate.MappableDomain
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
func DeletedByGTE(v string) predicate.MappableDomain
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
func DeletedByHasPrefix(v string) predicate.MappableDomain
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
func DeletedByHasSuffix(v string) predicate.MappableDomain
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
func DeletedByIn(vs ...string) predicate.MappableDomain
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
func DeletedByIsNil() predicate.MappableDomain
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
func DeletedByLT(v string) predicate.MappableDomain
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
func DeletedByLTE(v string) predicate.MappableDomain
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
func DeletedByNEQ(v string) predicate.MappableDomain
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
func DeletedByNotIn(vs ...string) predicate.MappableDomain
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
func DeletedByNotNil() predicate.MappableDomain
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func HasCustomDomains ¶
func HasCustomDomains() predicate.MappableDomain
HasCustomDomains applies the HasEdge predicate on the "custom_domains" edge.
func HasCustomDomainsWith ¶
func HasCustomDomainsWith(preds ...predicate.CustomDomain) predicate.MappableDomain
HasCustomDomainsWith applies the HasEdge predicate on the "custom_domains" edge with a given conditions (other predicates).
func IDContainsFold ¶
func IDContainsFold(id string) predicate.MappableDomain
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEQ ¶
func IDEQ(id string) predicate.MappableDomain
IDEQ applies the EQ predicate on the ID field.
func IDEqualFold ¶
func IDEqualFold(id string) predicate.MappableDomain
IDEqualFold applies the EqualFold predicate on the ID field.
func IDGT ¶
func IDGT(id string) predicate.MappableDomain
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id string) predicate.MappableDomain
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...string) predicate.MappableDomain
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id string) predicate.MappableDomain
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id string) predicate.MappableDomain
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id string) predicate.MappableDomain
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...string) predicate.MappableDomain
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.MappableDomain
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.MappableDomain
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.MappableDomain
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.MappableDomain
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.MappableDomain
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.MappableDomain
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.MappableDomain
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.MappableDomain
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.MappableDomain
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.MappableDomain
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.MappableDomain
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.MappableDomain
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.MappableDomain
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.MappableDomain
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.MappableDomain) predicate.MappableDomain
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.MappableDomain) predicate.MappableDomain
Or groups predicates with the OR operator between them.
func TagsIsNil ¶
func TagsIsNil() predicate.MappableDomain
TagsIsNil applies the IsNil predicate on the "tags" field.
func TagsNotNil ¶
func TagsNotNil() predicate.MappableDomain
TagsNotNil applies the NotNil predicate on the "tags" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.MappableDomain
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.MappableDomain
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.MappableDomain
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.MappableDomain
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.MappableDomain
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.MappableDomain
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.MappableDomain
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.MappableDomain
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.MappableDomain
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.MappableDomain
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.MappableDomain
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
func UpdatedBy(v string) predicate.MappableDomain
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
func UpdatedByContains(v string) predicate.MappableDomain
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
func UpdatedByContainsFold(v string) predicate.MappableDomain
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
func UpdatedByEQ(v string) predicate.MappableDomain
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
func UpdatedByEqualFold(v string) predicate.MappableDomain
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
func UpdatedByGT(v string) predicate.MappableDomain
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
func UpdatedByGTE(v string) predicate.MappableDomain
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
func UpdatedByHasPrefix(v string) predicate.MappableDomain
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
func UpdatedByHasSuffix(v string) predicate.MappableDomain
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
func UpdatedByIn(vs ...string) predicate.MappableDomain
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
func UpdatedByIsNil() predicate.MappableDomain
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
func UpdatedByLT(v string) predicate.MappableDomain
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
func UpdatedByLTE(v string) predicate.MappableDomain
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
func UpdatedByNEQ(v string) predicate.MappableDomain
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
func UpdatedByNotIn(vs ...string) predicate.MappableDomain
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
func UpdatedByNotNil() predicate.MappableDomain
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func ZoneID ¶ added in v0.15.0
func ZoneID(v string) predicate.MappableDomain
ZoneID applies equality check predicate on the "zone_id" field. It's identical to ZoneIDEQ.
func ZoneIDContains ¶ added in v0.15.0
func ZoneIDContains(v string) predicate.MappableDomain
ZoneIDContains applies the Contains predicate on the "zone_id" field.
func ZoneIDContainsFold ¶ added in v0.15.0
func ZoneIDContainsFold(v string) predicate.MappableDomain
ZoneIDContainsFold applies the ContainsFold predicate on the "zone_id" field.
func ZoneIDEQ ¶ added in v0.15.0
func ZoneIDEQ(v string) predicate.MappableDomain
ZoneIDEQ applies the EQ predicate on the "zone_id" field.
func ZoneIDEqualFold ¶ added in v0.15.0
func ZoneIDEqualFold(v string) predicate.MappableDomain
ZoneIDEqualFold applies the EqualFold predicate on the "zone_id" field.
func ZoneIDGT ¶ added in v0.15.0
func ZoneIDGT(v string) predicate.MappableDomain
ZoneIDGT applies the GT predicate on the "zone_id" field.
func ZoneIDGTE ¶ added in v0.15.0
func ZoneIDGTE(v string) predicate.MappableDomain
ZoneIDGTE applies the GTE predicate on the "zone_id" field.
func ZoneIDHasPrefix ¶ added in v0.15.0
func ZoneIDHasPrefix(v string) predicate.MappableDomain
ZoneIDHasPrefix applies the HasPrefix predicate on the "zone_id" field.
func ZoneIDHasSuffix ¶ added in v0.15.0
func ZoneIDHasSuffix(v string) predicate.MappableDomain
ZoneIDHasSuffix applies the HasSuffix predicate on the "zone_id" field.
func ZoneIDIn ¶ added in v0.15.0
func ZoneIDIn(vs ...string) predicate.MappableDomain
ZoneIDIn applies the In predicate on the "zone_id" field.
func ZoneIDLT ¶ added in v0.15.0
func ZoneIDLT(v string) predicate.MappableDomain
ZoneIDLT applies the LT predicate on the "zone_id" field.
func ZoneIDLTE ¶ added in v0.15.0
func ZoneIDLTE(v string) predicate.MappableDomain
ZoneIDLTE applies the LTE predicate on the "zone_id" field.
func ZoneIDNEQ ¶ added in v0.15.0
func ZoneIDNEQ(v string) predicate.MappableDomain
ZoneIDNEQ applies the NEQ predicate on the "zone_id" field.
func ZoneIDNotIn ¶ added in v0.15.0
func ZoneIDNotIn(vs ...string) predicate.MappableDomain
ZoneIDNotIn applies the NotIn predicate on the "zone_id" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the MappableDomain queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByCustomDomains ¶
func ByCustomDomains(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByCustomDomains orders the results by custom_domains terms.
func ByCustomDomainsCount ¶
func ByCustomDomainsCount(opts ...sql.OrderTermOption) OrderOption
ByCustomDomainsCount orders the results by custom_domains count.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.
func ByZoneID ¶ added in v0.15.0
func ByZoneID(opts ...sql.OrderTermOption) OrderOption
ByZoneID orders the results by the zone_id field.