Documentation
¶
Index ¶
- Constants
- Variables
- func Active(v bool) predicate.OrgPrice
- func ActiveEQ(v bool) predicate.OrgPrice
- func ActiveNEQ(v bool) predicate.OrgPrice
- func And(predicates ...predicate.OrgPrice) predicate.OrgPrice
- func CreatedAt(v time.Time) predicate.OrgPrice
- func CreatedAtEQ(v time.Time) predicate.OrgPrice
- func CreatedAtGT(v time.Time) predicate.OrgPrice
- func CreatedAtGTE(v time.Time) predicate.OrgPrice
- func CreatedAtIn(vs ...time.Time) predicate.OrgPrice
- func CreatedAtIsNil() predicate.OrgPrice
- func CreatedAtLT(v time.Time) predicate.OrgPrice
- func CreatedAtLTE(v time.Time) predicate.OrgPrice
- func CreatedAtNEQ(v time.Time) predicate.OrgPrice
- func CreatedAtNotIn(vs ...time.Time) predicate.OrgPrice
- func CreatedAtNotNil() predicate.OrgPrice
- func CreatedBy(v string) predicate.OrgPrice
- func CreatedByContains(v string) predicate.OrgPrice
- func CreatedByContainsFold(v string) predicate.OrgPrice
- func CreatedByEQ(v string) predicate.OrgPrice
- func CreatedByEqualFold(v string) predicate.OrgPrice
- func CreatedByGT(v string) predicate.OrgPrice
- func CreatedByGTE(v string) predicate.OrgPrice
- func CreatedByHasPrefix(v string) predicate.OrgPrice
- func CreatedByHasSuffix(v string) predicate.OrgPrice
- func CreatedByIn(vs ...string) predicate.OrgPrice
- func CreatedByIsNil() predicate.OrgPrice
- func CreatedByLT(v string) predicate.OrgPrice
- func CreatedByLTE(v string) predicate.OrgPrice
- func CreatedByNEQ(v string) predicate.OrgPrice
- func CreatedByNotIn(vs ...string) predicate.OrgPrice
- func CreatedByNotNil() predicate.OrgPrice
- func DeletedAt(v time.Time) predicate.OrgPrice
- func DeletedAtEQ(v time.Time) predicate.OrgPrice
- func DeletedAtGT(v time.Time) predicate.OrgPrice
- func DeletedAtGTE(v time.Time) predicate.OrgPrice
- func DeletedAtIn(vs ...time.Time) predicate.OrgPrice
- func DeletedAtIsNil() predicate.OrgPrice
- func DeletedAtLT(v time.Time) predicate.OrgPrice
- func DeletedAtLTE(v time.Time) predicate.OrgPrice
- func DeletedAtNEQ(v time.Time) predicate.OrgPrice
- func DeletedAtNotIn(vs ...time.Time) predicate.OrgPrice
- func DeletedAtNotNil() predicate.OrgPrice
- func DeletedBy(v string) predicate.OrgPrice
- func DeletedByContains(v string) predicate.OrgPrice
- func DeletedByContainsFold(v string) predicate.OrgPrice
- func DeletedByEQ(v string) predicate.OrgPrice
- func DeletedByEqualFold(v string) predicate.OrgPrice
- func DeletedByGT(v string) predicate.OrgPrice
- func DeletedByGTE(v string) predicate.OrgPrice
- func DeletedByHasPrefix(v string) predicate.OrgPrice
- func DeletedByHasSuffix(v string) predicate.OrgPrice
- func DeletedByIn(vs ...string) predicate.OrgPrice
- func DeletedByIsNil() predicate.OrgPrice
- func DeletedByLT(v string) predicate.OrgPrice
- func DeletedByLTE(v string) predicate.OrgPrice
- func DeletedByNEQ(v string) predicate.OrgPrice
- func DeletedByNotIn(vs ...string) predicate.OrgPrice
- func DeletedByNotNil() predicate.OrgPrice
- func HasOrgModules() predicate.OrgPrice
- func HasOrgModulesWith(preds ...predicate.OrgModule) predicate.OrgPrice
- func HasOrgProducts() predicate.OrgPrice
- func HasOrgProductsWith(preds ...predicate.OrgProduct) predicate.OrgPrice
- func HasOrgSubscription() predicate.OrgPrice
- func HasOrgSubscriptionWith(preds ...predicate.OrgSubscription) predicate.OrgPrice
- func HasOwner() predicate.OrgPrice
- func HasOwnerWith(preds ...predicate.Organization) predicate.OrgPrice
- func ID(id string) predicate.OrgPrice
- func IDContainsFold(id string) predicate.OrgPrice
- func IDEQ(id string) predicate.OrgPrice
- func IDEqualFold(id string) predicate.OrgPrice
- func IDGT(id string) predicate.OrgPrice
- func IDGTE(id string) predicate.OrgPrice
- func IDIn(ids ...string) predicate.OrgPrice
- func IDLT(id string) predicate.OrgPrice
- func IDLTE(id string) predicate.OrgPrice
- func IDNEQ(id string) predicate.OrgPrice
- func IDNotIn(ids ...string) predicate.OrgPrice
- func Not(p predicate.OrgPrice) predicate.OrgPrice
- func Or(predicates ...predicate.OrgPrice) predicate.OrgPrice
- func OwnerID(v string) predicate.OrgPrice
- func OwnerIDContains(v string) predicate.OrgPrice
- func OwnerIDContainsFold(v string) predicate.OrgPrice
- func OwnerIDEQ(v string) predicate.OrgPrice
- func OwnerIDEqualFold(v string) predicate.OrgPrice
- func OwnerIDGT(v string) predicate.OrgPrice
- func OwnerIDGTE(v string) predicate.OrgPrice
- func OwnerIDHasPrefix(v string) predicate.OrgPrice
- func OwnerIDHasSuffix(v string) predicate.OrgPrice
- func OwnerIDIn(vs ...string) predicate.OrgPrice
- func OwnerIDIsNil() predicate.OrgPrice
- func OwnerIDLT(v string) predicate.OrgPrice
- func OwnerIDLTE(v string) predicate.OrgPrice
- func OwnerIDNEQ(v string) predicate.OrgPrice
- func OwnerIDNotIn(vs ...string) predicate.OrgPrice
- func OwnerIDNotNil() predicate.OrgPrice
- func PriceIsNil() predicate.OrgPrice
- func PriceNotNil() predicate.OrgPrice
- func ProductID(v string) predicate.OrgPrice
- func ProductIDContains(v string) predicate.OrgPrice
- func ProductIDContainsFold(v string) predicate.OrgPrice
- func ProductIDEQ(v string) predicate.OrgPrice
- func ProductIDEqualFold(v string) predicate.OrgPrice
- func ProductIDGT(v string) predicate.OrgPrice
- func ProductIDGTE(v string) predicate.OrgPrice
- func ProductIDHasPrefix(v string) predicate.OrgPrice
- func ProductIDHasSuffix(v string) predicate.OrgPrice
- func ProductIDIn(vs ...string) predicate.OrgPrice
- func ProductIDIsNil() predicate.OrgPrice
- func ProductIDLT(v string) predicate.OrgPrice
- func ProductIDLTE(v string) predicate.OrgPrice
- func ProductIDNEQ(v string) predicate.OrgPrice
- func ProductIDNotIn(vs ...string) predicate.OrgPrice
- func ProductIDNotNil() predicate.OrgPrice
- func Status(v string) predicate.OrgPrice
- func StatusContains(v string) predicate.OrgPrice
- func StatusContainsFold(v string) predicate.OrgPrice
- func StatusEQ(v string) predicate.OrgPrice
- func StatusEqualFold(v string) predicate.OrgPrice
- func StatusGT(v string) predicate.OrgPrice
- func StatusGTE(v string) predicate.OrgPrice
- func StatusHasPrefix(v string) predicate.OrgPrice
- func StatusHasSuffix(v string) predicate.OrgPrice
- func StatusIn(vs ...string) predicate.OrgPrice
- func StatusIsNil() predicate.OrgPrice
- func StatusLT(v string) predicate.OrgPrice
- func StatusLTE(v string) predicate.OrgPrice
- func StatusNEQ(v string) predicate.OrgPrice
- func StatusNotIn(vs ...string) predicate.OrgPrice
- func StatusNotNil() predicate.OrgPrice
- func StripePriceID(v string) predicate.OrgPrice
- func StripePriceIDContains(v string) predicate.OrgPrice
- func StripePriceIDContainsFold(v string) predicate.OrgPrice
- func StripePriceIDEQ(v string) predicate.OrgPrice
- func StripePriceIDEqualFold(v string) predicate.OrgPrice
- func StripePriceIDGT(v string) predicate.OrgPrice
- func StripePriceIDGTE(v string) predicate.OrgPrice
- func StripePriceIDHasPrefix(v string) predicate.OrgPrice
- func StripePriceIDHasSuffix(v string) predicate.OrgPrice
- func StripePriceIDIn(vs ...string) predicate.OrgPrice
- func StripePriceIDIsNil() predicate.OrgPrice
- func StripePriceIDLT(v string) predicate.OrgPrice
- func StripePriceIDLTE(v string) predicate.OrgPrice
- func StripePriceIDNEQ(v string) predicate.OrgPrice
- func StripePriceIDNotIn(vs ...string) predicate.OrgPrice
- func StripePriceIDNotNil() predicate.OrgPrice
- func SubscriptionID(v string) predicate.OrgPrice
- func SubscriptionIDContains(v string) predicate.OrgPrice
- func SubscriptionIDContainsFold(v string) predicate.OrgPrice
- func SubscriptionIDEQ(v string) predicate.OrgPrice
- func SubscriptionIDEqualFold(v string) predicate.OrgPrice
- func SubscriptionIDGT(v string) predicate.OrgPrice
- func SubscriptionIDGTE(v string) predicate.OrgPrice
- func SubscriptionIDHasPrefix(v string) predicate.OrgPrice
- func SubscriptionIDHasSuffix(v string) predicate.OrgPrice
- func SubscriptionIDIn(vs ...string) predicate.OrgPrice
- func SubscriptionIDIsNil() predicate.OrgPrice
- func SubscriptionIDLT(v string) predicate.OrgPrice
- func SubscriptionIDLTE(v string) predicate.OrgPrice
- func SubscriptionIDNEQ(v string) predicate.OrgPrice
- func SubscriptionIDNotIn(vs ...string) predicate.OrgPrice
- func SubscriptionIDNotNil() predicate.OrgPrice
- func TagsIsNil() predicate.OrgPrice
- func TagsNotNil() predicate.OrgPrice
- func UpdatedAt(v time.Time) predicate.OrgPrice
- func UpdatedAtEQ(v time.Time) predicate.OrgPrice
- func UpdatedAtGT(v time.Time) predicate.OrgPrice
- func UpdatedAtGTE(v time.Time) predicate.OrgPrice
- func UpdatedAtIn(vs ...time.Time) predicate.OrgPrice
- func UpdatedAtIsNil() predicate.OrgPrice
- func UpdatedAtLT(v time.Time) predicate.OrgPrice
- func UpdatedAtLTE(v time.Time) predicate.OrgPrice
- func UpdatedAtNEQ(v time.Time) predicate.OrgPrice
- func UpdatedAtNotIn(vs ...time.Time) predicate.OrgPrice
- func UpdatedAtNotNil() predicate.OrgPrice
- func UpdatedBy(v string) predicate.OrgPrice
- func UpdatedByContains(v string) predicate.OrgPrice
- func UpdatedByContainsFold(v string) predicate.OrgPrice
- func UpdatedByEQ(v string) predicate.OrgPrice
- func UpdatedByEqualFold(v string) predicate.OrgPrice
- func UpdatedByGT(v string) predicate.OrgPrice
- func UpdatedByGTE(v string) predicate.OrgPrice
- func UpdatedByHasPrefix(v string) predicate.OrgPrice
- func UpdatedByHasSuffix(v string) predicate.OrgPrice
- func UpdatedByIn(vs ...string) predicate.OrgPrice
- func UpdatedByIsNil() predicate.OrgPrice
- func UpdatedByLT(v string) predicate.OrgPrice
- func UpdatedByLTE(v string) predicate.OrgPrice
- func UpdatedByNEQ(v string) predicate.OrgPrice
- func UpdatedByNotIn(vs ...string) predicate.OrgPrice
- func UpdatedByNotNil() predicate.OrgPrice
- func ValidColumn(column string) bool
- type OrderOption
- func ByActive(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByOrgModules(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOrgModulesCount(opts ...sql.OrderTermOption) OrderOption
- func ByOrgProducts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOrgProductsCount(opts ...sql.OrderTermOption) OrderOption
- func ByOrgSubscriptionField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByProductID(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByStripePriceID(opts ...sql.OrderTermOption) OrderOption
- func BySubscriptionID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the orgprice type in the database. Label = "org_price" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeletedBy holds the string denoting the deleted_by field in the database. FieldDeletedBy = "deleted_by" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldPrice holds the string denoting the price field in the database. FieldPrice = "price" // FieldStripePriceID holds the string denoting the stripe_price_id field in the database. FieldStripePriceID = "stripe_price_id" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldActive holds the string denoting the active field in the database. FieldActive = "active" // FieldProductID holds the string denoting the product_id field in the database. FieldProductID = "product_id" // FieldSubscriptionID holds the string denoting the subscription_id field in the database. FieldSubscriptionID = "subscription_id" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // EdgeOrgProducts holds the string denoting the org_products edge name in mutations. EdgeOrgProducts = "org_products" // EdgeOrgModules holds the string denoting the org_modules edge name in mutations. EdgeOrgModules = "org_modules" // EdgeOrgSubscription holds the string denoting the org_subscription edge name in mutations. EdgeOrgSubscription = "org_subscription" // Table holds the table name of the orgprice in the database. Table = "org_prices" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "org_prices" // OwnerInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OwnerInverseTable = "organizations" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "owner_id" // OrgProductsTable is the table that holds the org_products relation/edge. The primary key declared below. OrgProductsTable = "org_product_org_prices" // OrgProductsInverseTable is the table name for the OrgProduct entity. // It exists in this package in order to avoid circular dependency with the "orgproduct" package. OrgProductsInverseTable = "org_products" // OrgModulesTable is the table that holds the org_modules relation/edge. The primary key declared below. OrgModulesTable = "org_module_org_prices" // OrgModulesInverseTable is the table name for the OrgModule entity. // It exists in this package in order to avoid circular dependency with the "orgmodule" package. OrgModulesInverseTable = "org_modules" // OrgSubscriptionTable is the table that holds the org_subscription relation/edge. OrgSubscriptionTable = "org_prices" // OrgSubscriptionInverseTable is the table name for the OrgSubscription entity. // It exists in this package in order to avoid circular dependency with the "orgsubscription" package. OrgSubscriptionInverseTable = "org_subscriptions" // OrgSubscriptionColumn is the table column denoting the org_subscription relation/edge. OrgSubscriptionColumn = "subscription_id" )
Variables ¶
var ( // OrgProductsPrimaryKey and OrgProductsColumn2 are the table columns denoting the // primary key for the org_products relation (M2M). OrgProductsPrimaryKey = []string{"org_product_id", "org_price_id"} // OrgModulesPrimaryKey and OrgModulesColumn2 are the table columns denoting the // primary key for the org_modules relation (M2M). OrgModulesPrimaryKey = []string{"org_module_id", "org_price_id"} )
var ( Hooks [4]ent.Hook Interceptors [2]ent.Interceptor // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultTags holds the default value on creation for the "tags" field. DefaultTags []string // OwnerIDValidator is a validator for the "owner_id" field. It is called by the builders before save. OwnerIDValidator func(string) error // DefaultActive holds the default value on creation for the "active" field. DefaultActive bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/theopenlane/core/internal/ent/generated/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldCreatedBy, FieldUpdatedBy, FieldDeletedAt, FieldDeletedBy, FieldTags, FieldOwnerID, FieldPrice, FieldStripePriceID, FieldStatus, FieldActive, FieldProductID, FieldSubscriptionID, }
Columns holds all SQL columns for orgprice fields.
Functions ¶
func Active ¶
Active applies equality check predicate on the "active" field. It's identical to ActiveEQ.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedBy ¶
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByContains ¶
CreatedByContains applies the Contains predicate on the "created_by" field.
func CreatedByContainsFold ¶
CreatedByContainsFold applies the ContainsFold predicate on the "created_by" field.
func CreatedByEQ ¶
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByEqualFold ¶
CreatedByEqualFold applies the EqualFold predicate on the "created_by" field.
func CreatedByGT ¶
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByHasPrefix ¶
CreatedByHasPrefix applies the HasPrefix predicate on the "created_by" field.
func CreatedByHasSuffix ¶
CreatedByHasSuffix applies the HasSuffix predicate on the "created_by" field.
func CreatedByIn ¶
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedBy ¶
DeletedBy applies equality check predicate on the "deleted_by" field. It's identical to DeletedByEQ.
func DeletedByContains ¶
DeletedByContains applies the Contains predicate on the "deleted_by" field.
func DeletedByContainsFold ¶
DeletedByContainsFold applies the ContainsFold predicate on the "deleted_by" field.
func DeletedByEQ ¶
DeletedByEQ applies the EQ predicate on the "deleted_by" field.
func DeletedByEqualFold ¶
DeletedByEqualFold applies the EqualFold predicate on the "deleted_by" field.
func DeletedByGT ¶
DeletedByGT applies the GT predicate on the "deleted_by" field.
func DeletedByGTE ¶
DeletedByGTE applies the GTE predicate on the "deleted_by" field.
func DeletedByHasPrefix ¶
DeletedByHasPrefix applies the HasPrefix predicate on the "deleted_by" field.
func DeletedByHasSuffix ¶
DeletedByHasSuffix applies the HasSuffix predicate on the "deleted_by" field.
func DeletedByIn ¶
DeletedByIn applies the In predicate on the "deleted_by" field.
func DeletedByIsNil ¶
DeletedByIsNil applies the IsNil predicate on the "deleted_by" field.
func DeletedByLT ¶
DeletedByLT applies the LT predicate on the "deleted_by" field.
func DeletedByLTE ¶
DeletedByLTE applies the LTE predicate on the "deleted_by" field.
func DeletedByNEQ ¶
DeletedByNEQ applies the NEQ predicate on the "deleted_by" field.
func DeletedByNotIn ¶
DeletedByNotIn applies the NotIn predicate on the "deleted_by" field.
func DeletedByNotNil ¶
DeletedByNotNil applies the NotNil predicate on the "deleted_by" field.
func HasOrgModules ¶ added in v0.19.0
HasOrgModules applies the HasEdge predicate on the "org_modules" edge.
func HasOrgModulesWith ¶ added in v0.19.0
HasOrgModulesWith applies the HasEdge predicate on the "org_modules" edge with a given conditions (other predicates).
func HasOrgProducts ¶ added in v0.19.0
HasOrgProducts applies the HasEdge predicate on the "org_products" edge.
func HasOrgProductsWith ¶ added in v0.19.0
func HasOrgProductsWith(preds ...predicate.OrgProduct) predicate.OrgPrice
HasOrgProductsWith applies the HasEdge predicate on the "org_products" edge with a given conditions (other predicates).
func HasOrgSubscription ¶ added in v0.19.0
HasOrgSubscription applies the HasEdge predicate on the "org_subscription" edge.
func HasOrgSubscriptionWith ¶ added in v0.19.0
func HasOrgSubscriptionWith(preds ...predicate.OrgSubscription) predicate.OrgPrice
HasOrgSubscriptionWith applies the HasEdge predicate on the "org_subscription" edge with a given conditions (other predicates).
func HasOwnerWith ¶
func HasOwnerWith(preds ...predicate.Organization) predicate.OrgPrice
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func OwnerID ¶
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDContains ¶
OwnerIDContains applies the Contains predicate on the "owner_id" field.
func OwnerIDContainsFold ¶
OwnerIDContainsFold applies the ContainsFold predicate on the "owner_id" field.
func OwnerIDEqualFold ¶
OwnerIDEqualFold applies the EqualFold predicate on the "owner_id" field.
func OwnerIDGTE ¶
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDHasPrefix ¶
OwnerIDHasPrefix applies the HasPrefix predicate on the "owner_id" field.
func OwnerIDHasSuffix ¶
OwnerIDHasSuffix applies the HasSuffix predicate on the "owner_id" field.
func OwnerIDIsNil ¶
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLTE ¶
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func PriceIsNil ¶
PriceIsNil applies the IsNil predicate on the "price" field.
func PriceNotNil ¶
PriceNotNil applies the NotNil predicate on the "price" field.
func ProductID ¶
ProductID applies equality check predicate on the "product_id" field. It's identical to ProductIDEQ.
func ProductIDContains ¶
ProductIDContains applies the Contains predicate on the "product_id" field.
func ProductIDContainsFold ¶
ProductIDContainsFold applies the ContainsFold predicate on the "product_id" field.
func ProductIDEQ ¶
ProductIDEQ applies the EQ predicate on the "product_id" field.
func ProductIDEqualFold ¶
ProductIDEqualFold applies the EqualFold predicate on the "product_id" field.
func ProductIDGT ¶
ProductIDGT applies the GT predicate on the "product_id" field.
func ProductIDGTE ¶
ProductIDGTE applies the GTE predicate on the "product_id" field.
func ProductIDHasPrefix ¶
ProductIDHasPrefix applies the HasPrefix predicate on the "product_id" field.
func ProductIDHasSuffix ¶
ProductIDHasSuffix applies the HasSuffix predicate on the "product_id" field.
func ProductIDIn ¶
ProductIDIn applies the In predicate on the "product_id" field.
func ProductIDIsNil ¶
ProductIDIsNil applies the IsNil predicate on the "product_id" field.
func ProductIDLT ¶
ProductIDLT applies the LT predicate on the "product_id" field.
func ProductIDLTE ¶
ProductIDLTE applies the LTE predicate on the "product_id" field.
func ProductIDNEQ ¶
ProductIDNEQ applies the NEQ predicate on the "product_id" field.
func ProductIDNotIn ¶
ProductIDNotIn applies the NotIn predicate on the "product_id" field.
func ProductIDNotNil ¶
ProductIDNotNil applies the NotNil predicate on the "product_id" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusIsNil ¶
StatusIsNil applies the IsNil predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusNotNil ¶
StatusNotNil applies the NotNil predicate on the "status" field.
func StripePriceID ¶
StripePriceID applies equality check predicate on the "stripe_price_id" field. It's identical to StripePriceIDEQ.
func StripePriceIDContains ¶
StripePriceIDContains applies the Contains predicate on the "stripe_price_id" field.
func StripePriceIDContainsFold ¶
StripePriceIDContainsFold applies the ContainsFold predicate on the "stripe_price_id" field.
func StripePriceIDEQ ¶
StripePriceIDEQ applies the EQ predicate on the "stripe_price_id" field.
func StripePriceIDEqualFold ¶
StripePriceIDEqualFold applies the EqualFold predicate on the "stripe_price_id" field.
func StripePriceIDGT ¶
StripePriceIDGT applies the GT predicate on the "stripe_price_id" field.
func StripePriceIDGTE ¶
StripePriceIDGTE applies the GTE predicate on the "stripe_price_id" field.
func StripePriceIDHasPrefix ¶
StripePriceIDHasPrefix applies the HasPrefix predicate on the "stripe_price_id" field.
func StripePriceIDHasSuffix ¶
StripePriceIDHasSuffix applies the HasSuffix predicate on the "stripe_price_id" field.
func StripePriceIDIn ¶
StripePriceIDIn applies the In predicate on the "stripe_price_id" field.
func StripePriceIDIsNil ¶
StripePriceIDIsNil applies the IsNil predicate on the "stripe_price_id" field.
func StripePriceIDLT ¶
StripePriceIDLT applies the LT predicate on the "stripe_price_id" field.
func StripePriceIDLTE ¶
StripePriceIDLTE applies the LTE predicate on the "stripe_price_id" field.
func StripePriceIDNEQ ¶
StripePriceIDNEQ applies the NEQ predicate on the "stripe_price_id" field.
func StripePriceIDNotIn ¶
StripePriceIDNotIn applies the NotIn predicate on the "stripe_price_id" field.
func StripePriceIDNotNil ¶
StripePriceIDNotNil applies the NotNil predicate on the "stripe_price_id" field.
func SubscriptionID ¶ added in v0.19.0
SubscriptionID applies equality check predicate on the "subscription_id" field. It's identical to SubscriptionIDEQ.
func SubscriptionIDContains ¶ added in v0.19.0
SubscriptionIDContains applies the Contains predicate on the "subscription_id" field.
func SubscriptionIDContainsFold ¶ added in v0.19.0
SubscriptionIDContainsFold applies the ContainsFold predicate on the "subscription_id" field.
func SubscriptionIDEQ ¶ added in v0.19.0
SubscriptionIDEQ applies the EQ predicate on the "subscription_id" field.
func SubscriptionIDEqualFold ¶ added in v0.19.0
SubscriptionIDEqualFold applies the EqualFold predicate on the "subscription_id" field.
func SubscriptionIDGT ¶ added in v0.19.0
SubscriptionIDGT applies the GT predicate on the "subscription_id" field.
func SubscriptionIDGTE ¶ added in v0.19.0
SubscriptionIDGTE applies the GTE predicate on the "subscription_id" field.
func SubscriptionIDHasPrefix ¶ added in v0.19.0
SubscriptionIDHasPrefix applies the HasPrefix predicate on the "subscription_id" field.
func SubscriptionIDHasSuffix ¶ added in v0.19.0
SubscriptionIDHasSuffix applies the HasSuffix predicate on the "subscription_id" field.
func SubscriptionIDIn ¶ added in v0.19.0
SubscriptionIDIn applies the In predicate on the "subscription_id" field.
func SubscriptionIDIsNil ¶ added in v0.19.0
SubscriptionIDIsNil applies the IsNil predicate on the "subscription_id" field.
func SubscriptionIDLT ¶ added in v0.19.0
SubscriptionIDLT applies the LT predicate on the "subscription_id" field.
func SubscriptionIDLTE ¶ added in v0.19.0
SubscriptionIDLTE applies the LTE predicate on the "subscription_id" field.
func SubscriptionIDNEQ ¶ added in v0.19.0
SubscriptionIDNEQ applies the NEQ predicate on the "subscription_id" field.
func SubscriptionIDNotIn ¶ added in v0.19.0
SubscriptionIDNotIn applies the NotIn predicate on the "subscription_id" field.
func SubscriptionIDNotNil ¶ added in v0.19.0
SubscriptionIDNotNil applies the NotNil predicate on the "subscription_id" field.
func TagsNotNil ¶
TagsNotNil applies the NotNil predicate on the "tags" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByContains ¶
UpdatedByContains applies the Contains predicate on the "updated_by" field.
func UpdatedByContainsFold ¶
UpdatedByContainsFold applies the ContainsFold predicate on the "updated_by" field.
func UpdatedByEQ ¶
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByEqualFold ¶
UpdatedByEqualFold applies the EqualFold predicate on the "updated_by" field.
func UpdatedByGT ¶
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByHasPrefix ¶
UpdatedByHasPrefix applies the HasPrefix predicate on the "updated_by" field.
func UpdatedByHasSuffix ¶
UpdatedByHasSuffix applies the HasSuffix predicate on the "updated_by" field.
func UpdatedByIn ¶
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the OrgPrice queries.
func ByActive ¶
func ByActive(opts ...sql.OrderTermOption) OrderOption
ByActive orders the results by the active field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedBy ¶
func ByDeletedBy(opts ...sql.OrderTermOption) OrderOption
ByDeletedBy orders the results by the deleted_by field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByOrgModules ¶ added in v0.19.0
func ByOrgModules(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOrgModules orders the results by org_modules terms.
func ByOrgModulesCount ¶ added in v0.19.0
func ByOrgModulesCount(opts ...sql.OrderTermOption) OrderOption
ByOrgModulesCount orders the results by org_modules count.
func ByOrgProducts ¶ added in v0.19.0
func ByOrgProducts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOrgProducts orders the results by org_products terms.
func ByOrgProductsCount ¶ added in v0.19.0
func ByOrgProductsCount(opts ...sql.OrderTermOption) OrderOption
ByOrgProductsCount orders the results by org_products count.
func ByOrgSubscriptionField ¶ added in v0.19.0
func ByOrgSubscriptionField(field string, opts ...sql.OrderTermOption) OrderOption
ByOrgSubscriptionField orders the results by org_subscription field.
func ByOwnerField ¶
func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption
ByOwnerField orders the results by owner field.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByProductID ¶
func ByProductID(opts ...sql.OrderTermOption) OrderOption
ByProductID orders the results by the product_id field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByStripePriceID ¶
func ByStripePriceID(opts ...sql.OrderTermOption) OrderOption
ByStripePriceID orders the results by the stripe_price_id field.
func BySubscriptionID ¶ added in v0.19.0
func BySubscriptionID(opts ...sql.OrderTermOption) OrderOption
BySubscriptionID orders the results by the subscription_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.