Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
// CustomHostnames returns the service for managing custom hostnames in Cloudflare.
CustomHostnames() CustomHostnamesService
}
Client defines the interface for the Cloudflare client. It provides access to various Cloudflare API services.
type CustomHostnamesService ¶
type CustomHostnamesService interface {
// New creates a new custom hostname in Cloudflare with the provided parameters.
New(context.Context, custom_hostnames.CustomHostnameNewParams, ...option.RequestOption) (*custom_hostnames.CustomHostnameNewResponse, error)
// Delete removes a custom hostname from Cloudflare using the provided hostname ID and parameters.
Delete(context.Context, string, custom_hostnames.CustomHostnameDeleteParams, ...option.RequestOption) (*custom_hostnames.CustomHostnameDeleteResponse, error)
// Get retrieves a custom hostname from Cloudflare using the provided hostname ID and parameters.
Get(context.Context, string, custom_hostnames.CustomHostnameGetParams, ...option.RequestOption) (*custom_hostnames.CustomHostnameGetResponse, error)
}
CustomHostnamesService defines the interface for interacting with Cloudflare's custom hostnames API. It provides methods for creating and deleting custom hostnames.
Click to show internal directories.
Click to hide internal directories.