Documentation
¶
Index ¶
- type MockClient
- type MockClient_CustomHostnames_Call
- func (_c *MockClient_CustomHostnames_Call) Return(customHostnamesService cloudflare.CustomHostnamesService) *MockClient_CustomHostnames_Call
- func (_c *MockClient_CustomHostnames_Call) Run(run func()) *MockClient_CustomHostnames_Call
- func (_c *MockClient_CustomHostnames_Call) RunAndReturn(run func() cloudflare.CustomHostnamesService) *MockClient_CustomHostnames_Call
- type MockClient_Expecter
- type MockCustomHostnamesService
- func (_mock *MockCustomHostnamesService) Delete(context1 context.Context, s string, ...) (*custom_hostnames.CustomHostnameDeleteResponse, error)
- func (_m *MockCustomHostnamesService) EXPECT() *MockCustomHostnamesService_Expecter
- func (_mock *MockCustomHostnamesService) Get(context1 context.Context, s string, ...) (*custom_hostnames.CustomHostnameGetResponse, error)
- func (_mock *MockCustomHostnamesService) New(context1 context.Context, ...) (*custom_hostnames.CustomHostnameNewResponse, error)
- type MockCustomHostnamesService_Delete_Call
- func (_c *MockCustomHostnamesService_Delete_Call) Return(customHostnameDeleteResponse *custom_hostnames.CustomHostnameDeleteResponse, ...) *MockCustomHostnamesService_Delete_Call
- func (_c *MockCustomHostnamesService_Delete_Call) Run(run func(context1 context.Context, s string, ...)) *MockCustomHostnamesService_Delete_Call
- func (_c *MockCustomHostnamesService_Delete_Call) RunAndReturn(...) *MockCustomHostnamesService_Delete_Call
- type MockCustomHostnamesService_Expecter
- func (_e *MockCustomHostnamesService_Expecter) Delete(context1 interface{}, s interface{}, customHostnameDeleteParams interface{}, ...) *MockCustomHostnamesService_Delete_Call
- func (_e *MockCustomHostnamesService_Expecter) Get(context1 interface{}, s interface{}, customHostnameGetParams interface{}, ...) *MockCustomHostnamesService_Get_Call
- func (_e *MockCustomHostnamesService_Expecter) New(context1 interface{}, customHostnameNewParams interface{}, vs ...interface{}) *MockCustomHostnamesService_New_Call
- type MockCustomHostnamesService_Get_Call
- func (_c *MockCustomHostnamesService_Get_Call) Return(customHostnameGetResponse *custom_hostnames.CustomHostnameGetResponse, ...) *MockCustomHostnamesService_Get_Call
- func (_c *MockCustomHostnamesService_Get_Call) Run(run func(context1 context.Context, s string, ...)) *MockCustomHostnamesService_Get_Call
- func (_c *MockCustomHostnamesService_Get_Call) RunAndReturn(...) *MockCustomHostnamesService_Get_Call
- type MockCustomHostnamesService_New_Call
- func (_c *MockCustomHostnamesService_New_Call) Return(customHostnameNewResponse *custom_hostnames.CustomHostnameNewResponse, ...) *MockCustomHostnamesService_New_Call
- func (_c *MockCustomHostnamesService_New_Call) Run(run func(context1 context.Context, ...)) *MockCustomHostnamesService_New_Call
- func (_c *MockCustomHostnamesService_New_Call) RunAndReturn(...) *MockCustomHostnamesService_New_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockClient ¶
MockClient is an autogenerated mock type for the Client type
func NewMockClient ¶
func NewMockClient(t interface {
mock.TestingT
Cleanup(func())
}) *MockClient
NewMockClient creates a new instance of MockClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockClient) CustomHostnames ¶
func (_mock *MockClient) CustomHostnames() cloudflare.CustomHostnamesService
CustomHostnames provides a mock function for the type MockClient
func (*MockClient) EXPECT ¶
func (_m *MockClient) EXPECT() *MockClient_Expecter
type MockClient_CustomHostnames_Call ¶
MockClient_CustomHostnames_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CustomHostnames'
func (*MockClient_CustomHostnames_Call) Return ¶
func (_c *MockClient_CustomHostnames_Call) Return(customHostnamesService cloudflare.CustomHostnamesService) *MockClient_CustomHostnames_Call
func (*MockClient_CustomHostnames_Call) Run ¶
func (_c *MockClient_CustomHostnames_Call) Run(run func()) *MockClient_CustomHostnames_Call
func (*MockClient_CustomHostnames_Call) RunAndReturn ¶
func (_c *MockClient_CustomHostnames_Call) RunAndReturn(run func() cloudflare.CustomHostnamesService) *MockClient_CustomHostnames_Call
type MockClient_Expecter ¶
type MockClient_Expecter struct {
// contains filtered or unexported fields
}
func (*MockClient_Expecter) CustomHostnames ¶
func (_e *MockClient_Expecter) CustomHostnames() *MockClient_CustomHostnames_Call
CustomHostnames is a helper method to define mock.On call
type MockCustomHostnamesService ¶
MockCustomHostnamesService is an autogenerated mock type for the CustomHostnamesService type
func NewMockCustomHostnamesService ¶
func NewMockCustomHostnamesService(t interface {
mock.TestingT
Cleanup(func())
}) *MockCustomHostnamesService
NewMockCustomHostnamesService creates a new instance of MockCustomHostnamesService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockCustomHostnamesService) Delete ¶
func (_mock *MockCustomHostnamesService) Delete(context1 context.Context, s string, customHostnameDeleteParams custom_hostnames.CustomHostnameDeleteParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameDeleteResponse, error)
Delete provides a mock function for the type MockCustomHostnamesService
func (*MockCustomHostnamesService) EXPECT ¶
func (_m *MockCustomHostnamesService) EXPECT() *MockCustomHostnamesService_Expecter
func (*MockCustomHostnamesService) Get ¶
func (_mock *MockCustomHostnamesService) Get(context1 context.Context, s string, customHostnameGetParams custom_hostnames.CustomHostnameGetParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameGetResponse, error)
Get provides a mock function for the type MockCustomHostnamesService
func (*MockCustomHostnamesService) New ¶
func (_mock *MockCustomHostnamesService) New(context1 context.Context, customHostnameNewParams custom_hostnames.CustomHostnameNewParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameNewResponse, error)
New provides a mock function for the type MockCustomHostnamesService
type MockCustomHostnamesService_Delete_Call ¶
MockCustomHostnamesService_Delete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Delete'
func (*MockCustomHostnamesService_Delete_Call) Return ¶
func (_c *MockCustomHostnamesService_Delete_Call) Return(customHostnameDeleteResponse *custom_hostnames.CustomHostnameDeleteResponse, err error) *MockCustomHostnamesService_Delete_Call
func (*MockCustomHostnamesService_Delete_Call) Run ¶
func (_c *MockCustomHostnamesService_Delete_Call) Run(run func(context1 context.Context, s string, customHostnameDeleteParams custom_hostnames.CustomHostnameDeleteParams, vs ...option.RequestOption)) *MockCustomHostnamesService_Delete_Call
func (*MockCustomHostnamesService_Delete_Call) RunAndReturn ¶
func (_c *MockCustomHostnamesService_Delete_Call) RunAndReturn(run func(context1 context.Context, s string, customHostnameDeleteParams custom_hostnames.CustomHostnameDeleteParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameDeleteResponse, error)) *MockCustomHostnamesService_Delete_Call
type MockCustomHostnamesService_Expecter ¶
type MockCustomHostnamesService_Expecter struct {
// contains filtered or unexported fields
}
func (*MockCustomHostnamesService_Expecter) Delete ¶
func (_e *MockCustomHostnamesService_Expecter) Delete(context1 interface{}, s interface{}, customHostnameDeleteParams interface{}, vs ...interface{}) *MockCustomHostnamesService_Delete_Call
Delete is a helper method to define mock.On call
- context1 context.Context
- s string
- customHostnameDeleteParams custom_hostnames.CustomHostnameDeleteParams
- vs ...option.RequestOption
func (*MockCustomHostnamesService_Expecter) Get ¶
func (_e *MockCustomHostnamesService_Expecter) Get(context1 interface{}, s interface{}, customHostnameGetParams interface{}, vs ...interface{}) *MockCustomHostnamesService_Get_Call
Get is a helper method to define mock.On call
- context1 context.Context
- s string
- customHostnameGetParams custom_hostnames.CustomHostnameGetParams
- vs ...option.RequestOption
func (*MockCustomHostnamesService_Expecter) New ¶
func (_e *MockCustomHostnamesService_Expecter) New(context1 interface{}, customHostnameNewParams interface{}, vs ...interface{}) *MockCustomHostnamesService_New_Call
New is a helper method to define mock.On call
- context1 context.Context
- customHostnameNewParams custom_hostnames.CustomHostnameNewParams
- vs ...option.RequestOption
type MockCustomHostnamesService_Get_Call ¶
MockCustomHostnamesService_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'
func (*MockCustomHostnamesService_Get_Call) Return ¶
func (_c *MockCustomHostnamesService_Get_Call) Return(customHostnameGetResponse *custom_hostnames.CustomHostnameGetResponse, err error) *MockCustomHostnamesService_Get_Call
func (*MockCustomHostnamesService_Get_Call) Run ¶
func (_c *MockCustomHostnamesService_Get_Call) Run(run func(context1 context.Context, s string, customHostnameGetParams custom_hostnames.CustomHostnameGetParams, vs ...option.RequestOption)) *MockCustomHostnamesService_Get_Call
func (*MockCustomHostnamesService_Get_Call) RunAndReturn ¶
func (_c *MockCustomHostnamesService_Get_Call) RunAndReturn(run func(context1 context.Context, s string, customHostnameGetParams custom_hostnames.CustomHostnameGetParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameGetResponse, error)) *MockCustomHostnamesService_Get_Call
type MockCustomHostnamesService_New_Call ¶
MockCustomHostnamesService_New_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'New'
func (*MockCustomHostnamesService_New_Call) Return ¶
func (_c *MockCustomHostnamesService_New_Call) Return(customHostnameNewResponse *custom_hostnames.CustomHostnameNewResponse, err error) *MockCustomHostnamesService_New_Call
func (*MockCustomHostnamesService_New_Call) Run ¶
func (_c *MockCustomHostnamesService_New_Call) Run(run func(context1 context.Context, customHostnameNewParams custom_hostnames.CustomHostnameNewParams, vs ...option.RequestOption)) *MockCustomHostnamesService_New_Call
func (*MockCustomHostnamesService_New_Call) RunAndReturn ¶
func (_c *MockCustomHostnamesService_New_Call) RunAndReturn(run func(context1 context.Context, customHostnameNewParams custom_hostnames.CustomHostnameNewParams, vs ...option.RequestOption) (*custom_hostnames.CustomHostnameNewResponse, error)) *MockCustomHostnamesService_New_Call